{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# LFP example"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "pycharm": {
     "name": "#%%\n"
    }
   },
   "outputs": [],
   "source": [
    "import altair as alt\n",
    "from bayes_window import BayesWindow, models, BayesRegression, LMERegression\n",
    "from bayes_window.generative_models import generate_fake_lfp\n",
    "\n",
    "try:\n",
    "    alt.renderers.enable('altair_saver', fmts=['png'])\n",
    "except Exception:\n",
    "    pass"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Make and visualize model oscillation power\n",
    "40 trials of \"theta power\" is generated for every animal. It is drawn randomly as a poisson process.\n",
    "\n",
    "This is repeated for \"stimulation\" trials, but poisson rate is higher."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "pycharm": {
     "name": "#%%\n"
    },
    "scrolled": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [],
   "source": [
    "# Draw some fake data:\n",
    "df, df_monster, index_cols, _ = generate_fake_lfp(mouse_response_slope=15, n_trials=30)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "Mice vary in their baseline power.\n",
    "\n",
    "Higher-baseline mice tend to have smaller stim response:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-b52f541fa7d34484a1ad542ad7d6aa71\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-b52f541fa7d34484a1ad542ad7d6aa71\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-b52f541fa7d34484a1ad542ad7d6aa71\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-ce9fca907dbdeef07d390c8383190ed8\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"stim\"}}, \"spec\": {\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"mouse\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}, \"title\": \"Log power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"mouse\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"mouse\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}}}}]}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-ce9fca907dbdeef07d390c8383190ed8\": [{\"stim\": 0, \"mouse\": 0, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.955295818792631, \"Firing rate\": 90.21854501261329, \"Power\": 90.21854501261329, \"i_spike\": 47.5, \"isi\": 0.0731915996436363, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6026484195029185, \"Firing rate\": 40.054232969747986, \"Power\": 40.054232969747986, \"i_spike\": 39.5, \"isi\": 0.08505458474637603, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1244493253919545, \"Firing rate\": 133.18316316728252, \"Power\": 133.18316316728252, \"i_spike\": 42.5, \"isi\": 0.08224071637572535, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8708094709723913, \"Firing rate\": 74.2693239984203, \"Power\": 74.2693239984203, \"i_spike\": 33.5, \"isi\": 0.10505328377444978, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9711426825012743, \"Firing rate\": 93.57130415068605, \"Power\": 93.57130415068605, \"i_spike\": 40.5, \"isi\": 0.08430258433195234, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8590874397971908, \"Firing rate\": 72.29153389710372, \"Power\": 72.29153389710372, \"i_spike\": 44.0, \"isi\": 0.0795434324837374, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0132461342812213, \"Firing rate\": 103.09702522654109, \"Power\": 103.09702522654109, \"i_spike\": 47.5, \"isi\": 0.07286723599674903, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0127266901312217, \"Firing rate\": 102.97378826377438, \"Power\": 102.97378826377438, \"i_spike\": 39.0, \"isi\": 0.08914566084967086, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503131681143027, \"Firing rate\": 56.27469736390204, \"Power\": 56.27469736390204, \"i_spike\": 40.0, \"isi\": 0.08700029609063652, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1169032082350827, \"Firing rate\": 130.88901764671587, \"Power\": 130.88901764671587, \"i_spike\": 62.0, \"isi\": 0.05659763212840744, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8770680415974088, \"Firing rate\": 75.34736023774802, \"Power\": 75.34736023774802, \"i_spike\": 39.0, \"isi\": 0.09009246539035318, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9310965336855828, \"Firing rate\": 85.32897596494497, \"Power\": 85.32897596494497, \"i_spike\": 34.0, \"isi\": 0.10149738234291991, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.5333013820605306, \"Firing rate\": 34.14297672922771, \"Power\": 34.14297672922771, \"i_spike\": 40.5, \"isi\": 0.08685116325741157, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.030855072834198, \"Firing rate\": 107.36310742084633, \"Power\": 107.36310742084633, \"i_spike\": 54.5, \"isi\": 0.059448248477706966, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.794551727002911, \"Firing rate\": 623.0913568201987, \"Power\": 623.0913568201987, \"i_spike\": 48.5, \"isi\": 0.0713719442616052, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7955427567112552, \"Firing rate\": 62.451483134242046, \"Power\": 62.451483134242046, \"i_spike\": 35.5, \"isi\": 0.09057886752422038, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9082000854510324, \"Firing rate\": 80.94687466873414, \"Power\": 80.94687466873414, \"i_spike\": 53.0, \"isi\": 0.06529444835938969, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6555352624426098, \"Firing rate\": 45.24131944286433, \"Power\": 45.24131944286433, \"i_spike\": 43.5, \"isi\": 0.0768533496686384, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.177328557623848, \"Firing rate\": 150.42795711808552, \"Power\": 150.42795711808552, \"i_spike\": 34.5, \"isi\": 0.09830229180875018, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8645215585407622, \"Firing rate\": 73.20176599287585, \"Power\": 73.20176599287585, \"i_spike\": 55.5, \"isi\": 0.06179006984103724, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.535025958406892, \"Firing rate\": 34.27882748831966, \"Power\": 34.27882748831966, \"i_spike\": 34.5, \"isi\": 0.09915726015773765, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.32247920697616, \"Firing rate\": 210.125716326415, \"Power\": 210.125716326415, \"i_spike\": 33.0, \"isi\": 0.10502063399832753, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.43733847759269, \"Firing rate\": 273.74013531042965, \"Power\": 273.74013531042965, \"i_spike\": 56.0, \"isi\": 0.061967941571928455, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7969419629962189, \"Firing rate\": 62.653013263585784, \"Power\": 62.653013263585784, \"i_spike\": 37.0, \"isi\": 0.09259944757473725, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9846064873802938, \"Firing rate\": 96.51759403196418, \"Power\": 96.51759403196418, \"i_spike\": 41.5, \"isi\": 0.08460263304467304, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503293230777222, \"Firing rate\": 56.27679071904272, \"Power\": 56.27679071904272, \"i_spike\": 42.5, \"isi\": 0.07988986525214349, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.4286782943328151, \"Firing rate\": 26.83356000776027, \"Power\": 26.83356000776027, \"i_spike\": 35.5, \"isi\": 0.09874338503855341, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1383088558675207, \"Firing rate\": 137.50194957559475, \"Power\": 137.50194957559475, \"i_spike\": 48.5, \"isi\": 0.07210812725187593, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0035263866631934, \"Firing rate\": 100.81528603885884, \"Power\": 100.81528603885884, \"i_spike\": 49.5, \"isi\": 0.0672853207791876, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6296351063659993, \"Firing rate\": 42.62212577953956, \"Power\": 42.62212577953956, \"i_spike\": 41.5, \"isi\": 0.0790188469593832, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.193262117122394, \"Firing rate\": 156.04940501335037, \"Power\": 156.04940501335037, \"i_spike\": 48.0, \"isi\": 0.07263392600048459, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9760548637782647, \"Firing rate\": 94.63567056548113, \"Power\": 94.63567056548113, \"i_spike\": 44.5, \"isi\": 0.0776680429623508, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6250730368645014, \"Firing rate\": 42.17674276093685, \"Power\": 42.17674276093685, \"i_spike\": 42.5, \"isi\": 0.08104853472101264, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.491206995038427, \"Firing rate\": 309.8895954508339, \"Power\": 309.8895954508339, \"i_spike\": 51.5, \"isi\": 0.06708115735632907, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3589480963384455, \"Firing rate\": 228.53256618481504, \"Power\": 228.53256618481504, \"i_spike\": 47.5, \"isi\": 0.07348993800862964, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9281754169377023, \"Firing rate\": 84.75696889405249, \"Power\": 84.75696889405249, \"i_spike\": 53.0, \"isi\": 0.06509876660602372, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9843209349691886, \"Firing rate\": 96.45415373032593, \"Power\": 96.45415373032593, \"i_spike\": 59.5, \"isi\": 0.05870376554536328, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7638817011892445, \"Firing rate\": 58.06062428577546, \"Power\": 58.06062428577546, \"i_spike\": 52.0, \"isi\": 0.06566204692122644, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.650862407397869, \"Firing rate\": 44.75714827077759, \"Power\": 44.75714827077759, \"i_spike\": 49.0, \"isi\": 0.07040754805798212, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0583883119213846, \"Firing rate\": 114.39006635603113, \"Power\": 114.39006635603113, \"i_spike\": 51.0, \"isi\": 0.06837143070736648, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2173425763203, \"Firing rate\": 164.9462993258368, \"Power\": 164.9462993258368, \"i_spike\": 53.5, \"isi\": 0.06501277873096038, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2107084188475756, \"Firing rate\": 162.44577441851425, \"Power\": 162.44577441851425, \"i_spike\": 49.0, \"isi\": 0.06869119253150469, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5946141113333705, \"Firing rate\": 39.320054519388265, \"Power\": 39.320054519388265, \"i_spike\": 43.0, \"isi\": 0.08147481958019963, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.211944529140798, \"Firing rate\": 162.90879418557492, \"Power\": 162.90879418557492, \"i_spike\": 55.5, \"isi\": 0.06320352970416626, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5907555117125005, \"Firing rate\": 389.7225286301253, \"Power\": 389.7225286301253, \"i_spike\": 48.5, \"isi\": 0.07106759705283149, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.197050324722152, \"Firing rate\": 157.4165263375544, \"Power\": 157.4165263375544, \"i_spike\": 42.5, \"isi\": 0.08120962422114071, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.900738498847488, \"Firing rate\": 79.56801043564009, \"Power\": 79.56801043564009, \"i_spike\": 43.5, \"isi\": 0.07999246270715814, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7701446630135824, \"Firing rate\": 58.90398311997898, \"Power\": 58.90398311997898, \"i_spike\": 42.0, \"isi\": 0.08041029857361554, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5942453724234489, \"Firing rate\": 39.28668388897537, \"Power\": 39.28668388897537, \"i_spike\": 32.5, \"isi\": 0.1019318698052081, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6923353756705557, \"Firing rate\": 49.24196506231455, \"Power\": 49.24196506231455, \"i_spike\": 44.0, \"isi\": 0.07851300689834464, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9096430648934821, \"Firing rate\": 81.21627467876483, \"Power\": 81.21627467876483, \"i_spike\": 42.0, \"isi\": 0.08279141280781681, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7227625327508387, \"Firing rate\": 52.815638294554915, \"Power\": 52.815638294554915, \"i_spike\": 47.0, \"isi\": 0.07465675585663739, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0772331102040815, \"Firing rate\": 119.4629156868915, \"Power\": 119.4629156868915, \"i_spike\": 45.0, \"isi\": 0.07778279269254963, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8962156003531803, \"Firing rate\": 78.7436606258303, \"Power\": 78.7436606258303, \"i_spike\": 45.0, \"isi\": 0.07723000353960975, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.539325164353972, \"Firing rate\": 34.61984860582479, \"Power\": 34.61984860582479, \"i_spike\": 43.5, \"isi\": 0.08038783649040848, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.795290559690197, \"Firing rate\": 62.41522776726645, \"Power\": 62.41522776726645, \"i_spike\": 51.0, \"isi\": 0.06863876971272939, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7829257189432979, \"Firing rate\": 60.6632563219068, \"Power\": 60.6632563219068, \"i_spike\": 51.5, \"isi\": 0.06724356364949484, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8506258960042894, \"Firing rate\": 70.89667964004052, \"Power\": 70.89667964004052, \"i_spike\": 53.0, \"isi\": 0.06603508775646316, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9623740441999131, \"Firing rate\": 91.70099419760025, \"Power\": 91.70099419760025, \"i_spike\": 45.0, \"isi\": 0.0739363878905739, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0543726256433428, \"Firing rate\": 113.33723822345725, \"Power\": 113.33723822345725, \"i_spike\": 59.5, \"isi\": 0.05882184181366276, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0311570012276237, \"Firing rate\": 107.4377739030315, \"Power\": 107.4377739030315, \"i_spike\": 43.5, \"isi\": 0.08064172994284798, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.149704072470153, \"Firing rate\": 141.15753717632737, \"Power\": 141.15753717632737, \"i_spike\": 59.0, \"isi\": 0.059210435905617934, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0114163933193723, \"Firing rate\": 102.6635773453862, \"Power\": 102.6635773453862, \"i_spike\": 55.0, \"isi\": 0.06332773568755358, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9540841070386274, \"Firing rate\": 89.96717983510673, \"Power\": 89.96717983510673, \"i_spike\": 42.5, \"isi\": 0.08201299481958542, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8156677764444182, \"Firing rate\": 65.41355865573313, \"Power\": 65.41355865573313, \"i_spike\": 54.0, \"isi\": 0.06526466311001969, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.893859348236818, \"Firing rate\": 78.31759602448699, \"Power\": 78.31759602448699, \"i_spike\": 56.5, \"isi\": 0.06184020841304989, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.773984421574805, \"Firing rate\": 59.427084135210976, \"Power\": 59.427084135210976, \"i_spike\": 60.0, \"isi\": 0.058270067505733734, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.210840290387196, \"Firing rate\": 162.49510782693136, \"Power\": 162.49510782693136, \"i_spike\": 56.5, \"isi\": 0.06020300273286523, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9713400241427212, \"Firing rate\": 93.61383223125311, \"Power\": 93.61383223125311, \"i_spike\": 61.0, \"isi\": 0.0543980735122145, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8497634918355093, \"Firing rate\": 70.75603561035722, \"Power\": 70.75603561035722, \"i_spike\": 47.5, \"isi\": 0.07274197195399083, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9624750863491771, \"Firing rate\": 91.72233166302841, \"Power\": 91.72233166302841, \"i_spike\": 48.5, \"isi\": 0.07010114635983886, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.855302039054747, \"Firing rate\": 71.66416401500264, \"Power\": 71.66416401500264, \"i_spike\": 46.0, \"isi\": 0.0766119040381658, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.046426832369158, \"Firing rate\": 111.28248941720267, \"Power\": 111.28248941720267, \"i_spike\": 64.0, \"isi\": 0.05429137856724891, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7100483491678449, \"Firing rate\": 51.29184830393363, \"Power\": 51.29184830393363, \"i_spike\": 49.5, \"isi\": 0.0703751778152302, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3453546584516265, \"Firing rate\": 221.49027300778377, \"Power\": 221.49027300778377, \"i_spike\": 59.5, \"isi\": 0.058785042141719916, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.875277533612671, \"Firing rate\": 75.03735784498373, \"Power\": 75.03735784498373, \"i_spike\": 56.0, \"isi\": 0.06218241581461111, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6818911486395558, \"Firing rate\": 48.071884620822175, \"Power\": 48.071884620822175, \"i_spike\": 56.0, \"isi\": 0.06219590540248409, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7807624476641064, \"Firing rate\": 60.36183691888134, \"Power\": 60.36183691888134, \"i_spike\": 46.0, \"isi\": 0.07429803181700052, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7183011441323788, \"Firing rate\": 52.27585493529653, \"Power\": 52.27585493529653, \"i_spike\": 52.5, \"isi\": 0.06577263809678958, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.763346825231255, \"Firing rate\": 57.98916098746875, \"Power\": 57.98916098746875, \"i_spike\": 48.5, \"isi\": 0.07131264606340101, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.835065458404151, \"Firing rate\": 68.40147366385926, \"Power\": 68.40147366385926, \"i_spike\": 49.0, \"isi\": 0.07194196841840346, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.924715551322173, \"Firing rate\": 84.08442357857703, \"Power\": 84.08442357857703, \"i_spike\": 55.5, \"isi\": 0.06318891040674948, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.017073838923778, \"Firing rate\": 104.00969885083077, \"Power\": 104.00969885083077, \"i_spike\": 49.0, \"isi\": 0.07044066419783745, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7143174946332422, \"Firing rate\": 517.9853711282016, \"Power\": 517.9853711282016, \"i_spike\": 65.0, \"isi\": 0.052930696952406625, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.974181294239221, \"Firing rate\": 94.22828660927348, \"Power\": 94.22828660927348, \"i_spike\": 58.0, \"isi\": 0.060053602856178986, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9399526356112446, \"Firing rate\": 87.08686073800901, \"Power\": 87.08686073800901, \"i_spike\": 53.0, \"isi\": 0.06646977245711418, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6853656755730138, \"Firing rate\": 48.45802119713409, \"Power\": 48.45802119713409, \"i_spike\": 40.0, \"isi\": 0.08662078631540625, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9336719560475775, \"Firing rate\": 85.83649113967905, \"Power\": 85.83649113967905, \"i_spike\": 57.0, \"isi\": 0.060295111833858245, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0093234248133296, \"Firing rate\": 102.17000739461349, \"Power\": 102.17000739461349, \"i_spike\": 49.0, \"isi\": 0.06980898473808321, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6653323391451258, \"Firing rate\": 46.27349888819327, \"Power\": 46.27349888819327, \"i_spike\": 52.5, \"isi\": 0.06664468983496366, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.319563597750638, \"Firing rate\": 208.71977491726287, \"Power\": 208.71977491726287, \"i_spike\": 62.5, \"isi\": 0.054778780974004924, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9501238550989324, \"Firing rate\": 89.15051474767834, \"Power\": 89.15051474767834, \"i_spike\": 65.0, \"isi\": 0.052393936924168064, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.058384385790344, \"Firing rate\": 114.38903224581574, \"Power\": 114.38903224581574, \"i_spike\": 67.0, \"isi\": 0.051939822712101694, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.341203185363342, \"Firing rate\": 219.38310826468677, \"Power\": 219.38310826468677, \"i_spike\": 63.5, \"isi\": 0.054996827366133136, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9819991440519158, \"Firing rate\": 95.9398740641521, \"Power\": 95.9398740641521, \"i_spike\": 56.0, \"isi\": 0.06266914967033387, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.369563712635469, \"Firing rate\": 234.18750118502433, \"Power\": 234.18750118502433, \"i_spike\": 66.0, \"isi\": 0.05307466490753688, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8499974740031297, \"Firing rate\": 70.79416667549492, \"Power\": 70.79416667549492, \"i_spike\": 50.0, \"isi\": 0.06964434411828664, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4140871865689233, \"Firing rate\": 259.4700207563056, \"Power\": 259.4700207563056, \"i_spike\": 57.5, \"isi\": 0.05932812658617926, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2992730643707255, \"Firing rate\": 199.19253762816092, \"Power\": 199.19253762816092, \"i_spike\": 69.0, \"isi\": 0.0505200086604451, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1143279384255944, \"Firing rate\": 130.11517148140396, \"Power\": 130.11517148140396, \"i_spike\": 58.0, \"isi\": 0.06039580425018153, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1347425595996863, \"Firing rate\": 136.37744808427303, \"Power\": 136.37744808427303, \"i_spike\": 57.5, \"isi\": 0.06059068471302143, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9227227083724787, \"Firing rate\": 83.69947007723921, \"Power\": 83.69947007723921, \"i_spike\": 74.5, \"isi\": 0.04700841293964799, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9356641657046738, \"Firing rate\": 86.23114755907184, \"Power\": 86.23114755907184, \"i_spike\": 59.0, \"isi\": 0.05819722837595124, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1650029836128866, \"Firing rate\": 146.21872196813922, \"Power\": 146.21872196813922, \"i_spike\": 66.5, \"isi\": 0.05230105943774251, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.090242481076867, \"Firing rate\": 123.09558626462615, \"Power\": 123.09558626462615, \"i_spike\": 57.5, \"isi\": 0.059929836211731397, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9223690348846298, \"Firing rate\": 83.63133604719516, \"Power\": 83.63133604719516, \"i_spike\": 60.5, \"isi\": 0.05806760763773719, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1491227759212217, \"Firing rate\": 140.9687263512985, \"Power\": 140.9687263512985, \"i_spike\": 54.5, \"isi\": 0.06367419112012151, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3941117654392667, \"Firing rate\": 247.80597028438038, \"Power\": 247.80597028438038, \"i_spike\": 63.0, \"isi\": 0.05461154211696954, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9896786925487997, \"Firing rate\": 97.65144913558673, \"Power\": 97.65144913558673, \"i_spike\": 62.5, \"isi\": 0.05504185225729406, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.7731494316094232, \"Firing rate\": 59.31293728328963, \"Power\": 59.31293728328963, \"i_spike\": 55.0, \"isi\": 0.06267698786541855, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8554169772491347, \"Firing rate\": 71.68313280237724, \"Power\": 71.68313280237724, \"i_spike\": 60.5, \"isi\": 0.056999565632898194, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3716727528341055, \"Firing rate\": 235.32753886515357, \"Power\": 235.32753886515357, \"i_spike\": 52.0, \"isi\": 0.067154049479885, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2364092112497285, \"Firing rate\": 172.34917594410877, \"Power\": 172.34917594410877, \"i_spike\": 59.5, \"isi\": 0.05869502074828589, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2557126583819076, \"Firing rate\": 180.18252074391486, \"Power\": 180.18252074391486, \"i_spike\": 73.5, \"isi\": 0.04743594072717539, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.7433869258557073, \"Firing rate\": 553.8433249443033, \"Power\": 553.8433249443033, \"i_spike\": 55.0, \"isi\": 0.06360854706023654, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9410922920516542, \"Firing rate\": 87.31569035109068, \"Power\": 87.31569035109068, \"i_spike\": 65.5, \"isi\": 0.052877411734321145, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.053756802379095, \"Firing rate\": 113.17664155543305, \"Power\": 113.17664155543305, \"i_spike\": 54.0, \"isi\": 0.06436186527784456, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.034873477705347, \"Firing rate\": 108.36111813754236, \"Power\": 108.36111813754236, \"i_spike\": 66.5, \"isi\": 0.050938903955247916, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9885417764206283, \"Firing rate\": 97.39614698417968, \"Power\": 97.39614698417968, \"i_spike\": 60.0, \"isi\": 0.05780359441402076, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4369749555623357, \"Firing rate\": 273.51109962529904, \"Power\": 273.51109962529904, \"i_spike\": 64.0, \"isi\": 0.053993497700095504, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1065489309483487, \"Firing rate\": 127.8053196733479, \"Power\": 127.8053196733479, \"i_spike\": 66.0, \"isi\": 0.05304312813996159, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9049237369041854, \"Firing rate\": 80.33850335646146, \"Power\": 80.33850335646146, \"i_spike\": 74.0, \"isi\": 0.046752172315214786, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.089842705284853, \"Firing rate\": 122.98232672563184, \"Power\": 122.98232672563184, \"i_spike\": 62.5, \"isi\": 0.055459566693195586, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0542996219949314, \"Firing rate\": 113.3181881621406, \"Power\": 113.3181881621406, \"i_spike\": 68.5, \"isi\": 0.04886679113481873, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5270188880084747, \"Firing rate\": 336.5262050014474, \"Power\": 336.5262050014474, \"i_spike\": 77.0, \"isi\": 0.045084314963419254, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8366391281202479, \"Firing rate\": 68.64977657243634, \"Power\": 68.64977657243634, \"i_spike\": 70.5, \"isi\": 0.04950827198418861, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9617130502576103, \"Firing rate\": 91.56153191880342, \"Power\": 91.56153191880342, \"i_spike\": 68.5, \"isi\": 0.05136728010783104, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.241494871870913, \"Firing rate\": 174.37927667202098, \"Power\": 174.37927667202098, \"i_spike\": 63.0, \"isi\": 0.05576348859764074, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 3.1251395921423315, \"Firing rate\": 1333.9501252294517, \"Power\": 1333.9501252294517, \"i_spike\": 64.5, \"isi\": 0.054262100729024564, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8958624054342972, \"Firing rate\": 78.67964748291678, \"Power\": 78.67964748291678, \"i_spike\": 74.0, \"isi\": 0.046877125846140295, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5517732739731294, \"Firing rate\": 356.2650945497233, \"Power\": 356.2650945497233, \"i_spike\": 76.5, \"isi\": 0.04517211033649603, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0919634725229534, \"Firing rate\": 123.58434852138122, \"Power\": 123.58434852138122, \"i_spike\": 68.0, \"isi\": 0.05101734433625525, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3525110631387873, \"Firing rate\": 225.17027754817553, \"Power\": 225.17027754817553, \"i_spike\": 65.0, \"isi\": 0.05404540309717516, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.7819954120481858, \"Firing rate\": 60.53344798762198, \"Power\": 60.53344798762198, \"i_spike\": 53.0, \"isi\": 0.06467002728543748, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8422213318301035, \"Firing rate\": 69.5378616839905, \"Power\": 69.5378616839905, \"i_spike\": 69.0, \"isi\": 0.05037331163693314, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1868975598998643, \"Firing rate\": 153.77918677144316, \"Power\": 153.77918677144316, \"i_spike\": 70.0, \"isi\": 0.049775509977722336, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9726367908939046, \"Firing rate\": 93.89377298287559, \"Power\": 93.89377298287559, \"i_spike\": 75.5, \"isi\": 0.04639225026242182, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.778101000828387, \"Firing rate\": 59.99305816899431, \"Power\": 59.99305816899431, \"i_spike\": 68.5, \"isi\": 0.05075104338195106, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9121660273135348, \"Firing rate\": 81.68946039587414, \"Power\": 81.68946039587414, \"i_spike\": 64.0, \"isi\": 0.05481280145440375, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0478218930526535, \"Firing rate\": 111.64053089208255, \"Power\": 111.64053089208255, \"i_spike\": 70.0, \"isi\": 0.0489888087012864, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.117471278561992, \"Firing rate\": 131.0603364640247, \"Power\": 131.0603364640247, \"i_spike\": 65.5, \"isi\": 0.051671766893329675, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.931167591711936, \"Firing rate\": 853.4293839120918, \"Power\": 853.4293839120918, \"i_spike\": 63.0, \"isi\": 0.05525138390063168, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.277774705751867, \"Firing rate\": 189.57222427760698, \"Power\": 189.57222427760698, \"i_spike\": 78.0, \"isi\": 0.04456622398656536, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.845684289414062, \"Firing rate\": 70.09455604474384, \"Power\": 70.09455604474384, \"i_spike\": 63.5, \"isi\": 0.05469869440456847, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10431894281778, \"Firing rate\": 127.15075486242938, \"Power\": 127.15075486242938, \"i_spike\": 67.0, \"isi\": 0.05227215134911894, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.033552725921547, \"Firing rate\": 108.03207702586286, \"Power\": 108.03207702586286, \"i_spike\": 57.5, \"isi\": 0.060347774168580594, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1643005604050174, \"Firing rate\": 145.98242053251482, \"Power\": 145.98242053251482, \"i_spike\": 72.5, \"isi\": 0.04783783469680652, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0012121960819167, \"Firing rate\": 100.27950836105705, \"Power\": 100.27950836105705, \"i_spike\": 71.5, \"isi\": 0.048990832561469015, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9583920039283502, \"Firing rate\": 90.86403192498832, \"Power\": 90.86403192498832, \"i_spike\": 76.0, \"isi\": 0.04556701067411184, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1124885757403176, \"Firing rate\": 129.56526144990931, \"Power\": 129.56526144990931, \"i_spike\": 75.0, \"isi\": 0.046659913362027156, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7844790003053106, \"Firing rate\": 608.8061070924601, \"Power\": 608.8061070924601, \"i_spike\": 92.0, \"isi\": 0.03797865081756185, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1928313296970376, \"Firing rate\": 155.8946924977612, \"Power\": 155.8946924977612, \"i_spike\": 92.0, \"isi\": 0.038121755542223995, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077615601977832, \"Firing rate\": 119.56817539419721, \"Power\": 119.56817539419721, \"i_spike\": 74.5, \"isi\": 0.04660934195613513, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3240668465311076, \"Firing rate\": 210.895273459069, \"Power\": 210.895273459069, \"i_spike\": 75.5, \"isi\": 0.04641624316187993, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9441862764582671, \"Firing rate\": 87.93996257483187, \"Power\": 87.93996257483187, \"i_spike\": 73.0, \"isi\": 0.04692146801636959, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.0247285177119982, \"Firing rate\": 1058.591780864329, \"Power\": 1058.591780864329, \"i_spike\": 77.0, \"isi\": 0.045685464766526206, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.7391920768878777, \"Firing rate\": 54.85195068575797, \"Power\": 54.85195068575797, \"i_spike\": 64.5, \"isi\": 0.05399592200088135, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1934103426446043, \"Firing rate\": 156.10267405821313, \"Power\": 156.10267405821313, \"i_spike\": 74.5, \"isi\": 0.046628423844649644, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.297774880328158, \"Firing rate\": 198.50656775360184, \"Power\": 198.50656775360184, \"i_spike\": 80.0, \"isi\": 0.04397457503735967, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1110133951114576, \"Firing rate\": 129.1259099799552, \"Power\": 129.1259099799552, \"i_spike\": 87.5, \"isi\": 0.03951101481601628, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9798834285720046, \"Firing rate\": 95.47362854816234, \"Power\": 95.47362854816234, \"i_spike\": 82.0, \"isi\": 0.04281447867823779, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9839401087688497, \"Firing rate\": 96.36961162784607, \"Power\": 96.36961162784607, \"i_spike\": 80.5, \"isi\": 0.0436343619819139, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9292502786690382, \"Firing rate\": 84.96699885333383, \"Power\": 84.96699885333383, \"i_spike\": 84.5, \"isi\": 0.040212763358464985, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.110242887829347, \"Firing rate\": 128.89702323935285, \"Power\": 128.89702323935285, \"i_spike\": 78.0, \"isi\": 0.044671705231796116, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9896296651016587, \"Firing rate\": 97.6404258985101, \"Power\": 97.6404258985101, \"i_spike\": 96.5, \"isi\": 0.03602341732975196, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.524514898794598, \"Firing rate\": 3345.9149606607, \"Power\": 3345.9149606607, \"i_spike\": 67.0, \"isi\": 0.05228146274267083, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1112668565940305, \"Firing rate\": 129.20129200352847, \"Power\": 129.20129200352847, \"i_spike\": 72.5, \"isi\": 0.04765721891987244, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9572989808412744, \"Firing rate\": 90.63563480094187, \"Power\": 90.63563480094187, \"i_spike\": 77.5, \"isi\": 0.04525372674699464, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.543885879418327, \"Firing rate\": 349.85322319506616, \"Power\": 349.85322319506616, \"i_spike\": 71.5, \"isi\": 0.048639441668922465, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1757930037804383, \"Firing rate\": 149.89702164205846, \"Power\": 149.89702164205846, \"i_spike\": 82.0, \"isi\": 0.04242030307116036, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9882434867575853, \"Firing rate\": 97.32927464232434, \"Power\": 97.32927464232434, \"i_spike\": 73.0, \"isi\": 0.047906156958600565, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.123436432758141, \"Firing rate\": 132.8729058171096, \"Power\": 132.8729058171096, \"i_spike\": 74.0, \"isi\": 0.04678579996295997, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2883138118447697, \"Firing rate\": 194.22888267612504, \"Power\": 194.22888267612504, \"i_spike\": 76.0, \"isi\": 0.04579097873240445, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3338630531397206, \"Firing rate\": 215.70641109917793, \"Power\": 215.70641109917793, \"i_spike\": 82.0, \"isi\": 0.04253295769330548, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1368082310712584, \"Firing rate\": 137.02765673763616, \"Power\": 137.02765673763616, \"i_spike\": 87.0, \"isi\": 0.04009013967311376, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.304411865772515, \"Firing rate\": 201.5634883150203, \"Power\": 201.5634883150203, \"i_spike\": 84.5, \"isi\": 0.040969846937519115, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1578448451318133, \"Firing rate\": 143.82846487878152, \"Power\": 143.82846487878152, \"i_spike\": 93.0, \"isi\": 0.037192354679684805, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.026210332863069, \"Firing rate\": 106.22098707802203, \"Power\": 106.22098707802203, \"i_spike\": 86.0, \"isi\": 0.039883894146009444, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0309948773666058, \"Firing rate\": 107.39767443894033, \"Power\": 107.39767443894033, \"i_spike\": 71.5, \"isi\": 0.04790202069793337, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1102417146873824, \"Firing rate\": 128.89667505555326, \"Power\": 128.89667505555326, \"i_spike\": 85.5, \"isi\": 0.040840328777172155, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3598760140799757, \"Firing rate\": 229.0213730590734, \"Power\": 229.0213730590734, \"i_spike\": 85.5, \"isi\": 0.041093869337129094, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4487993661694656, \"Firing rate\": 281.0602098401713, \"Power\": 281.0602098401713, \"i_spike\": 88.5, \"isi\": 0.03916681921061969, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1541973100299687, \"Firing rate\": 142.6255427263312, \"Power\": 142.6255427263312, \"i_spike\": 87.5, \"isi\": 0.039474320407279974, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.234900540025064, \"Firing rate\": 171.7515005319624, \"Power\": 171.7515005319624, \"i_spike\": 94.5, \"isi\": 0.03655183866180524, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.7078341872007305, \"Firing rate\": 510.31012735003867, \"Power\": 510.31012735003867, \"i_spike\": 83.5, \"isi\": 0.041988842659945944, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1126963123799873, \"Firing rate\": 129.6272513932111, \"Power\": 129.6272513932111, \"i_spike\": 89.0, \"isi\": 0.03919921663226311, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1692211907420162, \"Firing rate\": 147.6458317545557, \"Power\": 147.6458317545557, \"i_spike\": 88.0, \"isi\": 0.03956930417423602, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1644556852991537, \"Firing rate\": 146.03457305415864, \"Power\": 146.03457305415864, \"i_spike\": 96.5, \"isi\": 0.03588734853002937, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.31196565210909, \"Firing rate\": 205.0999960994725, \"Power\": 205.0999960994725, \"i_spike\": 90.0, \"isi\": 0.03903067099230167, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.074577597091679, \"Firing rate\": 118.73468299886356, \"Power\": 118.73468299886356, \"i_spike\": 104.0, \"isi\": 0.03353750893302584, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2092160144315107, \"Firing rate\": 161.88850572662918, \"Power\": 161.88850572662918, \"i_spike\": 104.5, \"isi\": 0.03279156198398983, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.49914214982962, \"Firing rate\": 315.60374635173724, \"Power\": 315.60374635173724, \"i_spike\": 101.5, \"isi\": 0.034537567878371166, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1418864131165836, \"Firing rate\": 138.63931793743396, \"Power\": 138.63931793743396, \"i_spike\": 91.5, \"isi\": 0.03818102135269262, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8765227305978964, \"Firing rate\": 752.5281158141704, \"Power\": 752.5281158141704, \"i_spike\": 93.5, \"isi\": 0.03689839236734887, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.939461561874331, \"Firing rate\": 86.98844387480378, \"Power\": 86.98844387480378, \"i_spike\": 92.0, \"isi\": 0.03758519178898388, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2870436262828573, \"Firing rate\": 193.66164935551598, \"Power\": 193.66164935551598, \"i_spike\": 89.5, \"isi\": 0.03894744817039956, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1430297227592443, \"Firing rate\": 139.0047761690239, \"Power\": 139.0047761690239, \"i_spike\": 97.0, \"isi\": 0.03603976087193819, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.310726570280992, \"Firing rate\": 204.51566105247213, \"Power\": 204.51566105247213, \"i_spike\": 91.0, \"isi\": 0.03830441539373303, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3968118547257453, \"Firing rate\": 249.35142514175052, \"Power\": 249.35142514175052, \"i_spike\": 96.0, \"isi\": 0.03647169049835178, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 3.469141414513526, \"Firing rate\": 2945.3805493938794, \"Power\": 2945.3805493938794, \"i_spike\": 97.0, \"isi\": 0.03567197347869549, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189566775673024, \"Firing rate\": 262.39567812258474, \"Power\": 262.39567812258474, \"i_spike\": 109.0, \"isi\": 0.03178383198414856, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.404076689518491, \"Firing rate\": 253.55763335396162, \"Power\": 253.55763335396162, \"i_spike\": 100.0, \"isi\": 0.034975946689714515, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4991139433760545, \"Firing rate\": 315.58324926114744, \"Power\": 315.58324926114744, \"i_spike\": 83.5, \"isi\": 0.04187307899164901, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.379747962179488, \"Firing rate\": 239.7441187730139, \"Power\": 239.7441187730139, \"i_spike\": 100.0, \"isi\": 0.03471693037002835, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.8902246293874716, \"Firing rate\": 77.66487174396306, \"Power\": 77.66487174396306, \"i_spike\": 87.5, \"isi\": 0.03966381661521433, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.814843398948089, \"Firing rate\": 652.8950845550662, \"Power\": 652.8950845550662, \"i_spike\": 85.5, \"isi\": 0.040891388126968714, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.9487896110579808, \"Firing rate\": 888.7704589764036, \"Power\": 888.7704589764036, \"i_spike\": 89.5, \"isi\": 0.03915085074928612, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.0149402045520945, \"Firing rate\": 103.49996538656313, \"Power\": 103.49996538656313, \"i_spike\": 89.5, \"isi\": 0.03921140742804705, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.9542028872402641, \"Firing rate\": 89.9917893609065, \"Power\": 89.9917893609065, \"i_spike\": 85.5, \"isi\": 0.04054868314386225, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4881910216727383, \"Firing rate\": 307.74501140084084, \"Power\": 307.74501140084084, \"i_spike\": 88.0, \"isi\": 0.03904624656724844, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4115277428777, \"Firing rate\": 257.945373553756, \"Power\": 257.945373553756, \"i_spike\": 119.5, \"isi\": 0.02880924312756989, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4545567386868696, \"Firing rate\": 284.81098690467894, \"Power\": 284.81098690467894, \"i_spike\": 109.0, \"isi\": 0.03179620656212547, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3111719305423497, \"Firing rate\": 204.7254953238993, \"Power\": 204.7254953238993, \"i_spike\": 97.5, \"isi\": 0.03580379043600067, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.165545723182864, \"Firing rate\": 146.40156632304382, \"Power\": 146.40156632304382, \"i_spike\": 105.5, \"isi\": 0.03278382952607013, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2578646424397553, \"Firing rate\": 181.07756360533585, \"Power\": 181.07756360533585, \"i_spike\": 119.0, \"isi\": 0.029343681835626842, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.8107940843269335, \"Firing rate\": 646.835853340232, \"Power\": 646.835853340232, \"i_spike\": 116.0, \"isi\": 0.029999599974023163, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.39182087209241, \"Firing rate\": 246.50224111651946, \"Power\": 246.50224111651946, \"i_spike\": 117.5, \"isi\": 0.029502232467124783, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0658291633993806, \"Firing rate\": 116.36681920867568, \"Power\": 116.36681920867568, \"i_spike\": 101.0, \"isi\": 0.034668414565907774, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3285225511020813, \"Firing rate\": 213.07012031018914, \"Power\": 213.07012031018914, \"i_spike\": 113.5, \"isi\": 0.03083920593859388, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6729864873429214, \"Firing rate\": 470.9626726162531, \"Power\": 470.9626726162531, \"i_spike\": 122.0, \"isi\": 0.028568916959577716, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2018925265651847, \"Firing rate\": 159.18147571149987, \"Power\": 159.18147571149987, \"i_spike\": 112.0, \"isi\": 0.030867054694338973, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.374213868452394, \"Firing rate\": 236.70850822985395, \"Power\": 236.70850822985395, \"i_spike\": 105.0, \"isi\": 0.03330704053094981, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.311456530252207, \"Firing rate\": 204.85969899001685, \"Power\": 204.85969899001685, \"i_spike\": 104.0, \"isi\": 0.03379316964890372, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.18089067422046, \"Firing rate\": 151.66685255353084, \"Power\": 151.66685255353084, \"i_spike\": 108.0, \"isi\": 0.03226254920952097, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1779833854348714, \"Firing rate\": 150.65494298513445, \"Power\": 150.65494298513445, \"i_spike\": 113.0, \"isi\": 0.030897373044620688, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3035855615368024, \"Firing rate\": 201.18035100403486, \"Power\": 201.18035100403486, \"i_spike\": 112.5, \"isi\": 0.031017803226141994, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4551657383947396, \"Firing rate\": 285.2106499995778, \"Power\": 285.2106499995778, \"i_spike\": 119.5, \"isi\": 0.02922791099470977, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 3.100538081982483, \"Firing rate\": 1260.486161305173, \"Power\": 1260.486161305173, \"i_spike\": 117.5, \"isi\": 0.029697418256461976, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1111083966350765, \"Firing rate\": 129.15415924516745, \"Power\": 129.15415924516745, \"i_spike\": 118.5, \"isi\": 0.02948619911662466, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.044552627498885, \"Firing rate\": 110.80328278754759, \"Power\": 110.80328278754759, \"i_spike\": 101.0, \"isi\": 0.03429723398050743, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.016091787828533, \"Firing rate\": 103.77477198816491, \"Power\": 103.77477198816491, \"i_spike\": 103.5, \"isi\": 0.03346541480440439, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2697421877977257, \"Firing rate\": 186.09820654703583, \"Power\": 186.09820654703583, \"i_spike\": 118.5, \"isi\": 0.029214269965179746, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.687691210640336, \"Firing rate\": 487.1819738340354, \"Power\": 487.1819738340354, \"i_spike\": 112.0, \"isi\": 0.031291789674142416, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.5700111791336004, \"Firing rate\": 371.5447928738117, \"Power\": 371.5447928738117, \"i_spike\": 119.5, \"isi\": 0.029125995163474167, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.324688636610815, \"Firing rate\": 211.19743365693657, \"Power\": 211.19743365693657, \"i_spike\": 128.5, \"isi\": 0.02689077169759444, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.197745717540907, \"Firing rate\": 157.668783762246, \"Power\": 157.668783762246, \"i_spike\": 116.5, \"isi\": 0.029739505746504635, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.232111730437686, \"Firing rate\": 170.65213673060103, \"Power\": 170.65213673060103, \"i_spike\": 119.5, \"isi\": 0.029278118430901116, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.226281785132872, \"Firing rate\": 168.3766191894407, \"Power\": 168.3766191894407, \"i_spike\": 100.5, \"isi\": 0.03487511849895156, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4240095717708385, \"Firing rate\": 265.4664069640671, \"Power\": 265.4664069640671, \"i_spike\": 109.0, \"isi\": 0.032083977077943644, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0765668363240124, \"Firing rate\": 119.27978189302107, \"Power\": 119.27978189302107, \"i_spike\": 118.0, \"isi\": 0.02924333618462232, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.710200388455537, \"Firing rate\": 513.0980787193608, \"Power\": 513.0980787193608, \"i_spike\": 58.0, \"isi\": 0.05755769778597422, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.086495554586632, \"Firing rate\": 122.03813289272098, \"Power\": 122.03813289272098, \"i_spike\": 58.0, \"isi\": 0.05954567433072462, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.4599942127543875, \"Firing rate\": 288.3993071858994, \"Power\": 288.3993071858994, \"i_spike\": 69.0, \"isi\": 0.050452157477652144, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8764248252258178, \"Firing rate\": 75.23584884202715, \"Power\": 75.23584884202715, \"i_spike\": 47.5, \"isi\": 0.0729232484181408, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.943371360287594, \"Firing rate\": 87.77510553153151, \"Power\": 87.77510553153151, \"i_spike\": 72.0, \"isi\": 0.04794968452690702, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0095288502408404, \"Firing rate\": 102.21834621295545, \"Power\": 102.21834621295545, \"i_spike\": 58.5, \"isi\": 0.05900199429876669, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.108813974324886, \"Firing rate\": 128.47362382167685, \"Power\": 128.47362382167685, \"i_spike\": 74.0, \"isi\": 0.04704885530644372, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9546575480473676, \"Firing rate\": 90.08605066518454, \"Power\": 90.08605066518454, \"i_spike\": 66.0, \"isi\": 0.05192063434120186, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9556030665055126, \"Firing rate\": 90.28239396841717, \"Power\": 90.28239396841717, \"i_spike\": 63.0, \"isi\": 0.05547055572684698, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.116207536382213, \"Firing rate\": 130.6795217411474, \"Power\": 130.6795217411474, \"i_spike\": 60.5, \"isi\": 0.0574361231164934, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.125243880671493, \"Firing rate\": 133.4270489421996, \"Power\": 133.4270489421996, \"i_spike\": 68.0, \"isi\": 0.04981296493334266, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.067202187376957, \"Firing rate\": 116.73529559924685, \"Power\": 116.73529559924685, \"i_spike\": 61.5, \"isi\": 0.0564927141817096, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3223316454945286, \"Firing rate\": 210.0543334368294, \"Power\": 210.0543334368294, \"i_spike\": 59.5, \"isi\": 0.058641352393127184, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0012989243549466, \"Firing rate\": 100.29953610121872, \"Power\": 100.29953610121872, \"i_spike\": 63.5, \"isi\": 0.053258724806304336, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.740752379052743, \"Firing rate\": 55.049373283103336, \"Power\": 55.049373283103336, \"i_spike\": 68.5, \"isi\": 0.05025347412312059, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8372359506262905, \"Firing rate\": 68.74418232403539, \"Power\": 68.74418232403539, \"i_spike\": 58.5, \"isi\": 0.05883024786315191, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3872683261080843, \"Firing rate\": 243.9317469805847, \"Power\": 243.9317469805847, \"i_spike\": 52.0, \"isi\": 0.06463987437697509, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1699952647940046, \"Firing rate\": 147.90922612197502, \"Power\": 147.90922612197502, \"i_spike\": 58.0, \"isi\": 0.06041749419783433, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0727936321681573, \"Firing rate\": 118.24795321797994, \"Power\": 118.24795321797994, \"i_spike\": 74.0, \"isi\": 0.04733033921726912, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.44888166908114, \"Firing rate\": 281.11347845536557, \"Power\": 281.11347845536557, \"i_spike\": 64.0, \"isi\": 0.05283053800228937, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.268675264450081, \"Firing rate\": 185.64158358911618, \"Power\": 185.64158358911618, \"i_spike\": 65.5, \"isi\": 0.05201986674274169, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.428906190296464, \"Firing rate\": 268.4764460943622, \"Power\": 268.4764460943622, \"i_spike\": 58.5, \"isi\": 0.05911180928366123, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.049008675060004, \"Firing rate\": 111.94602445336766, \"Power\": 111.94602445336766, \"i_spike\": 84.0, \"isi\": 0.04125747764768612, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0516084499750704, \"Firing rate\": 112.61816585709414, \"Power\": 112.61816585709414, \"i_spike\": 66.0, \"isi\": 0.05216770534731938, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9822401781710393, \"Firing rate\": 95.99313562360203, \"Power\": 95.99313562360203, \"i_spike\": 68.5, \"isi\": 0.05091550082040577, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0413070869966092, \"Firing rate\": 109.97832146085658, \"Power\": 109.97832146085658, \"i_spike\": 69.5, \"isi\": 0.048261908955763336, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9162564740110344, \"Firing rate\": 82.4624956181202, \"Power\": 82.4624956181202, \"i_spike\": 72.5, \"isi\": 0.04580300353406743, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.0251706690400266, \"Firing rate\": 1059.6700724955876, \"Power\": 1059.6700724955876, \"i_spike\": 71.0, \"isi\": 0.048977335140478306, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9185288956668356, \"Firing rate\": 82.89510684752574, \"Power\": 82.89510684752574, \"i_spike\": 65.0, \"isi\": 0.053468477919304494, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.7155492922987285, \"Firing rate\": 5194.566283391101, \"Power\": 5194.566283391101, \"i_spike\": 70.0, \"isi\": 0.047831889076879165, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2880559296273484, \"Firing rate\": 194.11358462627942, \"Power\": 194.11358462627942, \"i_spike\": 77.0, \"isi\": 0.04377704062250514, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2863930549701847, \"Firing rate\": 193.37176219598692, \"Power\": 193.37176219598692, \"i_spike\": 71.5, \"isi\": 0.04739471740371852, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 3.485362624668281, \"Firing rate\": 3057.4729586064655, \"Power\": 3057.4729586064655, \"i_spike\": 61.0, \"isi\": 0.05730472197648097, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2096939236101893, \"Firing rate\": 162.06675019105623, \"Power\": 162.06675019105623, \"i_spike\": 70.0, \"isi\": 0.04860233815068464, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.837305629539864, \"Firing rate\": 687.5521263737877, \"Power\": 687.5521263737877, \"i_spike\": 76.0, \"isi\": 0.0462630290768705, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1604627571934727, \"Firing rate\": 144.6980762328094, \"Power\": 144.6980762328094, \"i_spike\": 71.5, \"isi\": 0.04871333606236235, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2330475254201847, \"Firing rate\": 171.0202454569647, \"Power\": 171.0202454569647, \"i_spike\": 71.5, \"isi\": 0.049080521297471015, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2588609326122553, \"Firing rate\": 181.4934401413059, \"Power\": 181.4934401413059, \"i_spike\": 66.5, \"isi\": 0.05057733095048499, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8829675842290474, \"Firing rate\": 76.37787729482577, \"Power\": 76.37787729482577, \"i_spike\": 81.0, \"isi\": 0.04283416965586292, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3279809733696553, \"Firing rate\": 212.80458133268078, \"Power\": 212.80458133268078, \"i_spike\": 74.5, \"isi\": 0.04442769500737385, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8091068615972408, \"Firing rate\": 64.43277879673587, \"Power\": 64.43277879673587, \"i_spike\": 60.5, \"isi\": 0.056408495878117026, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0634103765045717, \"Firing rate\": 115.7205199960153, \"Power\": 115.7205199960153, \"i_spike\": 62.5, \"isi\": 0.05494193964992375, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.057707201125165, \"Firing rate\": 114.21080723853781, \"Power\": 114.21080723853781, \"i_spike\": 66.5, \"isi\": 0.05118977826099244, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2746886859201556, \"Firing rate\": 188.2299322496126, \"Power\": 188.2299322496126, \"i_spike\": 76.5, \"isi\": 0.04519157254778185, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0019707623558363, \"Firing rate\": 100.45481596463469, \"Power\": 100.45481596463469, \"i_spike\": 76.0, \"isi\": 0.045327986132193195, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.295587633345161, \"Firing rate\": 197.50933799327007, \"Power\": 197.50933799327007, \"i_spike\": 74.0, \"isi\": 0.046483911938798965, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.945877973988118, \"Firing rate\": 88.28318116549227, \"Power\": 88.28318116549227, \"i_spike\": 66.5, \"isi\": 0.05264008421938133, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.471153315505243, \"Firing rate\": 295.90568943614835, \"Power\": 295.90568943614835, \"i_spike\": 87.0, \"isi\": 0.04015846530226762, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0265599217285164, \"Firing rate\": 106.30652494563125, \"Power\": 106.30652494563125, \"i_spike\": 78.5, \"isi\": 0.04422689053854093, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9009990463345725, \"Firing rate\": 79.61576021362671, \"Power\": 79.61576021362671, \"i_spike\": 60.0, \"isi\": 0.05558242287405482, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1371898250889654, \"Firing rate\": 137.14810936802255, \"Power\": 137.14810936802255, \"i_spike\": 78.0, \"isi\": 0.043423699441362415, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.18334195846327, \"Firing rate\": 152.5253247913568, \"Power\": 152.5253247913568, \"i_spike\": 79.5, \"isi\": 0.0439479607076074, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.018302892049905, \"Firing rate\": 104.30446313151317, \"Power\": 104.30446313151317, \"i_spike\": 69.5, \"isi\": 0.050417535373145216, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.520301793170094, \"Firing rate\": 331.36130594281525, \"Power\": 331.36130594281525, \"i_spike\": 63.0, \"isi\": 0.055194343234777954, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.140863371620742, \"Firing rate\": 138.3131179566823, \"Power\": 138.3131179566823, \"i_spike\": 67.0, \"isi\": 0.05011613503553582, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5790786138640915, \"Firing rate\": 379.38365293278486, \"Power\": 379.38365293278486, \"i_spike\": 70.0, \"isi\": 0.049862445465668585, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0046971363148742, \"Firing rate\": 101.08742556167319, \"Power\": 101.08742556167319, \"i_spike\": 77.0, \"isi\": 0.044773115940763754, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9299917883985747, \"Firing rate\": 85.11219451122186, \"Power\": 85.11219451122186, \"i_spike\": 63.5, \"isi\": 0.053279255805921924, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.507367640954118, \"Firing rate\": 321.63821330655077, \"Power\": 321.63821330655077, \"i_spike\": 83.0, \"isi\": 0.04180903485727737, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.043864219396577, \"Firing rate\": 110.62778561221664, \"Power\": 110.62778561221664, \"i_spike\": 60.5, \"isi\": 0.05613656256289283, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0343304902630406, \"Firing rate\": 108.2257216223445, \"Power\": 108.2257216223445, \"i_spike\": 76.5, \"isi\": 0.044990678072367146, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.265966193291141, \"Firing rate\": 184.48718035589718, \"Power\": 184.48718035589718, \"i_spike\": 82.5, \"isi\": 0.041218621498328945, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.184829164757981, \"Firing rate\": 153.0485307452557, \"Power\": 153.0485307452557, \"i_spike\": 79.5, \"isi\": 0.0438790508311261, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.482867251153031, \"Firing rate\": 303.99556740279854, \"Power\": 303.99556740279854, \"i_spike\": 72.0, \"isi\": 0.04732392940449676, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.679350887775424, \"Firing rate\": 477.91524884132025, \"Power\": 477.91524884132025, \"i_spike\": 75.0, \"isi\": 0.04487201851927047, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0102132106102126, \"Firing rate\": 102.37954865480673, \"Power\": 102.37954865480673, \"i_spike\": 71.5, \"isi\": 0.04878632929411457, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2925787627458876, \"Firing rate\": 196.14568689680337, \"Power\": 196.14568689680337, \"i_spike\": 71.5, \"isi\": 0.04751080235874853, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.408181131975511, \"Firing rate\": 255.96532234553712, \"Power\": 255.96532234553712, \"i_spike\": 78.5, \"isi\": 0.04224296754691385, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3855583224969688, \"Firing rate\": 242.97317148876678, \"Power\": 242.97317148876678, \"i_spike\": 76.5, \"isi\": 0.045168110305337704, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9994034804402283, \"Firing rate\": 99.862740582426, \"Power\": 99.862740582426, \"i_spike\": 76.5, \"isi\": 0.04461518511387296, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.420657135162534, \"Firing rate\": 263.4250888241149, \"Power\": 263.4250888241149, \"i_spike\": 86.5, \"isi\": 0.039763315255390425, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0333948498686167, \"Firing rate\": 107.99281201345569, \"Power\": 107.99281201345569, \"i_spike\": 71.5, \"isi\": 0.04905015663749419, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1771834940956576, \"Firing rate\": 150.3777193944357, \"Power\": 150.3777193944357, \"i_spike\": 71.5, \"isi\": 0.048168145819388865, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9004170909121822, \"Firing rate\": 79.50914639254572, \"Power\": 79.50914639254572, \"i_spike\": 72.0, \"isi\": 0.047053568472965865, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2706500732886123, \"Firing rate\": 186.4876487147454, \"Power\": 186.4876487147454, \"i_spike\": 76.5, \"isi\": 0.04478958523955221, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3226879927203563, \"Firing rate\": 210.22675790778925, \"Power\": 210.22675790778925, \"i_spike\": 84.5, \"isi\": 0.041448783649683865, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1236488593840726, \"Firing rate\": 132.93791388973483, \"Power\": 132.93791388973483, \"i_spike\": 73.5, \"isi\": 0.04771964422986316, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9611984491654064, \"Firing rate\": 91.45310373895767, \"Power\": 91.45310373895767, \"i_spike\": 70.5, \"isi\": 0.04936860543367102, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0824773391122404, \"Firing rate\": 120.91420899286925, \"Power\": 120.91420899286925, \"i_spike\": 88.0, \"isi\": 0.03935522162784246, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9787501002284225, \"Firing rate\": 95.22480680598018, \"Power\": 95.22480680598018, \"i_spike\": 75.0, \"isi\": 0.045602480439414186, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1685898325916213, \"Firing rate\": 147.43134670286034, \"Power\": 147.43134670286034, \"i_spike\": 80.0, \"isi\": 0.0428366177384345, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.230731641001414, \"Firing rate\": 170.11070364760798, \"Power\": 170.11070364760798, \"i_spike\": 86.0, \"isi\": 0.04069000316608182, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7109408735479223, \"Firing rate\": 513.9736725480508, \"Power\": 513.9736725480508, \"i_spike\": 90.5, \"isi\": 0.03808087796581317, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.8904891156107295, \"Firing rate\": 777.121842141343, \"Power\": 777.121842141343, \"i_spike\": 67.5, \"isi\": 0.05050650450585472, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3884444205618465, \"Firing rate\": 244.59322344535366, \"Power\": 244.59322344535366, \"i_spike\": 75.5, \"isi\": 0.046160864179237364, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.215221869412756, \"Firing rate\": 164.14281206772014, \"Power\": 164.14281206772014, \"i_spike\": 76.0, \"isi\": 0.045973777674205345, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1044452923402397, \"Firing rate\": 127.18775228011826, \"Power\": 127.18775228011826, \"i_spike\": 74.5, \"isi\": 0.046825315835458, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.304794192932069, \"Firing rate\": 201.74101101002248, \"Power\": 201.74101101002248, \"i_spike\": 84.5, \"isi\": 0.0415838404784538, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9519897390823953, \"Firing rate\": 89.53436113421678, \"Power\": 89.53436113421678, \"i_spike\": 73.0, \"isi\": 0.04637231437529422, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.050715177785326, \"Firing rate\": 112.38676690257596, \"Power\": 112.38676690257596, \"i_spike\": 72.5, \"isi\": 0.047898939712791556, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.093906240936936, \"Firing rate\": 124.13842784179043, \"Power\": 124.13842784179043, \"i_spike\": 77.0, \"isi\": 0.04521406966614064, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.142532137492843, \"Firing rate\": 138.84560509200531, \"Power\": 138.84560509200531, \"i_spike\": 85.5, \"isi\": 0.04088215523965275, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1247106556001505, \"Firing rate\": 133.26332826018398, \"Power\": 133.26332826018398, \"i_spike\": 94.0, \"isi\": 0.03699718718109058, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0404961635875494, \"Firing rate\": 109.77315932365002, \"Power\": 109.77315932365002, \"i_spike\": 84.5, \"isi\": 0.040822879176668145, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2076231068258, \"Firing rate\": 161.29581780251291, \"Power\": 161.29581780251291, \"i_spike\": 77.0, \"isi\": 0.04556164109048245, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0158640710626763, \"Firing rate\": 103.72037327450805, \"Power\": 103.72037327450805, \"i_spike\": 70.5, \"isi\": 0.04900422553915958, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1880248824801893, \"Firing rate\": 154.1788785708863, \"Power\": 154.1788785708863, \"i_spike\": 87.5, \"isi\": 0.039435886208280056, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9744105165726646, \"Firing rate\": 94.27803379629712, \"Power\": 94.27803379629712, \"i_spike\": 84.5, \"isi\": 0.04146392755918885, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 3.913843764110594, \"Firing rate\": 8200.564788680073, \"Power\": 8200.564788680073, \"i_spike\": 76.5, \"isi\": 0.04556363424648217, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1399954218244273, \"Firing rate\": 138.0369713167223, \"Power\": 138.0369713167223, \"i_spike\": 77.5, \"isi\": 0.0453981706218095, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9566148125838072, \"Firing rate\": 90.49296385155998, \"Power\": 90.49296385155998, \"i_spike\": 85.0, \"isi\": 0.03927323815030475, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2520245491348896, \"Firing rate\": 178.65885615461892, \"Power\": 178.65885615461892, \"i_spike\": 85.0, \"isi\": 0.040967992817435184, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1754321193760866, \"Firing rate\": 149.77251389430003, \"Power\": 149.77251389430003, \"i_spike\": 91.5, \"isi\": 0.03836696480836998, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.635716855961742, \"Firing rate\": 432.2319398170039, \"Power\": 432.2319398170039, \"i_spike\": 96.5, \"isi\": 0.03578166736861596, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2160850620865733, \"Firing rate\": 164.46938258310612, \"Power\": 164.46938258310612, \"i_spike\": 80.0, \"isi\": 0.043473098367445215, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1205612291989038, \"Firing rate\": 131.9961393928132, \"Power\": 131.9961393928132, \"i_spike\": 75.5, \"isi\": 0.04626035487513255, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.024827292545692, \"Firing rate\": 105.88325716711356, \"Power\": 105.88325716711356, \"i_spike\": 80.5, \"isi\": 0.04253930743384717, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.074114281950763, \"Firing rate\": 118.60808170570037, \"Power\": 118.60808170570037, \"i_spike\": 67.0, \"isi\": 0.051334204579878646, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2811373940485504, \"Firing rate\": 191.04575581686126, \"Power\": 191.04575581686126, \"i_spike\": 74.5, \"isi\": 0.046987279420234215, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.014403068402744, \"Firing rate\": 103.37203558262294, \"Power\": 103.37203558262294, \"i_spike\": 82.5, \"isi\": 0.04146065949524595, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.108863671481811, \"Firing rate\": 128.4883261479434, \"Power\": 128.4883261479434, \"i_spike\": 87.5, \"isi\": 0.03907275494403815, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.658304695266665, \"Firing rate\": 455.30738576183563, \"Power\": 455.30738576183563, \"i_spike\": 93.5, \"isi\": 0.036909663672368385, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2071328830952694, \"Firing rate\": 161.11385272898417, \"Power\": 161.11385272898417, \"i_spike\": 90.0, \"isi\": 0.03900063452819159, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.162120505142531, \"Firing rate\": 145.25145957605932, \"Power\": 145.25145957605932, \"i_spike\": 85.5, \"isi\": 0.0400904776550323, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9709911192109881, \"Firing rate\": 93.53865464453958, \"Power\": 93.53865464453958, \"i_spike\": 75.0, \"isi\": 0.045538771732070805, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.134880880431313, \"Firing rate\": 136.42089060349338, \"Power\": 136.42089060349338, \"i_spike\": 88.5, \"isi\": 0.03943188805380755, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.066832430618179, \"Firing rate\": 116.63594988602028, \"Power\": 116.63594988602028, \"i_spike\": 70.5, \"isi\": 0.048970343212981035, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3793806836767333, \"Firing rate\": 239.5414552752351, \"Power\": 239.5414552752351, \"i_spike\": 82.5, \"isi\": 0.042043561438028454, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.399500106264406, \"Firing rate\": 250.89967933737773, \"Power\": 250.89967933737773, \"i_spike\": 75.5, \"isi\": 0.04561264334500348, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.220242199517701, \"Firing rate\": 166.0512692284522, \"Power\": 166.0512692284522, \"i_spike\": 77.5, \"isi\": 0.04518223580077409, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3997220560187014, \"Firing rate\": 251.02793644541697, \"Power\": 251.02793644541697, \"i_spike\": 92.0, \"isi\": 0.037630914484962856, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.166020646368421, \"Firing rate\": 146.56175147859375, \"Power\": 146.56175147859375, \"i_spike\": 91.0, \"isi\": 0.03827176241185468, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.185888096679604, \"Firing rate\": 153.4221613710901, \"Power\": 153.4221613710901, \"i_spike\": 92.0, \"isi\": 0.03761591240242529, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.4587317399206245, \"Firing rate\": 287.562161854551, \"Power\": 287.562161854551, \"i_spike\": 91.5, \"isi\": 0.03834390692603616, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.212868070184563, \"Firing rate\": 163.25559353268687, \"Power\": 163.25559353268687, \"i_spike\": 92.0, \"isi\": 0.03802455357122872, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2357931191352933, \"Firing rate\": 172.10485396344228, \"Power\": 172.10485396344228, \"i_spike\": 79.0, \"isi\": 0.04382598137502598, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3035618471296804, \"Firing rate\": 201.16936596348194, \"Power\": 201.16936596348194, \"i_spike\": 109.5, \"isi\": 0.03202543684399708, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.8017110410666857, \"Firing rate\": 633.4481047134145, \"Power\": 633.4481047134145, \"i_spike\": 98.0, \"isi\": 0.03550739167328109, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1697988740587917, \"Firing rate\": 147.8423557471093, \"Power\": 147.8423557471093, \"i_spike\": 88.5, \"isi\": 0.03925960981462805, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.6760870929370943, \"Firing rate\": 474.3370987623261, \"Power\": 474.3370987623261, \"i_spike\": 87.5, \"isi\": 0.039431239454240596, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.433730632307909, \"Firing rate\": 271.47549414255656, \"Power\": 271.47549414255656, \"i_spike\": 96.5, \"isi\": 0.0363181558103682, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.063446911413506, \"Firing rate\": 115.73025536377592, \"Power\": 115.73025536377592, \"i_spike\": 79.0, \"isi\": 0.044476460189586564, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.175425654268593, \"Firing rate\": 149.77028432833717, \"Power\": 149.77028432833717, \"i_spike\": 80.5, \"isi\": 0.04299945260731721, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3612576848505684, \"Firing rate\": 229.75114521901307, \"Power\": 229.75114521901307, \"i_spike\": 77.0, \"isi\": 0.04469056636440316, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.147995753593227, \"Firing rate\": 140.60337762680615, \"Power\": 140.60337762680615, \"i_spike\": 87.5, \"isi\": 0.03976844291136797, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0929257700333896, \"Firing rate\": 123.85848685027362, \"Power\": 123.85848685027362, \"i_spike\": 94.0, \"isi\": 0.03657174288555396, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10475158728818, \"Firing rate\": 127.27748564862868, \"Power\": 127.27748564862868, \"i_spike\": 98.5, \"isi\": 0.03552973340735749, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2328647390747323, \"Firing rate\": 170.94828141071517, \"Power\": 170.94828141071517, \"i_spike\": 82.5, \"isi\": 0.04166360369234807, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1354623163537503, \"Firing rate\": 136.6036539827589, \"Power\": 136.6036539827589, \"i_spike\": 84.5, \"isi\": 0.040640693096263156, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0464608797536576, \"Firing rate\": 111.29121397251097, \"Power\": 111.29121397251097, \"i_spike\": 89.5, \"isi\": 0.03879007896451536, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3355625956917723, \"Firing rate\": 216.5521977627491, \"Power\": 216.5521977627491, \"i_spike\": 98.0, \"isi\": 0.035422439393446775, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2161677848183947, \"Firing rate\": 164.50071305822243, \"Power\": 164.50071305822243, \"i_spike\": 85.0, \"isi\": 0.04048577743104151, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2837266052282277, \"Firing rate\": 192.18814953172904, \"Power\": 192.18814953172904, \"i_spike\": 99.5, \"isi\": 0.03520251098408982, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.161668219920541, \"Firing rate\": 145.10026978437168, \"Power\": 145.10026978437168, \"i_spike\": 90.0, \"isi\": 0.038734070453864254, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.282132072264165, \"Firing rate\": 191.4838153372827, \"Power\": 191.4838153372827, \"i_spike\": 78.0, \"isi\": 0.043996610728127564, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0841752044242403, \"Firing rate\": 121.38784583039707, \"Power\": 121.38784583039707, \"i_spike\": 100.0, \"isi\": 0.03461991962811, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.447465040329036, \"Firing rate\": 280.1980059869962, \"Power\": 280.1980059869962, \"i_spike\": 79.0, \"isi\": 0.04452724337396078, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.081771364126096, \"Firing rate\": 120.71781445649961, \"Power\": 120.71781445649961, \"i_spike\": 91.0, \"isi\": 0.03856750376815478, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.9391326595223966, \"Firing rate\": 869.2259023424945, \"Power\": 869.2259023424945, \"i_spike\": 79.0, \"isi\": 0.04416616879896912, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8602028751437854, \"Firing rate\": 72.47744501747489, \"Power\": 72.47744501747489, \"i_spike\": 83.0, \"isi\": 0.04119329035591721, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1734123362153537, \"Firing rate\": 149.07758070284467, \"Power\": 149.07758070284467, \"i_spike\": 81.5, \"isi\": 0.0428418950531146, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.192601337300343, \"Firing rate\": 155.812156100815, \"Power\": 155.812156100815, \"i_spike\": 103.0, \"isi\": 0.03371726705897087, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.325538741593283, \"Firing rate\": 211.6112446357301, \"Power\": 211.6112446357301, \"i_spike\": 106.5, \"isi\": 0.03256875829829079, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0351612273023045, \"Firing rate\": 108.43293852986389, \"Power\": 108.43293852986389, \"i_spike\": 92.5, \"isi\": 0.03785767511850996, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3612887627039565, \"Firing rate\": 229.76758666182133, \"Power\": 229.76758666182133, \"i_spike\": 110.5, \"isi\": 0.0316478026663995, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.486602812028755, \"Firing rate\": 306.62164695003077, \"Power\": 306.62164695003077, \"i_spike\": 102.0, \"isi\": 0.03428746701402582, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.26907338816312, \"Firing rate\": 185.81184180415744, \"Power\": 185.81184180415744, \"i_spike\": 108.0, \"isi\": 0.03182822108027605, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2400289413579997, \"Firing rate\": 173.79166395502384, \"Power\": 173.79166395502384, \"i_spike\": 104.0, \"isi\": 0.03361245677188138, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.133061627118738, \"Firing rate\": 135.8506207230094, \"Power\": 135.8506207230094, \"i_spike\": 83.0, \"isi\": 0.04226663021993772, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.055873381143031, \"Firing rate\": 113.72956581458753, \"Power\": 113.72956581458753, \"i_spike\": 96.5, \"isi\": 0.03623434325043876, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077393494053492, \"Firing rate\": 119.50704118553142, \"Power\": 119.50704118553142, \"i_spike\": 86.0, \"isi\": 0.03999884944106042, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7032986753124226, \"Firing rate\": 505.00848528812185, \"Power\": 505.00848528812185, \"i_spike\": 94.5, \"isi\": 0.03642922221630557, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2487291617775735, \"Firing rate\": 177.30833914875691, \"Power\": 177.30833914875691, \"i_spike\": 95.0, \"isi\": 0.035509978483580056, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.6190312582185733, \"Firing rate\": 415.9405466161257, \"Power\": 415.9405466161257, \"i_spike\": 92.5, \"isi\": 0.03739794009579709, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2214636345147007, \"Firing rate\": 166.51893879392634, \"Power\": 166.51893879392634, \"i_spike\": 104.5, \"isi\": 0.03334968571838423, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.050033014448482, \"Firing rate\": 1122.1037517902018, \"Power\": 1122.1037517902018, \"i_spike\": 109.0, \"isi\": 0.03174363047623115, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0201521306738686, \"Firing rate\": 104.7495414963806, \"Power\": 104.7495414963806, \"i_spike\": 84.0, \"isi\": 0.04150443974238124, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.394368017909442, \"Firing rate\": 247.95222963713232, \"Power\": 247.95222963713232, \"i_spike\": 97.5, \"isi\": 0.034832136270722715, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.329502121112529, \"Firing rate\": 213.551251595498, \"Power\": 213.551251595498, \"i_spike\": 119.5, \"isi\": 0.02914255148960452, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.296426000518237, \"Firing rate\": 197.89098058624842, \"Power\": 197.89098058624842, \"i_spike\": 100.5, \"isi\": 0.03453794209724264, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9526063135638236, \"Firing rate\": 89.66156470356117, \"Power\": 89.66156470356117, \"i_spike\": 87.0, \"isi\": 0.0403252649629643, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1801699394018295, \"Firing rate\": 151.41536207419279, \"Power\": 151.41536207419279, \"i_spike\": 95.0, \"isi\": 0.0369374859002085, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9603011698286221, \"Firing rate\": 91.26435100880892, \"Power\": 91.26435100880892, \"i_spike\": 100.5, \"isi\": 0.03470962985025618, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1497807834136973, \"Firing rate\": 141.18247252479557, \"Power\": 141.18247252479557, \"i_spike\": 97.0, \"isi\": 0.03544340361561801, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.149622075943538, \"Firing rate\": 141.13088858728008, \"Power\": 141.13088858728008, \"i_spike\": 98.5, \"isi\": 0.03458549884764996, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.056159126623185, \"Firing rate\": 113.80441917809635, \"Power\": 113.80441917809635, \"i_spike\": 87.0, \"isi\": 0.03968042681843487, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3917479076029613, \"Firing rate\": 246.46083050660826, \"Power\": 246.46083050660826, \"i_spike\": 98.5, \"isi\": 0.035535360449709036, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0750924013179355, \"Firing rate\": 118.87551223280595, \"Power\": 118.87551223280595, \"i_spike\": 94.0, \"isi\": 0.03719199644955143, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.489337914838964, \"Firing rate\": 308.5587843479223, \"Power\": 308.5587843479223, \"i_spike\": 95.5, \"isi\": 0.03556131746210524, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.4520230739574873, \"Firing rate\": 283.154243094607, \"Power\": 283.154243094607, \"i_spike\": 107.0, \"isi\": 0.032710924682864184, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.323245560174936, \"Firing rate\": 210.49683012562227, \"Power\": 210.49683012562227, \"i_spike\": 107.5, \"isi\": 0.03260971008319308, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4551248825615755, \"Firing rate\": 285.183820345654, \"Power\": 285.183820345654, \"i_spike\": 119.5, \"isi\": 0.029121401254440946, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2034473494582008, \"Firing rate\": 159.75238457442458, \"Power\": 159.75238457442458, \"i_spike\": 117.5, \"isi\": 0.02942985917936488, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.185090643987662, \"Firing rate\": 153.1407056710173, \"Power\": 153.1407056710173, \"i_spike\": 107.5, \"isi\": 0.03182653781887098, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3319515266612205, \"Firing rate\": 214.7590759585309, \"Power\": 214.7590759585309, \"i_spike\": 125.0, \"isi\": 0.028084978019438673, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6162367962967754, \"Firing rate\": 413.2727749153624, \"Power\": 413.2727749153624, \"i_spike\": 106.5, \"isi\": 0.032651038144998264, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.251599839982757, \"Firing rate\": 178.48422588668325, \"Power\": 178.48422588668325, \"i_spike\": 112.0, \"isi\": 0.031077478691086027, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.700871783939369, \"Firing rate\": 502.194305618395, \"Power\": 502.194305618395, \"i_spike\": 94.0, \"isi\": 0.036901644723313094, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.314948450805621, \"Firing rate\": 206.5135017156736, \"Power\": 206.5135017156736, \"i_spike\": 93.5, \"isi\": 0.03744836002524842, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6205392303439177, \"Firing rate\": 417.3872998602738, \"Power\": 417.3872998602738, \"i_spike\": 112.5, \"isi\": 0.030901272636151618, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5103170415704716, \"Firing rate\": 323.82997146198255, \"Power\": 323.82997146198255, \"i_spike\": 118.5, \"isi\": 0.0292124077372491, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.267328656385887, \"Firing rate\": 185.06685998516417, \"Power\": 185.06685998516417, \"i_spike\": 112.0, \"isi\": 0.030900503373377113, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3735439867744246, \"Firing rate\": 236.34367636856805, \"Power\": 236.34367636856805, \"i_spike\": 111.5, \"isi\": 0.031086261056407043, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3925644433143702, \"Firing rate\": 246.9246479862117, \"Power\": 246.9246479862117, \"i_spike\": 116.5, \"isi\": 0.0291953589973033, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.561842054638256, \"Firing rate\": 364.6213163680733, \"Power\": 364.6213163680733, \"i_spike\": 111.5, \"isi\": 0.031029868021617713, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.171212511252901, \"Firing rate\": 148.32436961836746, \"Power\": 148.32436961836746, \"i_spike\": 98.0, \"isi\": 0.03548246558301557, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.305560627357594, \"Firing rate\": 202.09735394991617, \"Power\": 202.09735394991617, \"i_spike\": 116.5, \"isi\": 0.029539429675363767, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.230937526831537, \"Firing rate\": 170.19136708674088, \"Power\": 170.19136708674088, \"i_spike\": 109.5, \"isi\": 0.031509671304326574, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8998022408045885, \"Firing rate\": 793.9666138437617, \"Power\": 793.9666138437617, \"i_spike\": 117.0, \"isi\": 0.029395611103945375, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.318691352753477, \"Firing rate\": 208.3009989753317, \"Power\": 208.3009989753317, \"i_spike\": 114.0, \"isi\": 0.03080051727849002, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5660625459247224, \"Firing rate\": 368.181994406344, \"Power\": 368.181994406344, \"i_spike\": 110.5, \"isi\": 0.03146794625834939, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.09200788071158, \"Firing rate\": 123.59698611612541, \"Power\": 123.59698611612541, \"i_spike\": 105.5, \"isi\": 0.03222740436284654, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3257979747918998, \"Firing rate\": 211.73759446862695, \"Power\": 211.73759446862695, \"i_spike\": 99.0, \"isi\": 0.035110212287434966, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6983799828455997, \"Firing rate\": 499.3211738782113, \"Power\": 499.3211738782113, \"i_spike\": 100.5, \"isi\": 0.03493647252317627, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.295038880371647, \"Firing rate\": 197.25993258831056, \"Power\": 197.25993258831056, \"i_spike\": 99.5, \"isi\": 0.034805791974127157, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189777301058197, \"Firing rate\": 262.40839812996177, \"Power\": 262.40839812996177, \"i_spike\": 114.0, \"isi\": 0.030289604306854862, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.108818343863044, \"Firing rate\": 128.47491643129774, \"Power\": 128.47491643129774, \"i_spike\": 105.0, \"isi\": 0.033402650086276076, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3301618907903223, \"Firing rate\": 213.8759200460872, \"Power\": 213.8759200460872, \"i_spike\": 102.0, \"isi\": 0.033515540373164496, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2662952548825976, \"Firing rate\": 184.62701784490469, \"Power\": 184.62701784490469, \"i_spike\": 99.5, \"isi\": 0.03522950669230892, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.431293700022412, \"Firing rate\": 269.9564447816099, \"Power\": 269.9564447816099, \"i_spike\": 112.5, \"isi\": 0.031214818356640563, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3379956540094025, \"Firing rate\": 217.76879800918366, \"Power\": 217.76879800918366, \"i_spike\": 128.0, \"isi\": 0.027142001158740867, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 4.268793452708704, \"Firing rate\": 18569.21106902568, \"Power\": 18569.21106902568, \"i_spike\": 112.5, \"isi\": 0.030884711280865364, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.470335706667271, \"Firing rate\": 295.3491373163173, \"Power\": 295.3491373163173, \"i_spike\": 118.5, \"isi\": 0.029429433800978892, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2298279031444963, \"Firing rate\": 169.7570826751943, \"Power\": 169.7570826751943, \"i_spike\": 115.5, \"isi\": 0.030066265039225337, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.079781857998895, \"Firing rate\": 120.16607002272158, \"Power\": 120.16607002272158, \"i_spike\": 112.5, \"isi\": 0.031040291113719316, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3243380859972738, \"Firing rate\": 211.02702965366592, \"Power\": 211.02702965366592, \"i_spike\": 115.5, \"isi\": 0.03017297418481671, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.376992751237567, \"Firing rate\": 238.22797066527903, \"Power\": 238.22797066527903, \"i_spike\": 110.0, \"isi\": 0.03125175833885984, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.530486613796888, \"Firing rate\": 339.22403352142646, \"Power\": 339.22403352142646, \"i_spike\": 108.5, \"isi\": 0.03222598156798059, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4983008808245897, \"Firing rate\": 314.99298413824465, \"Power\": 314.99298413824465, \"i_spike\": 116.5, \"isi\": 0.029967692171019168, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.482166228126963, \"Firing rate\": 303.5052641678235, \"Power\": 303.5052641678235, \"i_spike\": 124.5, \"isi\": 0.02742142830301335, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6952270146103454, \"Firing rate\": 495.70924045465966, \"Power\": 495.70924045465966, \"i_spike\": 116.5, \"isi\": 0.029805997031659384, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 1.969829747877291, \"Firing rate\": 93.288851814792, \"Power\": 93.288851814792, \"i_spike\": 104.5, \"isi\": 0.033232072449794876, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3040227572766634, \"Firing rate\": 201.3829772917563, \"Power\": 201.3829772917563, \"i_spike\": 118.5, \"isi\": 0.02930928089506225, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2482213585722888, \"Firing rate\": 177.10114074206854, \"Power\": 177.10114074206854, \"i_spike\": 118.5, \"isi\": 0.02923254019041047, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.302306969151288, \"Firing rate\": 200.58893343119396, \"Power\": 200.58893343119396, \"i_spike\": 114.0, \"isi\": 0.030554998388585986, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1470214089632194, \"Firing rate\": 140.28828593141267, \"Power\": 140.28828593141267, \"i_spike\": 123.0, \"isi\": 0.02824600472582251, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1317778042739737, \"Firing rate\": 135.44962414921912, \"Power\": 135.44962414921912, \"i_spike\": 107.5, \"isi\": 0.03260242125359381, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.861629232615016, \"Firing rate\": 727.1587469920275, \"Power\": 727.1587469920275, \"i_spike\": 121.5, \"isi\": 0.02876842284627423, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.309175796871508, \"Firing rate\": 203.7866813288123, \"Power\": 203.7866813288123, \"i_spike\": 127.0, \"isi\": 0.02726151253501496, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1426446687258776, \"Firing rate\": 138.88158641854218, \"Power\": 138.88158641854218, \"i_spike\": 120.0, \"isi\": 0.02911404261537866, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4489418426509477, \"Firing rate\": 281.15243076571574, \"Power\": 281.15243076571574, \"i_spike\": 128.5, \"isi\": 0.026789992139581283, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.412848701632391, \"Firing rate\": 258.73113973987586, \"Power\": 258.73113973987586, \"i_spike\": 124.0, \"isi\": 0.028201124990781163, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.710877629385823, \"Firing rate\": 513.8988305482127, \"Power\": 513.8988305482127, \"i_spike\": 119.0, \"isi\": 0.0293764992264836, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.991538408306236, \"Firing rate\": 980.7050424652082, \"Power\": 980.7050424652082, \"i_spike\": 135.0, \"isi\": 0.025953587990479317, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2762121037042795, \"Firing rate\": 188.89136444020025, \"Power\": 188.89136444020025, \"i_spike\": 122.0, \"isi\": 0.028669385615676706, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.7177018467167304, \"Firing rate\": 522.0376749188929, \"Power\": 522.0376749188929, \"i_spike\": 138.0, \"isi\": 0.02496409561586277, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3914116825786387, \"Firing rate\": 246.27009764338933, \"Power\": 246.27009764338933, \"i_spike\": 110.5, \"isi\": 0.0316618510656651, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6892037162497906, \"Firing rate\": 488.8816272272226, \"Power\": 488.8816272272226, \"i_spike\": 131.5, \"isi\": 0.02658745064897301, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4434824501248773, \"Firing rate\": 277.64026491830793, \"Power\": 277.64026491830793, \"i_spike\": 120.0, \"isi\": 0.0290789856927443, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.238506636309727, \"Firing rate\": 173.18354941508804, \"Power\": 173.18354941508804, \"i_spike\": 121.0, \"isi\": 0.028971993333475, \"combined_condition\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "BayesWindow(df=df, y='Log power', treatment='stim', group='mouse').plot(x='mouse').facet(column='stim')\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-04c64c59d77a496287b685048edf556b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-04c64c59d77a496287b685048edf556b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-04c64c59d77a496287b685048edf556b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-ce9fca907dbdeef07d390c8383190ed8\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"mouse\"}}, \"spec\": {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}, \"title\": \"Log power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Log power\", \"scale\": {\"clamp\": true, \"domain\": [1.7698315149223656, 2.78498263664019], \"zero\": false}}}}]}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-ce9fca907dbdeef07d390c8383190ed8\": [{\"stim\": 0, \"mouse\": 0, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.955295818792631, \"Firing rate\": 90.21854501261329, \"Power\": 90.21854501261329, \"i_spike\": 47.5, \"isi\": 0.0731915996436363, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6026484195029185, \"Firing rate\": 40.054232969747986, \"Power\": 40.054232969747986, \"i_spike\": 39.5, \"isi\": 0.08505458474637603, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1244493253919545, \"Firing rate\": 133.18316316728252, \"Power\": 133.18316316728252, \"i_spike\": 42.5, \"isi\": 0.08224071637572535, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8708094709723913, \"Firing rate\": 74.2693239984203, \"Power\": 74.2693239984203, \"i_spike\": 33.5, \"isi\": 0.10505328377444978, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9711426825012743, \"Firing rate\": 93.57130415068605, \"Power\": 93.57130415068605, \"i_spike\": 40.5, \"isi\": 0.08430258433195234, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8590874397971908, \"Firing rate\": 72.29153389710372, \"Power\": 72.29153389710372, \"i_spike\": 44.0, \"isi\": 0.0795434324837374, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0132461342812213, \"Firing rate\": 103.09702522654109, \"Power\": 103.09702522654109, \"i_spike\": 47.5, \"isi\": 0.07286723599674903, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0127266901312217, \"Firing rate\": 102.97378826377438, \"Power\": 102.97378826377438, \"i_spike\": 39.0, \"isi\": 0.08914566084967086, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503131681143027, \"Firing rate\": 56.27469736390204, \"Power\": 56.27469736390204, \"i_spike\": 40.0, \"isi\": 0.08700029609063652, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1169032082350827, \"Firing rate\": 130.88901764671587, \"Power\": 130.88901764671587, \"i_spike\": 62.0, \"isi\": 0.05659763212840744, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8770680415974088, \"Firing rate\": 75.34736023774802, \"Power\": 75.34736023774802, \"i_spike\": 39.0, \"isi\": 0.09009246539035318, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9310965336855828, \"Firing rate\": 85.32897596494497, \"Power\": 85.32897596494497, \"i_spike\": 34.0, \"isi\": 0.10149738234291991, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.5333013820605306, \"Firing rate\": 34.14297672922771, \"Power\": 34.14297672922771, \"i_spike\": 40.5, \"isi\": 0.08685116325741157, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.030855072834198, \"Firing rate\": 107.36310742084633, \"Power\": 107.36310742084633, \"i_spike\": 54.5, \"isi\": 0.059448248477706966, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.794551727002911, \"Firing rate\": 623.0913568201987, \"Power\": 623.0913568201987, \"i_spike\": 48.5, \"isi\": 0.0713719442616052, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7955427567112552, \"Firing rate\": 62.451483134242046, \"Power\": 62.451483134242046, \"i_spike\": 35.5, \"isi\": 0.09057886752422038, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9082000854510324, \"Firing rate\": 80.94687466873414, \"Power\": 80.94687466873414, \"i_spike\": 53.0, \"isi\": 0.06529444835938969, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6555352624426098, \"Firing rate\": 45.24131944286433, \"Power\": 45.24131944286433, \"i_spike\": 43.5, \"isi\": 0.0768533496686384, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.177328557623848, \"Firing rate\": 150.42795711808552, \"Power\": 150.42795711808552, \"i_spike\": 34.5, \"isi\": 0.09830229180875018, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8645215585407622, \"Firing rate\": 73.20176599287585, \"Power\": 73.20176599287585, \"i_spike\": 55.5, \"isi\": 0.06179006984103724, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.535025958406892, \"Firing rate\": 34.27882748831966, \"Power\": 34.27882748831966, \"i_spike\": 34.5, \"isi\": 0.09915726015773765, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.32247920697616, \"Firing rate\": 210.125716326415, \"Power\": 210.125716326415, \"i_spike\": 33.0, \"isi\": 0.10502063399832753, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.43733847759269, \"Firing rate\": 273.74013531042965, \"Power\": 273.74013531042965, \"i_spike\": 56.0, \"isi\": 0.061967941571928455, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7969419629962189, \"Firing rate\": 62.653013263585784, \"Power\": 62.653013263585784, \"i_spike\": 37.0, \"isi\": 0.09259944757473725, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9846064873802938, \"Firing rate\": 96.51759403196418, \"Power\": 96.51759403196418, \"i_spike\": 41.5, \"isi\": 0.08460263304467304, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503293230777222, \"Firing rate\": 56.27679071904272, \"Power\": 56.27679071904272, \"i_spike\": 42.5, \"isi\": 0.07988986525214349, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.4286782943328151, \"Firing rate\": 26.83356000776027, \"Power\": 26.83356000776027, \"i_spike\": 35.5, \"isi\": 0.09874338503855341, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1383088558675207, \"Firing rate\": 137.50194957559475, \"Power\": 137.50194957559475, \"i_spike\": 48.5, \"isi\": 0.07210812725187593, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0035263866631934, \"Firing rate\": 100.81528603885884, \"Power\": 100.81528603885884, \"i_spike\": 49.5, \"isi\": 0.0672853207791876, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 0, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6296351063659993, \"Firing rate\": 42.62212577953956, \"Power\": 42.62212577953956, \"i_spike\": 41.5, \"isi\": 0.0790188469593832, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.193262117122394, \"Firing rate\": 156.04940501335037, \"Power\": 156.04940501335037, \"i_spike\": 48.0, \"isi\": 0.07263392600048459, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9760548637782647, \"Firing rate\": 94.63567056548113, \"Power\": 94.63567056548113, \"i_spike\": 44.5, \"isi\": 0.0776680429623508, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6250730368645014, \"Firing rate\": 42.17674276093685, \"Power\": 42.17674276093685, \"i_spike\": 42.5, \"isi\": 0.08104853472101264, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.491206995038427, \"Firing rate\": 309.8895954508339, \"Power\": 309.8895954508339, \"i_spike\": 51.5, \"isi\": 0.06708115735632907, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3589480963384455, \"Firing rate\": 228.53256618481504, \"Power\": 228.53256618481504, \"i_spike\": 47.5, \"isi\": 0.07348993800862964, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9281754169377023, \"Firing rate\": 84.75696889405249, \"Power\": 84.75696889405249, \"i_spike\": 53.0, \"isi\": 0.06509876660602372, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9843209349691886, \"Firing rate\": 96.45415373032593, \"Power\": 96.45415373032593, \"i_spike\": 59.5, \"isi\": 0.05870376554536328, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7638817011892445, \"Firing rate\": 58.06062428577546, \"Power\": 58.06062428577546, \"i_spike\": 52.0, \"isi\": 0.06566204692122644, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.650862407397869, \"Firing rate\": 44.75714827077759, \"Power\": 44.75714827077759, \"i_spike\": 49.0, \"isi\": 0.07040754805798212, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0583883119213846, \"Firing rate\": 114.39006635603113, \"Power\": 114.39006635603113, \"i_spike\": 51.0, \"isi\": 0.06837143070736648, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2173425763203, \"Firing rate\": 164.9462993258368, \"Power\": 164.9462993258368, \"i_spike\": 53.5, \"isi\": 0.06501277873096038, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2107084188475756, \"Firing rate\": 162.44577441851425, \"Power\": 162.44577441851425, \"i_spike\": 49.0, \"isi\": 0.06869119253150469, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5946141113333705, \"Firing rate\": 39.320054519388265, \"Power\": 39.320054519388265, \"i_spike\": 43.0, \"isi\": 0.08147481958019963, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.211944529140798, \"Firing rate\": 162.90879418557492, \"Power\": 162.90879418557492, \"i_spike\": 55.5, \"isi\": 0.06320352970416626, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5907555117125005, \"Firing rate\": 389.7225286301253, \"Power\": 389.7225286301253, \"i_spike\": 48.5, \"isi\": 0.07106759705283149, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.197050324722152, \"Firing rate\": 157.4165263375544, \"Power\": 157.4165263375544, \"i_spike\": 42.5, \"isi\": 0.08120962422114071, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.900738498847488, \"Firing rate\": 79.56801043564009, \"Power\": 79.56801043564009, \"i_spike\": 43.5, \"isi\": 0.07999246270715814, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7701446630135824, \"Firing rate\": 58.90398311997898, \"Power\": 58.90398311997898, \"i_spike\": 42.0, \"isi\": 0.08041029857361554, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5942453724234489, \"Firing rate\": 39.28668388897537, \"Power\": 39.28668388897537, \"i_spike\": 32.5, \"isi\": 0.1019318698052081, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6923353756705557, \"Firing rate\": 49.24196506231455, \"Power\": 49.24196506231455, \"i_spike\": 44.0, \"isi\": 0.07851300689834464, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9096430648934821, \"Firing rate\": 81.21627467876483, \"Power\": 81.21627467876483, \"i_spike\": 42.0, \"isi\": 0.08279141280781681, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7227625327508387, \"Firing rate\": 52.815638294554915, \"Power\": 52.815638294554915, \"i_spike\": 47.0, \"isi\": 0.07465675585663739, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0772331102040815, \"Firing rate\": 119.4629156868915, \"Power\": 119.4629156868915, \"i_spike\": 45.0, \"isi\": 0.07778279269254963, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8962156003531803, \"Firing rate\": 78.7436606258303, \"Power\": 78.7436606258303, \"i_spike\": 45.0, \"isi\": 0.07723000353960975, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.539325164353972, \"Firing rate\": 34.61984860582479, \"Power\": 34.61984860582479, \"i_spike\": 43.5, \"isi\": 0.08038783649040848, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.795290559690197, \"Firing rate\": 62.41522776726645, \"Power\": 62.41522776726645, \"i_spike\": 51.0, \"isi\": 0.06863876971272939, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7829257189432979, \"Firing rate\": 60.6632563219068, \"Power\": 60.6632563219068, \"i_spike\": 51.5, \"isi\": 0.06724356364949484, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8506258960042894, \"Firing rate\": 70.89667964004052, \"Power\": 70.89667964004052, \"i_spike\": 53.0, \"isi\": 0.06603508775646316, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9623740441999131, \"Firing rate\": 91.70099419760025, \"Power\": 91.70099419760025, \"i_spike\": 45.0, \"isi\": 0.0739363878905739, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 1, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0543726256433428, \"Firing rate\": 113.33723822345725, \"Power\": 113.33723822345725, \"i_spike\": 59.5, \"isi\": 0.05882184181366276, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0311570012276237, \"Firing rate\": 107.4377739030315, \"Power\": 107.4377739030315, \"i_spike\": 43.5, \"isi\": 0.08064172994284798, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.149704072470153, \"Firing rate\": 141.15753717632737, \"Power\": 141.15753717632737, \"i_spike\": 59.0, \"isi\": 0.059210435905617934, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0114163933193723, \"Firing rate\": 102.6635773453862, \"Power\": 102.6635773453862, \"i_spike\": 55.0, \"isi\": 0.06332773568755358, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9540841070386274, \"Firing rate\": 89.96717983510673, \"Power\": 89.96717983510673, \"i_spike\": 42.5, \"isi\": 0.08201299481958542, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8156677764444182, \"Firing rate\": 65.41355865573313, \"Power\": 65.41355865573313, \"i_spike\": 54.0, \"isi\": 0.06526466311001969, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.893859348236818, \"Firing rate\": 78.31759602448699, \"Power\": 78.31759602448699, \"i_spike\": 56.5, \"isi\": 0.06184020841304989, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.773984421574805, \"Firing rate\": 59.427084135210976, \"Power\": 59.427084135210976, \"i_spike\": 60.0, \"isi\": 0.058270067505733734, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.210840290387196, \"Firing rate\": 162.49510782693136, \"Power\": 162.49510782693136, \"i_spike\": 56.5, \"isi\": 0.06020300273286523, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9713400241427212, \"Firing rate\": 93.61383223125311, \"Power\": 93.61383223125311, \"i_spike\": 61.0, \"isi\": 0.0543980735122145, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8497634918355093, \"Firing rate\": 70.75603561035722, \"Power\": 70.75603561035722, \"i_spike\": 47.5, \"isi\": 0.07274197195399083, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9624750863491771, \"Firing rate\": 91.72233166302841, \"Power\": 91.72233166302841, \"i_spike\": 48.5, \"isi\": 0.07010114635983886, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.855302039054747, \"Firing rate\": 71.66416401500264, \"Power\": 71.66416401500264, \"i_spike\": 46.0, \"isi\": 0.0766119040381658, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.046426832369158, \"Firing rate\": 111.28248941720267, \"Power\": 111.28248941720267, \"i_spike\": 64.0, \"isi\": 0.05429137856724891, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7100483491678449, \"Firing rate\": 51.29184830393363, \"Power\": 51.29184830393363, \"i_spike\": 49.5, \"isi\": 0.0703751778152302, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3453546584516265, \"Firing rate\": 221.49027300778377, \"Power\": 221.49027300778377, \"i_spike\": 59.5, \"isi\": 0.058785042141719916, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.875277533612671, \"Firing rate\": 75.03735784498373, \"Power\": 75.03735784498373, \"i_spike\": 56.0, \"isi\": 0.06218241581461111, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6818911486395558, \"Firing rate\": 48.071884620822175, \"Power\": 48.071884620822175, \"i_spike\": 56.0, \"isi\": 0.06219590540248409, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7807624476641064, \"Firing rate\": 60.36183691888134, \"Power\": 60.36183691888134, \"i_spike\": 46.0, \"isi\": 0.07429803181700052, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7183011441323788, \"Firing rate\": 52.27585493529653, \"Power\": 52.27585493529653, \"i_spike\": 52.5, \"isi\": 0.06577263809678958, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.763346825231255, \"Firing rate\": 57.98916098746875, \"Power\": 57.98916098746875, \"i_spike\": 48.5, \"isi\": 0.07131264606340101, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.835065458404151, \"Firing rate\": 68.40147366385926, \"Power\": 68.40147366385926, \"i_spike\": 49.0, \"isi\": 0.07194196841840346, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.924715551322173, \"Firing rate\": 84.08442357857703, \"Power\": 84.08442357857703, \"i_spike\": 55.5, \"isi\": 0.06318891040674948, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.017073838923778, \"Firing rate\": 104.00969885083077, \"Power\": 104.00969885083077, \"i_spike\": 49.0, \"isi\": 0.07044066419783745, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7143174946332422, \"Firing rate\": 517.9853711282016, \"Power\": 517.9853711282016, \"i_spike\": 65.0, \"isi\": 0.052930696952406625, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.974181294239221, \"Firing rate\": 94.22828660927348, \"Power\": 94.22828660927348, \"i_spike\": 58.0, \"isi\": 0.060053602856178986, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9399526356112446, \"Firing rate\": 87.08686073800901, \"Power\": 87.08686073800901, \"i_spike\": 53.0, \"isi\": 0.06646977245711418, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6853656755730138, \"Firing rate\": 48.45802119713409, \"Power\": 48.45802119713409, \"i_spike\": 40.0, \"isi\": 0.08662078631540625, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9336719560475775, \"Firing rate\": 85.83649113967905, \"Power\": 85.83649113967905, \"i_spike\": 57.0, \"isi\": 0.060295111833858245, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0093234248133296, \"Firing rate\": 102.17000739461349, \"Power\": 102.17000739461349, \"i_spike\": 49.0, \"isi\": 0.06980898473808321, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 2, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6653323391451258, \"Firing rate\": 46.27349888819327, \"Power\": 46.27349888819327, \"i_spike\": 52.5, \"isi\": 0.06664468983496366, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.319563597750638, \"Firing rate\": 208.71977491726287, \"Power\": 208.71977491726287, \"i_spike\": 62.5, \"isi\": 0.054778780974004924, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9501238550989324, \"Firing rate\": 89.15051474767834, \"Power\": 89.15051474767834, \"i_spike\": 65.0, \"isi\": 0.052393936924168064, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.058384385790344, \"Firing rate\": 114.38903224581574, \"Power\": 114.38903224581574, \"i_spike\": 67.0, \"isi\": 0.051939822712101694, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.341203185363342, \"Firing rate\": 219.38310826468677, \"Power\": 219.38310826468677, \"i_spike\": 63.5, \"isi\": 0.054996827366133136, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9819991440519158, \"Firing rate\": 95.9398740641521, \"Power\": 95.9398740641521, \"i_spike\": 56.0, \"isi\": 0.06266914967033387, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.369563712635469, \"Firing rate\": 234.18750118502433, \"Power\": 234.18750118502433, \"i_spike\": 66.0, \"isi\": 0.05307466490753688, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8499974740031297, \"Firing rate\": 70.79416667549492, \"Power\": 70.79416667549492, \"i_spike\": 50.0, \"isi\": 0.06964434411828664, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4140871865689233, \"Firing rate\": 259.4700207563056, \"Power\": 259.4700207563056, \"i_spike\": 57.5, \"isi\": 0.05932812658617926, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2992730643707255, \"Firing rate\": 199.19253762816092, \"Power\": 199.19253762816092, \"i_spike\": 69.0, \"isi\": 0.0505200086604451, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1143279384255944, \"Firing rate\": 130.11517148140396, \"Power\": 130.11517148140396, \"i_spike\": 58.0, \"isi\": 0.06039580425018153, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1347425595996863, \"Firing rate\": 136.37744808427303, \"Power\": 136.37744808427303, \"i_spike\": 57.5, \"isi\": 0.06059068471302143, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9227227083724787, \"Firing rate\": 83.69947007723921, \"Power\": 83.69947007723921, \"i_spike\": 74.5, \"isi\": 0.04700841293964799, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9356641657046738, \"Firing rate\": 86.23114755907184, \"Power\": 86.23114755907184, \"i_spike\": 59.0, \"isi\": 0.05819722837595124, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1650029836128866, \"Firing rate\": 146.21872196813922, \"Power\": 146.21872196813922, \"i_spike\": 66.5, \"isi\": 0.05230105943774251, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.090242481076867, \"Firing rate\": 123.09558626462615, \"Power\": 123.09558626462615, \"i_spike\": 57.5, \"isi\": 0.059929836211731397, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9223690348846298, \"Firing rate\": 83.63133604719516, \"Power\": 83.63133604719516, \"i_spike\": 60.5, \"isi\": 0.05806760763773719, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1491227759212217, \"Firing rate\": 140.9687263512985, \"Power\": 140.9687263512985, \"i_spike\": 54.5, \"isi\": 0.06367419112012151, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3941117654392667, \"Firing rate\": 247.80597028438038, \"Power\": 247.80597028438038, \"i_spike\": 63.0, \"isi\": 0.05461154211696954, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9896786925487997, \"Firing rate\": 97.65144913558673, \"Power\": 97.65144913558673, \"i_spike\": 62.5, \"isi\": 0.05504185225729406, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.7731494316094232, \"Firing rate\": 59.31293728328963, \"Power\": 59.31293728328963, \"i_spike\": 55.0, \"isi\": 0.06267698786541855, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8554169772491347, \"Firing rate\": 71.68313280237724, \"Power\": 71.68313280237724, \"i_spike\": 60.5, \"isi\": 0.056999565632898194, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3716727528341055, \"Firing rate\": 235.32753886515357, \"Power\": 235.32753886515357, \"i_spike\": 52.0, \"isi\": 0.067154049479885, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2364092112497285, \"Firing rate\": 172.34917594410877, \"Power\": 172.34917594410877, \"i_spike\": 59.5, \"isi\": 0.05869502074828589, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2557126583819076, \"Firing rate\": 180.18252074391486, \"Power\": 180.18252074391486, \"i_spike\": 73.5, \"isi\": 0.04743594072717539, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.7433869258557073, \"Firing rate\": 553.8433249443033, \"Power\": 553.8433249443033, \"i_spike\": 55.0, \"isi\": 0.06360854706023654, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9410922920516542, \"Firing rate\": 87.31569035109068, \"Power\": 87.31569035109068, \"i_spike\": 65.5, \"isi\": 0.052877411734321145, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.053756802379095, \"Firing rate\": 113.17664155543305, \"Power\": 113.17664155543305, \"i_spike\": 54.0, \"isi\": 0.06436186527784456, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.034873477705347, \"Firing rate\": 108.36111813754236, \"Power\": 108.36111813754236, \"i_spike\": 66.5, \"isi\": 0.050938903955247916, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9885417764206283, \"Firing rate\": 97.39614698417968, \"Power\": 97.39614698417968, \"i_spike\": 60.0, \"isi\": 0.05780359441402076, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 3, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4369749555623357, \"Firing rate\": 273.51109962529904, \"Power\": 273.51109962529904, \"i_spike\": 64.0, \"isi\": 0.053993497700095504, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1065489309483487, \"Firing rate\": 127.8053196733479, \"Power\": 127.8053196733479, \"i_spike\": 66.0, \"isi\": 0.05304312813996159, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9049237369041854, \"Firing rate\": 80.33850335646146, \"Power\": 80.33850335646146, \"i_spike\": 74.0, \"isi\": 0.046752172315214786, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.089842705284853, \"Firing rate\": 122.98232672563184, \"Power\": 122.98232672563184, \"i_spike\": 62.5, \"isi\": 0.055459566693195586, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0542996219949314, \"Firing rate\": 113.3181881621406, \"Power\": 113.3181881621406, \"i_spike\": 68.5, \"isi\": 0.04886679113481873, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5270188880084747, \"Firing rate\": 336.5262050014474, \"Power\": 336.5262050014474, \"i_spike\": 77.0, \"isi\": 0.045084314963419254, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8366391281202479, \"Firing rate\": 68.64977657243634, \"Power\": 68.64977657243634, \"i_spike\": 70.5, \"isi\": 0.04950827198418861, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9617130502576103, \"Firing rate\": 91.56153191880342, \"Power\": 91.56153191880342, \"i_spike\": 68.5, \"isi\": 0.05136728010783104, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.241494871870913, \"Firing rate\": 174.37927667202098, \"Power\": 174.37927667202098, \"i_spike\": 63.0, \"isi\": 0.05576348859764074, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 3.1251395921423315, \"Firing rate\": 1333.9501252294517, \"Power\": 1333.9501252294517, \"i_spike\": 64.5, \"isi\": 0.054262100729024564, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8958624054342972, \"Firing rate\": 78.67964748291678, \"Power\": 78.67964748291678, \"i_spike\": 74.0, \"isi\": 0.046877125846140295, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5517732739731294, \"Firing rate\": 356.2650945497233, \"Power\": 356.2650945497233, \"i_spike\": 76.5, \"isi\": 0.04517211033649603, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0919634725229534, \"Firing rate\": 123.58434852138122, \"Power\": 123.58434852138122, \"i_spike\": 68.0, \"isi\": 0.05101734433625525, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3525110631387873, \"Firing rate\": 225.17027754817553, \"Power\": 225.17027754817553, \"i_spike\": 65.0, \"isi\": 0.05404540309717516, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.7819954120481858, \"Firing rate\": 60.53344798762198, \"Power\": 60.53344798762198, \"i_spike\": 53.0, \"isi\": 0.06467002728543748, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8422213318301035, \"Firing rate\": 69.5378616839905, \"Power\": 69.5378616839905, \"i_spike\": 69.0, \"isi\": 0.05037331163693314, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1868975598998643, \"Firing rate\": 153.77918677144316, \"Power\": 153.77918677144316, \"i_spike\": 70.0, \"isi\": 0.049775509977722336, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9726367908939046, \"Firing rate\": 93.89377298287559, \"Power\": 93.89377298287559, \"i_spike\": 75.5, \"isi\": 0.04639225026242182, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.778101000828387, \"Firing rate\": 59.99305816899431, \"Power\": 59.99305816899431, \"i_spike\": 68.5, \"isi\": 0.05075104338195106, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9121660273135348, \"Firing rate\": 81.68946039587414, \"Power\": 81.68946039587414, \"i_spike\": 64.0, \"isi\": 0.05481280145440375, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0478218930526535, \"Firing rate\": 111.64053089208255, \"Power\": 111.64053089208255, \"i_spike\": 70.0, \"isi\": 0.0489888087012864, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.117471278561992, \"Firing rate\": 131.0603364640247, \"Power\": 131.0603364640247, \"i_spike\": 65.5, \"isi\": 0.051671766893329675, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.931167591711936, \"Firing rate\": 853.4293839120918, \"Power\": 853.4293839120918, \"i_spike\": 63.0, \"isi\": 0.05525138390063168, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.277774705751867, \"Firing rate\": 189.57222427760698, \"Power\": 189.57222427760698, \"i_spike\": 78.0, \"isi\": 0.04456622398656536, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.845684289414062, \"Firing rate\": 70.09455604474384, \"Power\": 70.09455604474384, \"i_spike\": 63.5, \"isi\": 0.05469869440456847, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10431894281778, \"Firing rate\": 127.15075486242938, \"Power\": 127.15075486242938, \"i_spike\": 67.0, \"isi\": 0.05227215134911894, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.033552725921547, \"Firing rate\": 108.03207702586286, \"Power\": 108.03207702586286, \"i_spike\": 57.5, \"isi\": 0.060347774168580594, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1643005604050174, \"Firing rate\": 145.98242053251482, \"Power\": 145.98242053251482, \"i_spike\": 72.5, \"isi\": 0.04783783469680652, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0012121960819167, \"Firing rate\": 100.27950836105705, \"Power\": 100.27950836105705, \"i_spike\": 71.5, \"isi\": 0.048990832561469015, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9583920039283502, \"Firing rate\": 90.86403192498832, \"Power\": 90.86403192498832, \"i_spike\": 76.0, \"isi\": 0.04556701067411184, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 4, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1124885757403176, \"Firing rate\": 129.56526144990931, \"Power\": 129.56526144990931, \"i_spike\": 75.0, \"isi\": 0.046659913362027156, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7844790003053106, \"Firing rate\": 608.8061070924601, \"Power\": 608.8061070924601, \"i_spike\": 92.0, \"isi\": 0.03797865081756185, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1928313296970376, \"Firing rate\": 155.8946924977612, \"Power\": 155.8946924977612, \"i_spike\": 92.0, \"isi\": 0.038121755542223995, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077615601977832, \"Firing rate\": 119.56817539419721, \"Power\": 119.56817539419721, \"i_spike\": 74.5, \"isi\": 0.04660934195613513, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3240668465311076, \"Firing rate\": 210.895273459069, \"Power\": 210.895273459069, \"i_spike\": 75.5, \"isi\": 0.04641624316187993, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9441862764582671, \"Firing rate\": 87.93996257483187, \"Power\": 87.93996257483187, \"i_spike\": 73.0, \"isi\": 0.04692146801636959, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.0247285177119982, \"Firing rate\": 1058.591780864329, \"Power\": 1058.591780864329, \"i_spike\": 77.0, \"isi\": 0.045685464766526206, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.7391920768878777, \"Firing rate\": 54.85195068575797, \"Power\": 54.85195068575797, \"i_spike\": 64.5, \"isi\": 0.05399592200088135, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1934103426446043, \"Firing rate\": 156.10267405821313, \"Power\": 156.10267405821313, \"i_spike\": 74.5, \"isi\": 0.046628423844649644, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.297774880328158, \"Firing rate\": 198.50656775360184, \"Power\": 198.50656775360184, \"i_spike\": 80.0, \"isi\": 0.04397457503735967, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1110133951114576, \"Firing rate\": 129.1259099799552, \"Power\": 129.1259099799552, \"i_spike\": 87.5, \"isi\": 0.03951101481601628, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9798834285720046, \"Firing rate\": 95.47362854816234, \"Power\": 95.47362854816234, \"i_spike\": 82.0, \"isi\": 0.04281447867823779, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9839401087688497, \"Firing rate\": 96.36961162784607, \"Power\": 96.36961162784607, \"i_spike\": 80.5, \"isi\": 0.0436343619819139, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9292502786690382, \"Firing rate\": 84.96699885333383, \"Power\": 84.96699885333383, \"i_spike\": 84.5, \"isi\": 0.040212763358464985, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.110242887829347, \"Firing rate\": 128.89702323935285, \"Power\": 128.89702323935285, \"i_spike\": 78.0, \"isi\": 0.044671705231796116, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9896296651016587, \"Firing rate\": 97.6404258985101, \"Power\": 97.6404258985101, \"i_spike\": 96.5, \"isi\": 0.03602341732975196, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.524514898794598, \"Firing rate\": 3345.9149606607, \"Power\": 3345.9149606607, \"i_spike\": 67.0, \"isi\": 0.05228146274267083, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1112668565940305, \"Firing rate\": 129.20129200352847, \"Power\": 129.20129200352847, \"i_spike\": 72.5, \"isi\": 0.04765721891987244, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9572989808412744, \"Firing rate\": 90.63563480094187, \"Power\": 90.63563480094187, \"i_spike\": 77.5, \"isi\": 0.04525372674699464, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.543885879418327, \"Firing rate\": 349.85322319506616, \"Power\": 349.85322319506616, \"i_spike\": 71.5, \"isi\": 0.048639441668922465, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1757930037804383, \"Firing rate\": 149.89702164205846, \"Power\": 149.89702164205846, \"i_spike\": 82.0, \"isi\": 0.04242030307116036, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9882434867575853, \"Firing rate\": 97.32927464232434, \"Power\": 97.32927464232434, \"i_spike\": 73.0, \"isi\": 0.047906156958600565, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.123436432758141, \"Firing rate\": 132.8729058171096, \"Power\": 132.8729058171096, \"i_spike\": 74.0, \"isi\": 0.04678579996295997, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2883138118447697, \"Firing rate\": 194.22888267612504, \"Power\": 194.22888267612504, \"i_spike\": 76.0, \"isi\": 0.04579097873240445, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3338630531397206, \"Firing rate\": 215.70641109917793, \"Power\": 215.70641109917793, \"i_spike\": 82.0, \"isi\": 0.04253295769330548, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1368082310712584, \"Firing rate\": 137.02765673763616, \"Power\": 137.02765673763616, \"i_spike\": 87.0, \"isi\": 0.04009013967311376, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.304411865772515, \"Firing rate\": 201.5634883150203, \"Power\": 201.5634883150203, \"i_spike\": 84.5, \"isi\": 0.040969846937519115, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1578448451318133, \"Firing rate\": 143.82846487878152, \"Power\": 143.82846487878152, \"i_spike\": 93.0, \"isi\": 0.037192354679684805, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.026210332863069, \"Firing rate\": 106.22098707802203, \"Power\": 106.22098707802203, \"i_spike\": 86.0, \"isi\": 0.039883894146009444, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0309948773666058, \"Firing rate\": 107.39767443894033, \"Power\": 107.39767443894033, \"i_spike\": 71.5, \"isi\": 0.04790202069793337, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 5, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1102417146873824, \"Firing rate\": 128.89667505555326, \"Power\": 128.89667505555326, \"i_spike\": 85.5, \"isi\": 0.040840328777172155, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3598760140799757, \"Firing rate\": 229.0213730590734, \"Power\": 229.0213730590734, \"i_spike\": 85.5, \"isi\": 0.041093869337129094, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4487993661694656, \"Firing rate\": 281.0602098401713, \"Power\": 281.0602098401713, \"i_spike\": 88.5, \"isi\": 0.03916681921061969, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1541973100299687, \"Firing rate\": 142.6255427263312, \"Power\": 142.6255427263312, \"i_spike\": 87.5, \"isi\": 0.039474320407279974, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.234900540025064, \"Firing rate\": 171.7515005319624, \"Power\": 171.7515005319624, \"i_spike\": 94.5, \"isi\": 0.03655183866180524, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.7078341872007305, \"Firing rate\": 510.31012735003867, \"Power\": 510.31012735003867, \"i_spike\": 83.5, \"isi\": 0.041988842659945944, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1126963123799873, \"Firing rate\": 129.6272513932111, \"Power\": 129.6272513932111, \"i_spike\": 89.0, \"isi\": 0.03919921663226311, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1692211907420162, \"Firing rate\": 147.6458317545557, \"Power\": 147.6458317545557, \"i_spike\": 88.0, \"isi\": 0.03956930417423602, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1644556852991537, \"Firing rate\": 146.03457305415864, \"Power\": 146.03457305415864, \"i_spike\": 96.5, \"isi\": 0.03588734853002937, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.31196565210909, \"Firing rate\": 205.0999960994725, \"Power\": 205.0999960994725, \"i_spike\": 90.0, \"isi\": 0.03903067099230167, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.074577597091679, \"Firing rate\": 118.73468299886356, \"Power\": 118.73468299886356, \"i_spike\": 104.0, \"isi\": 0.03353750893302584, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2092160144315107, \"Firing rate\": 161.88850572662918, \"Power\": 161.88850572662918, \"i_spike\": 104.5, \"isi\": 0.03279156198398983, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.49914214982962, \"Firing rate\": 315.60374635173724, \"Power\": 315.60374635173724, \"i_spike\": 101.5, \"isi\": 0.034537567878371166, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1418864131165836, \"Firing rate\": 138.63931793743396, \"Power\": 138.63931793743396, \"i_spike\": 91.5, \"isi\": 0.03818102135269262, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8765227305978964, \"Firing rate\": 752.5281158141704, \"Power\": 752.5281158141704, \"i_spike\": 93.5, \"isi\": 0.03689839236734887, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.939461561874331, \"Firing rate\": 86.98844387480378, \"Power\": 86.98844387480378, \"i_spike\": 92.0, \"isi\": 0.03758519178898388, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2870436262828573, \"Firing rate\": 193.66164935551598, \"Power\": 193.66164935551598, \"i_spike\": 89.5, \"isi\": 0.03894744817039956, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1430297227592443, \"Firing rate\": 139.0047761690239, \"Power\": 139.0047761690239, \"i_spike\": 97.0, \"isi\": 0.03603976087193819, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.310726570280992, \"Firing rate\": 204.51566105247213, \"Power\": 204.51566105247213, \"i_spike\": 91.0, \"isi\": 0.03830441539373303, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3968118547257453, \"Firing rate\": 249.35142514175052, \"Power\": 249.35142514175052, \"i_spike\": 96.0, \"isi\": 0.03647169049835178, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 3.469141414513526, \"Firing rate\": 2945.3805493938794, \"Power\": 2945.3805493938794, \"i_spike\": 97.0, \"isi\": 0.03567197347869549, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189566775673024, \"Firing rate\": 262.39567812258474, \"Power\": 262.39567812258474, \"i_spike\": 109.0, \"isi\": 0.03178383198414856, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.404076689518491, \"Firing rate\": 253.55763335396162, \"Power\": 253.55763335396162, \"i_spike\": 100.0, \"isi\": 0.034975946689714515, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4991139433760545, \"Firing rate\": 315.58324926114744, \"Power\": 315.58324926114744, \"i_spike\": 83.5, \"isi\": 0.04187307899164901, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.379747962179488, \"Firing rate\": 239.7441187730139, \"Power\": 239.7441187730139, \"i_spike\": 100.0, \"isi\": 0.03471693037002835, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.8902246293874716, \"Firing rate\": 77.66487174396306, \"Power\": 77.66487174396306, \"i_spike\": 87.5, \"isi\": 0.03966381661521433, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.814843398948089, \"Firing rate\": 652.8950845550662, \"Power\": 652.8950845550662, \"i_spike\": 85.5, \"isi\": 0.040891388126968714, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.9487896110579808, \"Firing rate\": 888.7704589764036, \"Power\": 888.7704589764036, \"i_spike\": 89.5, \"isi\": 0.03915085074928612, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.0149402045520945, \"Firing rate\": 103.49996538656313, \"Power\": 103.49996538656313, \"i_spike\": 89.5, \"isi\": 0.03921140742804705, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.9542028872402641, \"Firing rate\": 89.9917893609065, \"Power\": 89.9917893609065, \"i_spike\": 85.5, \"isi\": 0.04054868314386225, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 6, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4881910216727383, \"Firing rate\": 307.74501140084084, \"Power\": 307.74501140084084, \"i_spike\": 88.0, \"isi\": 0.03904624656724844, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4115277428777, \"Firing rate\": 257.945373553756, \"Power\": 257.945373553756, \"i_spike\": 119.5, \"isi\": 0.02880924312756989, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4545567386868696, \"Firing rate\": 284.81098690467894, \"Power\": 284.81098690467894, \"i_spike\": 109.0, \"isi\": 0.03179620656212547, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3111719305423497, \"Firing rate\": 204.7254953238993, \"Power\": 204.7254953238993, \"i_spike\": 97.5, \"isi\": 0.03580379043600067, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.165545723182864, \"Firing rate\": 146.40156632304382, \"Power\": 146.40156632304382, \"i_spike\": 105.5, \"isi\": 0.03278382952607013, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2578646424397553, \"Firing rate\": 181.07756360533585, \"Power\": 181.07756360533585, \"i_spike\": 119.0, \"isi\": 0.029343681835626842, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.8107940843269335, \"Firing rate\": 646.835853340232, \"Power\": 646.835853340232, \"i_spike\": 116.0, \"isi\": 0.029999599974023163, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.39182087209241, \"Firing rate\": 246.50224111651946, \"Power\": 246.50224111651946, \"i_spike\": 117.5, \"isi\": 0.029502232467124783, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0658291633993806, \"Firing rate\": 116.36681920867568, \"Power\": 116.36681920867568, \"i_spike\": 101.0, \"isi\": 0.034668414565907774, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3285225511020813, \"Firing rate\": 213.07012031018914, \"Power\": 213.07012031018914, \"i_spike\": 113.5, \"isi\": 0.03083920593859388, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6729864873429214, \"Firing rate\": 470.9626726162531, \"Power\": 470.9626726162531, \"i_spike\": 122.0, \"isi\": 0.028568916959577716, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2018925265651847, \"Firing rate\": 159.18147571149987, \"Power\": 159.18147571149987, \"i_spike\": 112.0, \"isi\": 0.030867054694338973, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.374213868452394, \"Firing rate\": 236.70850822985395, \"Power\": 236.70850822985395, \"i_spike\": 105.0, \"isi\": 0.03330704053094981, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.311456530252207, \"Firing rate\": 204.85969899001685, \"Power\": 204.85969899001685, \"i_spike\": 104.0, \"isi\": 0.03379316964890372, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.18089067422046, \"Firing rate\": 151.66685255353084, \"Power\": 151.66685255353084, \"i_spike\": 108.0, \"isi\": 0.03226254920952097, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1779833854348714, \"Firing rate\": 150.65494298513445, \"Power\": 150.65494298513445, \"i_spike\": 113.0, \"isi\": 0.030897373044620688, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3035855615368024, \"Firing rate\": 201.18035100403486, \"Power\": 201.18035100403486, \"i_spike\": 112.5, \"isi\": 0.031017803226141994, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4551657383947396, \"Firing rate\": 285.2106499995778, \"Power\": 285.2106499995778, \"i_spike\": 119.5, \"isi\": 0.02922791099470977, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 3.100538081982483, \"Firing rate\": 1260.486161305173, \"Power\": 1260.486161305173, \"i_spike\": 117.5, \"isi\": 0.029697418256461976, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1111083966350765, \"Firing rate\": 129.15415924516745, \"Power\": 129.15415924516745, \"i_spike\": 118.5, \"isi\": 0.02948619911662466, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.044552627498885, \"Firing rate\": 110.80328278754759, \"Power\": 110.80328278754759, \"i_spike\": 101.0, \"isi\": 0.03429723398050743, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.016091787828533, \"Firing rate\": 103.77477198816491, \"Power\": 103.77477198816491, \"i_spike\": 103.5, \"isi\": 0.03346541480440439, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2697421877977257, \"Firing rate\": 186.09820654703583, \"Power\": 186.09820654703583, \"i_spike\": 118.5, \"isi\": 0.029214269965179746, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.687691210640336, \"Firing rate\": 487.1819738340354, \"Power\": 487.1819738340354, \"i_spike\": 112.0, \"isi\": 0.031291789674142416, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.5700111791336004, \"Firing rate\": 371.5447928738117, \"Power\": 371.5447928738117, \"i_spike\": 119.5, \"isi\": 0.029125995163474167, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.324688636610815, \"Firing rate\": 211.19743365693657, \"Power\": 211.19743365693657, \"i_spike\": 128.5, \"isi\": 0.02689077169759444, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.197745717540907, \"Firing rate\": 157.668783762246, \"Power\": 157.668783762246, \"i_spike\": 116.5, \"isi\": 0.029739505746504635, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.232111730437686, \"Firing rate\": 170.65213673060103, \"Power\": 170.65213673060103, \"i_spike\": 119.5, \"isi\": 0.029278118430901116, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.226281785132872, \"Firing rate\": 168.3766191894407, \"Power\": 168.3766191894407, \"i_spike\": 100.5, \"isi\": 0.03487511849895156, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4240095717708385, \"Firing rate\": 265.4664069640671, \"Power\": 265.4664069640671, \"i_spike\": 109.0, \"isi\": 0.032083977077943644, \"combined_condition\": 1.0}, {\"stim\": 0, \"mouse\": 7, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0765668363240124, \"Firing rate\": 119.27978189302107, \"Power\": 119.27978189302107, \"i_spike\": 118.0, \"isi\": 0.02924333618462232, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.710200388455537, \"Firing rate\": 513.0980787193608, \"Power\": 513.0980787193608, \"i_spike\": 58.0, \"isi\": 0.05755769778597422, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.086495554586632, \"Firing rate\": 122.03813289272098, \"Power\": 122.03813289272098, \"i_spike\": 58.0, \"isi\": 0.05954567433072462, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.4599942127543875, \"Firing rate\": 288.3993071858994, \"Power\": 288.3993071858994, \"i_spike\": 69.0, \"isi\": 0.050452157477652144, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8764248252258178, \"Firing rate\": 75.23584884202715, \"Power\": 75.23584884202715, \"i_spike\": 47.5, \"isi\": 0.0729232484181408, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.943371360287594, \"Firing rate\": 87.77510553153151, \"Power\": 87.77510553153151, \"i_spike\": 72.0, \"isi\": 0.04794968452690702, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0095288502408404, \"Firing rate\": 102.21834621295545, \"Power\": 102.21834621295545, \"i_spike\": 58.5, \"isi\": 0.05900199429876669, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.108813974324886, \"Firing rate\": 128.47362382167685, \"Power\": 128.47362382167685, \"i_spike\": 74.0, \"isi\": 0.04704885530644372, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9546575480473676, \"Firing rate\": 90.08605066518454, \"Power\": 90.08605066518454, \"i_spike\": 66.0, \"isi\": 0.05192063434120186, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9556030665055126, \"Firing rate\": 90.28239396841717, \"Power\": 90.28239396841717, \"i_spike\": 63.0, \"isi\": 0.05547055572684698, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.116207536382213, \"Firing rate\": 130.6795217411474, \"Power\": 130.6795217411474, \"i_spike\": 60.5, \"isi\": 0.0574361231164934, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.125243880671493, \"Firing rate\": 133.4270489421996, \"Power\": 133.4270489421996, \"i_spike\": 68.0, \"isi\": 0.04981296493334266, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.067202187376957, \"Firing rate\": 116.73529559924685, \"Power\": 116.73529559924685, \"i_spike\": 61.5, \"isi\": 0.0564927141817096, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3223316454945286, \"Firing rate\": 210.0543334368294, \"Power\": 210.0543334368294, \"i_spike\": 59.5, \"isi\": 0.058641352393127184, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0012989243549466, \"Firing rate\": 100.29953610121872, \"Power\": 100.29953610121872, \"i_spike\": 63.5, \"isi\": 0.053258724806304336, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.740752379052743, \"Firing rate\": 55.049373283103336, \"Power\": 55.049373283103336, \"i_spike\": 68.5, \"isi\": 0.05025347412312059, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8372359506262905, \"Firing rate\": 68.74418232403539, \"Power\": 68.74418232403539, \"i_spike\": 58.5, \"isi\": 0.05883024786315191, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3872683261080843, \"Firing rate\": 243.9317469805847, \"Power\": 243.9317469805847, \"i_spike\": 52.0, \"isi\": 0.06463987437697509, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1699952647940046, \"Firing rate\": 147.90922612197502, \"Power\": 147.90922612197502, \"i_spike\": 58.0, \"isi\": 0.06041749419783433, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0727936321681573, \"Firing rate\": 118.24795321797994, \"Power\": 118.24795321797994, \"i_spike\": 74.0, \"isi\": 0.04733033921726912, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.44888166908114, \"Firing rate\": 281.11347845536557, \"Power\": 281.11347845536557, \"i_spike\": 64.0, \"isi\": 0.05283053800228937, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.268675264450081, \"Firing rate\": 185.64158358911618, \"Power\": 185.64158358911618, \"i_spike\": 65.5, \"isi\": 0.05201986674274169, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.428906190296464, \"Firing rate\": 268.4764460943622, \"Power\": 268.4764460943622, \"i_spike\": 58.5, \"isi\": 0.05911180928366123, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.049008675060004, \"Firing rate\": 111.94602445336766, \"Power\": 111.94602445336766, \"i_spike\": 84.0, \"isi\": 0.04125747764768612, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0516084499750704, \"Firing rate\": 112.61816585709414, \"Power\": 112.61816585709414, \"i_spike\": 66.0, \"isi\": 0.05216770534731938, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9822401781710393, \"Firing rate\": 95.99313562360203, \"Power\": 95.99313562360203, \"i_spike\": 68.5, \"isi\": 0.05091550082040577, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0413070869966092, \"Firing rate\": 109.97832146085658, \"Power\": 109.97832146085658, \"i_spike\": 69.5, \"isi\": 0.048261908955763336, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9162564740110344, \"Firing rate\": 82.4624956181202, \"Power\": 82.4624956181202, \"i_spike\": 72.5, \"isi\": 0.04580300353406743, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.0251706690400266, \"Firing rate\": 1059.6700724955876, \"Power\": 1059.6700724955876, \"i_spike\": 71.0, \"isi\": 0.048977335140478306, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9185288956668356, \"Firing rate\": 82.89510684752574, \"Power\": 82.89510684752574, \"i_spike\": 65.0, \"isi\": 0.053468477919304494, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 0, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.7155492922987285, \"Firing rate\": 5194.566283391101, \"Power\": 5194.566283391101, \"i_spike\": 70.0, \"isi\": 0.047831889076879165, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2880559296273484, \"Firing rate\": 194.11358462627942, \"Power\": 194.11358462627942, \"i_spike\": 77.0, \"isi\": 0.04377704062250514, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2863930549701847, \"Firing rate\": 193.37176219598692, \"Power\": 193.37176219598692, \"i_spike\": 71.5, \"isi\": 0.04739471740371852, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 3.485362624668281, \"Firing rate\": 3057.4729586064655, \"Power\": 3057.4729586064655, \"i_spike\": 61.0, \"isi\": 0.05730472197648097, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2096939236101893, \"Firing rate\": 162.06675019105623, \"Power\": 162.06675019105623, \"i_spike\": 70.0, \"isi\": 0.04860233815068464, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.837305629539864, \"Firing rate\": 687.5521263737877, \"Power\": 687.5521263737877, \"i_spike\": 76.0, \"isi\": 0.0462630290768705, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1604627571934727, \"Firing rate\": 144.6980762328094, \"Power\": 144.6980762328094, \"i_spike\": 71.5, \"isi\": 0.04871333606236235, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2330475254201847, \"Firing rate\": 171.0202454569647, \"Power\": 171.0202454569647, \"i_spike\": 71.5, \"isi\": 0.049080521297471015, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2588609326122553, \"Firing rate\": 181.4934401413059, \"Power\": 181.4934401413059, \"i_spike\": 66.5, \"isi\": 0.05057733095048499, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8829675842290474, \"Firing rate\": 76.37787729482577, \"Power\": 76.37787729482577, \"i_spike\": 81.0, \"isi\": 0.04283416965586292, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3279809733696553, \"Firing rate\": 212.80458133268078, \"Power\": 212.80458133268078, \"i_spike\": 74.5, \"isi\": 0.04442769500737385, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8091068615972408, \"Firing rate\": 64.43277879673587, \"Power\": 64.43277879673587, \"i_spike\": 60.5, \"isi\": 0.056408495878117026, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0634103765045717, \"Firing rate\": 115.7205199960153, \"Power\": 115.7205199960153, \"i_spike\": 62.5, \"isi\": 0.05494193964992375, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.057707201125165, \"Firing rate\": 114.21080723853781, \"Power\": 114.21080723853781, \"i_spike\": 66.5, \"isi\": 0.05118977826099244, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2746886859201556, \"Firing rate\": 188.2299322496126, \"Power\": 188.2299322496126, \"i_spike\": 76.5, \"isi\": 0.04519157254778185, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0019707623558363, \"Firing rate\": 100.45481596463469, \"Power\": 100.45481596463469, \"i_spike\": 76.0, \"isi\": 0.045327986132193195, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.295587633345161, \"Firing rate\": 197.50933799327007, \"Power\": 197.50933799327007, \"i_spike\": 74.0, \"isi\": 0.046483911938798965, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.945877973988118, \"Firing rate\": 88.28318116549227, \"Power\": 88.28318116549227, \"i_spike\": 66.5, \"isi\": 0.05264008421938133, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.471153315505243, \"Firing rate\": 295.90568943614835, \"Power\": 295.90568943614835, \"i_spike\": 87.0, \"isi\": 0.04015846530226762, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0265599217285164, \"Firing rate\": 106.30652494563125, \"Power\": 106.30652494563125, \"i_spike\": 78.5, \"isi\": 0.04422689053854093, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9009990463345725, \"Firing rate\": 79.61576021362671, \"Power\": 79.61576021362671, \"i_spike\": 60.0, \"isi\": 0.05558242287405482, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1371898250889654, \"Firing rate\": 137.14810936802255, \"Power\": 137.14810936802255, \"i_spike\": 78.0, \"isi\": 0.043423699441362415, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.18334195846327, \"Firing rate\": 152.5253247913568, \"Power\": 152.5253247913568, \"i_spike\": 79.5, \"isi\": 0.0439479607076074, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.018302892049905, \"Firing rate\": 104.30446313151317, \"Power\": 104.30446313151317, \"i_spike\": 69.5, \"isi\": 0.050417535373145216, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.520301793170094, \"Firing rate\": 331.36130594281525, \"Power\": 331.36130594281525, \"i_spike\": 63.0, \"isi\": 0.055194343234777954, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.140863371620742, \"Firing rate\": 138.3131179566823, \"Power\": 138.3131179566823, \"i_spike\": 67.0, \"isi\": 0.05011613503553582, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5790786138640915, \"Firing rate\": 379.38365293278486, \"Power\": 379.38365293278486, \"i_spike\": 70.0, \"isi\": 0.049862445465668585, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0046971363148742, \"Firing rate\": 101.08742556167319, \"Power\": 101.08742556167319, \"i_spike\": 77.0, \"isi\": 0.044773115940763754, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9299917883985747, \"Firing rate\": 85.11219451122186, \"Power\": 85.11219451122186, \"i_spike\": 63.5, \"isi\": 0.053279255805921924, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.507367640954118, \"Firing rate\": 321.63821330655077, \"Power\": 321.63821330655077, \"i_spike\": 83.0, \"isi\": 0.04180903485727737, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 1, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.043864219396577, \"Firing rate\": 110.62778561221664, \"Power\": 110.62778561221664, \"i_spike\": 60.5, \"isi\": 0.05613656256289283, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0343304902630406, \"Firing rate\": 108.2257216223445, \"Power\": 108.2257216223445, \"i_spike\": 76.5, \"isi\": 0.044990678072367146, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.265966193291141, \"Firing rate\": 184.48718035589718, \"Power\": 184.48718035589718, \"i_spike\": 82.5, \"isi\": 0.041218621498328945, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.184829164757981, \"Firing rate\": 153.0485307452557, \"Power\": 153.0485307452557, \"i_spike\": 79.5, \"isi\": 0.0438790508311261, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.482867251153031, \"Firing rate\": 303.99556740279854, \"Power\": 303.99556740279854, \"i_spike\": 72.0, \"isi\": 0.04732392940449676, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.679350887775424, \"Firing rate\": 477.91524884132025, \"Power\": 477.91524884132025, \"i_spike\": 75.0, \"isi\": 0.04487201851927047, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0102132106102126, \"Firing rate\": 102.37954865480673, \"Power\": 102.37954865480673, \"i_spike\": 71.5, \"isi\": 0.04878632929411457, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2925787627458876, \"Firing rate\": 196.14568689680337, \"Power\": 196.14568689680337, \"i_spike\": 71.5, \"isi\": 0.04751080235874853, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.408181131975511, \"Firing rate\": 255.96532234553712, \"Power\": 255.96532234553712, \"i_spike\": 78.5, \"isi\": 0.04224296754691385, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3855583224969688, \"Firing rate\": 242.97317148876678, \"Power\": 242.97317148876678, \"i_spike\": 76.5, \"isi\": 0.045168110305337704, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9994034804402283, \"Firing rate\": 99.862740582426, \"Power\": 99.862740582426, \"i_spike\": 76.5, \"isi\": 0.04461518511387296, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.420657135162534, \"Firing rate\": 263.4250888241149, \"Power\": 263.4250888241149, \"i_spike\": 86.5, \"isi\": 0.039763315255390425, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0333948498686167, \"Firing rate\": 107.99281201345569, \"Power\": 107.99281201345569, \"i_spike\": 71.5, \"isi\": 0.04905015663749419, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1771834940956576, \"Firing rate\": 150.3777193944357, \"Power\": 150.3777193944357, \"i_spike\": 71.5, \"isi\": 0.048168145819388865, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9004170909121822, \"Firing rate\": 79.50914639254572, \"Power\": 79.50914639254572, \"i_spike\": 72.0, \"isi\": 0.047053568472965865, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2706500732886123, \"Firing rate\": 186.4876487147454, \"Power\": 186.4876487147454, \"i_spike\": 76.5, \"isi\": 0.04478958523955221, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3226879927203563, \"Firing rate\": 210.22675790778925, \"Power\": 210.22675790778925, \"i_spike\": 84.5, \"isi\": 0.041448783649683865, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1236488593840726, \"Firing rate\": 132.93791388973483, \"Power\": 132.93791388973483, \"i_spike\": 73.5, \"isi\": 0.04771964422986316, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9611984491654064, \"Firing rate\": 91.45310373895767, \"Power\": 91.45310373895767, \"i_spike\": 70.5, \"isi\": 0.04936860543367102, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0824773391122404, \"Firing rate\": 120.91420899286925, \"Power\": 120.91420899286925, \"i_spike\": 88.0, \"isi\": 0.03935522162784246, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9787501002284225, \"Firing rate\": 95.22480680598018, \"Power\": 95.22480680598018, \"i_spike\": 75.0, \"isi\": 0.045602480439414186, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1685898325916213, \"Firing rate\": 147.43134670286034, \"Power\": 147.43134670286034, \"i_spike\": 80.0, \"isi\": 0.0428366177384345, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.230731641001414, \"Firing rate\": 170.11070364760798, \"Power\": 170.11070364760798, \"i_spike\": 86.0, \"isi\": 0.04069000316608182, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7109408735479223, \"Firing rate\": 513.9736725480508, \"Power\": 513.9736725480508, \"i_spike\": 90.5, \"isi\": 0.03808087796581317, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.8904891156107295, \"Firing rate\": 777.121842141343, \"Power\": 777.121842141343, \"i_spike\": 67.5, \"isi\": 0.05050650450585472, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3884444205618465, \"Firing rate\": 244.59322344535366, \"Power\": 244.59322344535366, \"i_spike\": 75.5, \"isi\": 0.046160864179237364, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.215221869412756, \"Firing rate\": 164.14281206772014, \"Power\": 164.14281206772014, \"i_spike\": 76.0, \"isi\": 0.045973777674205345, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1044452923402397, \"Firing rate\": 127.18775228011826, \"Power\": 127.18775228011826, \"i_spike\": 74.5, \"isi\": 0.046825315835458, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.304794192932069, \"Firing rate\": 201.74101101002248, \"Power\": 201.74101101002248, \"i_spike\": 84.5, \"isi\": 0.0415838404784538, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9519897390823953, \"Firing rate\": 89.53436113421678, \"Power\": 89.53436113421678, \"i_spike\": 73.0, \"isi\": 0.04637231437529422, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 2, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.050715177785326, \"Firing rate\": 112.38676690257596, \"Power\": 112.38676690257596, \"i_spike\": 72.5, \"isi\": 0.047898939712791556, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.093906240936936, \"Firing rate\": 124.13842784179043, \"Power\": 124.13842784179043, \"i_spike\": 77.0, \"isi\": 0.04521406966614064, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.142532137492843, \"Firing rate\": 138.84560509200531, \"Power\": 138.84560509200531, \"i_spike\": 85.5, \"isi\": 0.04088215523965275, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1247106556001505, \"Firing rate\": 133.26332826018398, \"Power\": 133.26332826018398, \"i_spike\": 94.0, \"isi\": 0.03699718718109058, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0404961635875494, \"Firing rate\": 109.77315932365002, \"Power\": 109.77315932365002, \"i_spike\": 84.5, \"isi\": 0.040822879176668145, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2076231068258, \"Firing rate\": 161.29581780251291, \"Power\": 161.29581780251291, \"i_spike\": 77.0, \"isi\": 0.04556164109048245, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0158640710626763, \"Firing rate\": 103.72037327450805, \"Power\": 103.72037327450805, \"i_spike\": 70.5, \"isi\": 0.04900422553915958, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1880248824801893, \"Firing rate\": 154.1788785708863, \"Power\": 154.1788785708863, \"i_spike\": 87.5, \"isi\": 0.039435886208280056, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9744105165726646, \"Firing rate\": 94.27803379629712, \"Power\": 94.27803379629712, \"i_spike\": 84.5, \"isi\": 0.04146392755918885, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 3.913843764110594, \"Firing rate\": 8200.564788680073, \"Power\": 8200.564788680073, \"i_spike\": 76.5, \"isi\": 0.04556363424648217, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1399954218244273, \"Firing rate\": 138.0369713167223, \"Power\": 138.0369713167223, \"i_spike\": 77.5, \"isi\": 0.0453981706218095, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9566148125838072, \"Firing rate\": 90.49296385155998, \"Power\": 90.49296385155998, \"i_spike\": 85.0, \"isi\": 0.03927323815030475, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2520245491348896, \"Firing rate\": 178.65885615461892, \"Power\": 178.65885615461892, \"i_spike\": 85.0, \"isi\": 0.040967992817435184, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1754321193760866, \"Firing rate\": 149.77251389430003, \"Power\": 149.77251389430003, \"i_spike\": 91.5, \"isi\": 0.03836696480836998, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.635716855961742, \"Firing rate\": 432.2319398170039, \"Power\": 432.2319398170039, \"i_spike\": 96.5, \"isi\": 0.03578166736861596, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2160850620865733, \"Firing rate\": 164.46938258310612, \"Power\": 164.46938258310612, \"i_spike\": 80.0, \"isi\": 0.043473098367445215, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1205612291989038, \"Firing rate\": 131.9961393928132, \"Power\": 131.9961393928132, \"i_spike\": 75.5, \"isi\": 0.04626035487513255, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.024827292545692, \"Firing rate\": 105.88325716711356, \"Power\": 105.88325716711356, \"i_spike\": 80.5, \"isi\": 0.04253930743384717, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.074114281950763, \"Firing rate\": 118.60808170570037, \"Power\": 118.60808170570037, \"i_spike\": 67.0, \"isi\": 0.051334204579878646, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2811373940485504, \"Firing rate\": 191.04575581686126, \"Power\": 191.04575581686126, \"i_spike\": 74.5, \"isi\": 0.046987279420234215, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.014403068402744, \"Firing rate\": 103.37203558262294, \"Power\": 103.37203558262294, \"i_spike\": 82.5, \"isi\": 0.04146065949524595, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.108863671481811, \"Firing rate\": 128.4883261479434, \"Power\": 128.4883261479434, \"i_spike\": 87.5, \"isi\": 0.03907275494403815, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.658304695266665, \"Firing rate\": 455.30738576183563, \"Power\": 455.30738576183563, \"i_spike\": 93.5, \"isi\": 0.036909663672368385, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2071328830952694, \"Firing rate\": 161.11385272898417, \"Power\": 161.11385272898417, \"i_spike\": 90.0, \"isi\": 0.03900063452819159, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.162120505142531, \"Firing rate\": 145.25145957605932, \"Power\": 145.25145957605932, \"i_spike\": 85.5, \"isi\": 0.0400904776550323, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9709911192109881, \"Firing rate\": 93.53865464453958, \"Power\": 93.53865464453958, \"i_spike\": 75.0, \"isi\": 0.045538771732070805, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.134880880431313, \"Firing rate\": 136.42089060349338, \"Power\": 136.42089060349338, \"i_spike\": 88.5, \"isi\": 0.03943188805380755, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.066832430618179, \"Firing rate\": 116.63594988602028, \"Power\": 116.63594988602028, \"i_spike\": 70.5, \"isi\": 0.048970343212981035, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3793806836767333, \"Firing rate\": 239.5414552752351, \"Power\": 239.5414552752351, \"i_spike\": 82.5, \"isi\": 0.042043561438028454, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.399500106264406, \"Firing rate\": 250.89967933737773, \"Power\": 250.89967933737773, \"i_spike\": 75.5, \"isi\": 0.04561264334500348, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 3, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.220242199517701, \"Firing rate\": 166.0512692284522, \"Power\": 166.0512692284522, \"i_spike\": 77.5, \"isi\": 0.04518223580077409, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3997220560187014, \"Firing rate\": 251.02793644541697, \"Power\": 251.02793644541697, \"i_spike\": 92.0, \"isi\": 0.037630914484962856, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.166020646368421, \"Firing rate\": 146.56175147859375, \"Power\": 146.56175147859375, \"i_spike\": 91.0, \"isi\": 0.03827176241185468, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.185888096679604, \"Firing rate\": 153.4221613710901, \"Power\": 153.4221613710901, \"i_spike\": 92.0, \"isi\": 0.03761591240242529, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.4587317399206245, \"Firing rate\": 287.562161854551, \"Power\": 287.562161854551, \"i_spike\": 91.5, \"isi\": 0.03834390692603616, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.212868070184563, \"Firing rate\": 163.25559353268687, \"Power\": 163.25559353268687, \"i_spike\": 92.0, \"isi\": 0.03802455357122872, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2357931191352933, \"Firing rate\": 172.10485396344228, \"Power\": 172.10485396344228, \"i_spike\": 79.0, \"isi\": 0.04382598137502598, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3035618471296804, \"Firing rate\": 201.16936596348194, \"Power\": 201.16936596348194, \"i_spike\": 109.5, \"isi\": 0.03202543684399708, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.8017110410666857, \"Firing rate\": 633.4481047134145, \"Power\": 633.4481047134145, \"i_spike\": 98.0, \"isi\": 0.03550739167328109, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1697988740587917, \"Firing rate\": 147.8423557471093, \"Power\": 147.8423557471093, \"i_spike\": 88.5, \"isi\": 0.03925960981462805, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.6760870929370943, \"Firing rate\": 474.3370987623261, \"Power\": 474.3370987623261, \"i_spike\": 87.5, \"isi\": 0.039431239454240596, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.433730632307909, \"Firing rate\": 271.47549414255656, \"Power\": 271.47549414255656, \"i_spike\": 96.5, \"isi\": 0.0363181558103682, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.063446911413506, \"Firing rate\": 115.73025536377592, \"Power\": 115.73025536377592, \"i_spike\": 79.0, \"isi\": 0.044476460189586564, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.175425654268593, \"Firing rate\": 149.77028432833717, \"Power\": 149.77028432833717, \"i_spike\": 80.5, \"isi\": 0.04299945260731721, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3612576848505684, \"Firing rate\": 229.75114521901307, \"Power\": 229.75114521901307, \"i_spike\": 77.0, \"isi\": 0.04469056636440316, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.147995753593227, \"Firing rate\": 140.60337762680615, \"Power\": 140.60337762680615, \"i_spike\": 87.5, \"isi\": 0.03976844291136797, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0929257700333896, \"Firing rate\": 123.85848685027362, \"Power\": 123.85848685027362, \"i_spike\": 94.0, \"isi\": 0.03657174288555396, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10475158728818, \"Firing rate\": 127.27748564862868, \"Power\": 127.27748564862868, \"i_spike\": 98.5, \"isi\": 0.03552973340735749, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2328647390747323, \"Firing rate\": 170.94828141071517, \"Power\": 170.94828141071517, \"i_spike\": 82.5, \"isi\": 0.04166360369234807, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1354623163537503, \"Firing rate\": 136.6036539827589, \"Power\": 136.6036539827589, \"i_spike\": 84.5, \"isi\": 0.040640693096263156, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0464608797536576, \"Firing rate\": 111.29121397251097, \"Power\": 111.29121397251097, \"i_spike\": 89.5, \"isi\": 0.03879007896451536, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3355625956917723, \"Firing rate\": 216.5521977627491, \"Power\": 216.5521977627491, \"i_spike\": 98.0, \"isi\": 0.035422439393446775, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2161677848183947, \"Firing rate\": 164.50071305822243, \"Power\": 164.50071305822243, \"i_spike\": 85.0, \"isi\": 0.04048577743104151, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2837266052282277, \"Firing rate\": 192.18814953172904, \"Power\": 192.18814953172904, \"i_spike\": 99.5, \"isi\": 0.03520251098408982, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.161668219920541, \"Firing rate\": 145.10026978437168, \"Power\": 145.10026978437168, \"i_spike\": 90.0, \"isi\": 0.038734070453864254, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.282132072264165, \"Firing rate\": 191.4838153372827, \"Power\": 191.4838153372827, \"i_spike\": 78.0, \"isi\": 0.043996610728127564, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0841752044242403, \"Firing rate\": 121.38784583039707, \"Power\": 121.38784583039707, \"i_spike\": 100.0, \"isi\": 0.03461991962811, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.447465040329036, \"Firing rate\": 280.1980059869962, \"Power\": 280.1980059869962, \"i_spike\": 79.0, \"isi\": 0.04452724337396078, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.081771364126096, \"Firing rate\": 120.71781445649961, \"Power\": 120.71781445649961, \"i_spike\": 91.0, \"isi\": 0.03856750376815478, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.9391326595223966, \"Firing rate\": 869.2259023424945, \"Power\": 869.2259023424945, \"i_spike\": 79.0, \"isi\": 0.04416616879896912, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 4, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8602028751437854, \"Firing rate\": 72.47744501747489, \"Power\": 72.47744501747489, \"i_spike\": 83.0, \"isi\": 0.04119329035591721, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1734123362153537, \"Firing rate\": 149.07758070284467, \"Power\": 149.07758070284467, \"i_spike\": 81.5, \"isi\": 0.0428418950531146, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.192601337300343, \"Firing rate\": 155.812156100815, \"Power\": 155.812156100815, \"i_spike\": 103.0, \"isi\": 0.03371726705897087, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.325538741593283, \"Firing rate\": 211.6112446357301, \"Power\": 211.6112446357301, \"i_spike\": 106.5, \"isi\": 0.03256875829829079, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0351612273023045, \"Firing rate\": 108.43293852986389, \"Power\": 108.43293852986389, \"i_spike\": 92.5, \"isi\": 0.03785767511850996, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3612887627039565, \"Firing rate\": 229.76758666182133, \"Power\": 229.76758666182133, \"i_spike\": 110.5, \"isi\": 0.0316478026663995, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.486602812028755, \"Firing rate\": 306.62164695003077, \"Power\": 306.62164695003077, \"i_spike\": 102.0, \"isi\": 0.03428746701402582, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.26907338816312, \"Firing rate\": 185.81184180415744, \"Power\": 185.81184180415744, \"i_spike\": 108.0, \"isi\": 0.03182822108027605, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2400289413579997, \"Firing rate\": 173.79166395502384, \"Power\": 173.79166395502384, \"i_spike\": 104.0, \"isi\": 0.03361245677188138, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.133061627118738, \"Firing rate\": 135.8506207230094, \"Power\": 135.8506207230094, \"i_spike\": 83.0, \"isi\": 0.04226663021993772, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.055873381143031, \"Firing rate\": 113.72956581458753, \"Power\": 113.72956581458753, \"i_spike\": 96.5, \"isi\": 0.03623434325043876, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077393494053492, \"Firing rate\": 119.50704118553142, \"Power\": 119.50704118553142, \"i_spike\": 86.0, \"isi\": 0.03999884944106042, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7032986753124226, \"Firing rate\": 505.00848528812185, \"Power\": 505.00848528812185, \"i_spike\": 94.5, \"isi\": 0.03642922221630557, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2487291617775735, \"Firing rate\": 177.30833914875691, \"Power\": 177.30833914875691, \"i_spike\": 95.0, \"isi\": 0.035509978483580056, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.6190312582185733, \"Firing rate\": 415.9405466161257, \"Power\": 415.9405466161257, \"i_spike\": 92.5, \"isi\": 0.03739794009579709, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2214636345147007, \"Firing rate\": 166.51893879392634, \"Power\": 166.51893879392634, \"i_spike\": 104.5, \"isi\": 0.03334968571838423, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.050033014448482, \"Firing rate\": 1122.1037517902018, \"Power\": 1122.1037517902018, \"i_spike\": 109.0, \"isi\": 0.03174363047623115, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0201521306738686, \"Firing rate\": 104.7495414963806, \"Power\": 104.7495414963806, \"i_spike\": 84.0, \"isi\": 0.04150443974238124, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.394368017909442, \"Firing rate\": 247.95222963713232, \"Power\": 247.95222963713232, \"i_spike\": 97.5, \"isi\": 0.034832136270722715, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.329502121112529, \"Firing rate\": 213.551251595498, \"Power\": 213.551251595498, \"i_spike\": 119.5, \"isi\": 0.02914255148960452, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.296426000518237, \"Firing rate\": 197.89098058624842, \"Power\": 197.89098058624842, \"i_spike\": 100.5, \"isi\": 0.03453794209724264, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9526063135638236, \"Firing rate\": 89.66156470356117, \"Power\": 89.66156470356117, \"i_spike\": 87.0, \"isi\": 0.0403252649629643, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1801699394018295, \"Firing rate\": 151.41536207419279, \"Power\": 151.41536207419279, \"i_spike\": 95.0, \"isi\": 0.0369374859002085, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9603011698286221, \"Firing rate\": 91.26435100880892, \"Power\": 91.26435100880892, \"i_spike\": 100.5, \"isi\": 0.03470962985025618, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1497807834136973, \"Firing rate\": 141.18247252479557, \"Power\": 141.18247252479557, \"i_spike\": 97.0, \"isi\": 0.03544340361561801, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.149622075943538, \"Firing rate\": 141.13088858728008, \"Power\": 141.13088858728008, \"i_spike\": 98.5, \"isi\": 0.03458549884764996, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.056159126623185, \"Firing rate\": 113.80441917809635, \"Power\": 113.80441917809635, \"i_spike\": 87.0, \"isi\": 0.03968042681843487, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3917479076029613, \"Firing rate\": 246.46083050660826, \"Power\": 246.46083050660826, \"i_spike\": 98.5, \"isi\": 0.035535360449709036, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0750924013179355, \"Firing rate\": 118.87551223280595, \"Power\": 118.87551223280595, \"i_spike\": 94.0, \"isi\": 0.03719199644955143, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.489337914838964, \"Firing rate\": 308.5587843479223, \"Power\": 308.5587843479223, \"i_spike\": 95.5, \"isi\": 0.03556131746210524, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 5, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.4520230739574873, \"Firing rate\": 283.154243094607, \"Power\": 283.154243094607, \"i_spike\": 107.0, \"isi\": 0.032710924682864184, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.323245560174936, \"Firing rate\": 210.49683012562227, \"Power\": 210.49683012562227, \"i_spike\": 107.5, \"isi\": 0.03260971008319308, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4551248825615755, \"Firing rate\": 285.183820345654, \"Power\": 285.183820345654, \"i_spike\": 119.5, \"isi\": 0.029121401254440946, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2034473494582008, \"Firing rate\": 159.75238457442458, \"Power\": 159.75238457442458, \"i_spike\": 117.5, \"isi\": 0.02942985917936488, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.185090643987662, \"Firing rate\": 153.1407056710173, \"Power\": 153.1407056710173, \"i_spike\": 107.5, \"isi\": 0.03182653781887098, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3319515266612205, \"Firing rate\": 214.7590759585309, \"Power\": 214.7590759585309, \"i_spike\": 125.0, \"isi\": 0.028084978019438673, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6162367962967754, \"Firing rate\": 413.2727749153624, \"Power\": 413.2727749153624, \"i_spike\": 106.5, \"isi\": 0.032651038144998264, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.251599839982757, \"Firing rate\": 178.48422588668325, \"Power\": 178.48422588668325, \"i_spike\": 112.0, \"isi\": 0.031077478691086027, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.700871783939369, \"Firing rate\": 502.194305618395, \"Power\": 502.194305618395, \"i_spike\": 94.0, \"isi\": 0.036901644723313094, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.314948450805621, \"Firing rate\": 206.5135017156736, \"Power\": 206.5135017156736, \"i_spike\": 93.5, \"isi\": 0.03744836002524842, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6205392303439177, \"Firing rate\": 417.3872998602738, \"Power\": 417.3872998602738, \"i_spike\": 112.5, \"isi\": 0.030901272636151618, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5103170415704716, \"Firing rate\": 323.82997146198255, \"Power\": 323.82997146198255, \"i_spike\": 118.5, \"isi\": 0.0292124077372491, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.267328656385887, \"Firing rate\": 185.06685998516417, \"Power\": 185.06685998516417, \"i_spike\": 112.0, \"isi\": 0.030900503373377113, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3735439867744246, \"Firing rate\": 236.34367636856805, \"Power\": 236.34367636856805, \"i_spike\": 111.5, \"isi\": 0.031086261056407043, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3925644433143702, \"Firing rate\": 246.9246479862117, \"Power\": 246.9246479862117, \"i_spike\": 116.5, \"isi\": 0.0291953589973033, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.561842054638256, \"Firing rate\": 364.6213163680733, \"Power\": 364.6213163680733, \"i_spike\": 111.5, \"isi\": 0.031029868021617713, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.171212511252901, \"Firing rate\": 148.32436961836746, \"Power\": 148.32436961836746, \"i_spike\": 98.0, \"isi\": 0.03548246558301557, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.305560627357594, \"Firing rate\": 202.09735394991617, \"Power\": 202.09735394991617, \"i_spike\": 116.5, \"isi\": 0.029539429675363767, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.230937526831537, \"Firing rate\": 170.19136708674088, \"Power\": 170.19136708674088, \"i_spike\": 109.5, \"isi\": 0.031509671304326574, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8998022408045885, \"Firing rate\": 793.9666138437617, \"Power\": 793.9666138437617, \"i_spike\": 117.0, \"isi\": 0.029395611103945375, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.318691352753477, \"Firing rate\": 208.3009989753317, \"Power\": 208.3009989753317, \"i_spike\": 114.0, \"isi\": 0.03080051727849002, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5660625459247224, \"Firing rate\": 368.181994406344, \"Power\": 368.181994406344, \"i_spike\": 110.5, \"isi\": 0.03146794625834939, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.09200788071158, \"Firing rate\": 123.59698611612541, \"Power\": 123.59698611612541, \"i_spike\": 105.5, \"isi\": 0.03222740436284654, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3257979747918998, \"Firing rate\": 211.73759446862695, \"Power\": 211.73759446862695, \"i_spike\": 99.0, \"isi\": 0.035110212287434966, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6983799828455997, \"Firing rate\": 499.3211738782113, \"Power\": 499.3211738782113, \"i_spike\": 100.5, \"isi\": 0.03493647252317627, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.295038880371647, \"Firing rate\": 197.25993258831056, \"Power\": 197.25993258831056, \"i_spike\": 99.5, \"isi\": 0.034805791974127157, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189777301058197, \"Firing rate\": 262.40839812996177, \"Power\": 262.40839812996177, \"i_spike\": 114.0, \"isi\": 0.030289604306854862, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.108818343863044, \"Firing rate\": 128.47491643129774, \"Power\": 128.47491643129774, \"i_spike\": 105.0, \"isi\": 0.033402650086276076, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3301618907903223, \"Firing rate\": 213.8759200460872, \"Power\": 213.8759200460872, \"i_spike\": 102.0, \"isi\": 0.033515540373164496, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2662952548825976, \"Firing rate\": 184.62701784490469, \"Power\": 184.62701784490469, \"i_spike\": 99.5, \"isi\": 0.03522950669230892, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 6, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.431293700022412, \"Firing rate\": 269.9564447816099, \"Power\": 269.9564447816099, \"i_spike\": 112.5, \"isi\": 0.031214818356640563, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3379956540094025, \"Firing rate\": 217.76879800918366, \"Power\": 217.76879800918366, \"i_spike\": 128.0, \"isi\": 0.027142001158740867, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 4.268793452708704, \"Firing rate\": 18569.21106902568, \"Power\": 18569.21106902568, \"i_spike\": 112.5, \"isi\": 0.030884711280865364, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.470335706667271, \"Firing rate\": 295.3491373163173, \"Power\": 295.3491373163173, \"i_spike\": 118.5, \"isi\": 0.029429433800978892, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2298279031444963, \"Firing rate\": 169.7570826751943, \"Power\": 169.7570826751943, \"i_spike\": 115.5, \"isi\": 0.030066265039225337, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.079781857998895, \"Firing rate\": 120.16607002272158, \"Power\": 120.16607002272158, \"i_spike\": 112.5, \"isi\": 0.031040291113719316, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3243380859972738, \"Firing rate\": 211.02702965366592, \"Power\": 211.02702965366592, \"i_spike\": 115.5, \"isi\": 0.03017297418481671, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.376992751237567, \"Firing rate\": 238.22797066527903, \"Power\": 238.22797066527903, \"i_spike\": 110.0, \"isi\": 0.03125175833885984, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.530486613796888, \"Firing rate\": 339.22403352142646, \"Power\": 339.22403352142646, \"i_spike\": 108.5, \"isi\": 0.03222598156798059, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4983008808245897, \"Firing rate\": 314.99298413824465, \"Power\": 314.99298413824465, \"i_spike\": 116.5, \"isi\": 0.029967692171019168, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.482166228126963, \"Firing rate\": 303.5052641678235, \"Power\": 303.5052641678235, \"i_spike\": 124.5, \"isi\": 0.02742142830301335, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6952270146103454, \"Firing rate\": 495.70924045465966, \"Power\": 495.70924045465966, \"i_spike\": 116.5, \"isi\": 0.029805997031659384, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 1.969829747877291, \"Firing rate\": 93.288851814792, \"Power\": 93.288851814792, \"i_spike\": 104.5, \"isi\": 0.033232072449794876, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3040227572766634, \"Firing rate\": 201.3829772917563, \"Power\": 201.3829772917563, \"i_spike\": 118.5, \"isi\": 0.02930928089506225, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2482213585722888, \"Firing rate\": 177.10114074206854, \"Power\": 177.10114074206854, \"i_spike\": 118.5, \"isi\": 0.02923254019041047, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.302306969151288, \"Firing rate\": 200.58893343119396, \"Power\": 200.58893343119396, \"i_spike\": 114.0, \"isi\": 0.030554998388585986, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1470214089632194, \"Firing rate\": 140.28828593141267, \"Power\": 140.28828593141267, \"i_spike\": 123.0, \"isi\": 0.02824600472582251, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1317778042739737, \"Firing rate\": 135.44962414921912, \"Power\": 135.44962414921912, \"i_spike\": 107.5, \"isi\": 0.03260242125359381, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.861629232615016, \"Firing rate\": 727.1587469920275, \"Power\": 727.1587469920275, \"i_spike\": 121.5, \"isi\": 0.02876842284627423, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.309175796871508, \"Firing rate\": 203.7866813288123, \"Power\": 203.7866813288123, \"i_spike\": 127.0, \"isi\": 0.02726151253501496, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1426446687258776, \"Firing rate\": 138.88158641854218, \"Power\": 138.88158641854218, \"i_spike\": 120.0, \"isi\": 0.02911404261537866, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4489418426509477, \"Firing rate\": 281.15243076571574, \"Power\": 281.15243076571574, \"i_spike\": 128.5, \"isi\": 0.026789992139581283, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.412848701632391, \"Firing rate\": 258.73113973987586, \"Power\": 258.73113973987586, \"i_spike\": 124.0, \"isi\": 0.028201124990781163, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.710877629385823, \"Firing rate\": 513.8988305482127, \"Power\": 513.8988305482127, \"i_spike\": 119.0, \"isi\": 0.0293764992264836, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.991538408306236, \"Firing rate\": 980.7050424652082, \"Power\": 980.7050424652082, \"i_spike\": 135.0, \"isi\": 0.025953587990479317, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2762121037042795, \"Firing rate\": 188.89136444020025, \"Power\": 188.89136444020025, \"i_spike\": 122.0, \"isi\": 0.028669385615676706, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.7177018467167304, \"Firing rate\": 522.0376749188929, \"Power\": 522.0376749188929, \"i_spike\": 138.0, \"isi\": 0.02496409561586277, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3914116825786387, \"Firing rate\": 246.27009764338933, \"Power\": 246.27009764338933, \"i_spike\": 110.5, \"isi\": 0.0316618510656651, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6892037162497906, \"Firing rate\": 488.8816272272226, \"Power\": 488.8816272272226, \"i_spike\": 131.5, \"isi\": 0.02658745064897301, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4434824501248773, \"Firing rate\": 277.64026491830793, \"Power\": 277.64026491830793, \"i_spike\": 120.0, \"isi\": 0.0290789856927443, \"combined_condition\": 1.0}, {\"stim\": 1, \"mouse\": 7, \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.238506636309727, \"Firing rate\": 173.18354941508804, \"Power\": 173.18354941508804, \"i_spike\": 121.0, \"isi\": 0.028971993333475, \"combined_condition\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "BayesWindow(df=df, y='Log power', treatment='stim', group='mouse', detail='i_trial').data_box_detail().facet(\n",
    "    column='mouse')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Fit a Bayesian hierarchical model and plot slopes\n",
    "In a hierarchical model, parameters are viewed as a sample from a population distribution of parameters. Thus, we view them as being neither entirely different or exactly the same. This is ***partial pooling***:\n",
    "\n",
    "![hierarchical](../motivation/parpooled.png)\n",
    "This model allows intercepts to vary across mouse, according to a random effect. We just add a fixed slope for the predictor (i.e all mice will have the same slope):\n",
    "\n",
    "$$y_i = \\alpha_{j[i]} + \\beta x_{i} + \\epsilon_i$$\n",
    "\n",
    "where:\n",
    "- $j$ is mouse index\n",
    "- $i$ is observation index\n",
    "- $y_i$ is observed power\n",
    "- $x_i$ is 0 (no stimulation) or 1 (stimulation)\n",
    "- $\\epsilon_i \\sim N(0, \\sigma_y^2)$, error\n",
    "- $\\alpha_{j[i]} \\sim N(\\mu_{\\alpha}, \\sigma_{\\alpha}^2)$, Random intercept\n",
    "\n",
    "We set a separate intercept for each mouse, but rather than fitting separate regression models for each mouse, multilevel modeling **shares strength** among mice, allowing for more reasonable inference in mice with little data."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "The wrappers in this library allow us to fit and plot this inference in just three lines of code. Under the hood, it uses the following Numpyro code:\n",
    "```python\n",
    "# Given: y, treatment, group, n_subjects\n",
    "# Sample intercepts\n",
    "a = sample('a', Normal(0, 1))\n",
    "a_subject = sample('a_subject', Normal(jnp.tile(0, n_subjects), 1))\n",
    "\n",
    "# Sample variances\n",
    "sigma_a_subject = sample('sigma_a', HalfNormal(1))\n",
    "sigma_obs = sample('sigma_obs', HalfNormal(1))\n",
    "\n",
    "# Sample slope - this is what we are interested in!\n",
    "b = sample('b_stim', Normal(0, 1))\n",
    "\n",
    "# Regression equation\n",
    "theta = a + a_subject[group] * sigma_a_subject + b * treatment\n",
    "\n",
    "# Sample power\n",
    "sample('y', Normal(theta, sigma_obs), obs=y)\n",
    "```\n",
    "\n",
    "\n",
    "Above is the contents of `model_hier_stim_one_codition.py`, the function passed as argument in line 4 below."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [],
   "source": [
    "# Initialize:\n",
    "window = BayesRegression(df=df, y='Power', treatment='stim', group='mouse')\n",
    "# Fit:\n",
    "window.fit(model=models.model_hierarchical, add_group_intercept=True,\n",
    "           add_group_slope=False, robust_slopes=False,\n",
    "           do_make_change='subtract', dist_y='gamma')\n",
    "\n",
    "chart_power_difference = (window.chart + window.chart_posterior_kde).properties(title='Posterior')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-2a06cd7e88234ed38eab51685bcfd629\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-2a06cd7e88234ed38eab51685bcfd629\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-2a06cd7e88234ed38eab51685bcfd629\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\", \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-7b75ead138b5701714ef21e640a42f5e\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 237.74384705687086, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 166.46023493627612, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": 102.02669332812849, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": 273.27981160465947, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 25.7188242111219, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -69.5886318431294, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -79.3676220517491, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": 644.1470615759551, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-335274e0c5848c5eb146b4572e80f925\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -5.040781497955322, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -3.2319483757019043, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -14.338045120239258, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -9.673306465148926, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -4.925235748291016, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -12.546177864074707, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -11.706274032592773, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -14.756869316101074, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -12.631892204284668, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -16.163843154907227, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -4.770541191101074, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -6.212677478790283, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -9.943546295166016, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -8.178187370300293, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -8.886363983154297, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.480189323425293, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -10.987234115600586, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -10.944351196289062, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -11.506084442138672, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -1.8251782655715942, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -12.498072624206543, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -12.514010429382324, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -17.6185245513916, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -5.716065406799316, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -12.775249481201172, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -3.373499870300293, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -10.66567611694336, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -3.174480676651001, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -6.656539440155029, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -5.057694435119629, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -6.132038593292236, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -6.260168075561523, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -6.267385959625244, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -18.276689529418945, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -14.591009140014648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -6.426440715789795, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -14.020872116088867, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -8.92737102508545, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -8.799839973449707, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -10.442145347595215, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -11.592804908752441, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -1.3473926782608032, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -4.051822662353516, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -5.211493015289307, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -4.1107282638549805, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -2.415545701980591, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -16.093782424926758, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -17.072484970092773, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -20.167388916015625, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -23.8348388671875, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": -7.981138229370117, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -0.04728800058364868, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -8.871659278869629, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -9.35479736328125, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -3.8808343410491943, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -6.361900329589844, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -7.999002456665039, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -5.894481658935547, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -13.972681045532227, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -13.822797775268555, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -3.046886682510376, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -16.953060150146484, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -3.695838451385498, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -14.566791534423828, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -13.50625991821289, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -18.355134963989258, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -2.4528801441192627, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -7.53265905380249, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -6.505617618560791, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -12.704715728759766, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -1.9597692489624023, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -12.978065490722656, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -8.506797790527344, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -5.759369850158691, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": -25.789400100708008, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -22.311338424682617, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -8.781279563903809, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -13.314993858337402, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -1.3805243968963623, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -1.0229171514511108, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -7.584434986114502, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -7.566932678222656, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -7.094293117523193, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -11.389894485473633, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -8.709399223327637, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -10.357560157775879, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -16.34046173095703, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": 0.6019138693809509, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -1.9741706848144531, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -7.676919937133789, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -11.231236457824707, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -1.5288472175598145, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -16.779338836669922, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -4.3895158767700195, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -18.84963035583496, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -17.951358795166016, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -5.909987926483154, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -12.995099067687988, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -14.546140670776367, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -12.310595512390137, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -12.568388938903809, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -11.030439376831055, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -11.577783584594727, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -19.112316131591797, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -12.155937194824219, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -13.99992561340332, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -7.133065223693848, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -11.40817642211914, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -7.663388252258301, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -7.15134859085083, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -11.182429313659668, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -6.685650825500488, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -13.261324882507324, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -8.376654624938965, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -8.474446296691895, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -11.404654502868652, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -15.137195587158203, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -2.7283873558044434, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -5.247433662414551, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -9.17174243927002, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -3.0005855560302734, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -4.599752902984619, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -9.993454933166504, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -8.326324462890625, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -6.7738237380981445, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -18.34370994567871, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -16.528854370117188, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -6.6535491943359375, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -11.81106185913086, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -16.69459342956543, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -14.064314842224121, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -9.772653579711914, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -11.23830509185791, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -4.780694961547852, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -14.838922500610352, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -5.256370544433594, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -9.29879093170166, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -13.37845230102539, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -10.741788864135742, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -7.814037799835205, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -8.544958114624023, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -5.639056205749512, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -2.9378082752227783, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -8.153556823730469, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -14.391047477722168, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -4.369668960571289, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -2.46347713470459, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -3.629565954208374, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -10.348349571228027, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -4.948489665985107, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -12.884615898132324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -5.245946407318115, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -6.670903205871582, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -8.891148567199707, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -9.279622077941895, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -8.383540153503418, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -4.247647762298584, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -12.485112190246582, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -5.546526908874512, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -10.073062896728516, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -10.178902626037598, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -13.806653022766113, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -13.627968788146973, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -15.624517440795898, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -17.04638671875, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -8.39765453338623, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -9.610179901123047, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -12.103351593017578, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -19.356971740722656, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -2.4488518238067627, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -17.13677215576172, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -5.408355236053467, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -7.60662317276001, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": 0.21036642789840698, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -4.18886661529541, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -1.2615326642990112, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -6.848775863647461, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -9.153616905212402, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -2.357057571411133, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -7.682571887969971, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -3.3885879516601562, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -11.814712524414062, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -6.619076251983643, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -12.91315746307373, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -8.867708206176758, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -14.581746101379395, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -19.71653175354004, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -19.991769790649414, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -21.214252471923828, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -6.644197940826416, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -10.407630920410156, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -11.46703052520752, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -8.729238510131836, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -7.291738510131836, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -8.144486427307129, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.621789932250977, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -9.452020645141602, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -2.7215309143066406, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -3.036237955093384, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -19.85153579711914, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -12.849891662597656, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -6.997928142547607, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -10.627803802490234, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -5.472050189971924, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -16.494998931884766, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -16.4442138671875, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -5.7470502853393555, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -8.932648658752441, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -8.577373504638672, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -8.965713500976562, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -11.161826133728027, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -7.89268684387207, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -7.564478397369385, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -13.452535629272461, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -14.08469295501709, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -2.954566717147827, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -11.441118240356445, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -6.81473970413208, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -2.3359830379486084, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -3.075653553009033, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -11.325859069824219, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -4.258692264556885, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -4.423980712890625, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -13.428261756896973, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -11.3971586227417, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -13.256096839904785, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.62111234664917, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -4.03687047958374, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -11.875662803649902, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -7.4272379875183105, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -7.029792308807373, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -9.917837142944336, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -6.4340691566467285, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -8.416629791259766, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -9.764811515808105, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -13.684724807739258, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -9.332736015319824, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -5.513200759887695, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -5.412356853485107, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -10.102581977844238, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -9.726181030273438, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -8.257014274597168, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -3.624953508377075, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -2.589315891265869, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -8.779748916625977, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -6.400252342224121, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -8.629778861999512, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -16.5101318359375, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -17.6689453125, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": -4.915207386016846, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -6.15136194229126, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -6.802655220031738, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -7.658843517303467, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -9.336639404296875, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -6.3743815422058105, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -3.255826711654663, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -12.883275985717773, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -16.258590698242188, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -16.643815994262695, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -5.674232482910156, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -10.518762588500977, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -11.083512306213379, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -5.980678081512451, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -2.541947364807129, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -20.78319549560547, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -3.921635150909424, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": 0.5861846804618835, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -11.339868545532227, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -0.389615923166275, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -12.612652778625488, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -10.362377166748047, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -1.3020634651184082, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -14.657515525817871, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.195693016052246, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -13.869643211364746, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -14.57094669342041, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -13.50912857055664, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -8.952861785888672, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -8.80617904663086, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -3.6185855865478516, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -10.87226390838623, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -12.242692947387695, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -15.20461368560791, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -9.234443664550781, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -7.426700592041016, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -13.220755577087402, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -5.277491569519043, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -8.162809371948242, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -7.106990337371826, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -8.721697807312012, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -10.575236320495605, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -9.488320350646973, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -6.3274407386779785, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -8.079594612121582, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -8.850040435791016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -4.494203090667725, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -8.342353820800781, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -7.779570579528809, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -5.749445915222168, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -3.8445205688476562, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -9.672994613647461, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -2.8184850215911865, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -5.3096466064453125, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -9.379035949707031, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -8.699469566345215, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -6.1675639152526855, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.189728736877441, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -5.6182026863098145, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -2.484952211380005, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -4.12829065322876, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -11.519996643066406, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -7.22760009765625, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -4.460574626922607, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -14.75634479522705, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -1.8370130062103271, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -4.823190212249756, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -17.70157814025879, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -17.373361587524414, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -18.10245132446289, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -3.457681655883789, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -8.75065803527832, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -16.165645599365234, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -22.6804141998291, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -19.911861419677734, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -22.61591148376465, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -11.622304916381836, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": 0.998124361038208, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -6.8948655128479, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -4.078651428222656, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -7.3026604652404785, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -11.44503116607666, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -17.5340576171875, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -16.409536361694336, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -5.208342552185059, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -10.778684616088867, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -17.12391471862793, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -15.53206729888916, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -24.478370666503906, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -3.444739818572998, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -8.01969051361084, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -6.329585552215576, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -4.347865581512451, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -12.938542366027832, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -9.006197929382324, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -5.012093544006348, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -4.965196132659912, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -15.606342315673828, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -5.539521217346191, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -5.314929962158203, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -1.2871633768081665, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -14.534015655517578, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -4.73247766494751, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -11.297335624694824, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": 0.9405475854873657, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.757895469665527, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -10.374063491821289, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -16.98774528503418, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -8.18375015258789, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -4.701827526092529, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -11.026098251342773, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -10.939376831054688, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -2.6122803688049316, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -12.174870491027832, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -6.430441856384277, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -10.59070873260498, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -3.260490655899048, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -3.310577154159546, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -11.701184272766113, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -16.167146682739258, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -6.8973283767700195, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -19.691875457763672, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -11.031414985656738, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -5.411973476409912, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -3.844919443130493, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -5.477871417999268, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -9.450149536132812, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -7.657480239868164, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -13.941293716430664, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -9.572578430175781, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -8.065054893493652, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -4.444667339324951, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -6.401512145996094, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -7.924699306488037, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": 0.7744003534317017, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -24.4804630279541, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -39.773441314697266, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -31.81466293334961, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -20.902446746826172, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -17.315820693969727, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": 5.48476505279541, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -1.5803248882293701, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -18.618637084960938, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -8.642467498779297, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -11.297926902770996, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -15.921405792236328, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -6.936874866485596, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -0.2094547003507614, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -18.638042449951172, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -14.544658660888672, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -12.04907512664795, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -5.024633407592773, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -3.489513635635376, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -9.497099876403809, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -8.240531921386719, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -6.346133232116699, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -14.385534286499023, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -12.13107681274414, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -10.018568992614746, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -5.1738667488098145, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -10.29282283782959, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -9.026412963867188, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -4.315159320831299, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -6.5509257316589355, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -19.04126739501953, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -16.34767723083496, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -2.5898938179016113, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -3.3687591552734375, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -7.322995662689209, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -2.7231345176696777, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -10.025606155395508, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -3.8277714252471924, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -14.222061157226562, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -7.5450663566589355, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -9.19723892211914, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -9.410855293273926, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -1.858840823173523, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -9.601522445678711, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -23.54803466796875, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -23.492151260375977, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -2.0137908458709717, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -7.213013648986816, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -5.775428295135498, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -5.777145862579346, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -17.992870330810547, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -19.222583770751953, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -3.606680393218994, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -7.077849388122559, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -7.946872234344482, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -7.342119216918945, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -7.215571880340576, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -9.698287010192871, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -11.335079193115234, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -5.650229454040527, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -6.336968898773193, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -3.8731679916381836, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -11.074392318725586, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -3.630917549133301, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -6.614351749420166, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -8.51510238647461, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -2.4186511039733887, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -1.1323734521865845, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -18.85658073425293, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -3.8716964721679688, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -9.455548286437988, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -13.154111862182617, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -2.69400691986084, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -16.04335594177246, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -15.140952110290527, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -16.074392318725586, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -10.598502159118652, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -4.471084117889404, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -9.135819435119629, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -6.191133499145508, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -0.926066517829895, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -12.166131973266602, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -12.361000061035156, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -16.498821258544922, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -17.714357376098633, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -15.189769744873047, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -18.966697692871094, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -10.010828018188477, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -9.98740291595459, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -5.75197172164917, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -15.284516334533691, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -5.489589214324951, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -12.943856239318848, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -0.22668716311454773, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -15.675498008728027, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -6.588681221008301, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -7.812132835388184, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -6.533406734466553, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -8.366008758544922, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -6.541745662689209, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -7.343019485473633, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -2.4424896240234375, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -23.04140281677246, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -0.7497562766075134, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -4.742270469665527, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": 1.0736088752746582, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": 0.024408448487520218, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -2.8643569946289062, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -8.307125091552734, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -8.772392272949219, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -0.5112401843070984, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -6.886197090148926, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -6.327877998352051, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -12.50365924835205, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -11.757549285888672, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -1.3050986528396606, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -13.721922874450684, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -12.205488204956055, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -15.0798978805542, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -3.8415820598602295, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -9.192111015319824, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -7.257448673248291, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -6.073168754577637, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -6.093765735626221, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -9.180815696716309, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -14.790719032287598, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -8.083637237548828, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -16.844039916992188, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -15.44870376586914, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -7.9280314445495605, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -15.37336254119873, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": 0.20836150646209717, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -9.434063911437988, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -10.677699089050293, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -13.1483154296875, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -8.331754684448242, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -11.413102149963379, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -10.736640930175781, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -20.958683013916016, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -3.8055968284606934, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -5.030653953552246, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -13.732660293579102, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -12.01431655883789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -14.626978874206543, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -14.44836711883545, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -11.47911548614502, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -15.735791206359863, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -13.227349281311035, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -3.8430216312408447, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -10.357236862182617, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -8.008966445922852, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -6.926792144775391, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -7.791112899780273, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -6.468642711639404, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -9.571223258972168, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -3.7362332344055176, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -10.967222213745117, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -18.106294631958008, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -16.127092361450195, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -10.687830924987793, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -8.566162109375, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -4.050730228424072, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": 1.3152552843093872, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -2.0139448642730713, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -4.341344833374023, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -8.37908935546875, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -22.976163864135742, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -10.430059432983398, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -14.850079536437988, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -20.197887420654297, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -6.68999719619751, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -2.815863847732544, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -17.887845993041992, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -3.541370153427124, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -3.542423963546753, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -6.5178399085998535, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -6.637992858886719, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": -1.2293953895568848, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -17.230424880981445, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -11.51131534576416, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -8.765068054199219, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -6.458959102630615, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -5.430912017822266, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -3.6724812984466553, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -3.493516206741333, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -11.444568634033203, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -9.342259407043457, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -9.024116516113281, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -7.584840297698975, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -19.061552047729492, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -10.222793579101562, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -14.651355743408203, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -14.484232902526855, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -0.38055333495140076, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": 2.191359043121338, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -16.867826461791992, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -5.231989860534668, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -4.299243927001953, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -1.6465952396392822, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -18.220346450805664, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -6.526581287384033, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -9.6726713180542, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -9.635215759277344, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -13.181056022644043, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -5.687668323516846, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -16.44668197631836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -3.8459317684173584, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -10.190849304199219, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -11.476523399353027, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -5.591184616088867, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -5.949356555938721, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -5.420851230621338, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -14.403029441833496, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -10.093840599060059, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -18.961095809936523, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -11.777244567871094, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -13.17252254486084, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -12.879655838012695, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": 0.7822245359420776, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -10.36086654663086, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -28.181034088134766, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": 0.6640376448631287, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -17.449878692626953, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -13.05380916595459, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": 0.5147354602813721, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -0.6536664962768555, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": 2.406078338623047, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": 6.2492570877075195, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -16.29853057861328, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -14.67895221710205, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -14.72924518585205, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -7.888645172119141, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -13.071282386779785, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -5.036900043487549, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -16.05565071105957, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -7.945497035980225, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -12.781723022460938, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -11.250772476196289, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -5.3124680519104, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -11.05871868133545, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -13.738811492919922, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -5.289099216461182, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -2.5719308853149414, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": 4.691713809967041, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": 1.5101555585861206, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -16.513256072998047, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": 4.7369537353515625, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -16.79252052307129, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -17.795873641967773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -17.840864181518555, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -11.204030990600586, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -11.924735069274902, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -19.330913543701172, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -21.98118782043457, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -3.0958797931671143, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -2.735022783279419, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -10.548039436340332, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 640, \"mu_intercept_per_group\": -1.3955962657928467, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 641, \"mu_intercept_per_group\": -17.113033294677734, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 642, \"mu_intercept_per_group\": -11.39327621459961, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 643, \"mu_intercept_per_group\": -12.532562255859375, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 644, \"mu_intercept_per_group\": -8.902205467224121, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 645, \"mu_intercept_per_group\": -16.35418128967285, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 646, \"mu_intercept_per_group\": -18.42349624633789, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 647, \"mu_intercept_per_group\": -20.9619083404541, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 648, \"mu_intercept_per_group\": -18.798307418823242, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 649, \"mu_intercept_per_group\": 4.921034812927246, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 650, \"mu_intercept_per_group\": 2.829319953918457, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 651, \"mu_intercept_per_group\": -19.05095672607422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 652, \"mu_intercept_per_group\": -5.474806785583496, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 653, \"mu_intercept_per_group\": -4.922374725341797, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 654, \"mu_intercept_per_group\": -10.816702842712402, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 655, \"mu_intercept_per_group\": 0.6563606858253479, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 656, \"mu_intercept_per_group\": -11.115660667419434, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 657, \"mu_intercept_per_group\": -9.447301864624023, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 658, \"mu_intercept_per_group\": -13.556966781616211, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 659, \"mu_intercept_per_group\": -11.097416877746582, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 660, \"mu_intercept_per_group\": -5.995758533477783, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 661, \"mu_intercept_per_group\": -2.3554229736328125, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 662, \"mu_intercept_per_group\": -3.1295342445373535, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 663, \"mu_intercept_per_group\": -4.682866096496582, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 664, \"mu_intercept_per_group\": -3.5213005542755127, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 665, \"mu_intercept_per_group\": -4.978518486022949, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 666, \"mu_intercept_per_group\": -3.724959135055542, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 667, \"mu_intercept_per_group\": -6.1379313468933105, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 668, \"mu_intercept_per_group\": -4.124699115753174, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 669, \"mu_intercept_per_group\": -8.214367866516113, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 670, \"mu_intercept_per_group\": 1.0553821325302124, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 671, \"mu_intercept_per_group\": -11.239164352416992, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 672, \"mu_intercept_per_group\": -6.925349235534668, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 673, \"mu_intercept_per_group\": -6.511587619781494, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 674, \"mu_intercept_per_group\": -11.621158599853516, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 675, \"mu_intercept_per_group\": -10.887262344360352, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 676, \"mu_intercept_per_group\": -7.85366678237915, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 677, \"mu_intercept_per_group\": -9.883703231811523, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 678, \"mu_intercept_per_group\": -5.222884654998779, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 679, \"mu_intercept_per_group\": -7.691766262054443, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 680, \"mu_intercept_per_group\": -3.4161531925201416, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 681, \"mu_intercept_per_group\": -23.19988250732422, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 682, \"mu_intercept_per_group\": 0.4955381453037262, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 683, \"mu_intercept_per_group\": -19.23976707458496, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 684, \"mu_intercept_per_group\": -15.268034934997559, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 685, \"mu_intercept_per_group\": -15.744549751281738, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 686, \"mu_intercept_per_group\": -13.575891494750977, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 687, \"mu_intercept_per_group\": -12.361751556396484, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 688, \"mu_intercept_per_group\": -15.737735748291016, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 689, \"mu_intercept_per_group\": -3.832686424255371, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 690, \"mu_intercept_per_group\": -6.5279645919799805, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 691, \"mu_intercept_per_group\": -4.437520980834961, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 692, \"mu_intercept_per_group\": -3.609692096710205, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 693, \"mu_intercept_per_group\": 5.752180576324463, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 694, \"mu_intercept_per_group\": -6.594266414642334, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 695, \"mu_intercept_per_group\": -8.382157325744629, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 696, \"mu_intercept_per_group\": -5.280394077301025, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 697, \"mu_intercept_per_group\": -3.3657338619232178, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 698, \"mu_intercept_per_group\": -13.693631172180176, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 699, \"mu_intercept_per_group\": -15.320185661315918, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 700, \"mu_intercept_per_group\": -16.62302589416504, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 701, \"mu_intercept_per_group\": -14.20588207244873, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 702, \"mu_intercept_per_group\": -14.253565788269043, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 703, \"mu_intercept_per_group\": -1.8492915630340576, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 704, \"mu_intercept_per_group\": -9.212831497192383, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 705, \"mu_intercept_per_group\": -7.338194847106934, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 706, \"mu_intercept_per_group\": -14.641120910644531, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 707, \"mu_intercept_per_group\": -16.60073471069336, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 708, \"mu_intercept_per_group\": -1.3629611730575562, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 709, \"mu_intercept_per_group\": -7.777461051940918, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 710, \"mu_intercept_per_group\": -1.8500031232833862, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 711, \"mu_intercept_per_group\": -22.09663200378418, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 712, \"mu_intercept_per_group\": 0.018531644716858864, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 713, \"mu_intercept_per_group\": 3.0248255729675293, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 714, \"mu_intercept_per_group\": -7.417457580566406, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 715, \"mu_intercept_per_group\": -6.956211090087891, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 716, \"mu_intercept_per_group\": -8.928647994995117, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 717, \"mu_intercept_per_group\": -0.22857104241847992, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 718, \"mu_intercept_per_group\": -6.185298442840576, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 719, \"mu_intercept_per_group\": -16.681169509887695, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 720, \"mu_intercept_per_group\": -5.962151050567627, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 721, \"mu_intercept_per_group\": -6.805093288421631, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 722, \"mu_intercept_per_group\": -11.011396408081055, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 723, \"mu_intercept_per_group\": -9.850343704223633, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 724, \"mu_intercept_per_group\": -10.407118797302246, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 725, \"mu_intercept_per_group\": -10.117226600646973, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 726, \"mu_intercept_per_group\": -5.316917419433594, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 727, \"mu_intercept_per_group\": -6.945923328399658, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 728, \"mu_intercept_per_group\": -9.492375373840332, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 729, \"mu_intercept_per_group\": -8.86750602722168, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 730, \"mu_intercept_per_group\": -7.798107624053955, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 731, \"mu_intercept_per_group\": -12.682540893554688, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 732, \"mu_intercept_per_group\": -12.547581672668457, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 733, \"mu_intercept_per_group\": -18.491785049438477, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 734, \"mu_intercept_per_group\": -8.545707702636719, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 735, \"mu_intercept_per_group\": -17.687284469604492, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 736, \"mu_intercept_per_group\": -5.70229434967041, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 737, \"mu_intercept_per_group\": -13.548932075500488, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 738, \"mu_intercept_per_group\": -9.389627456665039, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 739, \"mu_intercept_per_group\": -15.26278305053711, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 740, \"mu_intercept_per_group\": -1.2251851558685303, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 741, \"mu_intercept_per_group\": -11.610944747924805, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 742, \"mu_intercept_per_group\": -1.3939104080200195, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 743, \"mu_intercept_per_group\": -1.9360616207122803, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 744, \"mu_intercept_per_group\": -10.431615829467773, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 745, \"mu_intercept_per_group\": -8.211955070495605, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 746, \"mu_intercept_per_group\": -13.654766082763672, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 747, \"mu_intercept_per_group\": -2.444514513015747, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 748, \"mu_intercept_per_group\": -9.148351669311523, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 749, \"mu_intercept_per_group\": -1.5807955265045166, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 750, \"mu_intercept_per_group\": -15.372639656066895, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 751, \"mu_intercept_per_group\": -5.23089075088501, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 752, \"mu_intercept_per_group\": -14.592620849609375, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 753, \"mu_intercept_per_group\": -9.639511108398438, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 754, \"mu_intercept_per_group\": -9.418307304382324, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 755, \"mu_intercept_per_group\": -3.8247220516204834, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 756, \"mu_intercept_per_group\": -5.8500590324401855, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 757, \"mu_intercept_per_group\": -5.908278465270996, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 758, \"mu_intercept_per_group\": -14.808974266052246, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 759, \"mu_intercept_per_group\": -9.69106388092041, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 0, \"draws\": 760, \"mu_intercept_per_group\": -8.039718627929688, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 0, \"draws\": 761, \"mu_intercept_per_group\": -6.686943531036377, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 0, \"draws\": 762, \"mu_intercept_per_group\": -6.237182140350342, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 0, \"draws\": 763, \"mu_intercept_per_group\": -15.060968399047852, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 0, \"draws\": 764, \"mu_intercept_per_group\": -0.531229555606842, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 0, \"draws\": 765, \"mu_intercept_per_group\": -4.671209812164307, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 0, \"draws\": 766, \"mu_intercept_per_group\": -15.774847030639648, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 0, \"draws\": 767, \"mu_intercept_per_group\": -16.489418029785156, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 0, \"draws\": 768, \"mu_intercept_per_group\": -13.781782150268555, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 0, \"draws\": 769, \"mu_intercept_per_group\": -13.473760604858398, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 0, \"draws\": 770, \"mu_intercept_per_group\": -0.21044935286045074, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 0, \"draws\": 771, \"mu_intercept_per_group\": -15.083337783813477, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 0, \"draws\": 772, \"mu_intercept_per_group\": -4.676630973815918, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 0, \"draws\": 773, \"mu_intercept_per_group\": -12.31003189086914, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 0, \"draws\": 774, \"mu_intercept_per_group\": -6.071263790130615, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 0, \"draws\": 775, \"mu_intercept_per_group\": -12.3790864944458, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 0, \"draws\": 776, \"mu_intercept_per_group\": -10.242154121398926, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 0, \"draws\": 777, \"mu_intercept_per_group\": -14.512199401855469, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 0, \"draws\": 778, \"mu_intercept_per_group\": -6.676771640777588, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 0, \"draws\": 779, \"mu_intercept_per_group\": -9.669127464294434, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 0, \"draws\": 780, \"mu_intercept_per_group\": -11.874094009399414, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 0, \"draws\": 781, \"mu_intercept_per_group\": 0.7495285272598267, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 0, \"draws\": 782, \"mu_intercept_per_group\": -11.307819366455078, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 0, \"draws\": 783, \"mu_intercept_per_group\": -11.859552383422852, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 0, \"draws\": 784, \"mu_intercept_per_group\": -6.786609649658203, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 0, \"draws\": 785, \"mu_intercept_per_group\": -4.8037872314453125, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 0, \"draws\": 786, \"mu_intercept_per_group\": -1.0827637910842896, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 0, \"draws\": 787, \"mu_intercept_per_group\": -9.0177583694458, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 0, \"draws\": 788, \"mu_intercept_per_group\": -2.8852615356445312, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 0, \"draws\": 789, \"mu_intercept_per_group\": -2.3375611305236816, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 0, \"draws\": 790, \"mu_intercept_per_group\": -5.916977882385254, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 0, \"draws\": 791, \"mu_intercept_per_group\": -5.5406341552734375, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 0, \"draws\": 792, \"mu_intercept_per_group\": -5.125442028045654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 0, \"draws\": 793, \"mu_intercept_per_group\": -9.392108917236328, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 0, \"draws\": 794, \"mu_intercept_per_group\": 5.721161365509033, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 0, \"draws\": 795, \"mu_intercept_per_group\": -3.4059906005859375, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 0, \"draws\": 796, \"mu_intercept_per_group\": -5.1101531982421875, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 0, \"draws\": 797, \"mu_intercept_per_group\": -15.806418418884277, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 0, \"draws\": 798, \"mu_intercept_per_group\": 4.5742669105529785, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 0, \"draws\": 799, \"mu_intercept_per_group\": -16.5518798828125, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -8.463964462280273, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -5.522490978240967, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -8.630327224731445, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -7.021143913269043, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -2.774968385696411, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -10.757180213928223, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -8.160569190979004, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -10.12001895904541, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -4.824865341186523, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -8.315885543823242, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -5.182793140411377, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -10.113337516784668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -7.616043567657471, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -7.081296443939209, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -8.140750885009766, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -11.904815673828125, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -11.351101875305176, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -4.601489067077637, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -5.248831748962402, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -6.81367301940918, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -2.246152639389038, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -5.514193058013916, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -11.95570182800293, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -3.89855694770813, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": 4.90255069732666, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": 13.422053337097168, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": 6.911807537078857, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -5.5922770500183105, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -6.857975482940674, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -2.1050865650177, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -6.132362365722656, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -2.787949323654175, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -7.256302833557129, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -15.257880210876465, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -5.019294738769531, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -16.966064453125, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -8.912954330444336, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -14.777284622192383, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -5.526966571807861, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -4.6448774337768555, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": 2.525085687637329, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -15.121261596679688, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -3.2543210983276367, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -4.027781963348389, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -3.056781053543091, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -4.625176906585693, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": 2.2165396213531494, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": 1.1302454471588135, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -8.88571548461914, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -12.499415397644043, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -5.258360385894775, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -1.1019741296768188, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -2.7254743576049805, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -4.00599479675293, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -7.0142059326171875, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -4.741383075714111, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -2.4022116661071777, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -7.611382961273193, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -7.375605583190918, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -13.864294052124023, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": 1.5573049783706665, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -18.688922882080078, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -3.8896350860595703, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -2.6664626598358154, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -5.915189266204834, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -11.641724586486816, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -24.968902587890625, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": 3.673384428024292, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": 3.2681491374969482, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -5.521426200866699, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -9.135942459106445, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -9.367850303649902, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -8.582090377807617, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -12.789557456970215, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -7.178985595703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -3.3624579906463623, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -3.7026774883270264, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -20.197704315185547, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -2.000335216522217, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": 0.3444068729877472, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -6.717190742492676, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -5.477149486541748, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -11.214262008666992, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -16.399005889892578, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -1.7473465204238892, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -1.0917484760284424, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -3.080193519592285, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": 0.8146815299987793, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": 4.521572113037109, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.99426555633545, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -9.336772918701172, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -5.096127033233643, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -18.555667877197266, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": 8.260923385620117, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -19.096702575683594, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -19.96316146850586, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -1.9338761568069458, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -7.733426570892334, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -11.19599723815918, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -3.0945422649383545, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -4.423023700714111, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -14.207892417907715, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -10.578598976135254, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -6.583150863647461, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -18.78107452392578, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -5.156072616577148, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -13.016656875610352, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -3.282268524169922, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -1.4693411588668823, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -1.5940797328948975, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -8.228626251220703, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -7.249871253967285, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -5.003849029541016, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -6.709216117858887, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -5.370258808135986, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -6.2389020919799805, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -4.802653789520264, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -3.672044515609741, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -2.5114827156066895, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -6.614682197570801, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -1.314194679260254, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -7.518023490905762, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -5.575322151184082, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -4.340911865234375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -6.025227069854736, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -11.910261154174805, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -13.2202730178833, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -10.20504379272461, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -10.171121597290039, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -7.420294761657715, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -8.76205062866211, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -8.214826583862305, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -1.5067857503890991, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -2.995762348175049, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -10.4031982421875, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -5.307545185089111, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -6.915334701538086, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -6.712177276611328, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -11.415205001831055, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -15.197175979614258, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -5.711830139160156, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -1.4785627126693726, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -3.285017490386963, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -5.481128215789795, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -11.936737060546875, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": 0.36717545986175537, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -4.167700290679932, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": 0.07449424266815186, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -7.763571262359619, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -5.035675048828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -9.300844192504883, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": 3.1366419792175293, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -12.75354290008545, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -12.582444190979004, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -2.3910295963287354, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -12.289669036865234, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -2.905604362487793, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -7.637528896331787, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -5.888548851013184, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -9.943721771240234, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -7.501426696777344, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -5.770092487335205, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -1.948828935623169, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -15.492814064025879, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": 4.272012233734131, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -7.3533501625061035, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -7.2175164222717285, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -14.558330535888672, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -16.98981285095215, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": 4.297924995422363, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -19.546592712402344, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -8.8070650100708, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -4.942563056945801, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": 0.48789316415786743, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -2.812572479248047, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -1.250403881072998, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": 0.201321542263031, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -5.401147842407227, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -8.158730506896973, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -4.766443729400635, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -10.177217483520508, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -1.0570824146270752, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -17.689987182617188, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -9.77273941040039, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -7.371433734893799, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": 2.80295991897583, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": 3.2416961193084717, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": 0.44132789969444275, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -2.6126503944396973, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -9.670760154724121, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -8.313094139099121, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -10.328643798828125, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -9.322820663452148, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -12.268668174743652, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -10.417738914489746, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -11.325778007507324, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -11.268610000610352, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -2.5182535648345947, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -2.6109728813171387, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -11.761697769165039, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -1.9480599164962769, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -15.995800971984863, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -7.968087196350098, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -12.817194938659668, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -7.802563190460205, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -2.0851564407348633, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -9.967320442199707, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -2.524480104446411, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -1.9567384719848633, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -6.825958728790283, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -3.56683611869812, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -10.835593223571777, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -8.808893203735352, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -6.46396017074585, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -10.878059387207031, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -2.6873679161071777, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -6.742923259735107, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -9.391840934753418, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": 1.4834914207458496, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -0.8790526390075684, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -16.255952835083008, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -14.247909545898438, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -5.371616363525391, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -5.0700883865356445, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -7.676242828369141, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -9.607836723327637, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -22.520721435546875, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -9.707636833190918, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -18.860963821411133, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": 2.2030763626098633, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": 2.202141523361206, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -0.7342286109924316, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -7.996046543121338, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -8.649276733398438, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -6.344440460205078, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -4.691237926483154, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -7.299112796783447, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -5.575038433074951, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -3.972187042236328, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -9.599820137023926, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -8.358413696289062, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -5.024391174316406, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -5.716562747955322, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -3.77807879447937, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -5.500432014465332, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -7.615743160247803, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -4.611034393310547, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -10.824134826660156, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -9.529510498046875, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -6.8019843101501465, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -7.914368152618408, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -6.4699482917785645, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -5.027370929718018, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -3.10154128074646, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": 0.27238428592681885, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -11.068960189819336, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -1.8688381910324097, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -1.5642330646514893, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": 2.16567063331604, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -4.079339027404785, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -0.5596898794174194, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -13.810405731201172, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -2.4614691734313965, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -4.566840171813965, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -9.446951866149902, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -6.827064037322998, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": 2.2277393341064453, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -5.073843479156494, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -0.4736955165863037, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -9.838051795959473, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -5.923642158508301, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -7.2732462882995605, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -2.9811365604400635, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -5.687343597412109, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -7.497012138366699, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -6.166018962860107, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": 1.1129947900772095, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -2.388124942779541, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -4.539252758026123, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -17.606914520263672, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -6.165983200073242, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -3.742136001586914, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -3.639493703842163, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -5.823246955871582, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -12.123866081237793, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -7.763772010803223, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -6.970352649688721, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -0.6010066866874695, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -2.378098249435425, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -5.7572832107543945, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -11.822481155395508, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -4.5131025314331055, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -7.647518634796143, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -5.036931037902832, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -8.063419342041016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -8.231720924377441, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -10.115706443786621, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": 11.774689674377441, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": 1.6975617408752441, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -0.44665879011154175, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -5.412267208099365, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -4.182696342468262, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -1.9100764989852905, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -8.234150886535645, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -8.763331413269043, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -5.511397361755371, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -9.85831356048584, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -12.8724946975708, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": 7.688490867614746, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -12.401480674743652, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": 4.287363529205322, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -11.154162406921387, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -9.18152141571045, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -5.775693416595459, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -6.747610569000244, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -7.762335300445557, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -8.072798728942871, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -7.486238479614258, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -12.458937644958496, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -3.4186317920684814, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -5.2962493896484375, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -4.723546981811523, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -2.6898562908172607, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -3.6324923038482666, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -13.080504417419434, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -6.417844772338867, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -1.665814995765686, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -4.46502161026001, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -14.899575233459473, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -10.645574569702148, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -3.14841628074646, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -13.237945556640625, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -12.312538146972656, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -7.097439765930176, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -14.861870765686035, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -11.7489652633667, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -11.972259521484375, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -10.411721229553223, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -11.556038856506348, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -1.303446888923645, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -8.312260627746582, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -11.57768726348877, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -13.761001586914062, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -6.086140155792236, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -5.489706039428711, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -2.0879509449005127, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -13.66417407989502, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -10.065771102905273, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -5.447312355041504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -9.46387004852295, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -5.7930755615234375, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.894649505615234, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -4.028882026672363, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -1.6248077154159546, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -13.211878776550293, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -12.292472839355469, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -6.505354404449463, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -9.881367683410645, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -0.13978375494480133, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -10.650283813476562, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -9.862833023071289, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -5.99295711517334, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -3.788276433944702, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -4.967767715454102, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -10.58394718170166, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": 1.6004167795181274, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -0.0031337225809693336, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -12.571540832519531, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -11.773927688598633, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -6.5745062828063965, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -6.903250694274902, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -4.94040060043335, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -11.601109504699707, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -12.11928653717041, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -3.1288840770721436, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -9.122939109802246, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -11.455864906311035, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -7.932468891143799, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -5.82853889465332, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -5.114236831665039, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -2.7878990173339844, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -4.554833889007568, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -13.072132110595703, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": 5.590129375457764, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -20.363454818725586, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -34.7641716003418, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -15.950664520263672, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -10.630252838134766, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -13.557367324829102, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": 2.0046355724334717, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -12.566685676574707, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -7.294683933258057, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -12.405985832214355, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -8.00912094116211, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -8.846941947937012, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.363330841064453, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -3.7095868587493896, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -4.117101669311523, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -6.945756435394287, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -8.627290725708008, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -1.4066123962402344, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -14.80611801147461, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -5.313531875610352, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -7.835374355316162, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -4.99541711807251, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -4.97422981262207, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -5.330106735229492, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -8.303894996643066, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": 2.135199546813965, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -16.06319808959961, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": 0.7605302333831787, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -13.170872688293457, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -15.687202453613281, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -1.7165426015853882, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -5.136164665222168, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -4.370528697967529, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -4.880247592926025, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -1.911839246749878, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -9.556730270385742, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -0.8126273155212402, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -6.101413726806641, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.357921600341797, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -13.671849250793457, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -3.5299882888793945, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -4.885555267333984, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -8.022061347961426, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -2.0411484241485596, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -9.610355377197266, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -1.847278118133545, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -11.80907154083252, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -8.462021827697754, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -4.326870441436768, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -5.468924522399902, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -6.299935817718506, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -13.798683166503906, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -3.594536304473877, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -8.656484603881836, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -6.9296417236328125, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -7.686049938201904, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -12.964165687561035, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -7.580221176147461, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -7.629336833953857, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -7.874495029449463, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -3.870492458343506, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -15.039116859436035, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -3.3166422843933105, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -10.479406356811523, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -10.407120704650879, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -3.1247706413269043, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -9.59276294708252, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -8.741473197937012, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -2.6316232681274414, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -10.259936332702637, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -16.08149528503418, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -22.595226287841797, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -13.521262168884277, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -15.243318557739258, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -8.26047420501709, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -5.657673358917236, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -3.0963892936706543, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -10.927461624145508, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -1.3937886953353882, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -12.800820350646973, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -2.9563820362091064, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": 3.0324513912200928, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -1.3185973167419434, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -10.170413970947266, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -8.437788009643555, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -29.883220672607422, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -2.5528335571289062, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -5.943991184234619, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.220870971679688, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -10.247591972351074, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -11.83267593383789, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -1.1434195041656494, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -3.710218906402588, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -4.687295913696289, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -6.169580936431885, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -12.876049041748047, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -7.897989749908447, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -7.6432037353515625, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -3.8371458053588867, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -7.476674556732178, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -6.591335773468018, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -2.628870964050293, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -19.54383087158203, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": 3.079812526702881, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": 3.0599868297576904, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -4.361057758331299, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -13.445945739746094, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -8.224185943603516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -5.457669258117676, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -7.8514838218688965, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -14.69129467010498, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -4.073327541351318, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -10.719621658325195, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -3.484194040298462, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -21.873950958251953, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -12.562688827514648, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -14.433303833007812, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -11.538043022155762, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -5.583098411560059, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -6.319106101989746, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -4.117209434509277, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -4.087664604187012, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -5.711300373077393, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -6.448568344116211, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -9.299012184143066, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -1.6976025104522705, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -10.521522521972656, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -9.352278709411621, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -14.279708862304688, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -11.237142562866211, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -3.7602996826171875, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -14.102614402770996, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": 1.834031581878662, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -6.776103496551514, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -7.349850654602051, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -11.03607177734375, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -10.871505737304688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -10.033157348632812, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -10.515748977661133, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -10.465447425842285, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -11.220648765563965, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -9.48349380493164, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -19.80289077758789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -18.929874420166016, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -15.037124633789062, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -15.797110557556152, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -11.973806381225586, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -11.365989685058594, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -14.679963111877441, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -11.842629432678223, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -2.3008553981781006, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -5.299274444580078, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -9.47567081451416, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -8.240625381469727, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -6.985145568847656, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -1.8116092681884766, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -14.579553604125977, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -0.15882565081119537, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -11.052987098693848, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -10.534075736999512, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -12.461343765258789, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -3.4963104724884033, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -3.2063283920288086, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -4.655256271362305, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": 3.90130352973938, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -9.238557815551758, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -12.395340919494629, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -10.23513412475586, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -10.9961576461792, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -9.297804832458496, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -8.414896965026855, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -11.95994758605957, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -2.9788801670074463, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -11.210237503051758, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -9.273188591003418, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -6.25204610824585, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -9.3336181640625, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -7.024564266204834, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -4.346048831939697, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -4.706249237060547, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -7.968608379364014, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -1.565627932548523, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -6.640815258026123, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -5.302150249481201, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -6.941023349761963, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -1.2704907655715942, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -7.112493515014648, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -8.465219497680664, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -5.155795097351074, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -6.536206245422363, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -9.535880088806152, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -10.2841157913208, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -8.211404800415039, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -8.24379825592041, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -8.449947357177734, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -10.331687927246094, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -16.199155807495117, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -13.972550392150879, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -18.041168212890625, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -3.4920613765716553, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -7.985953330993652, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -7.014187335968018, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -1.605649471282959, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -8.235715866088867, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -5.29293155670166, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -9.228889465332031, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -4.049346446990967, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -10.81877613067627, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -14.659221649169922, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -4.774314880371094, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -8.7986478805542, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -4.895114898681641, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -10.780174255371094, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -8.298257827758789, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -13.849451065063477, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -2.4056859016418457, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -3.175271987915039, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": 0.10836401581764221, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -14.298521041870117, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -9.087770462036133, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -10.402381896972656, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -9.93741512298584, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -10.765823364257812, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -6.67334508895874, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -4.509544372558594, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -9.220878601074219, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -4.86932897567749, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": 4.452273368835449, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -3.046302080154419, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -9.8165922164917, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -12.620911598205566, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -5.204877853393555, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -11.999639511108398, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -2.291882038116455, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -10.168539047241211, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -16.272212982177734, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -15.966462135314941, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -8.96129322052002, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -8.631392478942871, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": 3.074772834777832, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": 0.14587892591953278, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -12.751314163208008, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -13.256711959838867, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -10.27218246459961, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -7.958676815032959, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -5.983311176300049, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -4.754218578338623, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -7.612178325653076, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -10.645689010620117, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -0.6197846531867981, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -20.461259841918945, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -20.499818801879883, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -20.013587951660156, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -14.218558311462402, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": 2.9418017864227295, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": 0.09507820010185242, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": 0.4870001971721649, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 640, \"mu_intercept_per_group\": -6.998203754425049, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 641, \"mu_intercept_per_group\": -12.70267105102539, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 642, \"mu_intercept_per_group\": -12.564757347106934, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 643, \"mu_intercept_per_group\": -13.075398445129395, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 644, \"mu_intercept_per_group\": -14.863747596740723, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 645, \"mu_intercept_per_group\": -2.4183244705200195, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 646, \"mu_intercept_per_group\": -0.7938307523727417, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 647, \"mu_intercept_per_group\": -7.049498558044434, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 648, \"mu_intercept_per_group\": -5.135613918304443, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 649, \"mu_intercept_per_group\": -3.4538235664367676, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 650, \"mu_intercept_per_group\": -3.8301169872283936, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 651, \"mu_intercept_per_group\": -8.055845260620117, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 652, \"mu_intercept_per_group\": -10.992918014526367, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 653, \"mu_intercept_per_group\": -3.1368653774261475, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 654, \"mu_intercept_per_group\": -2.5501515865325928, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 655, \"mu_intercept_per_group\": -7.712600231170654, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 656, \"mu_intercept_per_group\": -8.44206714630127, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 657, \"mu_intercept_per_group\": -14.379984855651855, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 658, \"mu_intercept_per_group\": -11.493062973022461, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 659, \"mu_intercept_per_group\": -3.9389209747314453, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 660, \"mu_intercept_per_group\": -6.9828081130981445, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 661, \"mu_intercept_per_group\": -9.729299545288086, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 662, \"mu_intercept_per_group\": -9.274621963500977, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 663, \"mu_intercept_per_group\": -8.24915599822998, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 664, \"mu_intercept_per_group\": 1.9177732467651367, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 665, \"mu_intercept_per_group\": 0.6679157614707947, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 666, \"mu_intercept_per_group\": -6.791961193084717, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 667, \"mu_intercept_per_group\": -9.511539459228516, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 668, \"mu_intercept_per_group\": -8.007267951965332, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 669, \"mu_intercept_per_group\": -3.350052833557129, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 670, \"mu_intercept_per_group\": -3.5129752159118652, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 671, \"mu_intercept_per_group\": -6.794730186462402, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 672, \"mu_intercept_per_group\": 3.360326051712036, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 673, \"mu_intercept_per_group\": -1.6963112354278564, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 674, \"mu_intercept_per_group\": -11.35863208770752, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 675, \"mu_intercept_per_group\": -9.890142440795898, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 676, \"mu_intercept_per_group\": -6.259748458862305, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 677, \"mu_intercept_per_group\": -4.0634942054748535, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 678, \"mu_intercept_per_group\": -3.5187900066375732, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 679, \"mu_intercept_per_group\": -8.828516006469727, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 680, \"mu_intercept_per_group\": -5.272643566131592, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 681, \"mu_intercept_per_group\": -5.677806854248047, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 682, \"mu_intercept_per_group\": -11.633842468261719, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 683, \"mu_intercept_per_group\": -6.39860725402832, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 684, \"mu_intercept_per_group\": -15.06329345703125, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 685, \"mu_intercept_per_group\": -13.745234489440918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 686, \"mu_intercept_per_group\": -13.775030136108398, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 687, \"mu_intercept_per_group\": -10.523633003234863, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 688, \"mu_intercept_per_group\": -13.00391674041748, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 689, \"mu_intercept_per_group\": -0.534116268157959, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 690, \"mu_intercept_per_group\": -9.273967742919922, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 691, \"mu_intercept_per_group\": -1.7329838275909424, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 692, \"mu_intercept_per_group\": -0.6396942734718323, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 693, \"mu_intercept_per_group\": -7.303791046142578, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 694, \"mu_intercept_per_group\": -12.832805633544922, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 695, \"mu_intercept_per_group\": -12.848074913024902, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 696, \"mu_intercept_per_group\": 0.7132947444915771, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 697, \"mu_intercept_per_group\": -0.01631096377968788, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 698, \"mu_intercept_per_group\": -15.826177597045898, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 699, \"mu_intercept_per_group\": -14.799540519714355, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 700, \"mu_intercept_per_group\": -15.701089859008789, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 701, \"mu_intercept_per_group\": -25.847299575805664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 702, \"mu_intercept_per_group\": -15.596050262451172, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 703, \"mu_intercept_per_group\": -3.0136518478393555, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 704, \"mu_intercept_per_group\": -10.249879837036133, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 705, \"mu_intercept_per_group\": -3.0909831523895264, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 706, \"mu_intercept_per_group\": -11.727210998535156, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 707, \"mu_intercept_per_group\": -2.4828298091888428, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 708, \"mu_intercept_per_group\": -9.143221855163574, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 709, \"mu_intercept_per_group\": -8.30216121673584, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 710, \"mu_intercept_per_group\": -15.986251831054688, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 711, \"mu_intercept_per_group\": 3.363057851791382, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 712, \"mu_intercept_per_group\": -14.843551635742188, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 713, \"mu_intercept_per_group\": -9.049310684204102, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 714, \"mu_intercept_per_group\": -11.122550964355469, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 715, \"mu_intercept_per_group\": -10.008472442626953, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 716, \"mu_intercept_per_group\": -4.341726779937744, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 717, \"mu_intercept_per_group\": -6.1400651931762695, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 718, \"mu_intercept_per_group\": -10.843049049377441, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 719, \"mu_intercept_per_group\": -16.954082489013672, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 720, \"mu_intercept_per_group\": -1.3038560152053833, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 721, \"mu_intercept_per_group\": -3.9746432304382324, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 722, \"mu_intercept_per_group\": -15.726155281066895, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 723, \"mu_intercept_per_group\": -18.059703826904297, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 724, \"mu_intercept_per_group\": -15.85275936126709, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 725, \"mu_intercept_per_group\": -15.225875854492188, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 726, \"mu_intercept_per_group\": -0.8269123435020447, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 727, \"mu_intercept_per_group\": -8.880156517028809, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 728, \"mu_intercept_per_group\": -4.952438831329346, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 729, \"mu_intercept_per_group\": 2.1097402572631836, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 730, \"mu_intercept_per_group\": -19.530475616455078, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 731, \"mu_intercept_per_group\": -12.512855529785156, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 732, \"mu_intercept_per_group\": -11.262587547302246, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 733, \"mu_intercept_per_group\": -5.691250801086426, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 734, \"mu_intercept_per_group\": -5.709987163543701, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 735, \"mu_intercept_per_group\": -13.027153015136719, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 736, \"mu_intercept_per_group\": -4.580695152282715, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 737, \"mu_intercept_per_group\": -5.58447790145874, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 738, \"mu_intercept_per_group\": -7.456693649291992, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 739, \"mu_intercept_per_group\": -4.1011481285095215, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 740, \"mu_intercept_per_group\": -7.866563320159912, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 741, \"mu_intercept_per_group\": -2.8816299438476562, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 742, \"mu_intercept_per_group\": -3.1140661239624023, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 743, \"mu_intercept_per_group\": -7.392512798309326, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 744, \"mu_intercept_per_group\": -0.40461915731430054, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 745, \"mu_intercept_per_group\": -13.69776439666748, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 746, \"mu_intercept_per_group\": -2.8043599128723145, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 747, \"mu_intercept_per_group\": -5.48544454574585, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 748, \"mu_intercept_per_group\": -6.651001930236816, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 749, \"mu_intercept_per_group\": -0.7668727040290833, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 750, \"mu_intercept_per_group\": -13.935588836669922, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 751, \"mu_intercept_per_group\": -18.877792358398438, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 752, \"mu_intercept_per_group\": -13.951913833618164, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 753, \"mu_intercept_per_group\": 1.7729135751724243, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 754, \"mu_intercept_per_group\": -10.468303680419922, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 755, \"mu_intercept_per_group\": -5.0220441818237305, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 756, \"mu_intercept_per_group\": 1.5663807392120361, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 757, \"mu_intercept_per_group\": 4.801385402679443, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 758, \"mu_intercept_per_group\": -19.007904052734375, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 759, \"mu_intercept_per_group\": -4.879411220550537, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 760, \"mu_intercept_per_group\": -4.549781799316406, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 1, \"draws\": 761, \"mu_intercept_per_group\": -2.94614577293396, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 1, \"draws\": 762, \"mu_intercept_per_group\": -4.423861980438232, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 1, \"draws\": 763, \"mu_intercept_per_group\": -7.034924507141113, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 1, \"draws\": 764, \"mu_intercept_per_group\": 1.8200410604476929, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 1, \"draws\": 765, \"mu_intercept_per_group\": -8.238364219665527, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 1, \"draws\": 766, \"mu_intercept_per_group\": -7.395601749420166, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 1, \"draws\": 767, \"mu_intercept_per_group\": -20.068384170532227, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 1, \"draws\": 768, \"mu_intercept_per_group\": -17.523784637451172, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 1, \"draws\": 769, \"mu_intercept_per_group\": -11.089550018310547, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 1, \"draws\": 770, \"mu_intercept_per_group\": -2.1942050457000732, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 1, \"draws\": 771, \"mu_intercept_per_group\": -9.11524486541748, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 1, \"draws\": 772, \"mu_intercept_per_group\": -7.53018856048584, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 1, \"draws\": 773, \"mu_intercept_per_group\": -16.917530059814453, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 1, \"draws\": 774, \"mu_intercept_per_group\": -7.4532928466796875, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 1, \"draws\": 775, \"mu_intercept_per_group\": -8.408575057983398, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 1, \"draws\": 776, \"mu_intercept_per_group\": -10.65970230102539, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 1, \"draws\": 777, \"mu_intercept_per_group\": -11.440478324890137, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 1, \"draws\": 778, \"mu_intercept_per_group\": -3.9567081928253174, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 1, \"draws\": 779, \"mu_intercept_per_group\": -3.3428282737731934, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 1, \"draws\": 780, \"mu_intercept_per_group\": -3.787095546722412, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 1, \"draws\": 781, \"mu_intercept_per_group\": -5.192613124847412, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 1, \"draws\": 782, \"mu_intercept_per_group\": -1.9134330749511719, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 1, \"draws\": 783, \"mu_intercept_per_group\": -15.909469604492188, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 1, \"draws\": 784, \"mu_intercept_per_group\": -4.824670791625977, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 1, \"draws\": 785, \"mu_intercept_per_group\": -3.8470840454101562, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 1, \"draws\": 786, \"mu_intercept_per_group\": -10.330160140991211, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 1, \"draws\": 787, \"mu_intercept_per_group\": -2.9051589965820312, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 1, \"draws\": 788, \"mu_intercept_per_group\": -1.402732014656067, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 1, \"draws\": 789, \"mu_intercept_per_group\": -1.9129210710525513, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 1, \"draws\": 790, \"mu_intercept_per_group\": -2.001810312271118, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 1, \"draws\": 791, \"mu_intercept_per_group\": -1.3983904123306274, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 1, \"draws\": 792, \"mu_intercept_per_group\": -2.998652219772339, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 1, \"draws\": 793, \"mu_intercept_per_group\": -5.212745666503906, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 1, \"draws\": 794, \"mu_intercept_per_group\": -5.740200042724609, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 1, \"draws\": 795, \"mu_intercept_per_group\": -13.511787414550781, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 1, \"draws\": 796, \"mu_intercept_per_group\": -11.45315933227539, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 1, \"draws\": 797, \"mu_intercept_per_group\": 0.3158457577228546, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 1, \"draws\": 798, \"mu_intercept_per_group\": -7.817399978637695, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 1, \"draws\": 799, \"mu_intercept_per_group\": -5.6703596115112305, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": 3.732858419418335, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -14.74763298034668, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -0.7920447587966919, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -9.022059440612793, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": 0.6570751070976257, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -15.827178001403809, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": 1.0846809148788452, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -9.276813507080078, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -8.951321601867676, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -6.864566326141357, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -1.9341707229614258, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -2.0510671138763428, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -10.089612007141113, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -10.680008888244629, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -8.804644584655762, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -6.305605888366699, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": 0.3000829219818115, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -1.7551122903823853, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -2.3900818824768066, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -7.888637065887451, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -2.895343542098999, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": 1.3380863666534424, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -23.78074073791504, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -11.098406791687012, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -3.1819076538085938, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -4.800429344177246, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": 3.4133005142211914, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -4.96135139465332, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -2.690692663192749, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -2.0235795974731445, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -4.189643383026123, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -8.388700485229492, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -8.43273639678955, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -7.213374614715576, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -15.214789390563965, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -9.292546272277832, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": -2.4623196125030518, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -4.815928936004639, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -10.999615669250488, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -2.146559476852417, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": -0.2502283751964569, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -11.01223373413086, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": 0.8173249959945679, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": 1.2063239812850952, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -7.440464973449707, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": -2.0382120609283447, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -8.468244552612305, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": -10.96498966217041, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": -3.679169178009033, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": -1.5366096496582031, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -15.801124572753906, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -13.245361328125, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -1.2482539415359497, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -1.9702545404434204, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -10.261996269226074, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -6.809752464294434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -4.980435371398926, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -1.1392760276794434, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -14.793569564819336, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -9.13333797454834, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -12.414731979370117, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -6.6255903244018555, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -7.025851726531982, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -5.728945732116699, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -33.51395034790039, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -25.522985458374023, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -9.523961067199707, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -4.857399940490723, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -5.243505001068115, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -8.11296272277832, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -4.921431064605713, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -7.549405574798584, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -10.010002136230469, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -12.585983276367188, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -12.470001220703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -13.422882080078125, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -7.613100528717041, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -13.645598411560059, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": 1.5563081502914429, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -0.2708023190498352, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -3.8437490463256836, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -10.29825496673584, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -2.2668702602386475, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -18.09571075439453, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -2.0356709957122803, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -8.436660766601562, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -11.393402099609375, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -0.09373881667852402, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -7.675854682922363, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -10.161646842956543, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -5.003331184387207, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -5.881323337554932, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -15.590445518493652, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.46782112121582, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -6.074382305145264, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -9.703702926635742, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -11.3945894241333, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -22.94749641418457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -9.107547760009766, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -5.638185501098633, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -7.5632805824279785, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -5.779253005981445, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -12.833268165588379, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -24.00741195678711, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": -17.91518783569336, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -6.520063877105713, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -17.20440673828125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -0.8397051692008972, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -6.851493835449219, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -6.914797306060791, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -3.951817035675049, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -9.044754028320312, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -3.339143991470337, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -11.259417533874512, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -1.629762053489685, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -10.254329681396484, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -8.390010833740234, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -4.76670503616333, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -4.235963821411133, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -3.3014323711395264, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -3.503049373626709, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -1.417212963104248, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -12.009513854980469, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -2.5017096996307373, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -1.5731955766677856, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -15.161019325256348, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -11.574864387512207, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -5.0208420753479, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -11.90736198425293, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -10.829822540283203, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -3.8257577419281006, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -14.482948303222656, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -1.8139958381652832, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": 2.497969388961792, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": -16.498340606689453, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -0.2805044651031494, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -11.179259300231934, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -2.3191945552825928, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -16.078134536743164, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -8.03470230102539, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -7.668808937072754, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -6.628554821014404, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -9.30042839050293, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -4.862789630889893, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -13.12014102935791, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -4.942154407501221, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -1.706308364868164, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.927155017852783, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -5.129053592681885, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -5.170759677886963, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -9.57567024230957, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": 0.7154896855354309, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -10.724403381347656, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -6.5022735595703125, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -11.366816520690918, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -2.3977396488189697, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -2.8498568534851074, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -11.582931518554688, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -6.644885540008545, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -9.830425262451172, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -7.095962047576904, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -5.265265464782715, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -0.462955117225647, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -7.801544189453125, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -5.688144683837891, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -7.555182933807373, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -11.031906127929688, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -12.016904830932617, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -12.225738525390625, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -6.396834850311279, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -8.859726905822754, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -12.181182861328125, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -1.3500686883926392, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -0.9643192291259766, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": 5.729019641876221, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -7.027344226837158, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -8.903620719909668, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -11.632333755493164, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -7.708724021911621, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -4.908493995666504, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -2.233981132507324, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -11.19131851196289, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -3.624091863632202, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -8.907787322998047, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -10.99387264251709, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -13.788372039794922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -8.753623962402344, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -4.643501281738281, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -3.7619428634643555, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -13.322681427001953, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -13.632486343383789, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -13.1654691696167, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -21.33490753173828, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -20.72462272644043, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -8.248591423034668, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -11.590217590332031, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -0.4311475455760956, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -6.358354091644287, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -5.212062835693359, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -11.44992733001709, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -8.220882415771484, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -9.12226676940918, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -19.992965698242188, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.073141574859619, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -8.739863395690918, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -6.4528117179870605, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -1.6325939893722534, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -10.420852661132812, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -7.879732608795166, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -5.497306823730469, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -9.596871376037598, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -5.04962158203125, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -5.920009613037109, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -14.4966402053833, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -12.751287460327148, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -2.2573904991149902, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -7.686809539794922, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -4.8248610496521, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -1.765623927116394, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -3.668644428253174, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -11.203539848327637, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -5.001384258270264, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -5.6280837059021, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -8.435948371887207, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -16.05109405517578, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -11.728601455688477, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -10.938681602478027, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -12.06391716003418, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -9.29641342163086, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -8.03704833984375, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": -9.065410614013672, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -4.80192232131958, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": -1.2938531637191772, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": -9.983661651611328, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -8.687374114990234, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -8.76640796661377, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -13.491843223571777, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -14.784497261047363, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -7.058042049407959, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -8.410482406616211, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": -7.969771862030029, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": -5.700320720672607, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -8.23973274230957, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -6.37434720993042, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -4.339025974273682, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -12.471747398376465, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": 2.5074687004089355, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -7.676962375640869, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -9.073676109313965, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -3.8976588249206543, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -9.184854507446289, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -8.97800350189209, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": 0.567714512348175, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -9.884993553161621, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -2.6615822315216064, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -4.578339099884033, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -4.606342792510986, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -3.4974441528320312, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -7.455306529998779, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -8.015759468078613, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -6.008310794830322, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -9.581665992736816, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -18.30813217163086, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -5.676492691040039, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -5.461687088012695, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -10.037436485290527, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -5.408499240875244, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -3.463329315185547, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -8.462669372558594, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -0.7396417856216431, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": 0.3627697825431824, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -8.535021781921387, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -14.763421058654785, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -12.69399356842041, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -5.960251808166504, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -15.310663223266602, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -11.386277198791504, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": -0.6379175186157227, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": 2.479771614074707, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -27.945741653442383, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -25.226280212402344, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -25.83666229248047, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -25.84488868713379, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": -3.639381170272827, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -3.4970641136169434, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -8.06601619720459, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -1.5408661365509033, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -8.879176139831543, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -5.490477085113525, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": 0.7783665657043457, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": -5.810604572296143, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -6.816895008087158, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": -5.717819690704346, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": -3.2649192810058594, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -7.394350051879883, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -5.316237449645996, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -4.33823823928833, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -3.374006748199463, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -3.690908670425415, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -3.286393642425537, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -6.020491600036621, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -3.8602819442749023, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -3.8057656288146973, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -11.836518287658691, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -11.771985054016113, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -2.775174379348755, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -8.22934627532959, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -5.914505481719971, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": 0.35630086064338684, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -8.621039390563965, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": 0.03868190944194794, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -7.187379360198975, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -2.533694267272949, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -13.379923820495605, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -2.356395721435547, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -8.24489974975586, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -9.023186683654785, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -10.784841537475586, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -13.656123161315918, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -3.4743764400482178, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -7.933475971221924, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -11.61305046081543, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -12.829791069030762, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -13.294774055480957, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -0.8171144723892212, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -8.221381187438965, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -6.305694580078125, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -1.9388025999069214, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -8.794182777404785, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -14.92114543914795, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": 1.2037016153335571, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -0.29571962356567383, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -2.143641233444214, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": 0.28064489364624023, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -11.181112289428711, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -17.93585777282715, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -16.54886245727539, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -14.920042037963867, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -4.039874076843262, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -2.210084915161133, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -6.806283473968506, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -8.500036239624023, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -10.403523445129395, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -12.121692657470703, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -1.4248536825180054, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -6.124846935272217, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -9.547216415405273, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -7.770440101623535, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": -1.1363286972045898, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -5.304030895233154, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -16.298486709594727, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": 0.6669440269470215, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -12.736757278442383, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -0.40219584107398987, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -11.14700698852539, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -10.505026817321777, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -13.417987823486328, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -4.444047927856445, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -5.558975696563721, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -6.314434051513672, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -5.409777641296387, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -12.233269691467285, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": 2.4941351413726807, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -8.505087852478027, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -11.589695930480957, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": 2.68093204498291, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -2.3584933280944824, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -10.62534236907959, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -11.387564659118652, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -6.608433246612549, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -11.981107711791992, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -8.635040283203125, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -5.843832015991211, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.792159557342529, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -9.92165756225586, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -0.5195949077606201, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -0.48983699083328247, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -8.744340896606445, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -4.345973968505859, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -7.0246405601501465, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -8.06035041809082, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -3.0483062267303467, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -7.415585041046143, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -4.294566631317139, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -7.638671875, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -5.52531099319458, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": -22.398527145385742, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -26.254108428955078, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -22.66168212890625, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": 11.287065505981445, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -18.271297454833984, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": 5.90974760055542, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -20.47370147705078, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": -21.0311222076416, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -24.008012771606445, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": 3.4749786853790283, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -5.57877254486084, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": 7.922347545623779, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": 3.74188494682312, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -1.6988954544067383, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -5.097616672515869, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -8.846117973327637, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": 0.1722397655248642, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -11.248380661010742, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -5.576571464538574, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -11.188019752502441, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -7.977139472961426, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -7.824069499969482, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -6.561493873596191, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -4.329862117767334, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -9.109274864196777, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -2.5585813522338867, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -3.9632863998413086, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -8.33236312866211, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": -12.320808410644531, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -5.167570114135742, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -0.7097181081771851, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -6.286855697631836, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -3.0909993648529053, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -9.099831581115723, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -9.916319847106934, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -3.4401278495788574, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -10.867147445678711, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -3.1852986812591553, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -2.7473909854888916, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -8.0872163772583, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -6.562880992889404, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": -4.1757941246032715, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -7.16696834564209, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -10.26915168762207, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -9.438253402709961, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -9.75649356842041, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -10.471683502197266, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -6.7206597328186035, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -7.505468368530273, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -12.156686782836914, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -8.14764404296875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -12.892260551452637, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -7.857025146484375, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -5.481618404388428, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -7.646692752838135, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -8.294184684753418, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -6.671442031860352, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -5.029989719390869, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -6.067749977111816, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -8.702014923095703, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -1.9200150966644287, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": 2.897442579269409, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -6.439794540405273, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -9.116233825683594, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -8.189045906066895, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -7.817679405212402, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -8.17243480682373, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -7.344018936157227, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -9.187037467956543, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -11.351550102233887, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -6.207816123962402, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -12.242033004760742, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -8.850366592407227, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -7.808396339416504, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -6.700761795043945, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -4.922554969787598, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -7.77886962890625, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -8.31988525390625, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -12.699518203735352, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": 0.7110630869865417, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -5.795843124389648, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -9.777260780334473, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -12.110445976257324, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -0.4430992007255554, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -6.092288970947266, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -14.46850872039795, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": -13.915558815002441, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -11.345191955566406, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -9.869769096374512, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -14.827057838439941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": 2.4836864471435547, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -17.392253875732422, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -1.5566017627716064, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -4.168797969818115, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -6.886236190795898, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -2.3287723064422607, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": -9.082579612731934, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -8.306184768676758, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -10.162294387817383, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -6.873996257781982, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -10.086308479309082, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -8.069391250610352, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -10.074687004089355, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -17.203676223754883, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -15.812134742736816, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -10.763212203979492, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -3.6097567081451416, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -7.371165752410889, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -10.116365432739258, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": 2.3381083011627197, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -15.05810832977295, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -3.4082698822021484, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -8.308154106140137, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -9.934334754943848, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -4.966827869415283, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -13.838757514953613, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -8.109692573547363, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -2.6857166290283203, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -12.619490623474121, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -12.56435489654541, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -10.434200286865234, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -6.927921295166016, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -6.527944564819336, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -6.607351779937744, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -12.63137435913086, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": -12.4427490234375, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -3.7763655185699463, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -9.528964042663574, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -4.6869120597839355, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -10.90855598449707, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -6.655173301696777, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -3.270554304122925, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -16.982526779174805, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -15.353683471679688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -8.847289085388184, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -10.179303169250488, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -6.731151103973389, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -7.674241542816162, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -9.233016967773438, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -11.5830717086792, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -14.37897777557373, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -4.1582865715026855, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": 0.197475865483284, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -18.406869888305664, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -6.320181369781494, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -24.789236068725586, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -8.58946704864502, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -6.373545169830322, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -16.464635848999023, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -9.792702674865723, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -8.00907039642334, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": 6.568103790283203, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -1.1935948133468628, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -4.287923336029053, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -13.90717601776123, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -13.259078979492188, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -4.4597859382629395, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": 3.266550064086914, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -17.591632843017578, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -6.757795333862305, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -3.6606576442718506, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -0.4319865107536316, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -8.018631935119629, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -9.239262580871582, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": -5.867883682250977, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -16.606130599975586, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -11.81203842163086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -7.561521530151367, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": 3.4671599864959717, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -21.93998908996582, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -4.782626628875732, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -4.104213714599609, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -6.890751838684082, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -9.23733901977539, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -4.768161773681641, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -6.677367210388184, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -9.043994903564453, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -4.714869022369385, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -3.2620174884796143, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -5.250110149383545, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -6.488597393035889, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -3.883333683013916, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -5.378838062286377, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -8.393364906311035, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -4.350249767303467, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -10.24892520904541, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -5.905289649963379, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -13.357450485229492, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -16.178735733032227, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -15.908679008483887, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -7.344059944152832, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -7.44371223449707, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -9.754671096801758, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -14.778365135192871, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": -13.482151985168457, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -7.292673587799072, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -9.378966331481934, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -9.126514434814453, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": -4.56641960144043, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -4.477183818817139, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -6.549602031707764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -6.186005592346191, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -9.142590522766113, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -6.239355564117432, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": -2.2536373138427734, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": -1.894028902053833, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -8.125317573547363, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -6.698769569396973, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -9.687060356140137, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -5.876283168792725, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -15.55165958404541, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -11.94643783569336, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -9.460631370544434, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -11.773155212402344, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -11.088447570800781, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -3.3102426528930664, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -1.4685629606246948, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -7.10137414932251, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -17.07517433166504, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -9.918875694274902, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -2.0156307220458984, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -9.946962356567383, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -7.392494201660156, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -9.749910354614258, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -7.147546291351318, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -11.540006637573242, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -9.33851432800293, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -9.769523620605469, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -12.711801528930664, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -6.6422953605651855, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -7.653461456298828, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": 0.8141601085662842, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -0.6052043437957764, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -4.644975185394287, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": 5.55590295791626, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -19.888980865478516, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": 1.2527320384979248, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -4.81308650970459, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -9.619791030883789, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -12.583415985107422, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -1.2959754467010498, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -6.864170551300049, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -8.394363403320312, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -1.894271731376648, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -8.552262306213379, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -7.477956771850586, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -12.555445671081543, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -17.114042282104492, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -17.859159469604492, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -19.37428092956543, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -4.23969841003418, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -6.650465965270996, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -7.718262672424316, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -6.551194667816162, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 640, \"mu_intercept_per_group\": -7.141420841217041, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 641, \"mu_intercept_per_group\": -12.319287300109863, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 642, \"mu_intercept_per_group\": -1.9240094423294067, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 643, \"mu_intercept_per_group\": -12.14867877960205, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 644, \"mu_intercept_per_group\": -8.549842834472656, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 645, \"mu_intercept_per_group\": -4.7822747230529785, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 646, \"mu_intercept_per_group\": -7.511908054351807, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 647, \"mu_intercept_per_group\": -8.554618835449219, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 648, \"mu_intercept_per_group\": -6.192224025726318, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 649, \"mu_intercept_per_group\": -2.184715986251831, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 650, \"mu_intercept_per_group\": 0.327439546585083, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 651, \"mu_intercept_per_group\": -8.841228485107422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 652, \"mu_intercept_per_group\": -10.685248374938965, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 653, \"mu_intercept_per_group\": -11.242206573486328, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 654, \"mu_intercept_per_group\": -10.382344245910645, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 655, \"mu_intercept_per_group\": -5.185843467712402, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 656, \"mu_intercept_per_group\": -4.3155622482299805, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 657, \"mu_intercept_per_group\": -11.385210037231445, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 658, \"mu_intercept_per_group\": -15.944779396057129, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 659, \"mu_intercept_per_group\": -9.161582946777344, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 660, \"mu_intercept_per_group\": -7.693521976470947, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 661, \"mu_intercept_per_group\": -6.487646579742432, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 662, \"mu_intercept_per_group\": -6.708395004272461, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 663, \"mu_intercept_per_group\": -3.748321771621704, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 664, \"mu_intercept_per_group\": -3.1187522411346436, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 665, \"mu_intercept_per_group\": -5.392289161682129, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 666, \"mu_intercept_per_group\": -2.2252864837646484, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 667, \"mu_intercept_per_group\": -0.012133646756410599, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 668, \"mu_intercept_per_group\": -6.209344863891602, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 669, \"mu_intercept_per_group\": -4.447170257568359, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 670, \"mu_intercept_per_group\": 0.12659278512001038, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 671, \"mu_intercept_per_group\": -4.577426433563232, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 672, \"mu_intercept_per_group\": -8.053205490112305, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 673, \"mu_intercept_per_group\": -7.424107551574707, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 674, \"mu_intercept_per_group\": -7.840348243713379, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 675, \"mu_intercept_per_group\": -12.95202350616455, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 676, \"mu_intercept_per_group\": -2.3764352798461914, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 677, \"mu_intercept_per_group\": -7.701026916503906, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 678, \"mu_intercept_per_group\": 1.1807005405426025, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 679, \"mu_intercept_per_group\": -9.633260726928711, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 680, \"mu_intercept_per_group\": -8.008782386779785, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 681, \"mu_intercept_per_group\": -2.400926351547241, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 682, \"mu_intercept_per_group\": -16.178964614868164, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 683, \"mu_intercept_per_group\": -13.101844787597656, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 684, \"mu_intercept_per_group\": -8.684494972229004, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 685, \"mu_intercept_per_group\": -6.833575248718262, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 686, \"mu_intercept_per_group\": -3.6441476345062256, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 687, \"mu_intercept_per_group\": -3.5922977924346924, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 688, \"mu_intercept_per_group\": -18.850242614746094, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 689, \"mu_intercept_per_group\": 1.0820876359939575, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 690, \"mu_intercept_per_group\": -6.514820575714111, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 691, \"mu_intercept_per_group\": -1.3514366149902344, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 692, \"mu_intercept_per_group\": -1.5759904384613037, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 693, \"mu_intercept_per_group\": 2.053717613220215, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 694, \"mu_intercept_per_group\": -4.6263651847839355, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 695, \"mu_intercept_per_group\": -6.750999450683594, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 696, \"mu_intercept_per_group\": -4.758124351501465, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 697, \"mu_intercept_per_group\": -1.9505478143692017, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 698, \"mu_intercept_per_group\": -16.749841690063477, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 699, \"mu_intercept_per_group\": -13.986458778381348, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 700, \"mu_intercept_per_group\": -17.15596580505371, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 701, \"mu_intercept_per_group\": -17.973060607910156, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 702, \"mu_intercept_per_group\": -11.176142692565918, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 703, \"mu_intercept_per_group\": -0.8515474200248718, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 704, \"mu_intercept_per_group\": -16.14752769470215, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 705, \"mu_intercept_per_group\": -17.337581634521484, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 706, \"mu_intercept_per_group\": -5.1819167137146, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 707, \"mu_intercept_per_group\": -12.231256484985352, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 708, \"mu_intercept_per_group\": 1.0472511053085327, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 709, \"mu_intercept_per_group\": -26.541973114013672, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 710, \"mu_intercept_per_group\": -4.820431232452393, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 711, \"mu_intercept_per_group\": -17.555593490600586, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 712, \"mu_intercept_per_group\": -4.313548564910889, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 713, \"mu_intercept_per_group\": -12.815875053405762, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 714, \"mu_intercept_per_group\": -7.939393997192383, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 715, \"mu_intercept_per_group\": -9.014795303344727, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 716, \"mu_intercept_per_group\": -7.826602935791016, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 717, \"mu_intercept_per_group\": -1.84090256690979, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 718, \"mu_intercept_per_group\": -8.720623016357422, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 719, \"mu_intercept_per_group\": -13.187346458435059, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 720, \"mu_intercept_per_group\": -8.846368789672852, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 721, \"mu_intercept_per_group\": -6.637916564941406, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 722, \"mu_intercept_per_group\": -3.355745315551758, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 723, \"mu_intercept_per_group\": -2.7655088901519775, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 724, \"mu_intercept_per_group\": -4.8449811935424805, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 725, \"mu_intercept_per_group\": -3.848680257797241, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 726, \"mu_intercept_per_group\": -10.032918930053711, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 727, \"mu_intercept_per_group\": -3.0833189487457275, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 728, \"mu_intercept_per_group\": -9.624643325805664, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 729, \"mu_intercept_per_group\": -5.940707683563232, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 730, \"mu_intercept_per_group\": -7.710272789001465, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 731, \"mu_intercept_per_group\": -23.57373809814453, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 732, \"mu_intercept_per_group\": -15.726632118225098, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 733, \"mu_intercept_per_group\": -7.308401584625244, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 734, \"mu_intercept_per_group\": -9.822031021118164, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 735, \"mu_intercept_per_group\": -8.193119049072266, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 736, \"mu_intercept_per_group\": -1.6803587675094604, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 737, \"mu_intercept_per_group\": -14.743664741516113, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 738, \"mu_intercept_per_group\": -11.672747611999512, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 739, \"mu_intercept_per_group\": -8.721245765686035, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 740, \"mu_intercept_per_group\": -9.85912036895752, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 741, \"mu_intercept_per_group\": -1.3250946998596191, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 742, \"mu_intercept_per_group\": -6.714052677154541, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 743, \"mu_intercept_per_group\": -4.2093281745910645, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 744, \"mu_intercept_per_group\": -6.668892860412598, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 745, \"mu_intercept_per_group\": -3.4528956413269043, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 746, \"mu_intercept_per_group\": -6.977998733520508, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 747, \"mu_intercept_per_group\": -5.103305339813232, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 748, \"mu_intercept_per_group\": 0.21640686690807343, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 749, \"mu_intercept_per_group\": -2.2673940658569336, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 750, \"mu_intercept_per_group\": -1.6518634557724, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 751, \"mu_intercept_per_group\": -5.230224609375, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 752, \"mu_intercept_per_group\": -0.9623963832855225, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 753, \"mu_intercept_per_group\": -11.71789264678955, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 754, \"mu_intercept_per_group\": -3.776665210723877, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 755, \"mu_intercept_per_group\": -11.82597541809082, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 756, \"mu_intercept_per_group\": -12.082707405090332, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 757, \"mu_intercept_per_group\": -12.341635704040527, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 758, \"mu_intercept_per_group\": -14.834488868713379, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 759, \"mu_intercept_per_group\": -9.986968994140625, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 760, \"mu_intercept_per_group\": -10.320402145385742, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 2, \"draws\": 761, \"mu_intercept_per_group\": -13.905303955078125, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 2, \"draws\": 762, \"mu_intercept_per_group\": -16.491025924682617, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 2, \"draws\": 763, \"mu_intercept_per_group\": -5.7081732749938965, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 2, \"draws\": 764, \"mu_intercept_per_group\": -14.90152645111084, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 2, \"draws\": 765, \"mu_intercept_per_group\": -0.3089122772216797, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 2, \"draws\": 766, \"mu_intercept_per_group\": -15.320383071899414, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 2, \"draws\": 767, \"mu_intercept_per_group\": -4.846121788024902, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 2, \"draws\": 768, \"mu_intercept_per_group\": -6.406315326690674, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 2, \"draws\": 769, \"mu_intercept_per_group\": -10.758137702941895, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 2, \"draws\": 770, \"mu_intercept_per_group\": -7.8329854011535645, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 2, \"draws\": 771, \"mu_intercept_per_group\": 0.8221447467803955, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 2, \"draws\": 772, \"mu_intercept_per_group\": -21.661827087402344, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 2, \"draws\": 773, \"mu_intercept_per_group\": -12.66462230682373, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 2, \"draws\": 774, \"mu_intercept_per_group\": -14.172645568847656, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 2, \"draws\": 775, \"mu_intercept_per_group\": -8.050253868103027, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 2, \"draws\": 776, \"mu_intercept_per_group\": -11.800787925720215, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 2, \"draws\": 777, \"mu_intercept_per_group\": -21.02047348022461, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 2, \"draws\": 778, \"mu_intercept_per_group\": -7.51196813583374, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 2, \"draws\": 779, \"mu_intercept_per_group\": -8.911922454833984, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 2, \"draws\": 780, \"mu_intercept_per_group\": -10.23464298248291, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 2, \"draws\": 781, \"mu_intercept_per_group\": -2.848794460296631, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 2, \"draws\": 782, \"mu_intercept_per_group\": -3.9888498783111572, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 2, \"draws\": 783, \"mu_intercept_per_group\": -12.056135177612305, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 2, \"draws\": 784, \"mu_intercept_per_group\": -7.282134056091309, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 2, \"draws\": 785, \"mu_intercept_per_group\": -5.6719231605529785, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 2, \"draws\": 786, \"mu_intercept_per_group\": 0.6745861172676086, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 2, \"draws\": 787, \"mu_intercept_per_group\": -1.0155054330825806, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 2, \"draws\": 788, \"mu_intercept_per_group\": -8.687138557434082, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 2, \"draws\": 789, \"mu_intercept_per_group\": -7.499844074249268, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 2, \"draws\": 790, \"mu_intercept_per_group\": -2.866102933883667, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 2, \"draws\": 791, \"mu_intercept_per_group\": -3.8333287239074707, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 2, \"draws\": 792, \"mu_intercept_per_group\": -6.34598970413208, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 2, \"draws\": 793, \"mu_intercept_per_group\": -14.285922050476074, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 2, \"draws\": 794, \"mu_intercept_per_group\": -17.319591522216797, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 2, \"draws\": 795, \"mu_intercept_per_group\": -12.132493019104004, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 2, \"draws\": 796, \"mu_intercept_per_group\": -7.3018975257873535, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 2, \"draws\": 797, \"mu_intercept_per_group\": -10.934429168701172, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 2, \"draws\": 798, \"mu_intercept_per_group\": 1.3345128297805786, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 2, \"draws\": 799, \"mu_intercept_per_group\": -7.95594596862793, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": 1.1422832012176514, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": 3.4451889991760254, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -13.309249877929688, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -2.334221363067627, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -2.6834938526153564, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -1.050855040550232, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": -11.638349533081055, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -3.4021027088165283, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": -4.454543590545654, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -4.641628742218018, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": 1.0176398754119873, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": 1.382218837738037, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -4.815413475036621, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": 5.528326988220215, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": 8.008136749267578, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": 11.768983840942383, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -5.568403720855713, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -6.959604740142822, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -6.039422512054443, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": 2.300753116607666, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -5.080330848693848, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": -4.960811614990234, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -0.6755471229553223, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": 2.055466651916504, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": 15.956356048583984, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": 4.9173808097839355, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -14.728536605834961, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": -13.294828414916992, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -5.873209476470947, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": 2.3663792610168457, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -1.0872663259506226, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": 1.0575892925262451, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -0.23079244792461395, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -6.030643463134766, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -7.986595630645752, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -3.6445791721343994, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -1.7929785251617432, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -10.452860832214355, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -6.082972049713135, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -1.2904764413833618, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -0.5038827657699585, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -1.9818707704544067, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": -2.4391608238220215, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -3.6116600036621094, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": 1.880308985710144, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -1.596183180809021, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": 10.43369197845459, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": 10.978118896484375, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": 11.816225051879883, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": 7.06320858001709, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": 5.699960708618164, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.811556339263916, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": 7.416693687438965, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": 5.239987373352051, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -6.371124744415283, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -6.321715354919434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -0.8365016579627991, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -1.100523829460144, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -9.814924240112305, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -2.12493634223938, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.7239115238189697, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -6.467557430267334, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -9.944820404052734, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -9.137910842895508, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": 4.786907196044922, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": 7.342767715454102, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": 21.530065536499023, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -3.220067024230957, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -2.410952568054199, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -0.7614163756370544, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -3.118800163269043, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -7.121359348297119, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": 0.9711492657661438, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -9.067095756530762, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.610410690307617, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -1.9965918064117432, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -5.7381486892700195, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -5.407534599304199, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -3.1097052097320557, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -0.051551930606365204, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": 1.6425068378448486, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": 2.8682215213775635, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": -5.482365131378174, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.255630016326904, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -1.8998559713363647, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -4.396988391876221, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": 0.8396350145339966, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": 1.5524109601974487, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": 4.776217460632324, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": 11.44230842590332, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": 9.291142463684082, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": -5.650680065155029, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": 0.710728645324707, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -5.860079765319824, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": 3.1312332153320312, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": 1.5535598993301392, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -2.915241003036499, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": 0.9959485530853271, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": 8.354219436645508, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.838305950164795, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": -5.439314842224121, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": 4.786798477172852, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -1.9363937377929688, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -7.338453769683838, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": 0.36386746168136597, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": -10.497365951538086, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -8.698169708251953, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": 0.6599807143211365, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -4.565549373626709, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -4.984137535095215, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -3.4180290699005127, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -2.035233736038208, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": -2.8604378700256348, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": -3.704653263092041, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": 1.111017107963562, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -0.39979448914527893, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -6.098702430725098, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -1.463597059249878, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -0.000967649684753269, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": -2.249558448791504, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": -2.216856002807617, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": -4.691045761108398, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -0.8590145707130432, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -4.1990814208984375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -3.9876046180725098, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -0.9444401264190674, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -3.738778591156006, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": -9.33457088470459, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -1.212861180305481, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -9.126809120178223, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -16.431392669677734, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": 1.9312454462051392, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -6.761323928833008, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -2.729433536529541, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": 0.7777804732322693, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -6.178104877471924, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": 0.9076302647590637, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -6.937652587890625, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -2.5492546558380127, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -4.945709705352783, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -1.7667300701141357, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": 0.7200169563293457, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": 3.5294952392578125, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -4.999780178070068, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -2.732987642288208, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": 1.1399319171905518, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -0.09409604221582413, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -2.603269338607788, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": 2.263167381286621, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -2.1555821895599365, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": -4.189473628997803, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -1.4529013633728027, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": -2.817486524581909, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -0.8714385628700256, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -8.482097625732422, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": 4.959986686706543, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -6.086630344390869, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": 2.741875410079956, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -7.743535995483398, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": 11.827567100524902, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": 14.373174667358398, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -11.803725242614746, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": -17.219268798828125, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": 10.779607772827148, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": -7.521295070648193, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": 2.204723834991455, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": -0.06757959723472595, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -7.076362133026123, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -19.321819305419922, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": 10.665518760681152, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -15.639404296875, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": 7.635056018829346, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -0.4615268409252167, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": 8.905537605285645, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": 5.470874786376953, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -0.41181477904319763, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -3.8645167350769043, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": 2.6198697090148926, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -0.5493851900100708, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -2.6867988109588623, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -2.045103073120117, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -2.85786771774292, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -1.5691494941711426, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -6.313195705413818, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -5.157509803771973, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -1.6202298402786255, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": 0.9412631392478943, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -9.106287002563477, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -11.040139198303223, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": 5.320924758911133, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -1.043454885482788, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": 2.8296430110931396, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -3.5491135120391846, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -3.0336110591888428, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": 4.867432594299316, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -0.9833825826644897, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -0.5252104997634888, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": -5.145560264587402, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -4.320082187652588, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": 1.111548662185669, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -2.541640520095825, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -6.575405120849609, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -11.184614181518555, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -5.859685897827148, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -4.4939703941345215, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -6.390528202056885, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": 8.489559173583984, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -10.59765338897705, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -9.754304885864258, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -2.605734348297119, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": 3.5903382301330566, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -7.091739177703857, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -7.92171573638916, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": 0.17396149039268494, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -9.727476119995117, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": 3.487213373184204, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -2.6936447620391846, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": 12.155808448791504, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -3.0443296432495117, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -0.5025920271873474, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": 2.8304405212402344, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -10.801639556884766, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -0.5220856070518494, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -3.85499906539917, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -1.3167321681976318, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -6.445994853973389, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -6.1198835372924805, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": 4.902685165405273, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": 5.7540106773376465, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -5.082253456115723, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -3.7886149883270264, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -4.4853291511535645, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": 7.6265788078308105, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -1.692143201828003, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -4.007877349853516, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -3.221977710723877, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -1.347394585609436, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": 3.4872400760650635, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -6.5580620765686035, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": -5.686244010925293, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -1.484086275100708, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -6.134275436401367, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -3.998112201690674, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": 3.097943067550659, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -3.10587477684021, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -1.2060569524765015, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": 2.667961835861206, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -1.136277675628662, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": 0.020718803629279137, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": 2.6314878463745117, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -1.9009311199188232, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": -1.2595146894454956, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -1.4188594818115234, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": 0.3701774477958679, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -4.469882488250732, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -4.703858852386475, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": 2.9320223331451416, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": 3.490630865097046, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": -1.2078993320465088, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -4.197757244110107, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -6.318816661834717, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": 2.92828631401062, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -1.5768591165542603, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": 7.342698574066162, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -6.412532329559326, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": 3.4590110778808594, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": 5.967440605163574, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": 0.5187315940856934, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": 4.232466697692871, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -2.6163413524627686, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": 1.1103160381317139, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": -6.491605758666992, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -3.8196685314178467, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -2.652308702468872, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": 7.153045654296875, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -12.401137351989746, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -1.4257242679595947, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -3.7779064178466797, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": 5.371438026428223, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -10.941880226135254, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -11.144450187683105, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -3.7005515098571777, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -4.426377773284912, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -5.206786155700684, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": 8.41220474243164, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -3.45896053314209, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -2.978003740310669, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -1.7527974843978882, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -3.5697708129882812, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -7.499160289764404, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -2.673635244369507, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": -4.929272651672363, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -1.617139458656311, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -1.8594846725463867, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": -2.0745227336883545, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": 0.6467105746269226, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": 4.440384387969971, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": 1.7059365510940552, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -0.42386800050735474, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": -2.8983304500579834, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -3.9906091690063477, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -1.4967854022979736, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -2.459275960922241, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -0.5270119309425354, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -0.7536998391151428, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -4.541114807128906, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": 6.655881881713867, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -0.4428862929344177, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": 4.027284622192383, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -0.18719589710235596, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -5.053924560546875, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": -0.9571754336357117, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -4.632637977600098, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": 1.230791449546814, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -4.023431777954102, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -10.133399963378906, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -0.15544360876083374, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -5.1925859451293945, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": 10.034708976745605, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -11.376166343688965, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": -5.671952724456787, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -4.728982448577881, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -0.477090060710907, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -1.1253021955490112, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": 2.1307523250579834, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -4.218825817108154, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": 0.7177229523658752, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": 5.307969570159912, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -6.659838676452637, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": 0.8339402675628662, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -7.1644511222839355, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": 9.08468246459961, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": 8.221074104309082, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": 3.2874090671539307, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -10.034884452819824, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -7.14697790145874, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -5.812159061431885, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -9.020214080810547, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -0.0592881515622139, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -2.267007827758789, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": -2.3067283630371094, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": 2.1847925186157227, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": -8.609108924865723, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -7.968606472015381, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": 5.869666576385498, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -4.742668151855469, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": 2.67676043510437, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": -4.7433671951293945, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -5.591422080993652, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -4.894288539886475, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": 1.1010111570358276, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -10.362127304077148, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": 7.756590366363525, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": 10.190167427062988, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -2.9594478607177734, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -1.6523555517196655, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -8.56190299987793, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -2.955606460571289, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": 1.5201140642166138, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": 0.5285970568656921, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -0.9237287640571594, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -1.2570079565048218, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": -5.493432998657227, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -3.5231142044067383, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": 1.628109097480774, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": 0.5275156497955322, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": 5.90330696105957, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -7.689522743225098, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": 0.6258456707000732, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -8.762786865234375, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -5.9061994552612305, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -6.406050205230713, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -2.177804708480835, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -3.175398349761963, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.53462815284729, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.8630146980285645, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -3.1630401611328125, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -4.196714878082275, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -2.6307883262634277, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": 0.23636986315250397, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": 1.7251968383789062, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": -8.066803932189941, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -9.934847831726074, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": 10.237847328186035, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -16.784555435180664, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -14.604349136352539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -12.49198055267334, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -18.91082191467285, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -12.75493335723877, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": 8.327741622924805, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": -5.912790775299072, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -5.286569595336914, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -5.302486896514893, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -4.904359340667725, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -3.9771060943603516, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -2.971621513366699, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.789281845092773, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": 0.550115704536438, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -1.1442714929580688, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": 0.5929803252220154, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": -4.128983020782471, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": 0.654107928276062, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": 1.1824840307235718, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -4.839790344238281, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -3.5365540981292725, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.722402572631836, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": 3.623861074447632, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -1.5331995487213135, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -0.9055638909339905, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": -4.37939977645874, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -0.09710405766963959, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -4.23989725112915, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -5.184539318084717, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -1.9728769063949585, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": -5.851361274719238, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": 2.593122720718384, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": 3.2033915519714355, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -3.1738393306732178, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": 0.07471458613872528, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -5.293779373168945, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -0.15786832571029663, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": 7.1509528160095215, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -3.041566848754883, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -8.282413482666016, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": -8.749505043029785, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": 12.567148208618164, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -7.595125198364258, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -4.985073089599609, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -2.9983041286468506, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": 2.977707862854004, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -0.13216590881347656, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": 0.08115331083536148, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": 1.0226789712905884, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -6.061187744140625, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -12.322136878967285, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": 5.065090179443359, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": 7.918672561645508, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": 5.867305755615234, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": 2.042487621307373, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -0.6973666548728943, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -1.4755373001098633, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -0.40214118361473083, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": 1.972685694694519, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -5.049294948577881, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": 3.5060598850250244, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -3.3422980308532715, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": -2.1599979400634766, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -0.16590610146522522, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -0.675101637840271, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -1.7655251026153564, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": -3.0615193843841553, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": 0.9273499846458435, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -6.301034927368164, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -5.81266975402832, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -12.09800910949707, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -16.9748477935791, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -0.8389238119125366, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": 13.40527629852295, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": 4.561748027801514, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": 0.8433964848518372, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -6.979583263397217, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -0.5884028673171997, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -4.402454853057861, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -4.225096702575684, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -6.455096244812012, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -5.126056671142578, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -9.202210426330566, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -13.092423439025879, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": 2.330103874206543, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -3.111171245574951, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -1.5748965740203857, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": 6.025733470916748, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": -20.092267990112305, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -11.896636962890625, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": 0.13928580284118652, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": 8.409333229064941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -5.502542018890381, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -4.66280460357666, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -1.5036921501159668, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": 2.001307964324951, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": 5.179535865783691, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": 0.6891594529151917, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -3.987020254135132, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -3.130981683731079, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -8.0926513671875, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": 3.002039670944214, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -10.398992538452148, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -0.7789192795753479, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": 16.261219024658203, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -15.879326820373535, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -14.116984367370605, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -5.021420001983643, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": 0.48141056299209595, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": 3.443138360977173, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": -4.203012943267822, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": 1.2212390899658203, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": 2.878952741622925, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -4.4430155754089355, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -1.9320683479309082, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": 3.059864044189453, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": -1.5174566507339478, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -7.900796890258789, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -7.854007720947266, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": 5.19315242767334, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": 2.12386155128479, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": 2.578529119491577, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -1.7175145149230957, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -3.82033371925354, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": 0.0025268117897212505, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -5.460965156555176, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -0.6229301691055298, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -0.009420330636203289, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": 5.668510913848877, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -5.805806636810303, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -5.268351078033447, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": 3.3501031398773193, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": 2.2356791496276855, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -2.5880022048950195, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -6.686184883117676, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -7.809329509735107, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -5.405384540557861, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": 1.952531337738037, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -11.692564010620117, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -6.440998554229736, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -10.477301597595215, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": 7.941324234008789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": 9.543127059936523, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": 5.6837639808654785, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": 1.7521110773086548, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -5.787217140197754, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -7.043797969818115, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -8.691217422485352, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -3.84586238861084, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": 1.4004701375961304, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -1.488426685333252, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -6.012677192687988, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -1.4134918451309204, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.400400400161743, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": 0.3176666498184204, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -7.941269874572754, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -0.4374779462814331, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -5.062107563018799, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": 2.9750351905822754, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": 0.8638477325439453, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -1.4666558504104614, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": 5.508360862731934, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": 3.3465919494628906, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": 6.344620704650879, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": -2.2002763748168945, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -14.220636367797852, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": 6.004452705383301, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -19.313186645507812, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": 3.035220146179199, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -7.511860370635986, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": -1.2900664806365967, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -2.8503220081329346, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -6.260819435119629, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": -2.5331246852874756, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -8.642271995544434, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": 4.178277492523193, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": 2.3975954055786133, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -5.3959641456604, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -0.10079754143953323, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -4.879522323608398, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": 3.477522134780884, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -6.130655288696289, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": 1.7411397695541382, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": 9.138921737670898, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -10.642536163330078, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": 8.479148864746094, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": 6.1939873695373535, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": -11.953067779541016, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -9.57574462890625, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -12.450737953186035, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -1.5178221464157104, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": 0.982293963432312, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -4.705238342285156, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -1.3431538343429565, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -4.971939563751221, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -0.4891444742679596, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": 0.38888153433799744, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": 1.532944679260254, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -7.4955596923828125, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -10.090048789978027, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": 8.15038013458252, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": 7.267123699188232, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -2.7479090690612793, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": -9.160313606262207, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": -2.9178810119628906, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -1.0811572074890137, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -1.5299677848815918, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -3.080362558364868, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -6.4926676750183105, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -0.15025557577610016, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -5.4212188720703125, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": 0.12190693616867065, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -8.257290840148926, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -6.4581708908081055, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -1.8280775547027588, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -4.033593654632568, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": -2.4062139987945557, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -14.466475486755371, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": 3.689469575881958, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": 3.022028684616089, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -4.515467166900635, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -4.477755069732666, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -2.8041117191314697, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": 2.587585210800171, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": 6.183584213256836, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": 7.167823791503906, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": 9.330349922180176, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -0.7203639149665833, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -12.502355575561523, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": -10.53499984741211, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": 1.4793434143066406, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -9.836216926574707, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": 5.254878997802734, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -0.6041688323020935, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": 3.4832756519317627, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -3.310424327850342, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -6.958009719848633, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": 1.9582477807998657, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": 0.9501878023147583, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": 0.5971997380256653, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": 1.221201777458191, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -2.0772831439971924, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -5.599991321563721, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": 1.1452524662017822, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -3.9608592987060547, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": 2.485051155090332, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -6.193269729614258, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -5.742509841918945, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": 0.0498674251139164, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -13.879101753234863, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -14.36821460723877, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -18.042510986328125, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -3.22035813331604, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -1.0437861680984497, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": 0.015396964736282825, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -1.583577275276184, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 640, \"mu_intercept_per_group\": -2.0819149017333984, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 641, \"mu_intercept_per_group\": -0.7863612771034241, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 642, \"mu_intercept_per_group\": 7.002364635467529, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 643, \"mu_intercept_per_group\": 4.588798999786377, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 644, \"mu_intercept_per_group\": -10.203553199768066, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 645, \"mu_intercept_per_group\": 12.023187637329102, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 646, \"mu_intercept_per_group\": 6.173324108123779, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 647, \"mu_intercept_per_group\": 3.815366744995117, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 648, \"mu_intercept_per_group\": 1.77543306350708, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 649, \"mu_intercept_per_group\": 0.8806454539299011, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 650, \"mu_intercept_per_group\": 0.8425295352935791, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 651, \"mu_intercept_per_group\": -5.0908989906311035, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 652, \"mu_intercept_per_group\": -6.294406890869141, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 653, \"mu_intercept_per_group\": -4.240575790405273, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 654, \"mu_intercept_per_group\": 1.1153373718261719, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 655, \"mu_intercept_per_group\": -8.701765060424805, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 656, \"mu_intercept_per_group\": -8.359423637390137, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 657, \"mu_intercept_per_group\": -9.169832229614258, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 658, \"mu_intercept_per_group\": -4.485829830169678, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 659, \"mu_intercept_per_group\": -1.2002664804458618, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 660, \"mu_intercept_per_group\": -1.283840298652649, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 661, \"mu_intercept_per_group\": 0.8676854968070984, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 662, \"mu_intercept_per_group\": 1.0672951936721802, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 663, \"mu_intercept_per_group\": 4.966071605682373, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 664, \"mu_intercept_per_group\": -5.618011474609375, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 665, \"mu_intercept_per_group\": -3.85263729095459, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 666, \"mu_intercept_per_group\": 1.6280697584152222, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 667, \"mu_intercept_per_group\": 6.69218635559082, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 668, \"mu_intercept_per_group\": -1.8946659564971924, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 669, \"mu_intercept_per_group\": -3.206312417984009, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 670, \"mu_intercept_per_group\": -7.758072853088379, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 671, \"mu_intercept_per_group\": -8.816082000732422, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 672, \"mu_intercept_per_group\": -2.9414925575256348, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 673, \"mu_intercept_per_group\": 0.16837017238140106, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 674, \"mu_intercept_per_group\": -3.6111299991607666, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 675, \"mu_intercept_per_group\": -4.992269039154053, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 676, \"mu_intercept_per_group\": -0.8869007229804993, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 677, \"mu_intercept_per_group\": -3.622464656829834, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 678, \"mu_intercept_per_group\": -6.170212745666504, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 679, \"mu_intercept_per_group\": -8.245932579040527, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 680, \"mu_intercept_per_group\": -15.151115417480469, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 681, \"mu_intercept_per_group\": 5.21836519241333, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 682, \"mu_intercept_per_group\": -16.357988357543945, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 683, \"mu_intercept_per_group\": -1.631963849067688, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 684, \"mu_intercept_per_group\": -10.513628959655762, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 685, \"mu_intercept_per_group\": -9.62197494506836, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 686, \"mu_intercept_per_group\": -20.429683685302734, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 687, \"mu_intercept_per_group\": -21.109054565429688, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 688, \"mu_intercept_per_group\": -1.9177546501159668, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 689, \"mu_intercept_per_group\": -1.488953948020935, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 690, \"mu_intercept_per_group\": 1.6919147968292236, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 691, \"mu_intercept_per_group\": 2.763578176498413, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 692, \"mu_intercept_per_group\": -3.010648012161255, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 693, \"mu_intercept_per_group\": -6.339518070220947, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 694, \"mu_intercept_per_group\": 0.133871391415596, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 695, \"mu_intercept_per_group\": -2.2540857791900635, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 696, \"mu_intercept_per_group\": 1.3386919498443604, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 697, \"mu_intercept_per_group\": -0.2260308414697647, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 698, \"mu_intercept_per_group\": -8.835453987121582, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 699, \"mu_intercept_per_group\": 1.3694179058074951, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 700, \"mu_intercept_per_group\": 1.7521642446517944, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 701, \"mu_intercept_per_group\": -0.28043603897094727, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 702, \"mu_intercept_per_group\": -1.9403650760650635, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 703, \"mu_intercept_per_group\": -6.318399906158447, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 704, \"mu_intercept_per_group\": 13.841275215148926, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 705, \"mu_intercept_per_group\": 1.4841045141220093, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 706, \"mu_intercept_per_group\": 3.645707607269287, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 707, \"mu_intercept_per_group\": 1.5687335729599, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 708, \"mu_intercept_per_group\": -3.1403298377990723, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 709, \"mu_intercept_per_group\": -2.7531683444976807, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 710, \"mu_intercept_per_group\": -18.587854385375977, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 711, \"mu_intercept_per_group\": -5.753057479858398, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 712, \"mu_intercept_per_group\": 5.228336811065674, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 713, \"mu_intercept_per_group\": 3.0528054237365723, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 714, \"mu_intercept_per_group\": -6.099391937255859, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 715, \"mu_intercept_per_group\": -8.292634010314941, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 716, \"mu_intercept_per_group\": 1.57783842086792, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 717, \"mu_intercept_per_group\": 1.708120346069336, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 718, \"mu_intercept_per_group\": -1.237881064414978, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 719, \"mu_intercept_per_group\": -13.32564640045166, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 720, \"mu_intercept_per_group\": 2.978395938873291, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 721, \"mu_intercept_per_group\": -3.8427343368530273, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 722, \"mu_intercept_per_group\": 2.4600279331207275, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 723, \"mu_intercept_per_group\": 3.6240856647491455, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 724, \"mu_intercept_per_group\": 3.1564455032348633, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 725, \"mu_intercept_per_group\": 5.206112861633301, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 726, \"mu_intercept_per_group\": -10.339628219604492, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 727, \"mu_intercept_per_group\": 10.391362190246582, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 728, \"mu_intercept_per_group\": -13.145536422729492, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 729, \"mu_intercept_per_group\": -3.039750099182129, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 730, \"mu_intercept_per_group\": -1.8714406490325928, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 731, \"mu_intercept_per_group\": 2.5062243938446045, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 732, \"mu_intercept_per_group\": 2.355806827545166, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 733, \"mu_intercept_per_group\": 4.35094690322876, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 734, \"mu_intercept_per_group\": 2.01265811920166, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 735, \"mu_intercept_per_group\": -6.302050590515137, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 736, \"mu_intercept_per_group\": 1.2704237699508667, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 737, \"mu_intercept_per_group\": -6.088379859924316, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 738, \"mu_intercept_per_group\": 1.4410150051116943, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 739, \"mu_intercept_per_group\": -4.998089790344238, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 740, \"mu_intercept_per_group\": -1.0717111825942993, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 741, \"mu_intercept_per_group\": -2.8326401710510254, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 742, \"mu_intercept_per_group\": 0.5562751293182373, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 743, \"mu_intercept_per_group\": -4.102422714233398, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 744, \"mu_intercept_per_group\": -0.6741512417793274, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 745, \"mu_intercept_per_group\": -6.860042572021484, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 746, \"mu_intercept_per_group\": -7.127810001373291, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 747, \"mu_intercept_per_group\": -5.695292949676514, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 748, \"mu_intercept_per_group\": 8.79918384552002, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 749, \"mu_intercept_per_group\": 3.3661038875579834, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 750, \"mu_intercept_per_group\": -1.9716641902923584, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 751, \"mu_intercept_per_group\": 3.977968215942383, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 752, \"mu_intercept_per_group\": -4.175975799560547, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 753, \"mu_intercept_per_group\": -3.6886377334594727, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 754, \"mu_intercept_per_group\": -1.2347979545593262, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 755, \"mu_intercept_per_group\": -5.9835991859436035, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 756, \"mu_intercept_per_group\": -10.218194961547852, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 757, \"mu_intercept_per_group\": -4.862447261810303, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 758, \"mu_intercept_per_group\": -10.775684356689453, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 759, \"mu_intercept_per_group\": -3.4646146297454834, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 760, \"mu_intercept_per_group\": -2.4840354919433594, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 3, \"draws\": 761, \"mu_intercept_per_group\": -0.9740098714828491, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 3, \"draws\": 762, \"mu_intercept_per_group\": -3.4814372062683105, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 3, \"draws\": 763, \"mu_intercept_per_group\": -5.168466091156006, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 3, \"draws\": 764, \"mu_intercept_per_group\": -11.178720474243164, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 3, \"draws\": 765, \"mu_intercept_per_group\": -14.58297348022461, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 3, \"draws\": 766, \"mu_intercept_per_group\": -7.081275463104248, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 3, \"draws\": 767, \"mu_intercept_per_group\": 2.7455029487609863, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 3, \"draws\": 768, \"mu_intercept_per_group\": -0.04195941239595413, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 3, \"draws\": 769, \"mu_intercept_per_group\": -1.5294663906097412, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 3, \"draws\": 770, \"mu_intercept_per_group\": 9.213594436645508, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 3, \"draws\": 771, \"mu_intercept_per_group\": -4.530481815338135, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 3, \"draws\": 772, \"mu_intercept_per_group\": -8.007185935974121, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 3, \"draws\": 773, \"mu_intercept_per_group\": -8.879368782043457, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 3, \"draws\": 774, \"mu_intercept_per_group\": -8.491690635681152, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 3, \"draws\": 775, \"mu_intercept_per_group\": 5.7926249504089355, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 3, \"draws\": 776, \"mu_intercept_per_group\": -11.696650505065918, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 3, \"draws\": 777, \"mu_intercept_per_group\": -2.5717172622680664, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 3, \"draws\": 778, \"mu_intercept_per_group\": -1.936160683631897, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 3, \"draws\": 779, \"mu_intercept_per_group\": -4.924736499786377, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 3, \"draws\": 780, \"mu_intercept_per_group\": -9.15251636505127, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 3, \"draws\": 781, \"mu_intercept_per_group\": -0.9256086349487305, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 3, \"draws\": 782, \"mu_intercept_per_group\": -2.718745470046997, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 3, \"draws\": 783, \"mu_intercept_per_group\": 0.4050230085849762, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 3, \"draws\": 784, \"mu_intercept_per_group\": -6.642741680145264, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 3, \"draws\": 785, \"mu_intercept_per_group\": 3.859210252761841, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 3, \"draws\": 786, \"mu_intercept_per_group\": -5.522294521331787, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 3, \"draws\": 787, \"mu_intercept_per_group\": 7.714738845825195, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 3, \"draws\": 788, \"mu_intercept_per_group\": -5.8960394859313965, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 3, \"draws\": 789, \"mu_intercept_per_group\": -2.492332696914673, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 3, \"draws\": 790, \"mu_intercept_per_group\": 6.8780364990234375, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 3, \"draws\": 791, \"mu_intercept_per_group\": 6.295490741729736, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 3, \"draws\": 792, \"mu_intercept_per_group\": 3.3202102184295654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 3, \"draws\": 793, \"mu_intercept_per_group\": 0.27863284945487976, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 3, \"draws\": 794, \"mu_intercept_per_group\": -0.6200317144393921, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 3, \"draws\": 795, \"mu_intercept_per_group\": -0.4486876130104065, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 3, \"draws\": 796, \"mu_intercept_per_group\": -5.382551670074463, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 3, \"draws\": 797, \"mu_intercept_per_group\": 10.205591201782227, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 3, \"draws\": 798, \"mu_intercept_per_group\": -9.05825424194336, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 3, \"draws\": 799, \"mu_intercept_per_group\": 9.337186813354492, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": -10.222573280334473, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": 0.7351592779159546, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -4.840921878814697, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -2.0387380123138428, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": 1.2483538389205933, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -2.9457359313964844, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -5.501341819763184, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -8.34166431427002, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": -1.844313621520996, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -6.937033176422119, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": -3.4211442470550537, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": 0.9551476240158081, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -0.4594762623310089, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": -2.6546359062194824, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": -0.28176337480545044, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -2.703993797302246, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": 9.14089298248291, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": 6.106947422027588, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": 6.025209426879883, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -5.250345706939697, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": 6.868474960327148, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": -2.2628467082977295, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -11.139957427978516, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": 0.7120257616043091, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": 1.6031622886657715, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": -8.283370018005371, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": -1.4586102962493896, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": -1.5663509368896484, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -9.569623947143555, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": 3.1074273586273193, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": -1.128059983253479, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": 2.5137887001037598, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -1.8959046602249146, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -5.683225154876709, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -6.53802490234375, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -5.361851692199707, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -3.998962640762329, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -9.249808311462402, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -7.951653957366943, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": 6.277647495269775, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": 0.48686710000038147, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": -0.9286237955093384, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": 5.7846903800964355, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": 3.9058072566986084, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": 12.240160942077637, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": 7.2814507484436035, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -10.052249908447266, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": -10.43879222869873, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": 7.636048316955566, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": 9.484684944152832, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": 7.747954845428467, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -5.559622287750244, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -1.6774073839187622, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": 0.3476562798023224, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": -1.2113286256790161, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": 2.4230000972747803, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": 3.167386293411255, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": -1.7299370765686035, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -3.0267183780670166, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": 0.589921772480011, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -8.071708679199219, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -0.665273129940033, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -5.544233798980713, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": 0.5462062954902649, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -6.977456569671631, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -9.465309143066406, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": 2.9924938678741455, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": -0.47992295026779175, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": -0.25456222891807556, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -3.280860662460327, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": 1.5002942085266113, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -3.6058130264282227, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -0.7466505765914917, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -3.2043683528900146, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": -5.266552448272705, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": -12.962620735168457, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": -8.191950798034668, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": 1.2133440971374512, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -3.3012075424194336, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -4.116568088531494, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": 1.3200589418411255, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": 1.343465805053711, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -5.596874237060547, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -10.104131698608398, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": 3.3133914470672607, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": 5.00221061706543, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": 5.407783508300781, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -4.314720153808594, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": 18.991758346557617, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": -0.6752288937568665, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": -0.48365887999534607, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": -3.6919829845428467, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": 4.215518474578857, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -6.701752662658691, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": 4.814064979553223, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": 3.983412265777588, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -4.883889198303223, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -3.206291675567627, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": 3.3244102001190186, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": 5.707808971405029, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": 7.159797191619873, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -1.932453989982605, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": 3.110919713973999, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": -2.2059030532836914, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": 7.051965713500977, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": -4.265612602233887, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -12.290275573730469, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": 4.426063537597656, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": -2.242264747619629, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": -1.0556801557540894, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": -0.9302979111671448, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": -4.810073375701904, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": 1.5923924446105957, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": -3.728991746902466, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": 5.562324047088623, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": 3.485109329223633, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -0.3389970064163208, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -3.247162103652954, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": 1.2077232599258423, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": -1.7801531553268433, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": 0.6469892859458923, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": 0.7023070454597473, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -4.512775421142578, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -2.7560360431671143, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -1.5878812074661255, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -6.278449058532715, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -5.4340410232543945, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": -5.3703436851501465, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": 2.3976669311523438, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": -4.363067150115967, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -6.9952712059021, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -10.892335891723633, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": 3.478604793548584, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": 0.783741295337677, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": -4.214395523071289, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": 2.311872959136963, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -6.152163028717041, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": 3.9275498390197754, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": -7.379451274871826, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": 1.9290038347244263, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -5.134275913238525, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -2.58302640914917, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": 1.8919726610183716, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": 3.966975212097168, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -7.511531829833984, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -4.661186218261719, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": 4.783458232879639, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": 0.015353485941886902, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -2.604113817214966, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": 2.289116859436035, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -8.103594779968262, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": 2.359726667404175, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": -1.2524923086166382, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -3.437492847442627, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": 0.6847198605537415, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -1.9796546697616577, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": 5.471470355987549, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": -4.455415725708008, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": -2.1415693759918213, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": 5.087538719177246, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": 4.994999408721924, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": 3.9994425773620605, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": 3.4031996726989746, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -8.986064910888672, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": 3.3010106086730957, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -1.4659618139266968, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": 0.22813911736011505, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": 4.13400936126709, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -1.0655854940414429, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -5.3494873046875, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": 2.6429660320281982, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -2.794489622116089, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": 0.44388440251350403, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": 5.480645179748535, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": 2.0663249492645264, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": 3.190870761871338, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": 0.4560146629810333, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -1.3204753398895264, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": 4.639101505279541, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -2.3368122577667236, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": -0.12557123601436615, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -4.177392482757568, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -1.4043046236038208, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": 3.410184144973755, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": -4.618890762329102, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": 0.9706475734710693, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -5.469550132751465, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -10.25925350189209, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -5.198490142822266, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": 0.6035569906234741, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -4.91817045211792, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -1.833343744277954, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -1.9475245475769043, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -4.199075222015381, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -0.6295586228370667, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -7.06285285949707, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -7.332114219665527, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": -1.8951919078826904, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": -1.390397548675537, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": 5.134096145629883, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -3.130772352218628, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": -3.425441026687622, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -10.429344177246094, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -6.859905242919922, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -7.089567184448242, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -7.857722759246826, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -6.922474384307861, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": 0.9095247983932495, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": 1.1069105863571167, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -8.023462295532227, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -11.704340934753418, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": 5.241725921630859, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": 4.544750213623047, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -9.038421630859375, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -4.5517048835754395, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -2.0782558917999268, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": 4.884559154510498, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": -0.8930679559707642, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": 3.2035889625549316, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": 3.412111520767212, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": 6.3044891357421875, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -9.152482032775879, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": -0.036205701529979706, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -2.2955758571624756, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -11.870111465454102, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": 5.123497486114502, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -21.790081024169922, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -19.68638038635254, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -15.662795066833496, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": 10.203377723693848, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": 8.00701904296875, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": 5.623378276824951, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": 6.930778980255127, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": -2.4476048946380615, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": -4.406008720397949, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": -0.639160692691803, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -8.552936553955078, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -7.73972749710083, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": 1.669751524925232, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": -5.550314903259277, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -1.334588646888733, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -7.068094730377197, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -5.390186786651611, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": 1.802512764930725, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": 2.1883575916290283, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -2.4512076377868652, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": 0.2697095572948456, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": 2.4418365955352783, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": 3.1828649044036865, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -0.5853416919708252, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": -1.688409447669983, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": -0.321841835975647, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": 1.7025400400161743, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -5.3715972900390625, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -2.4557180404663086, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": -4.347818374633789, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -4.5496344566345215, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -3.889549732208252, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": -9.831265449523926, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -7.587305545806885, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -9.38453483581543, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": 11.450456619262695, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": 10.535062789916992, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -9.374042510986328, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -7.373213768005371, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -2.8359947204589844, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -3.4654200077056885, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": -1.794429898262024, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": 7.437652587890625, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": -3.163054943084717, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": 0.7324626445770264, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": 3.7192869186401367, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": 4.074527740478516, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": 3.914069890975952, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": 4.926583290100098, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": 1.005097508430481, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -6.599051475524902, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -13.909625053405762, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -14.652721405029297, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": 16.287742614746094, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": 15.183490753173828, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": 8.074374198913574, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": 7.079869747161865, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.352164268493652, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": 3.445081949234009, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": -0.13314545154571533, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": 0.12403306365013123, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": 3.615466833114624, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": 2.841648578643799, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": 6.290352821350098, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": -3.2495901584625244, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": -6.687504768371582, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": 1.56047523021698, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": -1.3200434446334839, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": -1.990303874015808, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": -0.9329994916915894, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": -0.19775116443634033, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": 4.739821434020996, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": 4.048184871673584, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": 0.6300459504127502, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": 0.37932610511779785, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": -1.1257051229476929, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": 0.17781753838062286, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.540189027786255, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -5.3517045974731445, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": 3.7807674407958984, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": 3.5766971111297607, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": 6.87188720703125, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": -0.2200179249048233, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": 4.251936435699463, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": 1.6953351497650146, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -1.2283800840377808, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": -5.675398349761963, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": 4.123122215270996, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -4.602899074554443, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": 2.192589044570923, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -5.83239221572876, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -5.904195785522461, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -6.1403422355651855, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": 2.6582698822021484, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -4.622495174407959, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -2.3200156688690186, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -10.623682975769043, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -15.656454086303711, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -11.915611267089844, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -7.29128885269165, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -9.28799057006836, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": -1.5844402313232422, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -9.355169296264648, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -9.797776222229004, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": 1.6542587280273438, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": 8.481145858764648, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": 4.470423221588135, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -1.3096708059310913, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -10.22557544708252, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -2.129939556121826, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": -3.6794984340667725, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": -2.065094470977783, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -3.083914041519165, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": 4.107353687286377, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": -1.0638706684112549, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": -1.496822714805603, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": -3.2917540073394775, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": 3.55251145362854, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": -2.9563403129577637, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": 4.9263505935668945, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": -9.568013191223145, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": -13.995607376098633, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": -4.618760108947754, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": 5.174973487854004, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -7.510647296905518, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": 5.256582260131836, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": -6.16785192489624, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": 2.0095841884613037, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": -0.8866797089576721, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": 1.922220230102539, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": 3.6239891052246094, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -8.089971542358398, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": 7.619902610778809, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -8.913562774658203, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": -8.175060272216797, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": -0.1956782341003418, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -1.8559167385101318, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": 2.4483916759490967, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": 2.8031749725341797, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": 1.4116320610046387, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": 1.2916738986968994, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": 0.016939561814069748, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -6.3288960456848145, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": -0.9084743857383728, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -2.4604382514953613, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -4.6587233543396, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -3.721674680709839, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -3.6613924503326416, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -7.367818355560303, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -2.456761598587036, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -0.811137855052948, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -3.5969862937927246, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": 3.7880971431732178, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": 2.0546035766601562, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": 3.7384068965911865, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -3.1992483139038086, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": 4.091832637786865, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": 3.10144305229187, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": 8.00448989868164, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -12.494241714477539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": -15.75905990600586, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": -15.911749839782715, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": -14.960686683654785, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": 7.879668712615967, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": -5.545164585113525, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -8.131694793701172, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": 6.875602722167969, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": 4.374419212341309, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": 6.496573448181152, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": -5.026095390319824, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -8.928727149963379, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -11.550392150878906, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -8.368969917297363, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -6.962975025177002, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": 6.889718055725098, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": 2.922802448272705, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": -4.909971237182617, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": -2.0281882286071777, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -0.21226929128170013, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -2.285454750061035, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -0.6161280274391174, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": 2.2025299072265625, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": -2.122138738632202, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": 4.103301525115967, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": -5.548608779907227, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": 2.7988741397857666, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -8.01515007019043, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": 0.42529040575027466, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": -3.6517932415008545, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": -0.5515525341033936, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": 2.0600452423095703, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": -1.0337955951690674, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": -1.0684521198272705, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -2.2774314880371094, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": -7.314043045043945, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -2.4525113105773926, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -4.27780818939209, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": 1.5510914325714111, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": -0.1506415456533432, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -3.740121841430664, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -5.2863545417785645, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": 5.354739665985107, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": 0.6194051504135132, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -4.08737850189209, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -2.1308741569519043, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -1.3846282958984375, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -2.911750555038452, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -9.480743408203125, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -1.6755708456039429, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -5.225432395935059, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": 4.965527057647705, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": 0.765901505947113, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -0.2432432472705841, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": 1.9107531309127808, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": 1.245962142944336, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -2.8260066509246826, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": 6.900586128234863, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -5.26108455657959, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": 2.28515625, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -4.239246845245361, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": 3.115494966506958, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -2.684730052947998, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -1.2988783121109009, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.9401421546936035, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -2.1803243160247803, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -3.8678042888641357, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": 1.2255836725234985, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": 0.8233058452606201, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": 6.4001641273498535, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -3.6718525886535645, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": 3.9332029819488525, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": 6.823799133300781, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -0.9171903133392334, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": -4.349397659301758, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": 1.7256262302398682, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -3.1465160846710205, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": 0.9560574889183044, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -3.488286256790161, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": 5.763370513916016, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -6.90833044052124, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": 0.5493221879005432, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -1.9435194730758667, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": -0.7900018692016602, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -7.044142246246338, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -6.870087146759033, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -6.215428352355957, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -0.42390817403793335, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -3.4466910362243652, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": 1.4385346174240112, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": 2.753023624420166, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": 2.7223126888275146, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": -6.31094217300415, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": 6.110436916351318, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": 6.438925743103027, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": 5.934630870819092, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": 4.618720054626465, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": -4.0582733154296875, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -8.378496170043945, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -9.8966646194458, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": 1.2092821598052979, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": -4.2657575607299805, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": 7.811222076416016, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": 1.8952081203460693, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": 2.6893508434295654, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": 5.602606296539307, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": 4.052567481994629, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -2.7636845111846924, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -1.1795055866241455, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -4.659461975097656, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": 7.605453968048096, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": -1.9424526691436768, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": 1.479622721672058, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": 4.631229877471924, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": 2.5250823497772217, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": 0.3759743273258209, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -8.323416709899902, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -1.308106780052185, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": -0.3469439446926117, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": -2.320566415786743, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": -1.714707612991333, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": 1.4244813919067383, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": 1.5334476232528687, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": 3.9070937633514404, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -9.991410255432129, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -0.1964610517024994, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": -2.2191975116729736, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -5.656458854675293, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -6.365799427032471, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -0.8335336446762085, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -1.2123515605926514, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": 6.899072647094727, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": 4.415450572967529, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -14.038524627685547, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -6.8309102058410645, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -1.3698656558990479, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -10.225632667541504, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": -2.8464319705963135, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": 0.6432567238807678, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -0.3441639244556427, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": -4.115943908691406, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": -4.275806903839111, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -1.2931828498840332, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -12.119006156921387, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -19.19034767150879, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": 2.8981902599334717, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": 2.008270263671875, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": 5.80705451965332, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": 1.1107293367385864, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -6.476484775543213, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -8.136292457580566, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": 0.5145658254623413, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -5.958985328674316, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": 1.2898212671279907, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -0.7434753775596619, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": -14.839637756347656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": 9.21174430847168, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -11.331006050109863, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -12.430768013000488, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": 3.0895018577575684, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": 0.7254382371902466, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": 2.220641851425171, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": 4.793663501739502, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": 0.6892642974853516, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -2.923584222793579, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": -5.301235198974609, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -2.648239850997925, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": -15.617238998413086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": 5.484040260314941, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": -0.8728763461112976, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -0.5054839253425598, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -0.6188060641288757, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -4.285893440246582, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -7.326533794403076, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -0.6164996027946472, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": 1.4153728485107422, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -9.29893684387207, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": -8.429384231567383, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": 5.165633201599121, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": -1.2580235004425049, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": 2.07047438621521, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": 0.11970026791095734, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": 3.7929165363311768, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -1.8149521350860596, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": 13.338642120361328, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": 6.8847150802612305, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -7.743525505065918, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -4.1702446937561035, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -5.477596282958984, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": -5.992972373962402, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": 2.686174154281616, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -5.086594104766846, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -8.534751892089844, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": 4.817463397979736, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -4.412678241729736, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -9.72543716430664, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -13.762779235839844, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": 4.749863147735596, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": -7.763848781585693, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": 9.345660209655762, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": 2.645254373550415, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -0.2019905000925064, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": 0.8105884790420532, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": 1.4256742000579834, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -3.2158706188201904, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": -0.8970597386360168, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": 0.28827059268951416, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -0.01489965058863163, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -7.373693943023682, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -0.13117434084415436, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -4.393489360809326, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -0.5609362125396729, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": 2.605276107788086, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": 2.394541025161743, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": 0.8525758385658264, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -4.941886901855469, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -4.616106986999512, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": 13.114214897155762, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -12.420550346374512, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": 2.9929749965667725, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": -0.11894222348928452, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -2.2654402256011963, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": 3.9687790870666504, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": 8.39231014251709, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": 19.870697021484375, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": 17.059907913208008, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": 0.5694618225097656, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": 5.5281548500061035, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": -3.6333203315734863, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": -10.495563507080078, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": 4.230743408203125, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": -5.583453178405762, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.991307497024536, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": 1.5501219034194946, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": 3.2045388221740723, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -6.84132194519043, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": 11.670865058898926, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -11.415975570678711, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -10.994959831237793, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -11.472407341003418, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -8.113114356994629, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": 4.982320308685303, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": 4.659554481506348, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -4.935208320617676, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": 9.936370849609375, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -10.630620956420898, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": -2.723560333251953, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -11.783170700073242, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -1.104187250137329, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -1.1529127359390259, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -7.889201641082764, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": 14.02910041809082, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": -5.565239906311035, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": -4.031822681427002, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": -1.7019822597503662, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 640, \"mu_intercept_per_group\": -0.26659125089645386, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 641, \"mu_intercept_per_group\": -4.296065330505371, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 642, \"mu_intercept_per_group\": -10.37691879272461, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 643, \"mu_intercept_per_group\": -18.959091186523438, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 644, \"mu_intercept_per_group\": 2.9422106742858887, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 645, \"mu_intercept_per_group\": -9.414095878601074, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 646, \"mu_intercept_per_group\": 5.117735385894775, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 647, \"mu_intercept_per_group\": 1.6604464054107666, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 648, \"mu_intercept_per_group\": 8.517123222351074, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 649, \"mu_intercept_per_group\": -5.795717239379883, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 650, \"mu_intercept_per_group\": -0.7973559498786926, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 651, \"mu_intercept_per_group\": 2.1765658855438232, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 652, \"mu_intercept_per_group\": -8.471039772033691, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 653, \"mu_intercept_per_group\": 2.805842638015747, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 654, \"mu_intercept_per_group\": 0.9290947318077087, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 655, \"mu_intercept_per_group\": -11.014189720153809, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 656, \"mu_intercept_per_group\": 4.851659774780273, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 657, \"mu_intercept_per_group\": -5.456446170806885, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 658, \"mu_intercept_per_group\": -7.925178527832031, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 659, \"mu_intercept_per_group\": 3.368788003921509, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 660, \"mu_intercept_per_group\": -2.5615501403808594, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 661, \"mu_intercept_per_group\": -0.13357359170913696, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 662, \"mu_intercept_per_group\": -1.440045952796936, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 663, \"mu_intercept_per_group\": -4.536013603210449, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 664, \"mu_intercept_per_group\": 3.1310298442840576, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 665, \"mu_intercept_per_group\": 3.234423875808716, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 666, \"mu_intercept_per_group\": -3.2979557514190674, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 667, \"mu_intercept_per_group\": -2.1722490787506104, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 668, \"mu_intercept_per_group\": -3.063098430633545, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 669, \"mu_intercept_per_group\": -0.7444708943367004, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 670, \"mu_intercept_per_group\": -2.700894355773926, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 671, \"mu_intercept_per_group\": -0.5761053562164307, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 672, \"mu_intercept_per_group\": 1.9821075201034546, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 673, \"mu_intercept_per_group\": 9.100384712219238, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 674, \"mu_intercept_per_group\": -8.743980407714844, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 675, \"mu_intercept_per_group\": -2.040138006210327, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 676, \"mu_intercept_per_group\": -2.3280317783355713, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 677, \"mu_intercept_per_group\": 1.358982801437378, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 678, \"mu_intercept_per_group\": -4.481082916259766, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 679, \"mu_intercept_per_group\": -0.7191506028175354, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 680, \"mu_intercept_per_group\": -3.6019070148468018, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 681, \"mu_intercept_per_group\": -7.443073749542236, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 682, \"mu_intercept_per_group\": -6.465905666351318, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 683, \"mu_intercept_per_group\": -7.507283687591553, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 684, \"mu_intercept_per_group\": -0.38660094141960144, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 685, \"mu_intercept_per_group\": 0.3696950376033783, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 686, \"mu_intercept_per_group\": -9.97179889678955, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 687, \"mu_intercept_per_group\": -9.013978958129883, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 688, \"mu_intercept_per_group\": 5.4107584953308105, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 689, \"mu_intercept_per_group\": -9.146997451782227, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 690, \"mu_intercept_per_group\": 9.48569107055664, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 691, \"mu_intercept_per_group\": -5.376854419708252, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 692, \"mu_intercept_per_group\": -6.184321880340576, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 693, \"mu_intercept_per_group\": -7.036289215087891, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 694, \"mu_intercept_per_group\": -7.786212921142578, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 695, \"mu_intercept_per_group\": -11.990128517150879, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 696, \"mu_intercept_per_group\": 10.64962387084961, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 697, \"mu_intercept_per_group\": 8.805665969848633, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 698, \"mu_intercept_per_group\": -13.136034965515137, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 699, \"mu_intercept_per_group\": -11.427478790283203, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 700, \"mu_intercept_per_group\": -11.816218376159668, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 701, \"mu_intercept_per_group\": -11.609723091125488, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 702, \"mu_intercept_per_group\": -4.233506202697754, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 703, \"mu_intercept_per_group\": 4.785616397857666, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 704, \"mu_intercept_per_group\": -4.93176794052124, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 705, \"mu_intercept_per_group\": -8.722419738769531, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 706, \"mu_intercept_per_group\": -2.6878652572631836, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 707, \"mu_intercept_per_group\": -6.328852653503418, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 708, \"mu_intercept_per_group\": 8.036919593811035, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 709, \"mu_intercept_per_group\": 0.8848922848701477, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 710, \"mu_intercept_per_group\": -11.791319847106934, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 711, \"mu_intercept_per_group\": -8.944643020629883, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 712, \"mu_intercept_per_group\": -3.957019567489624, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 713, \"mu_intercept_per_group\": -2.2577407360076904, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 714, \"mu_intercept_per_group\": -8.689230918884277, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 715, \"mu_intercept_per_group\": -3.3575379848480225, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 716, \"mu_intercept_per_group\": 3.798638343811035, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 717, \"mu_intercept_per_group\": 1.9333914518356323, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 718, \"mu_intercept_per_group\": -1.0012797117233276, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 719, \"mu_intercept_per_group\": -7.519647598266602, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 720, \"mu_intercept_per_group\": 1.144483208656311, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 721, \"mu_intercept_per_group\": -5.495861530303955, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 722, \"mu_intercept_per_group\": 7.084209442138672, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 723, \"mu_intercept_per_group\": 12.742281913757324, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 724, \"mu_intercept_per_group\": 9.369956016540527, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 725, \"mu_intercept_per_group\": 12.737908363342285, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 726, \"mu_intercept_per_group\": -6.68929386138916, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 727, \"mu_intercept_per_group\": 5.712256908416748, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 728, \"mu_intercept_per_group\": -7.096992015838623, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 729, \"mu_intercept_per_group\": -10.005788803100586, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 730, \"mu_intercept_per_group\": 5.818517684936523, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 731, \"mu_intercept_per_group\": -6.018786430358887, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 732, \"mu_intercept_per_group\": -0.7372608184814453, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 733, \"mu_intercept_per_group\": -2.1605422496795654, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 734, \"mu_intercept_per_group\": -9.852314949035645, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 735, \"mu_intercept_per_group\": -7.954211235046387, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 736, \"mu_intercept_per_group\": -0.5064754486083984, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 737, \"mu_intercept_per_group\": -4.683851718902588, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 738, \"mu_intercept_per_group\": -3.0086984634399414, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 739, \"mu_intercept_per_group\": -1.696182131767273, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 740, \"mu_intercept_per_group\": -6.719401836395264, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 741, \"mu_intercept_per_group\": 3.822751522064209, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 742, \"mu_intercept_per_group\": -4.209133148193359, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 743, \"mu_intercept_per_group\": -3.0948832035064697, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 744, \"mu_intercept_per_group\": 1.826290488243103, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 745, \"mu_intercept_per_group\": 2.9357244968414307, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 746, \"mu_intercept_per_group\": -6.093136787414551, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 747, \"mu_intercept_per_group\": -10.260705947875977, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 748, \"mu_intercept_per_group\": 8.261493682861328, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 749, \"mu_intercept_per_group\": 7.822362422943115, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 750, \"mu_intercept_per_group\": 4.961631774902344, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 751, \"mu_intercept_per_group\": -7.214239120483398, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 752, \"mu_intercept_per_group\": -6.27641487121582, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 753, \"mu_intercept_per_group\": 3.171701431274414, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 754, \"mu_intercept_per_group\": -4.702463626861572, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 755, \"mu_intercept_per_group\": 3.1011359691619873, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 756, \"mu_intercept_per_group\": 6.190070629119873, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 757, \"mu_intercept_per_group\": 4.508309364318848, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 758, \"mu_intercept_per_group\": -6.019010066986084, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 759, \"mu_intercept_per_group\": -2.8097918033599854, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 760, \"mu_intercept_per_group\": -4.367959499359131, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 4, \"draws\": 761, \"mu_intercept_per_group\": -2.824897050857544, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 4, \"draws\": 762, \"mu_intercept_per_group\": -3.17814564704895, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 4, \"draws\": 763, \"mu_intercept_per_group\": 3.206871509552002, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 4, \"draws\": 764, \"mu_intercept_per_group\": -2.970684766769409, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 4, \"draws\": 765, \"mu_intercept_per_group\": -5.780794620513916, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 4, \"draws\": 766, \"mu_intercept_per_group\": -1.0261821746826172, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 4, \"draws\": 767, \"mu_intercept_per_group\": 1.2663980722427368, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 4, \"draws\": 768, \"mu_intercept_per_group\": 1.2258639335632324, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 4, \"draws\": 769, \"mu_intercept_per_group\": -13.134469985961914, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 4, \"draws\": 770, \"mu_intercept_per_group\": 6.728440284729004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 4, \"draws\": 771, \"mu_intercept_per_group\": -5.930309295654297, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 4, \"draws\": 772, \"mu_intercept_per_group\": 2.635946273803711, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 4, \"draws\": 773, \"mu_intercept_per_group\": -11.658357620239258, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 4, \"draws\": 774, \"mu_intercept_per_group\": 5.645565032958984, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 4, \"draws\": 775, \"mu_intercept_per_group\": -13.9772367477417, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 4, \"draws\": 776, \"mu_intercept_per_group\": 6.683927059173584, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 4, \"draws\": 777, \"mu_intercept_per_group\": 3.967349052429199, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 4, \"draws\": 778, \"mu_intercept_per_group\": -2.4375128746032715, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 4, \"draws\": 779, \"mu_intercept_per_group\": 0.6895599365234375, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 4, \"draws\": 780, \"mu_intercept_per_group\": -0.7696780562400818, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 4, \"draws\": 781, \"mu_intercept_per_group\": -5.970967769622803, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 4, \"draws\": 782, \"mu_intercept_per_group\": 6.066479682922363, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 4, \"draws\": 783, \"mu_intercept_per_group\": -9.849822044372559, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 4, \"draws\": 784, \"mu_intercept_per_group\": 1.4375027418136597, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 4, \"draws\": 785, \"mu_intercept_per_group\": -2.4956202507019043, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 4, \"draws\": 786, \"mu_intercept_per_group\": 5.292853832244873, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 4, \"draws\": 787, \"mu_intercept_per_group\": -3.307516574859619, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 4, \"draws\": 788, \"mu_intercept_per_group\": 3.7796382904052734, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 4, \"draws\": 789, \"mu_intercept_per_group\": 4.240785121917725, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 4, \"draws\": 790, \"mu_intercept_per_group\": 11.235593795776367, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 4, \"draws\": 791, \"mu_intercept_per_group\": 10.83666706085205, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 4, \"draws\": 792, \"mu_intercept_per_group\": 2.236236810684204, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 4, \"draws\": 793, \"mu_intercept_per_group\": 0.5667391419410706, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 4, \"draws\": 794, \"mu_intercept_per_group\": -0.7058081030845642, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 4, \"draws\": 795, \"mu_intercept_per_group\": 7.67421817779541, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 4, \"draws\": 796, \"mu_intercept_per_group\": 2.026370048522949, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 4, \"draws\": 797, \"mu_intercept_per_group\": -1.2830697298049927, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 4, \"draws\": 798, \"mu_intercept_per_group\": 7.946447849273682, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 4, \"draws\": 799, \"mu_intercept_per_group\": 4.5653300285339355, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": -0.4936830699443817, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": 4.999171733856201, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": 0.6521782875061035, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": -1.6964330673217773, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": -1.5742603540420532, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": 5.283847808837891, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -11.31496810913086, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": -7.817002773284912, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": 0.5827797651290894, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": 0.2344091534614563, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": 6.792243003845215, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": -4.55280876159668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": 8.97771167755127, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": -4.939431667327881, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": -6.270378589630127, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": -1.8578853607177734, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": 8.810626029968262, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": 5.960352420806885, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": 5.344428539276123, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": 2.4586939811706543, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": 2.2995917797088623, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": 8.367406845092773, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": -6.627414226531982, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": -7.080750465393066, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": 5.021615028381348, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": 6.678419589996338, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": -7.590822219848633, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": 11.360928535461426, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": -5.0973334312438965, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": -0.12444468587636948, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": 0.7130396366119385, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": -1.6190998554229736, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": -0.8674359917640686, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": -1.1215295791625977, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": -5.713323593139648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": -0.21671302616596222, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": 5.190096855163574, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": 3.9520068168640137, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": -3.222916841506958, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": 3.779146194458008, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": 6.8436994552612305, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": -1.0128411054611206, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": 1.1723310947418213, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": 2.092717170715332, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": 2.262239456176758, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": 3.3816802501678467, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": 11.33073902130127, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": 11.15568733215332, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": 2.1022276878356934, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": 3.293247699737549, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": 8.383138656616211, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -11.438764572143555, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": 10.426858901977539, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": 2.6837852001190186, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": 1.2202776670455933, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": 3.7525627613067627, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": 6.483628273010254, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": -2.9187285900115967, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": 3.0211901664733887, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": -1.909820556640625, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": -2.5282647609710693, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": -1.0716947317123413, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": -0.8831166625022888, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": 3.354220390319824, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": -0.743996798992157, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": -0.5231768488883972, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": 8.232260704040527, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": 5.46297550201416, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": 4.69611120223999, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": 6.057387351989746, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": -4.416680335998535, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": 7.120400428771973, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": -7.168479919433594, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": -4.501968860626221, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": 8.21909236907959, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": 12.967597007751465, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": 8.842602729797363, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": -6.817704200744629, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": 0.530376672744751, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": 0.791788637638092, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": 2.006030321121216, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": 2.4872610569000244, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": -1.5326536893844604, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": 2.0414907932281494, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": -3.798283576965332, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": -1.8039244413375854, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": 2.816776752471924, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": 2.3101511001586914, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": 1.285831332206726, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": 14.7088041305542, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": 18.254072189331055, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": -7.443060398101807, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": 3.5992915630340576, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": 1.4925298690795898, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": 4.014184474945068, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": 2.11476731300354, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": 2.2457776069641113, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": 7.356701374053955, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": 10.132861137390137, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": -1.5818636417388916, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -2.462308168411255, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": 3.594944953918457, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": 1.8588958978652954, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": -0.5524792671203613, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": -0.6232576370239258, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": -13.410273551940918, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": -4.3677520751953125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": 1.3094727993011475, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -2.6252894401550293, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -4.273194313049316, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": 2.41314959526062, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": -2.153839111328125, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": 9.022931098937988, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": -7.887650966644287, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": 10.30448055267334, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": -9.876293182373047, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": 2.5861124992370605, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": 0.7091243863105774, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": 1.57363760471344, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": -0.503716230392456, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": 2.7997069358825684, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": 1.6879323720932007, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": -1.311571478843689, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": -2.7984085083007812, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": 0.46960511803627014, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": 7.710426330566406, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": 5.7630486488342285, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": -9.305146217346191, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": -2.0171682834625244, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": 3.2463467121124268, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -3.0720536708831787, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": -3.7099852561950684, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": -2.9686715602874756, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": 0.2306564897298813, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": 2.247824192047119, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": -1.3220113515853882, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": 0.9232107400894165, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": -0.6540190577507019, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": 1.9786392450332642, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": 0.9563783407211304, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": 0.7334156632423401, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": 2.3041305541992188, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": 0.6046547889709473, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": 8.854641914367676, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": -6.714970588684082, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -3.7840960025787354, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": 6.502985954284668, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": -1.8866745233535767, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": 7.441204071044922, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": -8.213418960571289, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": 11.891451835632324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": -0.8685718774795532, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": 3.430837631225586, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": 2.514370918273926, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": 0.09311062097549438, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": 1.293937087059021, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": 0.13305164873600006, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": 3.293895721435547, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": 4.343166828155518, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": 0.6446264386177063, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": 9.81774616241455, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": -2.293382406234741, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": -9.398703575134277, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": 0.90650874376297, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": 3.8641912937164307, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": -0.6476548910140991, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": 5.717311859130859, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": 11.154617309570312, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": 5.177521228790283, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": -5.699761867523193, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": 7.650353908538818, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": -3.251162052154541, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": 2.78304123878479, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": 8.93648624420166, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": 6.478943824768066, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": 2.8575520515441895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": 2.173811912536621, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": 0.5168248414993286, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": -0.9173110127449036, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": 1.0983010530471802, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": -1.128238320350647, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": 1.9474482536315918, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": 2.668318510055542, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": -2.6685452461242676, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": 2.5534586906433105, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": -9.7943115234375, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": -6.563799858093262, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -27.31961441040039, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -17.76662254333496, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": 8.505128860473633, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": 7.133119583129883, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": 8.601794242858887, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -2.6739165782928467, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": 2.1650185585021973, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": 4.0482635498046875, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": 9.812962532043457, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -3.7973835468292236, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": 3.87325382232666, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": 3.8319015502929688, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": 4.967145919799805, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": 3.728036403656006, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -8.574662208557129, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": 8.672873497009277, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": -7.8326802253723145, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": 12.981729507446289, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": 10.628742218017578, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": 0.11629725247621536, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": 5.866535186767578, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": 9.66776180267334, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -8.2392578125, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -8.03979778289795, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": 6.960459232330322, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": 8.417984962463379, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": -8.75178337097168, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -10.365260124206543, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": 12.472177505493164, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": -5.03244161605835, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": 5.089905738830566, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": 11.248644828796387, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": 9.39394474029541, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": 7.524884223937988, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": 3.66719388961792, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": 8.817556381225586, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -8.847822189331055, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": -1.8955214023590088, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -12.273404121398926, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": 4.217207431793213, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": -5.044497966766357, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": 2.819262742996216, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": 3.973588466644287, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": 4.765008926391602, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": 11.957687377929688, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": 3.02358078956604, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": 3.9243686199188232, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": 3.4044294357299805, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": -2.102890968322754, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": 0.602037250995636, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": -2.007368326187134, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -6.695186614990234, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": 11.105422973632812, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": -6.331599235534668, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": 5.3391571044921875, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": 2.7552473545074463, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": 8.030393600463867, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": -1.8643521070480347, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": 2.167123794555664, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": 9.887374877929688, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": 2.273650646209717, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": 1.265815019607544, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": 2.928429365158081, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": 10.590553283691406, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": 9.917350769042969, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": -4.333336353302002, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": -1.8468070030212402, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": -0.6399343013763428, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": 0.8221684098243713, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": -0.25098690390586853, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": 0.47165754437446594, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": 2.0731589794158936, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": 3.5841410160064697, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": 1.3557088375091553, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": 13.834127426147461, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": 14.456953048706055, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": -4.042296886444092, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": 6.682328701019287, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": -3.998976945877075, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": 4.560067176818848, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": 4.257584095001221, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": 0.5953791737556458, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": 8.030223846435547, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": 7.646004676818848, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": -3.9084184169769287, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": -3.7448387145996094, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": -8.0143461227417, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": -2.0092594623565674, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": 12.668036460876465, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": 9.397951126098633, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": 0.7062256932258606, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": 2.3495936393737793, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": 5.453965663909912, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": 6.526251316070557, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -9.583497047424316, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": -9.752381324768066, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": 8.808324813842773, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": -0.7570652961730957, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": -4.107381343841553, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": 7.210703372955322, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": -4.066314697265625, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": -5.4151611328125, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": -5.232656955718994, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": -1.9585570096969604, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": -3.251300573348999, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": -1.3458646535873413, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": 1.9364404678344727, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": -0.6752256155014038, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": -4.672120094299316, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": 0.4643610417842865, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": 7.394011974334717, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": 1.7245173454284668, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": 4.1162943840026855, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": 1.4681015014648438, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": 0.9539467692375183, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": -0.36705145239830017, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": 4.102670669555664, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": 6.861858367919922, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": -4.539209365844727, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": 4.347302436828613, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": 2.8213248252868652, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": 9.329455375671387, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": 1.9890902042388916, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": 0.6505970358848572, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": 2.8247857093811035, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": 3.5750627517700195, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": -1.6562188863754272, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": 3.6209089756011963, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": 0.9198087453842163, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -0.28500208258628845, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": -0.8128213882446289, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": 6.068824768066406, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": -0.8334502577781677, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": -3.7099437713623047, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": 1.714191198348999, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": 2.0969502925872803, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": 9.183207511901855, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": 10.86903190612793, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": 4.680744171142578, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": 2.815725088119507, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": -0.5970062017440796, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": 4.627745628356934, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": 3.6387157440185547, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": 2.4396767616271973, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": 5.886763572692871, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": 4.537914752960205, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": 6.9371337890625, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": -2.9177708625793457, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": 10.82784366607666, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": 8.419905662536621, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": 5.09188175201416, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": 0.40666913986206055, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": 8.009431838989258, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": -0.05580255761742592, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": 0.024308281019330025, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": 1.5205624103546143, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": 4.1790876388549805, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": 0.2244865894317627, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": 5.782747268676758, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": -7.930447101593018, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": 0.3207881450653076, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": 2.813279151916504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -5.610894680023193, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": 7.947093486785889, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -11.681249618530273, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": 15.034317016601562, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": 0.03979386016726494, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": 14.939435958862305, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": 13.074028968811035, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": 2.1421730518341064, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": -1.7453669309616089, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": 4.593339920043945, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": 5.567477226257324, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": 5.255597114562988, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": -4.950255393981934, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": 10.510313034057617, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": 4.427967071533203, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": -0.597438395023346, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": 11.320734024047852, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": 8.22661304473877, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": -5.545265197753906, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": -8.789752006530762, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": 5.041116714477539, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": -6.190657138824463, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": 2.533984661102295, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -9.193230628967285, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -7.052367210388184, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -4.734168529510498, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -4.440606594085693, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": -3.8006691932678223, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": 1.5238863229751587, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": -1.5220943689346313, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": -0.6359741687774658, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": -7.656125068664551, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": 9.146346092224121, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": 3.1164391040802, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": 8.489348411560059, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": 1.6961735486984253, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": 8.293295860290527, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": 5.431253433227539, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": 7.830577373504639, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": 8.568206787109375, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": -7.505928993225098, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": 2.1178689002990723, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": 2.7821342945098877, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": 5.693019390106201, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": 6.2944440841674805, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": 9.706086158752441, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": -10.40073299407959, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": -3.227675437927246, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": 2.30842924118042, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": -1.5283007621765137, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": -0.5001562833786011, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": 9.165095329284668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": 1.4900716543197632, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": -0.8814666867256165, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": -2.0296337604522705, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": 1.3305256366729736, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": 5.04124641418457, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": -4.7146782875061035, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": 5.809991359710693, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": 5.043154239654541, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": -1.7293035984039307, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": 3.3898768424987793, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": -0.8397834300994873, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": 5.915778636932373, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": 1.9669221639633179, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": 3.1190719604492188, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": -0.2337658703327179, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": 6.688932418823242, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": -2.4702565670013428, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": 2.3119709491729736, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": -3.015862464904785, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": -5.686969757080078, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": 4.881800174713135, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": -6.422973155975342, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": 9.18946647644043, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": 9.735956192016602, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": -12.410496711730957, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": 11.598301887512207, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": -2.832165479660034, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": -3.3463351726531982, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": 3.6924684047698975, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": 4.8262858390808105, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": 4.859366416931152, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": 4.933337211608887, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": 5.615426063537598, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": 7.1026291847229, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": -2.526503562927246, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": 14.279303550720215, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": 14.049449920654297, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": 10.146956443786621, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": -1.6144288778305054, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": -3.103341817855835, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": -10.78703498840332, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": -2.24977445602417, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": 7.7816481590271, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": 2.440359115600586, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": 0.9812870025634766, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": 0.7519392371177673, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": 10.234559059143066, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": -0.4684623181819916, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": 4.018322467803955, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": 3.347318410873413, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": -5.998703956604004, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": 4.131516933441162, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": -3.956796884536743, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": 2.4501700401306152, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": -7.225014686584473, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": 1.4161245822906494, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": 2.6986114978790283, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": 7.647429943084717, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": 3.9245128631591797, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": -7.178640365600586, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": 6.069210052490234, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": -7.366247653961182, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": -3.059081792831421, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": -4.277634620666504, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": -4.914758682250977, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": -2.5589759349823, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -6.704737663269043, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": 5.098209857940674, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -10.468371391296387, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": -5.892239093780518, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": 2.5162999629974365, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": 3.7081711292266846, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": 3.8927412033081055, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": -1.7580379247665405, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -2.632122039794922, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": 11.085421562194824, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": -2.4329164028167725, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": 2.66679048538208, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": 1.0495461225509644, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": 0.8502023816108704, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": -5.250965118408203, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": 6.950047492980957, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": -4.0179057121276855, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": -1.5065183639526367, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": 3.951291799545288, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": -2.1402275562286377, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": 7.854623317718506, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": -2.683741807937622, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": 14.440917015075684, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": 13.877155303955078, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": 11.458995819091797, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": -3.9448370933532715, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": -2.7637362480163574, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": 1.6091384887695312, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": 10.039451599121094, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": -5.605895519256592, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": 18.840381622314453, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": 4.888682842254639, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": -0.08786775171756744, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": -2.7071421146392822, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": 1.2054929733276367, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": 5.187563896179199, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -2.718552827835083, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": 1.6928390264511108, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": 2.8258514404296875, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": -0.6238449215888977, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": 5.984460830688477, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": 0.01763044111430645, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": 5.762425422668457, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": -3.868269205093384, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": -2.518726110458374, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": 2.960270881652832, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": -3.5001561641693115, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": 7.296746730804443, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": 1.4127551317214966, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": -2.601768970489502, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": -1.4885532855987549, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": -1.7040915489196777, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -6.998692989349365, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": 2.1867520809173584, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -9.845512390136719, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": 1.1358827352523804, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": 4.276721477508545, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -1.0788450241088867, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": -1.8729008436203003, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": -0.6531848907470703, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": -4.406121730804443, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": -3.4420886039733887, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -12.418782234191895, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": 6.173922061920166, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": -8.29879093170166, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": 11.020665168762207, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": 6.808164119720459, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": 5.0015058517456055, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": -1.2744996547698975, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": 0.6806426644325256, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -7.457321643829346, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": -5.819141387939453, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": 0.915133535861969, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": -1.2011756896972656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": 6.034015655517578, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -11.381556510925293, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": -7.319867134094238, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": 3.155782461166382, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": 7.666479110717773, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": 7.782724857330322, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": 0.21381761133670807, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": 12.560585975646973, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": -2.7401819229125977, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": 0.6657583713531494, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -3.632479667663574, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": 5.7790045738220215, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": -2.5474801063537598, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": 1.1199679374694824, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": -0.8119602799415588, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": 0.2681579887866974, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": 0.7113875150680542, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": -1.5859010219573975, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": 4.05252742767334, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": 2.554129123687744, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": 3.6585235595703125, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": 1.2316629886627197, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": -0.2994779050350189, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": 5.4572930335998535, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": -4.310985565185547, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": -0.5814806222915649, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": -4.7760329246521, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": 14.579337120056152, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": -4.133450031280518, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": -4.106779098510742, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": 6.196764945983887, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": 3.545785665512085, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": 8.385534286499023, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": 0.5849117636680603, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": 5.525136470794678, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": -6.678565979003906, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -8.455256462097168, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": 8.006284713745117, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -4.586374759674072, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": -4.955859184265137, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": -6.421501636505127, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": 3.928562879562378, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": -4.06256628036499, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": 10.368810653686523, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": 5.356241703033447, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": -2.9610393047332764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": 0.6189560890197754, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": 3.154837131500244, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": -0.1340140551328659, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": 7.543446063995361, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": 1.466381549835205, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": 3.515272855758667, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": 2.2773630619049072, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": -2.729767322540283, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": 4.216533184051514, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": -5.651655197143555, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": -3.35032057762146, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": 7.401084899902344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": 4.6678242683410645, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": -0.03037027269601822, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": -4.2660136222839355, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": 1.8521217107772827, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": 0.3156644403934479, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": 1.9550424814224243, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": 9.87182331085205, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": -3.2301228046417236, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": 10.981620788574219, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": 8.075916290283203, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": 3.7643399238586426, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": 0.19077926874160767, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": 3.4784345626831055, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": 4.375865459442139, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": 1.0993521213531494, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": -8.167473793029785, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": 4.648540019989014, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": 0.35695895552635193, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": -2.8153913021087646, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": -2.977693796157837, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": -1.1377506256103516, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": 0.04873131215572357, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": 3.1761634349823, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": -0.020863207057118416, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": 1.351028561592102, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": 12.045791625976562, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": -0.5252058506011963, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -18.708921432495117, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": -12.27900505065918, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": 11.218646049499512, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": -7.135178089141846, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": 6.958343982696533, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": 5.1873908042907715, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": 1.2365093231201172, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -4.957011699676514, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -5.30355978012085, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": -5.12799072265625, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": 6.813993453979492, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": -4.477818965911865, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": -5.169980049133301, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": -2.9529480934143066, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 640, \"mu_intercept_per_group\": -7.506115913391113, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 641, \"mu_intercept_per_group\": 4.841949939727783, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 642, \"mu_intercept_per_group\": -5.881920337677002, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 643, \"mu_intercept_per_group\": 16.809703826904297, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 644, \"mu_intercept_per_group\": 2.511122941970825, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 645, \"mu_intercept_per_group\": 0.4887118637561798, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 646, \"mu_intercept_per_group\": 0.8064342737197876, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 647, \"mu_intercept_per_group\": 1.4259870052337646, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 648, \"mu_intercept_per_group\": 1.4857269525527954, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 649, \"mu_intercept_per_group\": 8.055587768554688, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 650, \"mu_intercept_per_group\": 12.786767959594727, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 651, \"mu_intercept_per_group\": 2.306870460510254, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 652, \"mu_intercept_per_group\": -6.979279518127441, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 653, \"mu_intercept_per_group\": -0.41045838594436646, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 654, \"mu_intercept_per_group\": -0.3673120439052582, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 655, \"mu_intercept_per_group\": 4.506551742553711, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 656, \"mu_intercept_per_group\": 6.2370924949646, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 657, \"mu_intercept_per_group\": -0.3215402066707611, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 658, \"mu_intercept_per_group\": 5.281808376312256, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 659, \"mu_intercept_per_group\": -2.4257640838623047, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 660, \"mu_intercept_per_group\": -0.3196414113044739, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 661, \"mu_intercept_per_group\": 3.8381330966949463, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 662, \"mu_intercept_per_group\": 3.275034189224243, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 663, \"mu_intercept_per_group\": 4.178934097290039, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 664, \"mu_intercept_per_group\": -3.322736978530884, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 665, \"mu_intercept_per_group\": -2.479078769683838, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 666, \"mu_intercept_per_group\": 3.148167371749878, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 667, \"mu_intercept_per_group\": 7.899265766143799, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 668, \"mu_intercept_per_group\": -3.881068706512451, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 669, \"mu_intercept_per_group\": 3.0566978454589844, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 670, \"mu_intercept_per_group\": -1.6932018995285034, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 671, \"mu_intercept_per_group\": 0.5915698409080505, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 672, \"mu_intercept_per_group\": 4.123375415802002, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 673, \"mu_intercept_per_group\": 6.35595178604126, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 674, \"mu_intercept_per_group\": -3.740208864212036, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 675, \"mu_intercept_per_group\": -3.8673324584960938, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 676, \"mu_intercept_per_group\": 2.7119503021240234, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 677, \"mu_intercept_per_group\": -1.8882607221603394, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 678, \"mu_intercept_per_group\": -2.162415027618408, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 679, \"mu_intercept_per_group\": -0.3742189109325409, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 680, \"mu_intercept_per_group\": -2.5472350120544434, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 681, \"mu_intercept_per_group\": 1.0873957872390747, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 682, \"mu_intercept_per_group\": -1.8083175420761108, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 683, \"mu_intercept_per_group\": -6.07248592376709, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 684, \"mu_intercept_per_group\": 4.208353519439697, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 685, \"mu_intercept_per_group\": 4.22807502746582, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 686, \"mu_intercept_per_group\": 13.54815673828125, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 687, \"mu_intercept_per_group\": 12.544894218444824, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 688, \"mu_intercept_per_group\": 1.6133661270141602, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 689, \"mu_intercept_per_group\": 3.921630382537842, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 690, \"mu_intercept_per_group\": 2.686460018157959, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 691, \"mu_intercept_per_group\": 7.2498884201049805, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 692, \"mu_intercept_per_group\": 10.887166976928711, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 693, \"mu_intercept_per_group\": 16.479183197021484, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 694, \"mu_intercept_per_group\": -0.018748529255390167, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 695, \"mu_intercept_per_group\": -0.6615126729011536, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 696, \"mu_intercept_per_group\": 8.400014877319336, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 697, \"mu_intercept_per_group\": 6.954907417297363, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 698, \"mu_intercept_per_group\": -8.435911178588867, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 699, \"mu_intercept_per_group\": -10.450371742248535, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 700, \"mu_intercept_per_group\": -13.0982084274292, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 701, \"mu_intercept_per_group\": -7.1084208488464355, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 702, \"mu_intercept_per_group\": 0.5757467150688171, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 703, \"mu_intercept_per_group\": 6.972298622131348, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 704, \"mu_intercept_per_group\": -2.0960466861724854, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 705, \"mu_intercept_per_group\": 11.447457313537598, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 706, \"mu_intercept_per_group\": -6.721770763397217, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 707, \"mu_intercept_per_group\": -10.405341148376465, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 708, \"mu_intercept_per_group\": 16.467519760131836, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 709, \"mu_intercept_per_group\": 3.6985721588134766, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 710, \"mu_intercept_per_group\": -2.596336841583252, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 711, \"mu_intercept_per_group\": 1.6006039381027222, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 712, \"mu_intercept_per_group\": 11.543874740600586, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 713, \"mu_intercept_per_group\": 4.0602850914001465, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 714, \"mu_intercept_per_group\": -5.451816082000732, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 715, \"mu_intercept_per_group\": -0.4832264482975006, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 716, \"mu_intercept_per_group\": -0.1277807354927063, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 717, \"mu_intercept_per_group\": 9.382996559143066, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 718, \"mu_intercept_per_group\": 2.7434017658233643, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 719, \"mu_intercept_per_group\": -13.703967094421387, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 720, \"mu_intercept_per_group\": 11.376761436462402, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 721, \"mu_intercept_per_group\": -8.271041870117188, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 722, \"mu_intercept_per_group\": 5.795229911804199, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 723, \"mu_intercept_per_group\": -4.5389933586120605, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 724, \"mu_intercept_per_group\": -0.5400820374488831, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 725, \"mu_intercept_per_group\": -0.4254120886325836, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 726, \"mu_intercept_per_group\": 3.012491464614868, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 727, \"mu_intercept_per_group\": -1.6920281648635864, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 728, \"mu_intercept_per_group\": 2.6638760566711426, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 729, \"mu_intercept_per_group\": 7.623227596282959, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 730, \"mu_intercept_per_group\": -3.2628395557403564, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 731, \"mu_intercept_per_group\": 3.5190138816833496, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 732, \"mu_intercept_per_group\": 4.912494659423828, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 733, \"mu_intercept_per_group\": 2.229353427886963, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 734, \"mu_intercept_per_group\": -2.8037805557250977, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 735, \"mu_intercept_per_group\": 4.959327220916748, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 736, \"mu_intercept_per_group\": -4.8769683837890625, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 737, \"mu_intercept_per_group\": 4.81979513168335, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 738, \"mu_intercept_per_group\": -2.942124605178833, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 739, \"mu_intercept_per_group\": 0.570166826248169, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 740, \"mu_intercept_per_group\": -7.019355297088623, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 741, \"mu_intercept_per_group\": 4.785904884338379, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 742, \"mu_intercept_per_group\": -0.14491762220859528, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 743, \"mu_intercept_per_group\": 2.900390625, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 744, \"mu_intercept_per_group\": -3.1168389320373535, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 745, \"mu_intercept_per_group\": -3.2361035346984863, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 746, \"mu_intercept_per_group\": 5.309395790100098, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 747, \"mu_intercept_per_group\": 0.4705502390861511, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 748, \"mu_intercept_per_group\": 4.199631690979004, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 749, \"mu_intercept_per_group\": -2.6365833282470703, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 750, \"mu_intercept_per_group\": 5.085790634155273, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 751, \"mu_intercept_per_group\": -13.19575023651123, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 752, \"mu_intercept_per_group\": -4.775232791900635, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 753, \"mu_intercept_per_group\": 8.22763442993164, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 754, \"mu_intercept_per_group\": -5.417640209197998, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 755, \"mu_intercept_per_group\": 3.015061378479004, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 756, \"mu_intercept_per_group\": -1.2819138765335083, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 757, \"mu_intercept_per_group\": -0.46969661116600037, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 758, \"mu_intercept_per_group\": -2.6609880924224854, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 759, \"mu_intercept_per_group\": 2.6079695224761963, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 760, \"mu_intercept_per_group\": 0.9872055053710938, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 5, \"draws\": 761, \"mu_intercept_per_group\": 2.336440086364746, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 5, \"draws\": 762, \"mu_intercept_per_group\": 6.431071758270264, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 5, \"draws\": 763, \"mu_intercept_per_group\": -8.56132984161377, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 5, \"draws\": 764, \"mu_intercept_per_group\": -6.293648719787598, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 5, \"draws\": 765, \"mu_intercept_per_group\": 1.003957748413086, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 5, \"draws\": 766, \"mu_intercept_per_group\": 5.770401477813721, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 5, \"draws\": 767, \"mu_intercept_per_group\": -11.149538040161133, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 5, \"draws\": 768, \"mu_intercept_per_group\": -11.574239730834961, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 5, \"draws\": 769, \"mu_intercept_per_group\": -0.7626160979270935, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 5, \"draws\": 770, \"mu_intercept_per_group\": 6.175403594970703, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 5, \"draws\": 771, \"mu_intercept_per_group\": -6.830533504486084, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 5, \"draws\": 772, \"mu_intercept_per_group\": 5.845097541809082, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 5, \"draws\": 773, \"mu_intercept_per_group\": -4.2466254234313965, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 5, \"draws\": 774, \"mu_intercept_per_group\": -7.769762992858887, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 5, \"draws\": 775, \"mu_intercept_per_group\": -11.193673133850098, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 5, \"draws\": 776, \"mu_intercept_per_group\": 11.781404495239258, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 5, \"draws\": 777, \"mu_intercept_per_group\": -3.0879199504852295, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 5, \"draws\": 778, \"mu_intercept_per_group\": 2.3158674240112305, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 5, \"draws\": 779, \"mu_intercept_per_group\": 0.16726243495941162, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 5, \"draws\": 780, \"mu_intercept_per_group\": 1.4833091497421265, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 5, \"draws\": 781, \"mu_intercept_per_group\": 6.84270715713501, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 5, \"draws\": 782, \"mu_intercept_per_group\": 4.334469318389893, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 5, \"draws\": 783, \"mu_intercept_per_group\": -4.612475395202637, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 5, \"draws\": 784, \"mu_intercept_per_group\": 4.77070951461792, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 5, \"draws\": 785, \"mu_intercept_per_group\": 4.148092746734619, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 5, \"draws\": 786, \"mu_intercept_per_group\": 3.746044158935547, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 5, \"draws\": 787, \"mu_intercept_per_group\": 1.091285228729248, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 5, \"draws\": 788, \"mu_intercept_per_group\": 7.053884506225586, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 5, \"draws\": 789, \"mu_intercept_per_group\": 6.179688930511475, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 5, \"draws\": 790, \"mu_intercept_per_group\": 0.5649715065956116, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 5, \"draws\": 791, \"mu_intercept_per_group\": 1.1186014413833618, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 5, \"draws\": 792, \"mu_intercept_per_group\": 3.0303378105163574, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 5, \"draws\": 793, \"mu_intercept_per_group\": -0.02562352456152439, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 5, \"draws\": 794, \"mu_intercept_per_group\": -1.4256608486175537, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 5, \"draws\": 795, \"mu_intercept_per_group\": -0.9958571791648865, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 5, \"draws\": 796, \"mu_intercept_per_group\": -7.086660861968994, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 5, \"draws\": 797, \"mu_intercept_per_group\": 0.7649232745170593, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 5, \"draws\": 798, \"mu_intercept_per_group\": 10.123893737792969, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 5, \"draws\": 799, \"mu_intercept_per_group\": 5.146012306213379, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 6.37800407409668, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 14.657581329345703, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 2.7958216667175293, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 6.326478004455566, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 8.790563583374023, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 12.298267364501953, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": -0.6363531351089478, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": -1.6876857280731201, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 2.2299373149871826, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": -1.037280559539795, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 12.031730651855469, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 15.604928016662598, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 2.234408378601074, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 19.13079261779785, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 13.048595428466797, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 9.782146453857422, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 23.940692901611328, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 17.576452255249023, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 16.891254425048828, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 2.0913727283477783, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 12.74721908569336, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 15.554927825927734, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 7.008159637451172, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 0.5297897458076477, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": -5.370870113372803, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": -3.994481086730957, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 13.420904159545898, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 6.839694023132324, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 15.62886905670166, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 15.634469032287598, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 3.7431771755218506, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 9.442510604858398, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 3.235412120819092, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": -0.009158127009868622, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 7.253016471862793, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 8.9336576461792, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 5.424819469451904, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 7.15634298324585, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 6.180077075958252, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 10.72684097290039, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 11.890353202819824, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 7.474733352661133, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 10.881460189819336, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 11.45950698852539, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 17.818603515625, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 17.873416900634766, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 14.556384086608887, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 14.053670883178711, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 16.005577087402344, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 12.597241401672363, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 18.503889083862305, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 16.201860427856445, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 13.740428924560547, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 7.90291166305542, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 11.19510269165039, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 6.94672155380249, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 6.028234481811523, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 13.192073822021484, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 6.797860622406006, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 11.186580657958984, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 7.806375026702881, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 4.5859832763671875, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 3.5664408206939697, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 11.656661033630371, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 6.3669753074646, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 6.91317081451416, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 15.8410062789917, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 13.86631965637207, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 13.010332107543945, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 11.788223266601562, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 8.941932678222656, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 1.099101185798645, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 15.243159294128418, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 4.105511665344238, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 13.89879035949707, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 16.440013885498047, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 11.504037857055664, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 6.29906702041626, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 12.811902046203613, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 9.99511432647705, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 8.57177734375, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 5.0281853675842285, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 8.839679718017578, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 3.568502902984619, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 13.581151008605957, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 14.884998321533203, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 13.430789947509766, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 17.065746307373047, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 8.434178352355957, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 16.63286590576172, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 17.54259490966797, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 11.752270698547363, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 7.332230567932129, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 24.714874267578125, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 4.795590877532959, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 7.172306537628174, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 14.201985359191895, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 19.431533813476562, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 17.595199584960938, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 4.940769195556641, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 6.646292209625244, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 12.10807991027832, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 20.925168991088867, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 17.2150936126709, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 15.789444923400879, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": -0.5448676943778992, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 10.840235710144043, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 3.77411150932312, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 9.024848937988281, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 8.971269607543945, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 6.913607597351074, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 7.734762668609619, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 8.881319999694824, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 14.19491958618164, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 6.7448530197143555, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 18.282974243164062, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 2.9279086589813232, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 5.77211856842041, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 3.1763241291046143, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 12.246147155761719, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 8.492447853088379, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 7.793917179107666, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 3.3679537773132324, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 7.766360282897949, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 8.348556518554688, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 11.928165435791016, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 2.9560039043426514, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 6.947440147399902, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 6.06493616104126, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 7.14630126953125, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 14.731822967529297, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": -5.351778507232666, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 17.632570266723633, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 15.330568313598633, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 5.837926864624023, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 5.051054000854492, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 2.8629238605499268, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 13.25622844696045, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 6.890820503234863, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 17.45374870300293, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 4.656808853149414, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 5.447736740112305, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 10.446636199951172, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 17.325050354003906, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 4.206713676452637, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 9.519606590270996, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 4.474648952484131, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 8.139266014099121, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 9.792088508605957, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 7.3324737548828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 9.299038887023926, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 21.717971801757812, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": -3.0196897983551025, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 2.3027780055999756, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 16.383344650268555, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 5.840900421142578, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 16.744478225708008, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 1.3772361278533936, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 16.889774322509766, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 3.7015507221221924, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 8.963178634643555, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 23.01374626159668, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 28.747516632080078, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 3.696038246154785, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 18.486228942871094, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 9.797303199768066, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 3.586526393890381, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 6.628138542175293, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 5.736710071563721, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 18.295204162597656, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 4.394664764404297, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 10.175525665283203, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 8.979989051818848, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 12.775808334350586, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 15.53598690032959, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 10.567465782165527, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 6.854046821594238, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 9.789966583251953, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 8.406659126281738, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 9.414752006530762, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 8.134831428527832, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 5.053690433502197, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 12.37542724609375, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 19.121780395507812, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 8.219120025634766, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": -4.113567352294922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 12.86084270477295, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 6.4124274253845215, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 14.1568603515625, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 6.179751873016357, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 6.407765865325928, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 4.514246940612793, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 9.066909790039062, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 8.447477340698242, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": -0.7427571415901184, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 2.9169552326202393, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 5.465841770172119, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 7.129478454589844, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 7.043885707855225, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 18.49075698852539, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 5.5466132164001465, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 9.107548713684082, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": -0.9509438872337341, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 8.018399238586426, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 16.792940139770508, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 15.597270965576172, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 12.17685604095459, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 11.676979064941406, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 13.785839080810547, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 1.019270896911621, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": -0.9723620414733887, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 15.839048385620117, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 15.420255661010742, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 8.705223083496094, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 8.651837348937988, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.884833335876465, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 18.371557235717773, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 19.368759155273438, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 21.158721923828125, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 21.188085556030273, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 9.712406158447266, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 3.391413450241089, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 9.882966995239258, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 6.421112537384033, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 10.008955955505371, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": -3.7429559230804443, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 9.174446105957031, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 3.8171348571777344, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": -7.909400939941406, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 23.378190994262695, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 22.460115432739258, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 14.530881881713867, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 17.945173263549805, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 11.54576587677002, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.558603286743164, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 10.420690536499023, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 7.529940605163574, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.042562961578369, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 10.79625129699707, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 17.17136001586914, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 3.307905673980713, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 10.444380760192871, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 11.840070724487305, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 7.593770503997803, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 13.43736457824707, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 2.7093143463134766, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 7.846211910247803, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 9.694792747497559, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 13.173310279846191, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 11.132068634033203, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 12.776078224182129, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 12.271164894104004, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 8.114533424377441, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 10.828557014465332, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 13.942134857177734, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 13.534577369689941, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 9.729780197143555, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 8.994977951049805, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 10.113740921020508, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 6.392364501953125, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 9.727726936340332, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 17.571500778198242, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 18.674175262451172, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 9.110492706298828, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 7.621195316314697, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 21.381479263305664, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 15.83483600616455, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 15.66517448425293, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 12.354133605957031, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 18.962139129638672, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 18.399394989013672, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 9.42381477355957, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 12.00529956817627, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 14.56803035736084, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 12.271184921264648, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 12.291250228881836, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 12.071014404296875, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 15.146749496459961, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 17.343830108642578, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": -1.333060622215271, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 4.346193313598633, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 8.044883728027344, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 8.11178970336914, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 10.069868087768555, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 11.644989013671875, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 16.928489685058594, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 4.277830600738525, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 11.038383483886719, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 5.344930171966553, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 1.1706016063690186, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 6.807243347167969, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 3.9913034439086914, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 4.187417984008789, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 3.5455243587493896, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 8.3716459274292, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 8.537477493286133, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 14.718498229980469, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 16.58214569091797, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 14.316944122314453, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 9.237370491027832, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 8.002992630004883, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 6.624277114868164, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 4.020396709442139, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 11.198153495788574, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 9.070198059082031, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 8.491692543029785, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 17.469974517822266, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 11.335356712341309, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 17.74886703491211, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 9.17672348022461, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 13.998625755310059, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 8.742243766784668, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 2.12756609916687, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 17.68233871459961, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 4.9308319091796875, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 12.931241035461426, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 1.631303071975708, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 3.1112074851989746, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 10.88212776184082, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 10.226880073547363, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 3.8558602333068848, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 5.853753089904785, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 5.873215198516846, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 10.582910537719727, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 15.885552406311035, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 15.327390670776367, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 15.514052391052246, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 7.55764102935791, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 18.369102478027344, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 5.824795722961426, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 15.2969970703125, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 10.23908519744873, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 8.089719772338867, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 8.985725402832031, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 9.877602577209473, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 2.4321155548095703, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 3.6842031478881836, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 3.603825807571411, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 14.202850341796875, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 1.3368322849273682, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 14.970987319946289, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 15.470149040222168, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 8.07016658782959, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 9.706025123596191, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.609657287597656, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 8.33421516418457, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 8.960545539855957, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 8.190251350402832, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 5.345642566680908, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 16.278417587280273, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 9.505990028381348, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.281876564025879, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 15.586712837219238, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 19.380855560302734, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 22.9998722076416, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 21.67023277282715, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 7.986322402954102, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 7.836185932159424, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 13.142619132995605, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 5.911583423614502, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 6.9293131828308105, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 5.969613075256348, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 7.467096328735352, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 16.103960037231445, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 16.114681243896484, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 13.09213924407959, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 13.893994331359863, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 8.880234718322754, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 9.530762672424316, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 6.0966315269470215, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 4.595323085784912, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 2.449854612350464, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": -0.11971868574619293, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": -0.2585868835449219, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": -0.2848990857601166, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 3.782630681991577, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 3.4688425064086914, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 5.765459060668945, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 6.903364181518555, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 4.840702056884766, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 7.454947471618652, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 11.113530158996582, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 10.848203659057617, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 17.729427337646484, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 11.753292083740234, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 9.986661911010742, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": -7.832437038421631, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": -3.5750222206115723, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 0.8440127968788147, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 15.552513122558594, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 6.221508026123047, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 12.048630714416504, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 2.756791114807129, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 10.313526153564453, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 11.103602409362793, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 11.494327545166016, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": -3.0313894748687744, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": -1.2790906429290771, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": -2.8456315994262695, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 1.3038175106048584, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 10.289814949035645, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 10.481236457824707, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 7.539891719818115, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 9.063453674316406, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 5.2259440422058105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 7.041718006134033, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 6.661810874938965, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 4.747824192047119, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 8.413098335266113, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 16.330535888671875, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 1.163423776626587, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 16.63500213623047, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 14.909673690795898, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 6.084036350250244, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 5.330334663391113, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 10.525945663452148, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 6.898045063018799, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 4.190566062927246, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 2.7932097911834717, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 11.941429138183594, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 14.172198295593262, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 11.211122512817383, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 11.090378761291504, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 7.951909065246582, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 7.437392234802246, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 12.96187973022461, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 18.34876823425293, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 15.859905242919922, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 15.521785736083984, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 14.366753578186035, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 16.387638092041016, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 19.00131607055664, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 17.261402130126953, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 20.201961517333984, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 14.736574172973633, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 8.490274429321289, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 19.20979118347168, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 14.432631492614746, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 12.758526802062988, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 10.280341148376465, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 3.8434054851531982, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 4.33111572265625, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 12.005300521850586, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 13.142613410949707, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 16.458255767822266, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 7.13403844833374, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 11.828633308410645, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 21.70359992980957, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 1.3618173599243164, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 12.378552436828613, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 15.441965103149414, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 2.402390241622925, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 6.716982841491699, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 4.186927795410156, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 10.02583122253418, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 11.852301597595215, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 16.920223236083984, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 9.352701187133789, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 12.044156074523926, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 3.900907516479492, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 9.73930835723877, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 5.769766807556152, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 11.501866340637207, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 10.019037246704102, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 8.516297340393066, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 11.029529571533203, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.796485424041748, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 4.365727424621582, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.171832084655762, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 11.5953369140625, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 9.907891273498535, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 11.074311256408691, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 16.388078689575195, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 10.061064720153809, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 6.634213447570801, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 13.056344985961914, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 9.078526496887207, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 6.434875965118408, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 12.41024398803711, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 12.15449047088623, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 12.135732650756836, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 11.424830436706543, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 6.585651397705078, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 11.337423324584961, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 5.740451335906982, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 8.813603401184082, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 13.212648391723633, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 8.048795700073242, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 13.886929512023926, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 12.967419624328613, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 10.155488014221191, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 10.331839561462402, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 9.788475036621094, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 9.635385513305664, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 1.454776644706726, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 24.48976707458496, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 10.624290466308594, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 0.38632020354270935, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 5.080892086029053, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 8.836256980895996, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 10.883007049560547, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 2.214138984680176, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 0.55355304479599, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 11.85208797454834, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 15.452204704284668, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 15.978493690490723, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 17.14012908935547, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 19.22150993347168, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 6.54447603225708, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 11.839815139770508, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 9.87878704071045, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 11.059840202331543, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 13.870463371276855, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 6.411136627197266, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 10.61187744140625, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": -1.4397786855697632, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 6.009209632873535, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 6.391894817352295, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 7.629478931427002, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 17.496248245239258, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 0.5062999725341797, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 19.641016006469727, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": -0.46578502655029297, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 2.3438477516174316, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 5.278593063354492, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 11.609603881835938, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 10.233970642089844, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 5.613235950469971, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 5.573513031005859, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 13.94971752166748, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 1.6410958766937256, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 11.310317039489746, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 15.228354454040527, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 18.357946395874023, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 8.508772850036621, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 7.611819267272949, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 6.46488094329834, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 15.272871971130371, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 8.657197952270508, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 9.182524681091309, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 2.5536835193634033, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 7.748277187347412, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": -0.5391780734062195, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 5.00656270980835, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 15.768522262573242, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 16.949798583984375, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 11.616355895996094, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 5.791330337524414, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 24.58285903930664, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 3.07306170463562, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 8.841790199279785, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 6.011405944824219, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 16.98671531677246, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 4.259638786315918, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 15.975602149963379, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 7.204800605773926, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 8.972975730895996, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 7.0830559730529785, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 13.438091278076172, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 13.647506713867188, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 10.081512451171875, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 5.370123386383057, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 4.815537929534912, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 9.213953971862793, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 10.0669527053833, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 4.305802822113037, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 11.277573585510254, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 6.878101825714111, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 18.96354866027832, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 5.82699728012085, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 5.001354694366455, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 15.142876625061035, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 12.358677864074707, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 14.71912956237793, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 12.808987617492676, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.95818042755127, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 13.814603805541992, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 10.320548057556152, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 8.806737899780273, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 6.535454273223877, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 7.609572887420654, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 0.3184982240200043, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 14.00516128540039, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 11.082520484924316, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 13.876301765441895, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 11.884879112243652, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 2.0137856006622314, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 14.816924095153809, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 12.356063842773438, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 7.032673358917236, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 16.042600631713867, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 14.192509651184082, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 4.965102672576904, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 5.56322717666626, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 12.508365631103516, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 5.104037761688232, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 12.051085472106934, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 11.058951377868652, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 8.062950134277344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 6.636124610900879, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 5.17345666885376, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 10.239788055419922, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 8.55694580078125, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 15.09982681274414, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 8.833052635192871, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 20.978830337524414, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 6.275857448577881, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 16.890836715698242, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 23.01714324951172, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 22.67757225036621, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 20.975807189941406, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 2.482130765914917, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 10.07733154296875, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 13.909623146057129, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 1.9945781230926514, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 14.202008247375488, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 7.961235046386719, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 10.419793128967285, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 5.2984619140625, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 3.3702874183654785, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 8.156440734863281, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 19.221630096435547, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 4.177761077880859, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 0.9088281393051147, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": -9.801112174987793, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": -4.177274227142334, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 6.679325103759766, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 9.05578327178955, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 10.858011245727539, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 18.257614135742188, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 6.315979480743408, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 8.230443954467773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 0.6772663593292236, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 18.805233001708984, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 18.02728843688965, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 12.855727195739746, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 10.447681427001953, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 12.989734649658203, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 10.456489562988281, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 5.5458149909973145, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 640, \"mu_intercept_per_group\": 6.737189769744873, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 641, \"mu_intercept_per_group\": 9.193177223205566, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 642, \"mu_intercept_per_group\": 12.069136619567871, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 643, \"mu_intercept_per_group\": 6.221860408782959, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 644, \"mu_intercept_per_group\": 13.383099555969238, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 645, \"mu_intercept_per_group\": 16.529314041137695, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 646, \"mu_intercept_per_group\": 15.19991397857666, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 647, \"mu_intercept_per_group\": 11.386703491210938, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 648, \"mu_intercept_per_group\": 15.04826545715332, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 649, \"mu_intercept_per_group\": 4.552347660064697, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 650, \"mu_intercept_per_group\": 3.780327558517456, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 651, \"mu_intercept_per_group\": 5.112100601196289, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 652, \"mu_intercept_per_group\": 11.999035835266113, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 653, \"mu_intercept_per_group\": 13.317060470581055, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 654, \"mu_intercept_per_group\": 7.893313407897949, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 655, \"mu_intercept_per_group\": 12.060137748718262, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 656, \"mu_intercept_per_group\": 9.420783042907715, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 657, \"mu_intercept_per_group\": 8.989302635192871, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 658, \"mu_intercept_per_group\": 15.081155776977539, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 659, \"mu_intercept_per_group\": 6.784265041351318, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 660, \"mu_intercept_per_group\": 12.24379825592041, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 661, \"mu_intercept_per_group\": 2.469707727432251, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 662, \"mu_intercept_per_group\": 3.566190004348755, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 663, \"mu_intercept_per_group\": 8.301640510559082, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 664, \"mu_intercept_per_group\": 5.845261573791504, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 665, \"mu_intercept_per_group\": 4.558312892913818, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 666, \"mu_intercept_per_group\": 3.4723405838012695, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 667, \"mu_intercept_per_group\": 11.847676277160645, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 668, \"mu_intercept_per_group\": 11.610284805297852, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 669, \"mu_intercept_per_group\": 2.2657830715179443, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 670, \"mu_intercept_per_group\": 10.631192207336426, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 671, \"mu_intercept_per_group\": 13.213122367858887, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 672, \"mu_intercept_per_group\": 13.68525505065918, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 673, \"mu_intercept_per_group\": 10.926741600036621, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 674, \"mu_intercept_per_group\": 14.190625190734863, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 675, \"mu_intercept_per_group\": 5.748699188232422, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 676, \"mu_intercept_per_group\": 14.493550300598145, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 677, \"mu_intercept_per_group\": 10.242263793945312, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 678, \"mu_intercept_per_group\": 9.60313892364502, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 679, \"mu_intercept_per_group\": 16.792964935302734, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 680, \"mu_intercept_per_group\": 13.379315376281738, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 681, \"mu_intercept_per_group\": 1.0710054636001587, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 682, \"mu_intercept_per_group\": 15.035201072692871, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 683, \"mu_intercept_per_group\": -0.387957900762558, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 684, \"mu_intercept_per_group\": 15.181492805480957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 685, \"mu_intercept_per_group\": 16.71505355834961, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 686, \"mu_intercept_per_group\": 11.101946830749512, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 687, \"mu_intercept_per_group\": 12.336786270141602, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 688, \"mu_intercept_per_group\": 6.484126091003418, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 689, \"mu_intercept_per_group\": 15.515594482421875, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 690, \"mu_intercept_per_group\": 7.741927146911621, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 691, \"mu_intercept_per_group\": 17.842140197753906, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 692, \"mu_intercept_per_group\": 11.315420150756836, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 693, \"mu_intercept_per_group\": 16.897253036499023, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 694, \"mu_intercept_per_group\": -1.6949474811553955, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 695, \"mu_intercept_per_group\": -5.276398658752441, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 696, \"mu_intercept_per_group\": 25.23772621154785, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 697, \"mu_intercept_per_group\": 23.200729370117188, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 698, \"mu_intercept_per_group\": 2.4280004501342773, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 699, \"mu_intercept_per_group\": 6.299410343170166, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 700, \"mu_intercept_per_group\": 5.133821964263916, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 701, \"mu_intercept_per_group\": 1.0711069107055664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 702, \"mu_intercept_per_group\": 10.13552188873291, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 703, \"mu_intercept_per_group\": 6.255331039428711, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 704, \"mu_intercept_per_group\": 25.757722854614258, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 705, \"mu_intercept_per_group\": 6.712465763092041, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 706, \"mu_intercept_per_group\": 10.238642692565918, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 707, \"mu_intercept_per_group\": 10.30508041381836, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 708, \"mu_intercept_per_group\": 17.740585327148438, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 709, \"mu_intercept_per_group\": 17.416980743408203, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 710, \"mu_intercept_per_group\": 2.7176008224487305, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 711, \"mu_intercept_per_group\": 9.658129692077637, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 712, \"mu_intercept_per_group\": 20.566896438598633, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 713, \"mu_intercept_per_group\": 15.501233100891113, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 714, \"mu_intercept_per_group\": 9.931512832641602, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 715, \"mu_intercept_per_group\": 4.31850528717041, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 716, \"mu_intercept_per_group\": 8.438852310180664, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 717, \"mu_intercept_per_group\": 5.479158878326416, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 718, \"mu_intercept_per_group\": 13.189408302307129, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 719, \"mu_intercept_per_group\": -0.5001488924026489, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 720, \"mu_intercept_per_group\": 18.273456573486328, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 721, \"mu_intercept_per_group\": 9.747213363647461, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 722, \"mu_intercept_per_group\": 9.510597229003906, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 723, \"mu_intercept_per_group\": 16.200960159301758, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 724, \"mu_intercept_per_group\": 13.500121116638184, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 725, \"mu_intercept_per_group\": 12.953968048095703, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 726, \"mu_intercept_per_group\": 7.8639631271362305, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 727, \"mu_intercept_per_group\": 5.070074081420898, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 728, \"mu_intercept_per_group\": 15.302668571472168, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 729, \"mu_intercept_per_group\": 7.512243270874023, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 730, \"mu_intercept_per_group\": 11.778135299682617, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 731, \"mu_intercept_per_group\": 1.2225472927093506, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 732, \"mu_intercept_per_group\": 6.62372350692749, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 733, \"mu_intercept_per_group\": 5.657873630523682, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 734, \"mu_intercept_per_group\": 5.344048500061035, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 735, \"mu_intercept_per_group\": 8.548877716064453, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 736, \"mu_intercept_per_group\": 9.904463768005371, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 737, \"mu_intercept_per_group\": 19.767704010009766, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 738, \"mu_intercept_per_group\": 10.717267036437988, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 739, \"mu_intercept_per_group\": 10.820258140563965, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 740, \"mu_intercept_per_group\": 2.6831698417663574, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 741, \"mu_intercept_per_group\": 9.101056098937988, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 742, \"mu_intercept_per_group\": 2.4662649631500244, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 743, \"mu_intercept_per_group\": 10.721576690673828, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 744, \"mu_intercept_per_group\": 8.200984001159668, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 745, \"mu_intercept_per_group\": 15.698253631591797, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 746, \"mu_intercept_per_group\": 9.935863494873047, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 747, \"mu_intercept_per_group\": 17.09223175048828, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 748, \"mu_intercept_per_group\": 9.965093612670898, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 749, \"mu_intercept_per_group\": 21.839853286743164, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 750, \"mu_intercept_per_group\": 23.14823341369629, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 751, \"mu_intercept_per_group\": 6.278114318847656, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 752, \"mu_intercept_per_group\": 6.992970943450928, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 753, \"mu_intercept_per_group\": 8.06745433807373, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 754, \"mu_intercept_per_group\": 7.554111957550049, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 755, \"mu_intercept_per_group\": 12.436790466308594, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 756, \"mu_intercept_per_group\": 13.463346481323242, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 757, \"mu_intercept_per_group\": 11.4485445022583, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 758, \"mu_intercept_per_group\": 6.842139720916748, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 759, \"mu_intercept_per_group\": 11.513456344604492, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 760, \"mu_intercept_per_group\": 11.867603302001953, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 6, \"draws\": 761, \"mu_intercept_per_group\": 9.222723007202148, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 6, \"draws\": 762, \"mu_intercept_per_group\": 13.940552711486816, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 6, \"draws\": 763, \"mu_intercept_per_group\": 13.071642875671387, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 6, \"draws\": 764, \"mu_intercept_per_group\": 16.73880958557129, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 6, \"draws\": 765, \"mu_intercept_per_group\": 9.071429252624512, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 6, \"draws\": 766, \"mu_intercept_per_group\": 17.341548919677734, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 6, \"draws\": 767, \"mu_intercept_per_group\": -0.18725790083408356, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 6, \"draws\": 768, \"mu_intercept_per_group\": 1.9522686004638672, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 6, \"draws\": 769, \"mu_intercept_per_group\": 14.188538551330566, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 6, \"draws\": 770, \"mu_intercept_per_group\": 6.566876411437988, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 6, \"draws\": 771, \"mu_intercept_per_group\": 3.8686840534210205, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 6, \"draws\": 772, \"mu_intercept_per_group\": 12.66661262512207, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 6, \"draws\": 773, \"mu_intercept_per_group\": 9.155329704284668, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 6, \"draws\": 774, \"mu_intercept_per_group\": 4.318933963775635, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 6, \"draws\": 775, \"mu_intercept_per_group\": 0.6530895233154297, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 6, \"draws\": 776, \"mu_intercept_per_group\": 19.313690185546875, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 6, \"draws\": 777, \"mu_intercept_per_group\": 11.354860305786133, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 6, \"draws\": 778, \"mu_intercept_per_group\": 8.88536548614502, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 6, \"draws\": 779, \"mu_intercept_per_group\": 13.623076438903809, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 6, \"draws\": 780, \"mu_intercept_per_group\": 8.875946998596191, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 6, \"draws\": 781, \"mu_intercept_per_group\": 17.30560874938965, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 6, \"draws\": 782, \"mu_intercept_per_group\": 14.880852699279785, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 6, \"draws\": 783, \"mu_intercept_per_group\": -0.4047471284866333, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 6, \"draws\": 784, \"mu_intercept_per_group\": 8.562387466430664, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 6, \"draws\": 785, \"mu_intercept_per_group\": 9.902952194213867, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 6, \"draws\": 786, \"mu_intercept_per_group\": 7.32205057144165, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 6, \"draws\": 787, \"mu_intercept_per_group\": 8.498106956481934, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 6, \"draws\": 788, \"mu_intercept_per_group\": 7.786909103393555, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 6, \"draws\": 789, \"mu_intercept_per_group\": 9.666537284851074, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 6, \"draws\": 790, \"mu_intercept_per_group\": 10.754192352294922, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 6, \"draws\": 791, \"mu_intercept_per_group\": 9.705094337463379, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 6, \"draws\": 792, \"mu_intercept_per_group\": 8.534967422485352, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 6, \"draws\": 793, \"mu_intercept_per_group\": 23.202211380004883, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 6, \"draws\": 794, \"mu_intercept_per_group\": 15.786867141723633, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 6, \"draws\": 795, \"mu_intercept_per_group\": 15.403228759765625, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 6, \"draws\": 796, \"mu_intercept_per_group\": 11.287784576416016, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 6, \"draws\": 797, \"mu_intercept_per_group\": 8.130427360534668, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 6, \"draws\": 798, \"mu_intercept_per_group\": 21.378206253051758, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 6, \"draws\": 799, \"mu_intercept_per_group\": 10.32075023651123, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 13.365216255187988, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 15.986224174499512, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 13.506922721862793, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 12.583298683166504, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 13.145959854125977, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 10.314718246459961, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 11.695979118347168, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 1.184268832206726, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 6.262317180633545, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 6.309609889984131, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 21.440279006958008, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 17.677780151367188, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 7.256966590881348, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 19.48111343383789, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 15.224678039550781, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 16.807680130004883, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 17.123653411865234, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 15.230988502502441, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 15.25283432006836, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 4.390932559967041, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 20.541927337646484, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 18.01485252380371, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 10.836176872253418, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 1.6970674991607666, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 15.565256118774414, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 6.240877628326416, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 4.461719512939453, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 21.099756240844727, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 12.546746253967285, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 8.020142555236816, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 6.100507736206055, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 8.693058967590332, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 5.853026390075684, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 8.21872329711914, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 6.160982608795166, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 9.93838119506836, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 7.362545967102051, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 13.141714096069336, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 10.554520606994629, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 10.737625122070312, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 6.138772964477539, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 11.563729286193848, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 15.39007568359375, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 18.455303192138672, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 20.07542610168457, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 21.19367790222168, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 24.960893630981445, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 24.519468307495117, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 0.24309951066970825, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 0.8245984315872192, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 5.754743576049805, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 15.474645614624023, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 14.499691009521484, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 15.87287712097168, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 9.5660982131958, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 11.276510238647461, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 9.343570709228516, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 14.340816497802734, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 10.232099533081055, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 11.092317581176758, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 8.64330768585205, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 6.819952487945557, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 10.860028266906738, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 8.841946601867676, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 29.787004470825195, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 27.973697662353516, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 25.696727752685547, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 22.549034118652344, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 22.398578643798828, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 2.423912763595581, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 12.322992324829102, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 22.30177879333496, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 5.9411940574646, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 12.70667552947998, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 6.396772384643555, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 15.689356803894043, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 13.98384952545166, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 11.223548889160156, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 9.327942848205566, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 9.253957748413086, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 14.580586433410645, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 11.812888145446777, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 6.036093235015869, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 9.360658645629883, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 13.683189392089844, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 3.668138027191162, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 20.079404830932617, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 19.732669830322266, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": -7.2844624519348145, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 19.907825469970703, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 17.325971603393555, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 16.28411865234375, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 10.153678894042969, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 28.808917999267578, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 4.39420223236084, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 4.0098161697387695, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 20.725873947143555, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 5.349339485168457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 13.390400886535645, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 25.936500549316406, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 27.692113876342773, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 0.6892843246459961, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 7.705946922302246, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 8.074809074401855, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 8.449516296386719, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 10.009151458740234, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 13.588265419006348, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 8.753445625305176, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 7.985311985015869, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 7.765178680419922, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 12.855842590332031, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 5.831816673278809, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 19.002710342407227, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 7.596777439117432, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 18.083946228027344, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 18.949031829833984, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 16.835479736328125, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 3.3367068767547607, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 8.004900932312012, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 8.072371482849121, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 9.917716026306152, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 9.116827964782715, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 7.921419143676758, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 6.825031280517578, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 6.757511615753174, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 11.041048049926758, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 13.748991012573242, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 5.216953754425049, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 7.218094825744629, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 4.133030891418457, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 8.278654098510742, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 10.353484153747559, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 8.205766677856445, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 9.113909721374512, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 13.435678482055664, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 7.472805500030518, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 6.2927374839782715, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 12.961935997009277, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 13.134321212768555, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 3.311103582382202, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 20.138322830200195, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 15.088541030883789, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 7.937490463256836, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 24.575151443481445, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 1.3120315074920654, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 8.991385459899902, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 7.200927734375, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 9.841200828552246, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 8.015582084655762, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 8.205357551574707, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 13.542074203491211, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 11.515954971313477, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 16.647682189941406, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 15.563435554504395, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 2.6132571697235107, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 25.538162231445312, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 5.821999549865723, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 16.785518646240234, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 13.999275207519531, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 15.952714920043945, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 21.79082489013672, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 13.224407196044922, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 13.463597297668457, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 17.405467987060547, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 15.356319427490234, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 10.860158920288086, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 11.327224731445312, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 12.218438148498535, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 7.225792407989502, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 15.116665840148926, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 12.125268936157227, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 20.32888412475586, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 11.944461822509766, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 19.531972885131836, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 15.50171947479248, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 14.030842781066895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 8.110709190368652, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 11.908056259155273, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 6.210599422454834, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 11.965696334838867, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 8.917381286621094, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 7.367876052856445, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 20.438995361328125, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 8.617547035217285, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 12.958555221557617, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 14.83244514465332, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 18.258625030517578, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 8.951822280883789, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 11.939066886901855, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 15.721117973327637, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 16.21558952331543, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 15.323904991149902, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 17.336997985839844, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 11.583391189575195, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 11.544178009033203, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 7.748281002044678, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 9.992754936218262, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 4.86784029006958, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 4.973636627197266, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 21.17041015625, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 8.69924545288086, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.4944429397583, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 8.063563346862793, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 7.062926769256592, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 19.731889724731445, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 18.291259765625, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 8.747230529785156, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 18.810197830200195, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 15.205920219421387, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 11.039413452148438, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 12.377477645874023, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 11.87043285369873, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 14.266119956970215, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 4.876817226409912, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 4.9253435134887695, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 16.296428680419922, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 9.956404685974121, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 27.900943756103516, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 19.01661491394043, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 19.096683502197266, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 8.70776081085205, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 6.189742088317871, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 10.95691967010498, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 14.771323204040527, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 9.063048362731934, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 3.1430015563964844, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 18.078941345214844, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 23.35120964050293, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 25.607166290283203, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 4.532476425170898, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 8.57311725616455, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 9.384215354919434, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 18.20131492614746, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 16.084205627441406, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 12.738502502441406, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 11.328948020935059, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 10.262983322143555, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 4.377212047576904, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 17.15158462524414, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 17.101268768310547, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 10.145792007446289, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.732828140258789, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 11.779470443725586, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 16.50186538696289, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 10.43493938446045, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 11.151856422424316, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 16.47918701171875, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 12.971174240112305, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 13.91413688659668, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 15.176945686340332, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 7.0839128494262695, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 7.607177257537842, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 11.361753463745117, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 3.4405832290649414, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 11.53730583190918, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 12.28682804107666, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 10.009668350219727, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 8.554157257080078, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 21.14964485168457, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 12.436086654663086, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 11.749343872070312, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 21.76825523376465, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 22.942338943481445, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 9.235554695129395, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 6.003686904907227, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 9.031157493591309, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 8.527295112609863, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 14.437241554260254, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 19.985258102416992, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 13.9501953125, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 16.466049194335938, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.188323020935059, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 3.650052785873413, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": -0.5641259551048279, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 6.5888471603393555, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 11.593375205993652, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 12.203052520751953, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 8.825818061828613, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 3.8262438774108887, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 19.703861236572266, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 13.764286994934082, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 18.42430305480957, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 22.307876586914062, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 4.6359429359436035, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 20.210790634155273, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 8.959261894226074, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 11.98414421081543, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 7.425361633300781, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 9.654972076416016, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 9.502685546875, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 6.0089263916015625, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 0.37518641352653503, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 8.947497367858887, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 1.1788791418075562, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 13.108702659606934, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 15.722833633422852, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 17.616113662719727, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 18.214561462402344, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 18.49821662902832, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 15.843475341796875, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 12.071490287780762, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 7.961061954498291, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 7.763580322265625, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 8.794839859008789, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 8.805477142333984, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 15.065488815307617, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 19.071840286254883, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 15.21051025390625, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 17.50092315673828, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 10.562623023986816, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 12.626243591308594, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.377864837646484, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 3.399231433868408, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 19.375444412231445, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 6.916561603546143, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 11.265032768249512, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 7.75400972366333, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 8.189379692077637, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 14.990594863891602, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 11.744601249694824, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 15.621774673461914, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 14.313191413879395, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 13.430397033691406, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 13.630142211914062, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 3.9672305583953857, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 20.56456756591797, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 17.591711044311523, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 10.485973358154297, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 15.693488121032715, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 15.7683744430542, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 8.538536071777344, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 7.237646579742432, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 11.395334243774414, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 18.211868286132812, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": -3.2171363830566406, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 9.60183334350586, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 9.18093490600586, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 10.53969955444336, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 14.215615272521973, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 14.209391593933105, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 12.1614990234375, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 15.070243835449219, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.062638282775879, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 13.224609375, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 12.972430229187012, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 12.639427185058594, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 15.804996490478516, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 10.741495132446289, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 15.48204517364502, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 18.317256927490234, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 9.277792930603027, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 16.801820755004883, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 13.283445358276367, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 28.56692886352539, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 18.216144561767578, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 15.145745277404785, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 18.28443717956543, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 4.058918476104736, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 21.306411743164062, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 8.525124549865723, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 8.66665267944336, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 8.395552635192871, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 9.192790985107422, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 19.66211700439453, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 12.06894302368164, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 21.557912826538086, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 16.0334529876709, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 9.502646446228027, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": -7.473568439483643, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 27.26302146911621, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 5.679250717163086, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 3.9864566326141357, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 4.962776184082031, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 5.602456092834473, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 3.574613571166992, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 6.0953803062438965, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 4.117492198944092, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 4.3790388107299805, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 12.84201431274414, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 12.414887428283691, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 10.326018333435059, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 15.752734184265137, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 6.478569984436035, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 25.24509620666504, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 15.745749473571777, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 19.16963768005371, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 9.519261360168457, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 4.866501808166504, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 5.31254243850708, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 13.689255714416504, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 14.95084285736084, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 13.250029563903809, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 10.449140548706055, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 12.422623634338379, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 14.220320701599121, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 13.78234577178955, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 8.764466285705566, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 17.219280242919922, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 18.36520004272461, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 15.676915168762207, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 13.910944938659668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 14.644582748413086, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 11.859487533569336, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 12.685654640197754, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 5.6109538078308105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 5.270198345184326, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 14.604692459106445, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 13.351242065429688, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 14.131821632385254, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 11.933043479919434, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 9.581589698791504, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 11.551580429077148, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 13.48715877532959, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 17.530794143676758, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 23.088489532470703, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 10.952017784118652, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 7.797173023223877, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 7.918060779571533, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 3.837857961654663, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 14.90882682800293, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.232527732849121, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 11.916237831115723, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 11.307418823242188, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 10.764622688293457, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 12.162664413452148, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 11.911325454711914, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 6.723698616027832, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 18.798871994018555, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 20.45260238647461, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 12.415254592895508, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 11.33404541015625, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 16.511070251464844, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 22.255979537963867, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 7.811313629150391, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 9.574859619140625, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 16.238346099853516, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 16.363250732421875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 22.377403259277344, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 23.27312469482422, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 7.275153636932373, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 12.187787055969238, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 13.263769149780273, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 19.850170135498047, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 10.637458801269531, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 21.424161911010742, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 2.3877055644989014, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 17.00070571899414, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 16.119211196899414, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 4.714224338531494, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 9.48280143737793, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 11.932138442993164, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 11.462850570678711, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 4.972246170043945, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 11.98072624206543, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 17.432313919067383, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 24.201007843017578, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 1.2842515707015991, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 17.438961029052734, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.19468879699707, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 8.123538970947266, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 9.121965408325195, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 9.764420509338379, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 15.511746406555176, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 16.831241607666016, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 14.679157257080078, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 15.384532928466797, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 12.670796394348145, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 14.077652931213379, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 9.785552978515625, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 20.56226921081543, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 13.46574878692627, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 9.305739402770996, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 5.643798828125, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 10.33972454071045, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 14.556548118591309, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 24.412067413330078, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 8.456341743469238, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 17.468503952026367, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 12.381575584411621, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 18.401273727416992, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 20.803680419921875, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 16.706371307373047, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 7.785616874694824, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 5.340003490447998, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 5.669518947601318, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 11.059185981750488, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 16.556629180908203, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 16.046810150146484, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 21.35782814025879, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 12.369587898254395, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 15.511539459228516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 5.071626663208008, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 15.501636505126953, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 7.410902500152588, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 18.73247718811035, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 16.048852920532227, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 18.88574981689453, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 10.08126449584961, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 15.35366153717041, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 11.917501449584961, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 9.132963180541992, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 10.450651168823242, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 13.810266494750977, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 2.6890766620635986, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": -1.9913395643234253, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": -0.07536953687667847, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 10.385358810424805, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 13.682313919067383, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 8.612662315368652, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 21.080904006958008, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 2.9666049480438232, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 8.247576713562012, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 5.297784328460693, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 10.691640853881836, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 11.432547569274902, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 3.5715322494506836, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 8.139065742492676, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 7.719079971313477, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 10.299744606018066, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 10.130926132202148, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 11.452608108520508, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 10.793584823608398, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 8.838262557983398, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 7.482108116149902, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 11.77778148651123, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 5.817020893096924, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 13.539782524108887, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 2.742051601409912, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 2.0724174976348877, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": -3.768800735473633, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 21.81544303894043, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 4.7506608963012695, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 19.60413360595703, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 11.72191333770752, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 8.40286636352539, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 7.327067852020264, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 9.15285587310791, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 14.349908828735352, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 8.631303787231445, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 11.943130493164062, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 10.730412483215332, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 16.227359771728516, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 8.550874710083008, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 11.79819107055664, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 14.002288818359375, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 16.46881675720215, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 11.568902015686035, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 17.494281768798828, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 14.894147872924805, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 1.7984572649002075, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 12.85037899017334, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 8.293396949768066, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 18.77876853942871, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 6.6899333000183105, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 11.464505195617676, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 19.049238204956055, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 5.571662902832031, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 6.56072998046875, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 19.446683883666992, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 15.765954971313477, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 12.330999374389648, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 9.6436128616333, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 9.47997760772705, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 10.60527515411377, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.060279846191406, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 9.786256790161133, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 15.614481925964355, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 12.415962219238281, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 16.422975540161133, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 20.262948989868164, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 17.315725326538086, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 8.132803916931152, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 21.46075439453125, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 9.42358684539795, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 19.435306549072266, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 14.325714111328125, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 14.777213096618652, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 22.450634002685547, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 9.621647834777832, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 14.37435245513916, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 18.603113174438477, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 16.760051727294922, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 7.971218585968018, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 20.94237518310547, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 7.376929759979248, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 10.206183433532715, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 11.28425407409668, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 15.896408081054688, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 15.541982650756836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 8.340100288391113, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 17.229333877563477, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 17.312515258789062, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 9.402052879333496, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 8.678874969482422, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 9.498290061950684, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 11.953205108642578, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 10.073935508728027, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 16.469165802001953, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 15.24312686920166, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 17.935504913330078, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 9.6416015625, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 18.07929801940918, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 18.751453399658203, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 9.810301780700684, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 11.524846076965332, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.80354881286621, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 8.866294860839844, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 16.29786491394043, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 17.726667404174805, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 14.024088859558105, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 13.828648567199707, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 24.777212142944336, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 21.65932273864746, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 19.464895248413086, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 4.741896629333496, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 16.82868003845215, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.196017265319824, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 17.72896957397461, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 16.28904151916504, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 16.36051368713379, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 20.730735778808594, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 10.248053550720215, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 13.69138240814209, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 15.790809631347656, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 10.307531356811523, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 7.823513507843018, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 18.52081871032715, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 14.538589477539062, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 13.096989631652832, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 18.64503288269043, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 11.959044456481934, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 6.970203399658203, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 9.345170974731445, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 2.3109419345855713, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 3.450174331665039, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 1.402164101600647, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 19.996816635131836, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 5.368474006652832, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 8.667400360107422, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 8.736454963684082, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 640, \"mu_intercept_per_group\": 6.383976936340332, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 641, \"mu_intercept_per_group\": 17.02939796447754, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 642, \"mu_intercept_per_group\": 15.558263778686523, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 643, \"mu_intercept_per_group\": 11.166762351989746, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 644, \"mu_intercept_per_group\": 17.25875473022461, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 645, \"mu_intercept_per_group\": 10.982369422912598, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 646, \"mu_intercept_per_group\": 9.999495506286621, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 647, \"mu_intercept_per_group\": 6.820811748504639, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 648, \"mu_intercept_per_group\": 10.358931541442871, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 649, \"mu_intercept_per_group\": 23.390565872192383, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 650, \"mu_intercept_per_group\": 23.66953468322754, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 651, \"mu_intercept_per_group\": 24.429710388183594, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 652, \"mu_intercept_per_group\": 0.06105119735002518, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 653, \"mu_intercept_per_group\": 2.505930185317993, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 654, \"mu_intercept_per_group\": 11.448205947875977, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 655, \"mu_intercept_per_group\": 7.88395357131958, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 656, \"mu_intercept_per_group\": 14.944862365722656, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 657, \"mu_intercept_per_group\": 9.908576011657715, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 658, \"mu_intercept_per_group\": 8.306763648986816, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 659, \"mu_intercept_per_group\": 2.9190523624420166, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 660, \"mu_intercept_per_group\": 11.979454040527344, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 661, \"mu_intercept_per_group\": 8.05868911743164, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 662, \"mu_intercept_per_group\": 7.530640602111816, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 663, \"mu_intercept_per_group\": 9.62185001373291, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 664, \"mu_intercept_per_group\": 7.768664836883545, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 665, \"mu_intercept_per_group\": 7.691366672515869, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 666, \"mu_intercept_per_group\": 6.324993133544922, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 667, \"mu_intercept_per_group\": 15.22071361541748, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 668, \"mu_intercept_per_group\": 4.694248199462891, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 669, \"mu_intercept_per_group\": 5.925929069519043, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 670, \"mu_intercept_per_group\": 12.40772819519043, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 671, \"mu_intercept_per_group\": 6.877628326416016, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 672, \"mu_intercept_per_group\": 20.603790283203125, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 673, \"mu_intercept_per_group\": 20.2160587310791, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 674, \"mu_intercept_per_group\": 10.677534103393555, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 675, \"mu_intercept_per_group\": 9.891088485717773, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 676, \"mu_intercept_per_group\": 14.76111888885498, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 677, \"mu_intercept_per_group\": 5.17296028137207, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 678, \"mu_intercept_per_group\": 21.503398895263672, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 679, \"mu_intercept_per_group\": 13.5818452835083, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 680, \"mu_intercept_per_group\": 11.979031562805176, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 681, \"mu_intercept_per_group\": 13.752204895019531, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 682, \"mu_intercept_per_group\": 6.729361534118652, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 683, \"mu_intercept_per_group\": 14.156052589416504, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 684, \"mu_intercept_per_group\": 12.361424446105957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 685, \"mu_intercept_per_group\": 10.60273551940918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 686, \"mu_intercept_per_group\": 17.63189125061035, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 687, \"mu_intercept_per_group\": 17.9906005859375, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 688, \"mu_intercept_per_group\": 17.58872413635254, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 689, \"mu_intercept_per_group\": 10.29228687286377, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 690, \"mu_intercept_per_group\": 16.375364303588867, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 691, \"mu_intercept_per_group\": 11.047507286071777, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 692, \"mu_intercept_per_group\": 14.359484672546387, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 693, \"mu_intercept_per_group\": 13.661771774291992, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 694, \"mu_intercept_per_group\": 18.88800621032715, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 695, \"mu_intercept_per_group\": 17.933658599853516, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 696, \"mu_intercept_per_group\": 14.136847496032715, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 697, \"mu_intercept_per_group\": 14.391809463500977, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 698, \"mu_intercept_per_group\": 9.188444137573242, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 699, \"mu_intercept_per_group\": 2.5345370769500732, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 700, \"mu_intercept_per_group\": -1.8914897441864014, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 701, \"mu_intercept_per_group\": 11.63975715637207, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 702, \"mu_intercept_per_group\": 12.190738677978516, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 703, \"mu_intercept_per_group\": 13.46512222290039, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 704, \"mu_intercept_per_group\": 14.594451904296875, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 705, \"mu_intercept_per_group\": 26.660480499267578, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 706, \"mu_intercept_per_group\": -1.8297244310379028, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 707, \"mu_intercept_per_group\": 18.88283920288086, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 708, \"mu_intercept_per_group\": 13.798812866210938, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 709, \"mu_intercept_per_group\": 6.7603912353515625, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 710, \"mu_intercept_per_group\": 26.519031524658203, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 711, \"mu_intercept_per_group\": 9.139301300048828, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 712, \"mu_intercept_per_group\": 23.089824676513672, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 713, \"mu_intercept_per_group\": 17.76047134399414, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 714, \"mu_intercept_per_group\": 6.20468807220459, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 715, \"mu_intercept_per_group\": 10.100860595703125, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 716, \"mu_intercept_per_group\": 7.2865166664123535, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 717, \"mu_intercept_per_group\": 20.1359806060791, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 718, \"mu_intercept_per_group\": 10.927922248840332, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 719, \"mu_intercept_per_group\": 9.282352447509766, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 720, \"mu_intercept_per_group\": 10.734169006347656, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 721, \"mu_intercept_per_group\": 8.391326904296875, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 722, \"mu_intercept_per_group\": 12.880885124206543, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 723, \"mu_intercept_per_group\": 12.003371238708496, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 724, \"mu_intercept_per_group\": 14.61378002166748, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 725, \"mu_intercept_per_group\": 12.166694641113281, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 726, \"mu_intercept_per_group\": 15.044477462768555, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 727, \"mu_intercept_per_group\": 10.959748268127441, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 728, \"mu_intercept_per_group\": 14.52094554901123, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 729, \"mu_intercept_per_group\": 8.486616134643555, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 730, \"mu_intercept_per_group\": 15.75002384185791, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 731, \"mu_intercept_per_group\": 14.097485542297363, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 732, \"mu_intercept_per_group\": 2.0235254764556885, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 733, \"mu_intercept_per_group\": 3.8014142513275146, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 734, \"mu_intercept_per_group\": -0.5554197430610657, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 735, \"mu_intercept_per_group\": 17.080961227416992, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 736, \"mu_intercept_per_group\": 5.849990367889404, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 737, \"mu_intercept_per_group\": 19.19090461730957, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 738, \"mu_intercept_per_group\": 10.918693542480469, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 739, \"mu_intercept_per_group\": 13.553671836853027, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 740, \"mu_intercept_per_group\": 4.7978081703186035, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 741, \"mu_intercept_per_group\": 9.526103019714355, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 742, \"mu_intercept_per_group\": 6.554520130157471, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 743, \"mu_intercept_per_group\": 12.684871673583984, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 744, \"mu_intercept_per_group\": 9.742919921875, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 745, \"mu_intercept_per_group\": 19.76345443725586, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 746, \"mu_intercept_per_group\": 10.143475532531738, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 747, \"mu_intercept_per_group\": 17.446884155273438, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 748, \"mu_intercept_per_group\": 18.710128784179688, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 749, \"mu_intercept_per_group\": 14.642775535583496, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 750, \"mu_intercept_per_group\": 19.100881576538086, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 751, \"mu_intercept_per_group\": 8.402298927307129, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 752, \"mu_intercept_per_group\": 10.15411376953125, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 753, \"mu_intercept_per_group\": 6.538330554962158, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 754, \"mu_intercept_per_group\": 12.712666511535645, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 755, \"mu_intercept_per_group\": 7.455203533172607, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 756, \"mu_intercept_per_group\": 3.2716078758239746, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 757, \"mu_intercept_per_group\": 4.844691276550293, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 758, \"mu_intercept_per_group\": 17.15043067932129, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 759, \"mu_intercept_per_group\": 9.833940505981445, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 760, \"mu_intercept_per_group\": 8.629639625549316, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 7, \"draws\": 761, \"mu_intercept_per_group\": 8.8025541305542, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 7, \"draws\": 762, \"mu_intercept_per_group\": 13.855545043945312, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 7, \"draws\": 763, \"mu_intercept_per_group\": 17.514272689819336, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 7, \"draws\": 764, \"mu_intercept_per_group\": 14.950531959533691, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 7, \"draws\": 765, \"mu_intercept_per_group\": 15.36071491241455, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 7, \"draws\": 766, \"mu_intercept_per_group\": 17.131275177001953, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 7, \"draws\": 767, \"mu_intercept_per_group\": 6.334132671356201, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 7, \"draws\": 768, \"mu_intercept_per_group\": 4.500664234161377, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 7, \"draws\": 769, \"mu_intercept_per_group\": 31.4747314453125, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 7, \"draws\": 770, \"mu_intercept_per_group\": 5.083420753479004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 7, \"draws\": 771, \"mu_intercept_per_group\": 6.722559928894043, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 7, \"draws\": 772, \"mu_intercept_per_group\": 9.143126487731934, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 7, \"draws\": 773, \"mu_intercept_per_group\": 18.33839988708496, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 7, \"draws\": 774, \"mu_intercept_per_group\": 1.0376254320144653, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 7, \"draws\": 775, \"mu_intercept_per_group\": 24.4460391998291, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 7, \"draws\": 776, \"mu_intercept_per_group\": 3.071709394454956, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 7, \"draws\": 777, \"mu_intercept_per_group\": 11.179348945617676, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 7, \"draws\": 778, \"mu_intercept_per_group\": 11.647317886352539, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 7, \"draws\": 779, \"mu_intercept_per_group\": 11.261837005615234, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 7, \"draws\": 780, \"mu_intercept_per_group\": 14.204532623291016, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 7, \"draws\": 781, \"mu_intercept_per_group\": 10.796290397644043, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 7, \"draws\": 782, \"mu_intercept_per_group\": 12.963516235351562, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 7, \"draws\": 783, \"mu_intercept_per_group\": 6.624403953552246, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 7, \"draws\": 784, \"mu_intercept_per_group\": 20.135610580444336, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 7, \"draws\": 785, \"mu_intercept_per_group\": 11.501521110534668, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 7, \"draws\": 786, \"mu_intercept_per_group\": 9.679304122924805, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 7, \"draws\": 787, \"mu_intercept_per_group\": 9.904572486877441, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 7, \"draws\": 788, \"mu_intercept_per_group\": 11.821760177612305, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 7, \"draws\": 789, \"mu_intercept_per_group\": 10.323616027832031, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 7, \"draws\": 790, \"mu_intercept_per_group\": 15.954474449157715, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 7, \"draws\": 791, \"mu_intercept_per_group\": 17.040075302124023, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 7, \"draws\": 792, \"mu_intercept_per_group\": 13.847721099853516, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 7, \"draws\": 793, \"mu_intercept_per_group\": 16.707489013671875, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 7, \"draws\": 794, \"mu_intercept_per_group\": 11.388129234313965, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 7, \"draws\": 795, \"mu_intercept_per_group\": 10.363701820373535, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 7, \"draws\": 796, \"mu_intercept_per_group\": 16.580825805664062, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 7, \"draws\": 797, \"mu_intercept_per_group\": 7.494189739227295, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 7, \"draws\": 798, \"mu_intercept_per_group\": 26.840944290161133, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 7, \"draws\": 799, \"mu_intercept_per_group\": 16.009048461914062, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "chart_power_difference\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "In this chart:\n",
    "\n",
    "- The black line is the 94% posterior highest density interval\n",
    "\n",
    "- Shading is posterior density\n",
    "\n",
    "- Barplot comes directly from the data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-43f50eea4ead4bd3a25d65048e0f5f80\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-43f50eea4ead4bd3a25d65048e0f5f80\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-43f50eea4ead4bd3a25d65048e0f5f80\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-7b75ead138b5701714ef21e640a42f5e\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 237.74384705687086, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 166.46023493627612, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": 102.02669332812849, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": 273.27981160465947, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 25.7188242111219, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -69.5886318431294, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -79.3676220517491, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": 644.1470615759551, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-335274e0c5848c5eb146b4572e80f925\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -5.040781497955322, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -3.2319483757019043, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -14.338045120239258, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -9.673306465148926, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -4.925235748291016, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -12.546177864074707, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -11.706274032592773, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -14.756869316101074, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -12.631892204284668, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -16.163843154907227, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -4.770541191101074, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -6.212677478790283, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -9.943546295166016, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -8.178187370300293, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -8.886363983154297, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.480189323425293, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -10.987234115600586, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -10.944351196289062, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -11.506084442138672, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -1.8251782655715942, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -12.498072624206543, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -12.514010429382324, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -17.6185245513916, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -5.716065406799316, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -12.775249481201172, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -3.373499870300293, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -10.66567611694336, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -3.174480676651001, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -6.656539440155029, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -5.057694435119629, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -6.132038593292236, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -6.260168075561523, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -6.267385959625244, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -18.276689529418945, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -14.591009140014648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -6.426440715789795, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -14.020872116088867, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -8.92737102508545, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -8.799839973449707, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -10.442145347595215, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -11.592804908752441, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -1.3473926782608032, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -4.051822662353516, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -5.211493015289307, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -4.1107282638549805, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -2.415545701980591, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -16.093782424926758, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -17.072484970092773, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -20.167388916015625, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -23.8348388671875, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": -7.981138229370117, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -0.04728800058364868, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -8.871659278869629, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -9.35479736328125, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -3.8808343410491943, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -6.361900329589844, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -7.999002456665039, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -5.894481658935547, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -13.972681045532227, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -13.822797775268555, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -3.046886682510376, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -16.953060150146484, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -3.695838451385498, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -14.566791534423828, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -13.50625991821289, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -18.355134963989258, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -2.4528801441192627, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -7.53265905380249, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -6.505617618560791, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -12.704715728759766, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -1.9597692489624023, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -12.978065490722656, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -8.506797790527344, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -5.759369850158691, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": -25.789400100708008, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -22.311338424682617, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -8.781279563903809, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -13.314993858337402, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -1.3805243968963623, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -1.0229171514511108, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -7.584434986114502, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -7.566932678222656, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -7.094293117523193, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -11.389894485473633, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -8.709399223327637, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -10.357560157775879, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -16.34046173095703, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": 0.6019138693809509, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -1.9741706848144531, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -7.676919937133789, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -11.231236457824707, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -1.5288472175598145, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -16.779338836669922, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -4.3895158767700195, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -18.84963035583496, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -17.951358795166016, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -5.909987926483154, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -12.995099067687988, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -14.546140670776367, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -12.310595512390137, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -12.568388938903809, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -11.030439376831055, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -11.577783584594727, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -19.112316131591797, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -12.155937194824219, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -13.99992561340332, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -7.133065223693848, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -11.40817642211914, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -7.663388252258301, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -7.15134859085083, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -11.182429313659668, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -6.685650825500488, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -13.261324882507324, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -8.376654624938965, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -8.474446296691895, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -11.404654502868652, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -15.137195587158203, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -2.7283873558044434, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -5.247433662414551, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -9.17174243927002, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -3.0005855560302734, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -4.599752902984619, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -9.993454933166504, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -8.326324462890625, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -6.7738237380981445, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -18.34370994567871, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -16.528854370117188, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -6.6535491943359375, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -11.81106185913086, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -16.69459342956543, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -14.064314842224121, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -9.772653579711914, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -11.23830509185791, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -4.780694961547852, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -14.838922500610352, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -5.256370544433594, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -9.29879093170166, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -13.37845230102539, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -10.741788864135742, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -7.814037799835205, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -8.544958114624023, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -5.639056205749512, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -2.9378082752227783, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -8.153556823730469, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -14.391047477722168, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -4.369668960571289, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -2.46347713470459, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -3.629565954208374, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -10.348349571228027, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -4.948489665985107, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -12.884615898132324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -5.245946407318115, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -6.670903205871582, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -8.891148567199707, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -9.279622077941895, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -8.383540153503418, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -4.247647762298584, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -12.485112190246582, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -5.546526908874512, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -10.073062896728516, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -10.178902626037598, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -13.806653022766113, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -13.627968788146973, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -15.624517440795898, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -17.04638671875, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -8.39765453338623, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -9.610179901123047, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -12.103351593017578, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -19.356971740722656, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -2.4488518238067627, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -17.13677215576172, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -5.408355236053467, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -7.60662317276001, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": 0.21036642789840698, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -4.18886661529541, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -1.2615326642990112, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -6.848775863647461, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -9.153616905212402, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -2.357057571411133, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -7.682571887969971, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -3.3885879516601562, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -11.814712524414062, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -6.619076251983643, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -12.91315746307373, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -8.867708206176758, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -14.581746101379395, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -19.71653175354004, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -19.991769790649414, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -21.214252471923828, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -6.644197940826416, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -10.407630920410156, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -11.46703052520752, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -8.729238510131836, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -7.291738510131836, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -8.144486427307129, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.621789932250977, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -9.452020645141602, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -2.7215309143066406, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -3.036237955093384, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -19.85153579711914, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -12.849891662597656, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -6.997928142547607, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -10.627803802490234, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -5.472050189971924, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -16.494998931884766, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -16.4442138671875, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -5.7470502853393555, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -8.932648658752441, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -8.577373504638672, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -8.965713500976562, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -11.161826133728027, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -7.89268684387207, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -7.564478397369385, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -13.452535629272461, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -14.08469295501709, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -2.954566717147827, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -11.441118240356445, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -6.81473970413208, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -2.3359830379486084, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -3.075653553009033, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -11.325859069824219, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -4.258692264556885, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -4.423980712890625, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -13.428261756896973, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -11.3971586227417, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -13.256096839904785, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.62111234664917, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -4.03687047958374, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -11.875662803649902, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -7.4272379875183105, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -7.029792308807373, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -9.917837142944336, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -6.4340691566467285, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -8.416629791259766, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -9.764811515808105, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -13.684724807739258, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -9.332736015319824, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -5.513200759887695, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -5.412356853485107, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -10.102581977844238, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -9.726181030273438, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -8.257014274597168, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -3.624953508377075, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -2.589315891265869, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -8.779748916625977, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -6.400252342224121, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -8.629778861999512, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -16.5101318359375, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -17.6689453125, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": -4.915207386016846, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -6.15136194229126, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -6.802655220031738, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -7.658843517303467, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -9.336639404296875, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -6.3743815422058105, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -3.255826711654663, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -12.883275985717773, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -16.258590698242188, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -16.643815994262695, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -5.674232482910156, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -10.518762588500977, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -11.083512306213379, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -5.980678081512451, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -2.541947364807129, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -20.78319549560547, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -3.921635150909424, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": 0.5861846804618835, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -11.339868545532227, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -0.389615923166275, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -12.612652778625488, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -10.362377166748047, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -1.3020634651184082, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -14.657515525817871, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.195693016052246, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -13.869643211364746, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -14.57094669342041, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -13.50912857055664, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -8.952861785888672, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -8.80617904663086, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -3.6185855865478516, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -10.87226390838623, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -12.242692947387695, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -15.20461368560791, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -9.234443664550781, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -7.426700592041016, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -13.220755577087402, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -5.277491569519043, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -8.162809371948242, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -7.106990337371826, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -8.721697807312012, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -10.575236320495605, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -9.488320350646973, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -6.3274407386779785, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -8.079594612121582, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -8.850040435791016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -4.494203090667725, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -8.342353820800781, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -7.779570579528809, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -5.749445915222168, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -3.8445205688476562, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -9.672994613647461, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -2.8184850215911865, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -5.3096466064453125, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -9.379035949707031, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -8.699469566345215, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -6.1675639152526855, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.189728736877441, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -5.6182026863098145, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -2.484952211380005, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -4.12829065322876, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -11.519996643066406, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -7.22760009765625, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -4.460574626922607, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -14.75634479522705, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -1.8370130062103271, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -4.823190212249756, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -17.70157814025879, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -17.373361587524414, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -18.10245132446289, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -3.457681655883789, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -8.75065803527832, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -16.165645599365234, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -22.6804141998291, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -19.911861419677734, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -22.61591148376465, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -11.622304916381836, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": 0.998124361038208, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -6.8948655128479, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -4.078651428222656, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -7.3026604652404785, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -11.44503116607666, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -17.5340576171875, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -16.409536361694336, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -5.208342552185059, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -10.778684616088867, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -17.12391471862793, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -15.53206729888916, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -24.478370666503906, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -3.444739818572998, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -8.01969051361084, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -6.329585552215576, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -4.347865581512451, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -12.938542366027832, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -9.006197929382324, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -5.012093544006348, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -4.965196132659912, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -15.606342315673828, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -5.539521217346191, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -5.314929962158203, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -1.2871633768081665, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -14.534015655517578, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -4.73247766494751, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -11.297335624694824, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": 0.9405475854873657, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.757895469665527, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -10.374063491821289, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -16.98774528503418, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -8.18375015258789, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -4.701827526092529, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -11.026098251342773, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -10.939376831054688, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -2.6122803688049316, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -12.174870491027832, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -6.430441856384277, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -10.59070873260498, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -3.260490655899048, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -3.310577154159546, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -11.701184272766113, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -16.167146682739258, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -6.8973283767700195, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -19.691875457763672, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -11.031414985656738, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -5.411973476409912, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -3.844919443130493, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -5.477871417999268, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -9.450149536132812, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -7.657480239868164, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -13.941293716430664, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -9.572578430175781, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -8.065054893493652, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -4.444667339324951, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -6.401512145996094, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -7.924699306488037, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": 0.7744003534317017, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -24.4804630279541, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -39.773441314697266, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -31.81466293334961, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -20.902446746826172, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -17.315820693969727, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": 5.48476505279541, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -1.5803248882293701, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -18.618637084960938, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -8.642467498779297, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -11.297926902770996, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -15.921405792236328, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -6.936874866485596, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -0.2094547003507614, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -18.638042449951172, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -14.544658660888672, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -12.04907512664795, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -5.024633407592773, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -3.489513635635376, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -9.497099876403809, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -8.240531921386719, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -6.346133232116699, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -14.385534286499023, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -12.13107681274414, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -10.018568992614746, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -5.1738667488098145, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -10.29282283782959, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -9.026412963867188, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -4.315159320831299, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -6.5509257316589355, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -19.04126739501953, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -16.34767723083496, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -2.5898938179016113, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -3.3687591552734375, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -7.322995662689209, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -2.7231345176696777, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -10.025606155395508, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -3.8277714252471924, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -14.222061157226562, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -7.5450663566589355, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -9.19723892211914, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -9.410855293273926, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -1.858840823173523, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -9.601522445678711, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -23.54803466796875, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -23.492151260375977, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -2.0137908458709717, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -7.213013648986816, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -5.775428295135498, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -5.777145862579346, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -17.992870330810547, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -19.222583770751953, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -3.606680393218994, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -7.077849388122559, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -7.946872234344482, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -7.342119216918945, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -7.215571880340576, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -9.698287010192871, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -11.335079193115234, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -5.650229454040527, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -6.336968898773193, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -3.8731679916381836, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -11.074392318725586, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -3.630917549133301, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -6.614351749420166, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -8.51510238647461, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -2.4186511039733887, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -1.1323734521865845, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -18.85658073425293, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -3.8716964721679688, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -9.455548286437988, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -13.154111862182617, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -2.69400691986084, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -16.04335594177246, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -15.140952110290527, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -16.074392318725586, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -10.598502159118652, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -4.471084117889404, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -9.135819435119629, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -6.191133499145508, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -0.926066517829895, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -12.166131973266602, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -12.361000061035156, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -16.498821258544922, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -17.714357376098633, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -15.189769744873047, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -18.966697692871094, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -10.010828018188477, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -9.98740291595459, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -5.75197172164917, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -15.284516334533691, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -5.489589214324951, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -12.943856239318848, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -0.22668716311454773, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -15.675498008728027, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -6.588681221008301, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -7.812132835388184, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -6.533406734466553, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -8.366008758544922, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -6.541745662689209, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -7.343019485473633, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -2.4424896240234375, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -23.04140281677246, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -0.7497562766075134, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -4.742270469665527, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": 1.0736088752746582, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": 0.024408448487520218, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -2.8643569946289062, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -8.307125091552734, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -8.772392272949219, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -0.5112401843070984, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -6.886197090148926, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -6.327877998352051, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -12.50365924835205, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -11.757549285888672, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -1.3050986528396606, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -13.721922874450684, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -12.205488204956055, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -15.0798978805542, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -3.8415820598602295, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -9.192111015319824, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -7.257448673248291, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -6.073168754577637, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -6.093765735626221, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -9.180815696716309, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -14.790719032287598, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -8.083637237548828, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -16.844039916992188, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -15.44870376586914, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -7.9280314445495605, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -15.37336254119873, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": 0.20836150646209717, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -9.434063911437988, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -10.677699089050293, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -13.1483154296875, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -8.331754684448242, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -11.413102149963379, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -10.736640930175781, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -20.958683013916016, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -3.8055968284606934, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -5.030653953552246, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -13.732660293579102, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -12.01431655883789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -14.626978874206543, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -14.44836711883545, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -11.47911548614502, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -15.735791206359863, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -13.227349281311035, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -3.8430216312408447, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -10.357236862182617, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -8.008966445922852, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -6.926792144775391, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -7.791112899780273, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -6.468642711639404, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -9.571223258972168, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -3.7362332344055176, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -10.967222213745117, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -18.106294631958008, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -16.127092361450195, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -10.687830924987793, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -8.566162109375, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -4.050730228424072, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": 1.3152552843093872, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -2.0139448642730713, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -4.341344833374023, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -8.37908935546875, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -22.976163864135742, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -10.430059432983398, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -14.850079536437988, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -20.197887420654297, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -6.68999719619751, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -2.815863847732544, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -17.887845993041992, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -3.541370153427124, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -3.542423963546753, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -6.5178399085998535, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -6.637992858886719, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": -1.2293953895568848, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -17.230424880981445, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -11.51131534576416, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -8.765068054199219, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -6.458959102630615, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -5.430912017822266, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -3.6724812984466553, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -3.493516206741333, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -11.444568634033203, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -9.342259407043457, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -9.024116516113281, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -7.584840297698975, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -19.061552047729492, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -10.222793579101562, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -14.651355743408203, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -14.484232902526855, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -0.38055333495140076, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": 2.191359043121338, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -16.867826461791992, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -5.231989860534668, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -4.299243927001953, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -1.6465952396392822, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -18.220346450805664, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -6.526581287384033, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -9.6726713180542, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -9.635215759277344, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -13.181056022644043, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -5.687668323516846, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -16.44668197631836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -3.8459317684173584, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -10.190849304199219, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -11.476523399353027, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -5.591184616088867, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -5.949356555938721, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -5.420851230621338, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -14.403029441833496, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -10.093840599060059, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -18.961095809936523, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -11.777244567871094, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -13.17252254486084, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -12.879655838012695, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": 0.7822245359420776, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -10.36086654663086, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -28.181034088134766, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": 0.6640376448631287, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -17.449878692626953, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -13.05380916595459, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": 0.5147354602813721, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -0.6536664962768555, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": 2.406078338623047, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": 6.2492570877075195, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -16.29853057861328, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -14.67895221710205, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -14.72924518585205, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -7.888645172119141, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -13.071282386779785, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -5.036900043487549, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -16.05565071105957, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -7.945497035980225, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -12.781723022460938, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -11.250772476196289, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -5.3124680519104, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -11.05871868133545, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -13.738811492919922, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -5.289099216461182, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -2.5719308853149414, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": 4.691713809967041, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": 1.5101555585861206, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -16.513256072998047, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": 4.7369537353515625, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -16.79252052307129, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -17.795873641967773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -17.840864181518555, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -11.204030990600586, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -11.924735069274902, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -19.330913543701172, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -21.98118782043457, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -3.0958797931671143, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -2.735022783279419, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -10.548039436340332, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 640, \"mu_intercept_per_group\": -1.3955962657928467, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 641, \"mu_intercept_per_group\": -17.113033294677734, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 642, \"mu_intercept_per_group\": -11.39327621459961, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 643, \"mu_intercept_per_group\": -12.532562255859375, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 644, \"mu_intercept_per_group\": -8.902205467224121, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 645, \"mu_intercept_per_group\": -16.35418128967285, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 646, \"mu_intercept_per_group\": -18.42349624633789, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 647, \"mu_intercept_per_group\": -20.9619083404541, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 648, \"mu_intercept_per_group\": -18.798307418823242, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 649, \"mu_intercept_per_group\": 4.921034812927246, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 650, \"mu_intercept_per_group\": 2.829319953918457, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 651, \"mu_intercept_per_group\": -19.05095672607422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 652, \"mu_intercept_per_group\": -5.474806785583496, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 653, \"mu_intercept_per_group\": -4.922374725341797, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 654, \"mu_intercept_per_group\": -10.816702842712402, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 655, \"mu_intercept_per_group\": 0.6563606858253479, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 656, \"mu_intercept_per_group\": -11.115660667419434, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 657, \"mu_intercept_per_group\": -9.447301864624023, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 658, \"mu_intercept_per_group\": -13.556966781616211, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 659, \"mu_intercept_per_group\": -11.097416877746582, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 660, \"mu_intercept_per_group\": -5.995758533477783, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 661, \"mu_intercept_per_group\": -2.3554229736328125, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 662, \"mu_intercept_per_group\": -3.1295342445373535, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 663, \"mu_intercept_per_group\": -4.682866096496582, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 664, \"mu_intercept_per_group\": -3.5213005542755127, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 665, \"mu_intercept_per_group\": -4.978518486022949, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 666, \"mu_intercept_per_group\": -3.724959135055542, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 667, \"mu_intercept_per_group\": -6.1379313468933105, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 668, \"mu_intercept_per_group\": -4.124699115753174, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 669, \"mu_intercept_per_group\": -8.214367866516113, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 670, \"mu_intercept_per_group\": 1.0553821325302124, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 671, \"mu_intercept_per_group\": -11.239164352416992, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 672, \"mu_intercept_per_group\": -6.925349235534668, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 673, \"mu_intercept_per_group\": -6.511587619781494, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 674, \"mu_intercept_per_group\": -11.621158599853516, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 675, \"mu_intercept_per_group\": -10.887262344360352, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 676, \"mu_intercept_per_group\": -7.85366678237915, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 677, \"mu_intercept_per_group\": -9.883703231811523, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 678, \"mu_intercept_per_group\": -5.222884654998779, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 679, \"mu_intercept_per_group\": -7.691766262054443, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 680, \"mu_intercept_per_group\": -3.4161531925201416, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 681, \"mu_intercept_per_group\": -23.19988250732422, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 682, \"mu_intercept_per_group\": 0.4955381453037262, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 683, \"mu_intercept_per_group\": -19.23976707458496, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 684, \"mu_intercept_per_group\": -15.268034934997559, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 685, \"mu_intercept_per_group\": -15.744549751281738, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 686, \"mu_intercept_per_group\": -13.575891494750977, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 687, \"mu_intercept_per_group\": -12.361751556396484, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 688, \"mu_intercept_per_group\": -15.737735748291016, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 689, \"mu_intercept_per_group\": -3.832686424255371, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 690, \"mu_intercept_per_group\": -6.5279645919799805, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 691, \"mu_intercept_per_group\": -4.437520980834961, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 692, \"mu_intercept_per_group\": -3.609692096710205, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 693, \"mu_intercept_per_group\": 5.752180576324463, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 694, \"mu_intercept_per_group\": -6.594266414642334, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 695, \"mu_intercept_per_group\": -8.382157325744629, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 696, \"mu_intercept_per_group\": -5.280394077301025, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 697, \"mu_intercept_per_group\": -3.3657338619232178, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 698, \"mu_intercept_per_group\": -13.693631172180176, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 699, \"mu_intercept_per_group\": -15.320185661315918, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 700, \"mu_intercept_per_group\": -16.62302589416504, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 701, \"mu_intercept_per_group\": -14.20588207244873, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 702, \"mu_intercept_per_group\": -14.253565788269043, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 703, \"mu_intercept_per_group\": -1.8492915630340576, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 704, \"mu_intercept_per_group\": -9.212831497192383, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 705, \"mu_intercept_per_group\": -7.338194847106934, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 706, \"mu_intercept_per_group\": -14.641120910644531, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 707, \"mu_intercept_per_group\": -16.60073471069336, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 708, \"mu_intercept_per_group\": -1.3629611730575562, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 709, \"mu_intercept_per_group\": -7.777461051940918, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 710, \"mu_intercept_per_group\": -1.8500031232833862, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 711, \"mu_intercept_per_group\": -22.09663200378418, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 712, \"mu_intercept_per_group\": 0.018531644716858864, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 713, \"mu_intercept_per_group\": 3.0248255729675293, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 714, \"mu_intercept_per_group\": -7.417457580566406, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 715, \"mu_intercept_per_group\": -6.956211090087891, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 716, \"mu_intercept_per_group\": -8.928647994995117, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 717, \"mu_intercept_per_group\": -0.22857104241847992, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 718, \"mu_intercept_per_group\": -6.185298442840576, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 719, \"mu_intercept_per_group\": -16.681169509887695, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 720, \"mu_intercept_per_group\": -5.962151050567627, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 721, \"mu_intercept_per_group\": -6.805093288421631, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 722, \"mu_intercept_per_group\": -11.011396408081055, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 723, \"mu_intercept_per_group\": -9.850343704223633, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 724, \"mu_intercept_per_group\": -10.407118797302246, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 725, \"mu_intercept_per_group\": -10.117226600646973, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 726, \"mu_intercept_per_group\": -5.316917419433594, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 727, \"mu_intercept_per_group\": -6.945923328399658, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 728, \"mu_intercept_per_group\": -9.492375373840332, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 729, \"mu_intercept_per_group\": -8.86750602722168, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 730, \"mu_intercept_per_group\": -7.798107624053955, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 731, \"mu_intercept_per_group\": -12.682540893554688, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 732, \"mu_intercept_per_group\": -12.547581672668457, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 733, \"mu_intercept_per_group\": -18.491785049438477, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 734, \"mu_intercept_per_group\": -8.545707702636719, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 735, \"mu_intercept_per_group\": -17.687284469604492, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 736, \"mu_intercept_per_group\": -5.70229434967041, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 737, \"mu_intercept_per_group\": -13.548932075500488, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 738, \"mu_intercept_per_group\": -9.389627456665039, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 739, \"mu_intercept_per_group\": -15.26278305053711, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 740, \"mu_intercept_per_group\": -1.2251851558685303, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 741, \"mu_intercept_per_group\": -11.610944747924805, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 742, \"mu_intercept_per_group\": -1.3939104080200195, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 743, \"mu_intercept_per_group\": -1.9360616207122803, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 744, \"mu_intercept_per_group\": -10.431615829467773, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 745, \"mu_intercept_per_group\": -8.211955070495605, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 746, \"mu_intercept_per_group\": -13.654766082763672, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 747, \"mu_intercept_per_group\": -2.444514513015747, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 748, \"mu_intercept_per_group\": -9.148351669311523, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 749, \"mu_intercept_per_group\": -1.5807955265045166, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 750, \"mu_intercept_per_group\": -15.372639656066895, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 751, \"mu_intercept_per_group\": -5.23089075088501, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 752, \"mu_intercept_per_group\": -14.592620849609375, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 753, \"mu_intercept_per_group\": -9.639511108398438, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 754, \"mu_intercept_per_group\": -9.418307304382324, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 755, \"mu_intercept_per_group\": -3.8247220516204834, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 756, \"mu_intercept_per_group\": -5.8500590324401855, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 757, \"mu_intercept_per_group\": -5.908278465270996, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 758, \"mu_intercept_per_group\": -14.808974266052246, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 759, \"mu_intercept_per_group\": -9.69106388092041, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 0, \"draws\": 760, \"mu_intercept_per_group\": -8.039718627929688, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 0, \"draws\": 761, \"mu_intercept_per_group\": -6.686943531036377, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 0, \"draws\": 762, \"mu_intercept_per_group\": -6.237182140350342, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 0, \"draws\": 763, \"mu_intercept_per_group\": -15.060968399047852, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 0, \"draws\": 764, \"mu_intercept_per_group\": -0.531229555606842, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 0, \"draws\": 765, \"mu_intercept_per_group\": -4.671209812164307, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 0, \"draws\": 766, \"mu_intercept_per_group\": -15.774847030639648, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 0, \"draws\": 767, \"mu_intercept_per_group\": -16.489418029785156, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 0, \"draws\": 768, \"mu_intercept_per_group\": -13.781782150268555, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 0, \"draws\": 769, \"mu_intercept_per_group\": -13.473760604858398, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 0, \"draws\": 770, \"mu_intercept_per_group\": -0.21044935286045074, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 0, \"draws\": 771, \"mu_intercept_per_group\": -15.083337783813477, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 0, \"draws\": 772, \"mu_intercept_per_group\": -4.676630973815918, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 0, \"draws\": 773, \"mu_intercept_per_group\": -12.31003189086914, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 0, \"draws\": 774, \"mu_intercept_per_group\": -6.071263790130615, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 0, \"draws\": 775, \"mu_intercept_per_group\": -12.3790864944458, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 0, \"draws\": 776, \"mu_intercept_per_group\": -10.242154121398926, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 0, \"draws\": 777, \"mu_intercept_per_group\": -14.512199401855469, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 0, \"draws\": 778, \"mu_intercept_per_group\": -6.676771640777588, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 0, \"draws\": 779, \"mu_intercept_per_group\": -9.669127464294434, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 0, \"draws\": 780, \"mu_intercept_per_group\": -11.874094009399414, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 0, \"draws\": 781, \"mu_intercept_per_group\": 0.7495285272598267, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 0, \"draws\": 782, \"mu_intercept_per_group\": -11.307819366455078, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 0, \"draws\": 783, \"mu_intercept_per_group\": -11.859552383422852, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 0, \"draws\": 784, \"mu_intercept_per_group\": -6.786609649658203, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 0, \"draws\": 785, \"mu_intercept_per_group\": -4.8037872314453125, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 0, \"draws\": 786, \"mu_intercept_per_group\": -1.0827637910842896, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 0, \"draws\": 787, \"mu_intercept_per_group\": -9.0177583694458, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 0, \"draws\": 788, \"mu_intercept_per_group\": -2.8852615356445312, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 0, \"draws\": 789, \"mu_intercept_per_group\": -2.3375611305236816, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 0, \"draws\": 790, \"mu_intercept_per_group\": -5.916977882385254, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 0, \"draws\": 791, \"mu_intercept_per_group\": -5.5406341552734375, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 0, \"draws\": 792, \"mu_intercept_per_group\": -5.125442028045654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 0, \"draws\": 793, \"mu_intercept_per_group\": -9.392108917236328, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 0, \"draws\": 794, \"mu_intercept_per_group\": 5.721161365509033, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 0, \"draws\": 795, \"mu_intercept_per_group\": -3.4059906005859375, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 0, \"draws\": 796, \"mu_intercept_per_group\": -5.1101531982421875, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 0, \"draws\": 797, \"mu_intercept_per_group\": -15.806418418884277, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 0, \"draws\": 798, \"mu_intercept_per_group\": 4.5742669105529785, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 0, \"draws\": 799, \"mu_intercept_per_group\": -16.5518798828125, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -8.463964462280273, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -5.522490978240967, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -8.630327224731445, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -7.021143913269043, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -2.774968385696411, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -10.757180213928223, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -8.160569190979004, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -10.12001895904541, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -4.824865341186523, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -8.315885543823242, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -5.182793140411377, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -10.113337516784668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -7.616043567657471, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -7.081296443939209, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -8.140750885009766, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -11.904815673828125, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -11.351101875305176, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -4.601489067077637, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -5.248831748962402, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -6.81367301940918, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -2.246152639389038, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -5.514193058013916, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -11.95570182800293, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -3.89855694770813, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": 4.90255069732666, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": 13.422053337097168, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": 6.911807537078857, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -5.5922770500183105, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -6.857975482940674, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -2.1050865650177, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -6.132362365722656, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -2.787949323654175, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -7.256302833557129, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -15.257880210876465, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -5.019294738769531, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -16.966064453125, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -8.912954330444336, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -14.777284622192383, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -5.526966571807861, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -4.6448774337768555, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": 2.525085687637329, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -15.121261596679688, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -3.2543210983276367, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -4.027781963348389, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -3.056781053543091, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -4.625176906585693, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": 2.2165396213531494, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": 1.1302454471588135, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -8.88571548461914, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -12.499415397644043, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -5.258360385894775, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -1.1019741296768188, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -2.7254743576049805, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -4.00599479675293, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -7.0142059326171875, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -4.741383075714111, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -2.4022116661071777, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -7.611382961273193, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -7.375605583190918, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -13.864294052124023, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": 1.5573049783706665, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -18.688922882080078, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -3.8896350860595703, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -2.6664626598358154, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -5.915189266204834, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -11.641724586486816, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -24.968902587890625, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": 3.673384428024292, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": 3.2681491374969482, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -5.521426200866699, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -9.135942459106445, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -9.367850303649902, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -8.582090377807617, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -12.789557456970215, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -7.178985595703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -3.3624579906463623, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -3.7026774883270264, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -20.197704315185547, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -2.000335216522217, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": 0.3444068729877472, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -6.717190742492676, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -5.477149486541748, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -11.214262008666992, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -16.399005889892578, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -1.7473465204238892, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -1.0917484760284424, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -3.080193519592285, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": 0.8146815299987793, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": 4.521572113037109, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.99426555633545, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -9.336772918701172, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -5.096127033233643, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -18.555667877197266, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": 8.260923385620117, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -19.096702575683594, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -19.96316146850586, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -1.9338761568069458, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -7.733426570892334, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -11.19599723815918, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -3.0945422649383545, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -4.423023700714111, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -14.207892417907715, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -10.578598976135254, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -6.583150863647461, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -18.78107452392578, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -5.156072616577148, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -13.016656875610352, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -3.282268524169922, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -1.4693411588668823, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -1.5940797328948975, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -8.228626251220703, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -7.249871253967285, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -5.003849029541016, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -6.709216117858887, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -5.370258808135986, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -6.2389020919799805, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -4.802653789520264, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -3.672044515609741, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -2.5114827156066895, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -6.614682197570801, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -1.314194679260254, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -7.518023490905762, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -5.575322151184082, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -4.340911865234375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -6.025227069854736, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -11.910261154174805, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -13.2202730178833, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -10.20504379272461, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -10.171121597290039, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -7.420294761657715, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -8.76205062866211, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -8.214826583862305, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -1.5067857503890991, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -2.995762348175049, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -10.4031982421875, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -5.307545185089111, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -6.915334701538086, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -6.712177276611328, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -11.415205001831055, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -15.197175979614258, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -5.711830139160156, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -1.4785627126693726, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -3.285017490386963, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -5.481128215789795, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -11.936737060546875, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": 0.36717545986175537, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -4.167700290679932, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": 0.07449424266815186, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -7.763571262359619, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -5.035675048828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -9.300844192504883, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": 3.1366419792175293, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -12.75354290008545, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -12.582444190979004, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -2.3910295963287354, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -12.289669036865234, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -2.905604362487793, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -7.637528896331787, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -5.888548851013184, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -9.943721771240234, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -7.501426696777344, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -5.770092487335205, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -1.948828935623169, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -15.492814064025879, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": 4.272012233734131, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -7.3533501625061035, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -7.2175164222717285, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -14.558330535888672, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -16.98981285095215, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": 4.297924995422363, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -19.546592712402344, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -8.8070650100708, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -4.942563056945801, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": 0.48789316415786743, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -2.812572479248047, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -1.250403881072998, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": 0.201321542263031, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -5.401147842407227, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -8.158730506896973, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -4.766443729400635, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -10.177217483520508, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -1.0570824146270752, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -17.689987182617188, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -9.77273941040039, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -7.371433734893799, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": 2.80295991897583, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": 3.2416961193084717, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": 0.44132789969444275, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -2.6126503944396973, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -9.670760154724121, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -8.313094139099121, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -10.328643798828125, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -9.322820663452148, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -12.268668174743652, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -10.417738914489746, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -11.325778007507324, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -11.268610000610352, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -2.5182535648345947, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -2.6109728813171387, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -11.761697769165039, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -1.9480599164962769, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -15.995800971984863, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -7.968087196350098, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -12.817194938659668, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -7.802563190460205, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -2.0851564407348633, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -9.967320442199707, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -2.524480104446411, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -1.9567384719848633, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -6.825958728790283, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -3.56683611869812, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -10.835593223571777, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -8.808893203735352, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -6.46396017074585, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -10.878059387207031, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -2.6873679161071777, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -6.742923259735107, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -9.391840934753418, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": 1.4834914207458496, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -0.8790526390075684, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -16.255952835083008, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -14.247909545898438, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -5.371616363525391, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -5.0700883865356445, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -7.676242828369141, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -9.607836723327637, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -22.520721435546875, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -9.707636833190918, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -18.860963821411133, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": 2.2030763626098633, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": 2.202141523361206, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -0.7342286109924316, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -7.996046543121338, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -8.649276733398438, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -6.344440460205078, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -4.691237926483154, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -7.299112796783447, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -5.575038433074951, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -3.972187042236328, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -9.599820137023926, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -8.358413696289062, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -5.024391174316406, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -5.716562747955322, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -3.77807879447937, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -5.500432014465332, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -7.615743160247803, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -4.611034393310547, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -10.824134826660156, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -9.529510498046875, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -6.8019843101501465, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -7.914368152618408, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -6.4699482917785645, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -5.027370929718018, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -3.10154128074646, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": 0.27238428592681885, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -11.068960189819336, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -1.8688381910324097, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -1.5642330646514893, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": 2.16567063331604, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -4.079339027404785, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -0.5596898794174194, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -13.810405731201172, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -2.4614691734313965, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -4.566840171813965, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -9.446951866149902, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -6.827064037322998, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": 2.2277393341064453, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -5.073843479156494, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -0.4736955165863037, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -9.838051795959473, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -5.923642158508301, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -7.2732462882995605, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -2.9811365604400635, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -5.687343597412109, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -7.497012138366699, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -6.166018962860107, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": 1.1129947900772095, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -2.388124942779541, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -4.539252758026123, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -17.606914520263672, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -6.165983200073242, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -3.742136001586914, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -3.639493703842163, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -5.823246955871582, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -12.123866081237793, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -7.763772010803223, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -6.970352649688721, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -0.6010066866874695, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -2.378098249435425, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -5.7572832107543945, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -11.822481155395508, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -4.5131025314331055, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -7.647518634796143, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -5.036931037902832, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -8.063419342041016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -8.231720924377441, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -10.115706443786621, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": 11.774689674377441, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": 1.6975617408752441, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -0.44665879011154175, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -5.412267208099365, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -4.182696342468262, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -1.9100764989852905, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -8.234150886535645, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -8.763331413269043, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -5.511397361755371, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -9.85831356048584, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -12.8724946975708, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": 7.688490867614746, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -12.401480674743652, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": 4.287363529205322, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -11.154162406921387, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -9.18152141571045, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -5.775693416595459, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -6.747610569000244, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -7.762335300445557, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -8.072798728942871, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -7.486238479614258, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -12.458937644958496, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -3.4186317920684814, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -5.2962493896484375, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -4.723546981811523, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -2.6898562908172607, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -3.6324923038482666, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -13.080504417419434, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -6.417844772338867, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -1.665814995765686, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -4.46502161026001, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -14.899575233459473, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -10.645574569702148, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -3.14841628074646, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -13.237945556640625, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -12.312538146972656, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -7.097439765930176, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -14.861870765686035, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -11.7489652633667, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -11.972259521484375, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -10.411721229553223, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -11.556038856506348, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -1.303446888923645, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -8.312260627746582, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -11.57768726348877, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -13.761001586914062, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -6.086140155792236, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -5.489706039428711, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -2.0879509449005127, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -13.66417407989502, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -10.065771102905273, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -5.447312355041504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -9.46387004852295, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -5.7930755615234375, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.894649505615234, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -4.028882026672363, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -1.6248077154159546, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -13.211878776550293, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -12.292472839355469, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -6.505354404449463, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -9.881367683410645, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -0.13978375494480133, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -10.650283813476562, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -9.862833023071289, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -5.99295711517334, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -3.788276433944702, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -4.967767715454102, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -10.58394718170166, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": 1.6004167795181274, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -0.0031337225809693336, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -12.571540832519531, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -11.773927688598633, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -6.5745062828063965, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -6.903250694274902, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -4.94040060043335, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -11.601109504699707, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -12.11928653717041, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -3.1288840770721436, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -9.122939109802246, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -11.455864906311035, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -7.932468891143799, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -5.82853889465332, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -5.114236831665039, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -2.7878990173339844, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -4.554833889007568, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -13.072132110595703, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": 5.590129375457764, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -20.363454818725586, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -34.7641716003418, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -15.950664520263672, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -10.630252838134766, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -13.557367324829102, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": 2.0046355724334717, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -12.566685676574707, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -7.294683933258057, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -12.405985832214355, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -8.00912094116211, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -8.846941947937012, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.363330841064453, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -3.7095868587493896, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -4.117101669311523, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -6.945756435394287, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -8.627290725708008, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -1.4066123962402344, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -14.80611801147461, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -5.313531875610352, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -7.835374355316162, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -4.99541711807251, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -4.97422981262207, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -5.330106735229492, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -8.303894996643066, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": 2.135199546813965, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -16.06319808959961, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": 0.7605302333831787, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -13.170872688293457, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -15.687202453613281, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -1.7165426015853882, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -5.136164665222168, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -4.370528697967529, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -4.880247592926025, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -1.911839246749878, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -9.556730270385742, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -0.8126273155212402, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -6.101413726806641, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.357921600341797, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -13.671849250793457, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -3.5299882888793945, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -4.885555267333984, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -8.022061347961426, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -2.0411484241485596, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -9.610355377197266, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -1.847278118133545, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -11.80907154083252, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -8.462021827697754, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -4.326870441436768, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -5.468924522399902, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -6.299935817718506, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -13.798683166503906, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -3.594536304473877, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -8.656484603881836, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -6.9296417236328125, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -7.686049938201904, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -12.964165687561035, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -7.580221176147461, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -7.629336833953857, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -7.874495029449463, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -3.870492458343506, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -15.039116859436035, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -3.3166422843933105, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -10.479406356811523, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -10.407120704650879, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -3.1247706413269043, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -9.59276294708252, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -8.741473197937012, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -2.6316232681274414, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -10.259936332702637, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -16.08149528503418, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -22.595226287841797, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -13.521262168884277, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -15.243318557739258, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -8.26047420501709, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -5.657673358917236, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -3.0963892936706543, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -10.927461624145508, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -1.3937886953353882, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -12.800820350646973, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -2.9563820362091064, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": 3.0324513912200928, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -1.3185973167419434, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -10.170413970947266, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -8.437788009643555, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -29.883220672607422, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -2.5528335571289062, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -5.943991184234619, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.220870971679688, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -10.247591972351074, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -11.83267593383789, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -1.1434195041656494, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -3.710218906402588, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -4.687295913696289, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -6.169580936431885, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -12.876049041748047, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -7.897989749908447, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -7.6432037353515625, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -3.8371458053588867, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -7.476674556732178, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -6.591335773468018, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -2.628870964050293, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -19.54383087158203, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": 3.079812526702881, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": 3.0599868297576904, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -4.361057758331299, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -13.445945739746094, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -8.224185943603516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -5.457669258117676, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -7.8514838218688965, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -14.69129467010498, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -4.073327541351318, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -10.719621658325195, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -3.484194040298462, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -21.873950958251953, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -12.562688827514648, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -14.433303833007812, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -11.538043022155762, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -5.583098411560059, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -6.319106101989746, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -4.117209434509277, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -4.087664604187012, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -5.711300373077393, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -6.448568344116211, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -9.299012184143066, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -1.6976025104522705, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -10.521522521972656, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -9.352278709411621, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -14.279708862304688, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -11.237142562866211, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -3.7602996826171875, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -14.102614402770996, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": 1.834031581878662, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -6.776103496551514, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -7.349850654602051, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -11.03607177734375, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -10.871505737304688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -10.033157348632812, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -10.515748977661133, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -10.465447425842285, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -11.220648765563965, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -9.48349380493164, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -19.80289077758789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -18.929874420166016, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -15.037124633789062, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -15.797110557556152, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -11.973806381225586, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -11.365989685058594, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -14.679963111877441, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -11.842629432678223, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -2.3008553981781006, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -5.299274444580078, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -9.47567081451416, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -8.240625381469727, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -6.985145568847656, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -1.8116092681884766, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -14.579553604125977, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -0.15882565081119537, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -11.052987098693848, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -10.534075736999512, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -12.461343765258789, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -3.4963104724884033, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -3.2063283920288086, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -4.655256271362305, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": 3.90130352973938, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -9.238557815551758, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -12.395340919494629, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -10.23513412475586, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -10.9961576461792, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -9.297804832458496, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -8.414896965026855, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -11.95994758605957, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -2.9788801670074463, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -11.210237503051758, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -9.273188591003418, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -6.25204610824585, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -9.3336181640625, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -7.024564266204834, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -4.346048831939697, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -4.706249237060547, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -7.968608379364014, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -1.565627932548523, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -6.640815258026123, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -5.302150249481201, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -6.941023349761963, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -1.2704907655715942, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -7.112493515014648, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -8.465219497680664, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -5.155795097351074, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -6.536206245422363, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -9.535880088806152, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -10.2841157913208, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -8.211404800415039, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -8.24379825592041, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -8.449947357177734, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -10.331687927246094, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -16.199155807495117, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -13.972550392150879, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -18.041168212890625, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -3.4920613765716553, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -7.985953330993652, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -7.014187335968018, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -1.605649471282959, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -8.235715866088867, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -5.29293155670166, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -9.228889465332031, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -4.049346446990967, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -10.81877613067627, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -14.659221649169922, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -4.774314880371094, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -8.7986478805542, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -4.895114898681641, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -10.780174255371094, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -8.298257827758789, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -13.849451065063477, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -2.4056859016418457, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -3.175271987915039, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": 0.10836401581764221, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -14.298521041870117, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -9.087770462036133, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -10.402381896972656, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -9.93741512298584, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -10.765823364257812, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -6.67334508895874, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -4.509544372558594, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -9.220878601074219, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -4.86932897567749, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": 4.452273368835449, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -3.046302080154419, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -9.8165922164917, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -12.620911598205566, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -5.204877853393555, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -11.999639511108398, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -2.291882038116455, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -10.168539047241211, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -16.272212982177734, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -15.966462135314941, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -8.96129322052002, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -8.631392478942871, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": 3.074772834777832, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": 0.14587892591953278, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -12.751314163208008, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -13.256711959838867, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -10.27218246459961, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -7.958676815032959, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -5.983311176300049, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -4.754218578338623, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -7.612178325653076, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -10.645689010620117, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -0.6197846531867981, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -20.461259841918945, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -20.499818801879883, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -20.013587951660156, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -14.218558311462402, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": 2.9418017864227295, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": 0.09507820010185242, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": 0.4870001971721649, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 640, \"mu_intercept_per_group\": -6.998203754425049, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 641, \"mu_intercept_per_group\": -12.70267105102539, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 642, \"mu_intercept_per_group\": -12.564757347106934, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 643, \"mu_intercept_per_group\": -13.075398445129395, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 644, \"mu_intercept_per_group\": -14.863747596740723, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 645, \"mu_intercept_per_group\": -2.4183244705200195, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 646, \"mu_intercept_per_group\": -0.7938307523727417, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 647, \"mu_intercept_per_group\": -7.049498558044434, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 648, \"mu_intercept_per_group\": -5.135613918304443, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 649, \"mu_intercept_per_group\": -3.4538235664367676, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 650, \"mu_intercept_per_group\": -3.8301169872283936, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 651, \"mu_intercept_per_group\": -8.055845260620117, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 652, \"mu_intercept_per_group\": -10.992918014526367, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 653, \"mu_intercept_per_group\": -3.1368653774261475, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 654, \"mu_intercept_per_group\": -2.5501515865325928, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 655, \"mu_intercept_per_group\": -7.712600231170654, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 656, \"mu_intercept_per_group\": -8.44206714630127, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 657, \"mu_intercept_per_group\": -14.379984855651855, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 658, \"mu_intercept_per_group\": -11.493062973022461, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 659, \"mu_intercept_per_group\": -3.9389209747314453, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 660, \"mu_intercept_per_group\": -6.9828081130981445, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 661, \"mu_intercept_per_group\": -9.729299545288086, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 662, \"mu_intercept_per_group\": -9.274621963500977, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 663, \"mu_intercept_per_group\": -8.24915599822998, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 664, \"mu_intercept_per_group\": 1.9177732467651367, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 665, \"mu_intercept_per_group\": 0.6679157614707947, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 666, \"mu_intercept_per_group\": -6.791961193084717, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 667, \"mu_intercept_per_group\": -9.511539459228516, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 668, \"mu_intercept_per_group\": -8.007267951965332, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 669, \"mu_intercept_per_group\": -3.350052833557129, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 670, \"mu_intercept_per_group\": -3.5129752159118652, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 671, \"mu_intercept_per_group\": -6.794730186462402, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 672, \"mu_intercept_per_group\": 3.360326051712036, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 673, \"mu_intercept_per_group\": -1.6963112354278564, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 674, \"mu_intercept_per_group\": -11.35863208770752, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 675, \"mu_intercept_per_group\": -9.890142440795898, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 676, \"mu_intercept_per_group\": -6.259748458862305, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 677, \"mu_intercept_per_group\": -4.0634942054748535, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 678, \"mu_intercept_per_group\": -3.5187900066375732, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 679, \"mu_intercept_per_group\": -8.828516006469727, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 680, \"mu_intercept_per_group\": -5.272643566131592, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 681, \"mu_intercept_per_group\": -5.677806854248047, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 682, \"mu_intercept_per_group\": -11.633842468261719, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 683, \"mu_intercept_per_group\": -6.39860725402832, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 684, \"mu_intercept_per_group\": -15.06329345703125, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 685, \"mu_intercept_per_group\": -13.745234489440918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 686, \"mu_intercept_per_group\": -13.775030136108398, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 687, \"mu_intercept_per_group\": -10.523633003234863, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 688, \"mu_intercept_per_group\": -13.00391674041748, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 689, \"mu_intercept_per_group\": -0.534116268157959, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 690, \"mu_intercept_per_group\": -9.273967742919922, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 691, \"mu_intercept_per_group\": -1.7329838275909424, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 692, \"mu_intercept_per_group\": -0.6396942734718323, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 693, \"mu_intercept_per_group\": -7.303791046142578, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 694, \"mu_intercept_per_group\": -12.832805633544922, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 695, \"mu_intercept_per_group\": -12.848074913024902, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 696, \"mu_intercept_per_group\": 0.7132947444915771, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 697, \"mu_intercept_per_group\": -0.01631096377968788, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 698, \"mu_intercept_per_group\": -15.826177597045898, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 699, \"mu_intercept_per_group\": -14.799540519714355, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 700, \"mu_intercept_per_group\": -15.701089859008789, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 701, \"mu_intercept_per_group\": -25.847299575805664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 702, \"mu_intercept_per_group\": -15.596050262451172, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 703, \"mu_intercept_per_group\": -3.0136518478393555, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 704, \"mu_intercept_per_group\": -10.249879837036133, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 705, \"mu_intercept_per_group\": -3.0909831523895264, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 706, \"mu_intercept_per_group\": -11.727210998535156, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 707, \"mu_intercept_per_group\": -2.4828298091888428, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 708, \"mu_intercept_per_group\": -9.143221855163574, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 709, \"mu_intercept_per_group\": -8.30216121673584, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 710, \"mu_intercept_per_group\": -15.986251831054688, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 711, \"mu_intercept_per_group\": 3.363057851791382, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 712, \"mu_intercept_per_group\": -14.843551635742188, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 713, \"mu_intercept_per_group\": -9.049310684204102, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 714, \"mu_intercept_per_group\": -11.122550964355469, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 715, \"mu_intercept_per_group\": -10.008472442626953, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 716, \"mu_intercept_per_group\": -4.341726779937744, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 717, \"mu_intercept_per_group\": -6.1400651931762695, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 718, \"mu_intercept_per_group\": -10.843049049377441, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 719, \"mu_intercept_per_group\": -16.954082489013672, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 720, \"mu_intercept_per_group\": -1.3038560152053833, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 721, \"mu_intercept_per_group\": -3.9746432304382324, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 722, \"mu_intercept_per_group\": -15.726155281066895, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 723, \"mu_intercept_per_group\": -18.059703826904297, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 724, \"mu_intercept_per_group\": -15.85275936126709, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 725, \"mu_intercept_per_group\": -15.225875854492188, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 726, \"mu_intercept_per_group\": -0.8269123435020447, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 727, \"mu_intercept_per_group\": -8.880156517028809, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 728, \"mu_intercept_per_group\": -4.952438831329346, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 729, \"mu_intercept_per_group\": 2.1097402572631836, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 730, \"mu_intercept_per_group\": -19.530475616455078, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 731, \"mu_intercept_per_group\": -12.512855529785156, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 732, \"mu_intercept_per_group\": -11.262587547302246, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 733, \"mu_intercept_per_group\": -5.691250801086426, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 734, \"mu_intercept_per_group\": -5.709987163543701, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 735, \"mu_intercept_per_group\": -13.027153015136719, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 736, \"mu_intercept_per_group\": -4.580695152282715, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 737, \"mu_intercept_per_group\": -5.58447790145874, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 738, \"mu_intercept_per_group\": -7.456693649291992, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 739, \"mu_intercept_per_group\": -4.1011481285095215, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 740, \"mu_intercept_per_group\": -7.866563320159912, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 741, \"mu_intercept_per_group\": -2.8816299438476562, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 742, \"mu_intercept_per_group\": -3.1140661239624023, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 743, \"mu_intercept_per_group\": -7.392512798309326, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 744, \"mu_intercept_per_group\": -0.40461915731430054, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 745, \"mu_intercept_per_group\": -13.69776439666748, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 746, \"mu_intercept_per_group\": -2.8043599128723145, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 747, \"mu_intercept_per_group\": -5.48544454574585, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 748, \"mu_intercept_per_group\": -6.651001930236816, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 749, \"mu_intercept_per_group\": -0.7668727040290833, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 750, \"mu_intercept_per_group\": -13.935588836669922, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 751, \"mu_intercept_per_group\": -18.877792358398438, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 752, \"mu_intercept_per_group\": -13.951913833618164, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 753, \"mu_intercept_per_group\": 1.7729135751724243, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 754, \"mu_intercept_per_group\": -10.468303680419922, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 755, \"mu_intercept_per_group\": -5.0220441818237305, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 756, \"mu_intercept_per_group\": 1.5663807392120361, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 757, \"mu_intercept_per_group\": 4.801385402679443, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 758, \"mu_intercept_per_group\": -19.007904052734375, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 759, \"mu_intercept_per_group\": -4.879411220550537, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 760, \"mu_intercept_per_group\": -4.549781799316406, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 1, \"draws\": 761, \"mu_intercept_per_group\": -2.94614577293396, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 1, \"draws\": 762, \"mu_intercept_per_group\": -4.423861980438232, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 1, \"draws\": 763, \"mu_intercept_per_group\": -7.034924507141113, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 1, \"draws\": 764, \"mu_intercept_per_group\": 1.8200410604476929, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 1, \"draws\": 765, \"mu_intercept_per_group\": -8.238364219665527, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 1, \"draws\": 766, \"mu_intercept_per_group\": -7.395601749420166, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 1, \"draws\": 767, \"mu_intercept_per_group\": -20.068384170532227, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 1, \"draws\": 768, \"mu_intercept_per_group\": -17.523784637451172, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 1, \"draws\": 769, \"mu_intercept_per_group\": -11.089550018310547, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 1, \"draws\": 770, \"mu_intercept_per_group\": -2.1942050457000732, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 1, \"draws\": 771, \"mu_intercept_per_group\": -9.11524486541748, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 1, \"draws\": 772, \"mu_intercept_per_group\": -7.53018856048584, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 1, \"draws\": 773, \"mu_intercept_per_group\": -16.917530059814453, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 1, \"draws\": 774, \"mu_intercept_per_group\": -7.4532928466796875, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 1, \"draws\": 775, \"mu_intercept_per_group\": -8.408575057983398, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 1, \"draws\": 776, \"mu_intercept_per_group\": -10.65970230102539, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 1, \"draws\": 777, \"mu_intercept_per_group\": -11.440478324890137, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 1, \"draws\": 778, \"mu_intercept_per_group\": -3.9567081928253174, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 1, \"draws\": 779, \"mu_intercept_per_group\": -3.3428282737731934, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 1, \"draws\": 780, \"mu_intercept_per_group\": -3.787095546722412, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 1, \"draws\": 781, \"mu_intercept_per_group\": -5.192613124847412, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 1, \"draws\": 782, \"mu_intercept_per_group\": -1.9134330749511719, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 1, \"draws\": 783, \"mu_intercept_per_group\": -15.909469604492188, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 1, \"draws\": 784, \"mu_intercept_per_group\": -4.824670791625977, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 1, \"draws\": 785, \"mu_intercept_per_group\": -3.8470840454101562, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 1, \"draws\": 786, \"mu_intercept_per_group\": -10.330160140991211, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 1, \"draws\": 787, \"mu_intercept_per_group\": -2.9051589965820312, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 1, \"draws\": 788, \"mu_intercept_per_group\": -1.402732014656067, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 1, \"draws\": 789, \"mu_intercept_per_group\": -1.9129210710525513, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 1, \"draws\": 790, \"mu_intercept_per_group\": -2.001810312271118, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 1, \"draws\": 791, \"mu_intercept_per_group\": -1.3983904123306274, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 1, \"draws\": 792, \"mu_intercept_per_group\": -2.998652219772339, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 1, \"draws\": 793, \"mu_intercept_per_group\": -5.212745666503906, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 1, \"draws\": 794, \"mu_intercept_per_group\": -5.740200042724609, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 1, \"draws\": 795, \"mu_intercept_per_group\": -13.511787414550781, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 1, \"draws\": 796, \"mu_intercept_per_group\": -11.45315933227539, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 1, \"draws\": 797, \"mu_intercept_per_group\": 0.3158457577228546, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 1, \"draws\": 798, \"mu_intercept_per_group\": -7.817399978637695, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 1, \"draws\": 799, \"mu_intercept_per_group\": -5.6703596115112305, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": 3.732858419418335, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -14.74763298034668, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -0.7920447587966919, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -9.022059440612793, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": 0.6570751070976257, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -15.827178001403809, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": 1.0846809148788452, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -9.276813507080078, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -8.951321601867676, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -6.864566326141357, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -1.9341707229614258, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -2.0510671138763428, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -10.089612007141113, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -10.680008888244629, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -8.804644584655762, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -6.305605888366699, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": 0.3000829219818115, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -1.7551122903823853, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -2.3900818824768066, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -7.888637065887451, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -2.895343542098999, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": 1.3380863666534424, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -23.78074073791504, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -11.098406791687012, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -3.1819076538085938, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -4.800429344177246, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": 3.4133005142211914, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -4.96135139465332, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -2.690692663192749, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -2.0235795974731445, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -4.189643383026123, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -8.388700485229492, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -8.43273639678955, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -7.213374614715576, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -15.214789390563965, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -9.292546272277832, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": -2.4623196125030518, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -4.815928936004639, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -10.999615669250488, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -2.146559476852417, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": -0.2502283751964569, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -11.01223373413086, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": 0.8173249959945679, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": 1.2063239812850952, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -7.440464973449707, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": -2.0382120609283447, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -8.468244552612305, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": -10.96498966217041, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": -3.679169178009033, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": -1.5366096496582031, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -15.801124572753906, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -13.245361328125, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -1.2482539415359497, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -1.9702545404434204, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -10.261996269226074, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -6.809752464294434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -4.980435371398926, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -1.1392760276794434, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -14.793569564819336, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -9.13333797454834, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -12.414731979370117, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -6.6255903244018555, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -7.025851726531982, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -5.728945732116699, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -33.51395034790039, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -25.522985458374023, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -9.523961067199707, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -4.857399940490723, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -5.243505001068115, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -8.11296272277832, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -4.921431064605713, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -7.549405574798584, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -10.010002136230469, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -12.585983276367188, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -12.470001220703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -13.422882080078125, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -7.613100528717041, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -13.645598411560059, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": 1.5563081502914429, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -0.2708023190498352, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -3.8437490463256836, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -10.29825496673584, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -2.2668702602386475, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -18.09571075439453, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -2.0356709957122803, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -8.436660766601562, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -11.393402099609375, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -0.09373881667852402, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -7.675854682922363, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -10.161646842956543, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -5.003331184387207, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -5.881323337554932, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -15.590445518493652, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.46782112121582, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -6.074382305145264, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -9.703702926635742, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -11.3945894241333, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -22.94749641418457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -9.107547760009766, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -5.638185501098633, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -7.5632805824279785, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -5.779253005981445, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -12.833268165588379, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -24.00741195678711, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": -17.91518783569336, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -6.520063877105713, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -17.20440673828125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -0.8397051692008972, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -6.851493835449219, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -6.914797306060791, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -3.951817035675049, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -9.044754028320312, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -3.339143991470337, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -11.259417533874512, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -1.629762053489685, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -10.254329681396484, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -8.390010833740234, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -4.76670503616333, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -4.235963821411133, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -3.3014323711395264, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -3.503049373626709, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -1.417212963104248, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -12.009513854980469, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -2.5017096996307373, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -1.5731955766677856, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -15.161019325256348, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -11.574864387512207, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -5.0208420753479, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -11.90736198425293, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -10.829822540283203, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -3.8257577419281006, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -14.482948303222656, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -1.8139958381652832, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": 2.497969388961792, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": -16.498340606689453, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -0.2805044651031494, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -11.179259300231934, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -2.3191945552825928, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -16.078134536743164, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -8.03470230102539, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -7.668808937072754, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -6.628554821014404, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -9.30042839050293, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -4.862789630889893, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -13.12014102935791, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -4.942154407501221, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -1.706308364868164, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.927155017852783, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -5.129053592681885, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -5.170759677886963, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -9.57567024230957, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": 0.7154896855354309, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -10.724403381347656, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -6.5022735595703125, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -11.366816520690918, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -2.3977396488189697, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -2.8498568534851074, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -11.582931518554688, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -6.644885540008545, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -9.830425262451172, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -7.095962047576904, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -5.265265464782715, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -0.462955117225647, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -7.801544189453125, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -5.688144683837891, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -7.555182933807373, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -11.031906127929688, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -12.016904830932617, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -12.225738525390625, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -6.396834850311279, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -8.859726905822754, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -12.181182861328125, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -1.3500686883926392, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -0.9643192291259766, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": 5.729019641876221, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -7.027344226837158, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -8.903620719909668, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -11.632333755493164, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -7.708724021911621, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -4.908493995666504, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -2.233981132507324, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -11.19131851196289, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -3.624091863632202, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -8.907787322998047, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -10.99387264251709, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -13.788372039794922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -8.753623962402344, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -4.643501281738281, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -3.7619428634643555, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -13.322681427001953, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -13.632486343383789, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -13.1654691696167, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -21.33490753173828, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -20.72462272644043, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -8.248591423034668, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -11.590217590332031, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -0.4311475455760956, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -6.358354091644287, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -5.212062835693359, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -11.44992733001709, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -8.220882415771484, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -9.12226676940918, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -19.992965698242188, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.073141574859619, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -8.739863395690918, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -6.4528117179870605, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -1.6325939893722534, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -10.420852661132812, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -7.879732608795166, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -5.497306823730469, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -9.596871376037598, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -5.04962158203125, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -5.920009613037109, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -14.4966402053833, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -12.751287460327148, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -2.2573904991149902, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -7.686809539794922, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -4.8248610496521, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -1.765623927116394, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -3.668644428253174, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -11.203539848327637, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -5.001384258270264, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -5.6280837059021, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -8.435948371887207, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -16.05109405517578, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -11.728601455688477, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -10.938681602478027, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -12.06391716003418, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -9.29641342163086, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -8.03704833984375, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": -9.065410614013672, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -4.80192232131958, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": -1.2938531637191772, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": -9.983661651611328, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -8.687374114990234, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -8.76640796661377, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -13.491843223571777, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -14.784497261047363, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -7.058042049407959, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -8.410482406616211, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": -7.969771862030029, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": -5.700320720672607, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -8.23973274230957, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -6.37434720993042, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -4.339025974273682, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -12.471747398376465, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": 2.5074687004089355, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -7.676962375640869, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -9.073676109313965, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -3.8976588249206543, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -9.184854507446289, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -8.97800350189209, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": 0.567714512348175, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -9.884993553161621, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -2.6615822315216064, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -4.578339099884033, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -4.606342792510986, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -3.4974441528320312, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -7.455306529998779, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -8.015759468078613, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -6.008310794830322, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -9.581665992736816, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -18.30813217163086, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -5.676492691040039, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -5.461687088012695, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -10.037436485290527, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -5.408499240875244, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -3.463329315185547, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -8.462669372558594, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -0.7396417856216431, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": 0.3627697825431824, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -8.535021781921387, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -14.763421058654785, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -12.69399356842041, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -5.960251808166504, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -15.310663223266602, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -11.386277198791504, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": -0.6379175186157227, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": 2.479771614074707, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -27.945741653442383, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -25.226280212402344, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -25.83666229248047, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -25.84488868713379, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": -3.639381170272827, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -3.4970641136169434, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -8.06601619720459, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -1.5408661365509033, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -8.879176139831543, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -5.490477085113525, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": 0.7783665657043457, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": -5.810604572296143, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -6.816895008087158, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": -5.717819690704346, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": -3.2649192810058594, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -7.394350051879883, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -5.316237449645996, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -4.33823823928833, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -3.374006748199463, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -3.690908670425415, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -3.286393642425537, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -6.020491600036621, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -3.8602819442749023, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -3.8057656288146973, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -11.836518287658691, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -11.771985054016113, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -2.775174379348755, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -8.22934627532959, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -5.914505481719971, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": 0.35630086064338684, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -8.621039390563965, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": 0.03868190944194794, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -7.187379360198975, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -2.533694267272949, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -13.379923820495605, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -2.356395721435547, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -8.24489974975586, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -9.023186683654785, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -10.784841537475586, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -13.656123161315918, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -3.4743764400482178, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -7.933475971221924, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -11.61305046081543, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -12.829791069030762, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -13.294774055480957, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -0.8171144723892212, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -8.221381187438965, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -6.305694580078125, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -1.9388025999069214, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -8.794182777404785, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -14.92114543914795, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": 1.2037016153335571, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -0.29571962356567383, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -2.143641233444214, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": 0.28064489364624023, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -11.181112289428711, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -17.93585777282715, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -16.54886245727539, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -14.920042037963867, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -4.039874076843262, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -2.210084915161133, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -6.806283473968506, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -8.500036239624023, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -10.403523445129395, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -12.121692657470703, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -1.4248536825180054, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -6.124846935272217, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -9.547216415405273, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -7.770440101623535, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": -1.1363286972045898, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -5.304030895233154, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -16.298486709594727, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": 0.6669440269470215, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -12.736757278442383, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -0.40219584107398987, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -11.14700698852539, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -10.505026817321777, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -13.417987823486328, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -4.444047927856445, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -5.558975696563721, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -6.314434051513672, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -5.409777641296387, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -12.233269691467285, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": 2.4941351413726807, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -8.505087852478027, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -11.589695930480957, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": 2.68093204498291, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -2.3584933280944824, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -10.62534236907959, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -11.387564659118652, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -6.608433246612549, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -11.981107711791992, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -8.635040283203125, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -5.843832015991211, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.792159557342529, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -9.92165756225586, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -0.5195949077606201, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -0.48983699083328247, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -8.744340896606445, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -4.345973968505859, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -7.0246405601501465, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -8.06035041809082, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -3.0483062267303467, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -7.415585041046143, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -4.294566631317139, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -7.638671875, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -5.52531099319458, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": -22.398527145385742, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -26.254108428955078, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -22.66168212890625, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": 11.287065505981445, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -18.271297454833984, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": 5.90974760055542, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -20.47370147705078, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": -21.0311222076416, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -24.008012771606445, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": 3.4749786853790283, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -5.57877254486084, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": 7.922347545623779, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": 3.74188494682312, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -1.6988954544067383, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -5.097616672515869, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -8.846117973327637, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": 0.1722397655248642, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -11.248380661010742, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -5.576571464538574, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -11.188019752502441, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -7.977139472961426, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -7.824069499969482, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -6.561493873596191, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -4.329862117767334, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -9.109274864196777, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -2.5585813522338867, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -3.9632863998413086, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -8.33236312866211, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": -12.320808410644531, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -5.167570114135742, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -0.7097181081771851, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -6.286855697631836, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -3.0909993648529053, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -9.099831581115723, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -9.916319847106934, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -3.4401278495788574, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -10.867147445678711, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -3.1852986812591553, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -2.7473909854888916, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -8.0872163772583, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -6.562880992889404, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": -4.1757941246032715, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -7.16696834564209, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -10.26915168762207, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -9.438253402709961, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -9.75649356842041, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -10.471683502197266, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -6.7206597328186035, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -7.505468368530273, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -12.156686782836914, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -8.14764404296875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -12.892260551452637, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -7.857025146484375, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -5.481618404388428, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -7.646692752838135, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -8.294184684753418, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -6.671442031860352, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -5.029989719390869, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -6.067749977111816, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -8.702014923095703, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -1.9200150966644287, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": 2.897442579269409, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -6.439794540405273, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -9.116233825683594, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -8.189045906066895, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -7.817679405212402, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -8.17243480682373, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -7.344018936157227, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -9.187037467956543, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -11.351550102233887, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -6.207816123962402, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -12.242033004760742, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -8.850366592407227, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -7.808396339416504, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -6.700761795043945, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -4.922554969787598, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -7.77886962890625, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -8.31988525390625, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -12.699518203735352, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": 0.7110630869865417, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -5.795843124389648, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -9.777260780334473, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -12.110445976257324, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -0.4430992007255554, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -6.092288970947266, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -14.46850872039795, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": -13.915558815002441, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -11.345191955566406, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -9.869769096374512, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -14.827057838439941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": 2.4836864471435547, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -17.392253875732422, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -1.5566017627716064, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -4.168797969818115, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -6.886236190795898, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -2.3287723064422607, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": -9.082579612731934, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -8.306184768676758, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -10.162294387817383, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -6.873996257781982, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -10.086308479309082, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -8.069391250610352, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -10.074687004089355, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -17.203676223754883, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -15.812134742736816, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -10.763212203979492, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -3.6097567081451416, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -7.371165752410889, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -10.116365432739258, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": 2.3381083011627197, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -15.05810832977295, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -3.4082698822021484, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -8.308154106140137, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -9.934334754943848, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -4.966827869415283, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -13.838757514953613, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -8.109692573547363, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -2.6857166290283203, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -12.619490623474121, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -12.56435489654541, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -10.434200286865234, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -6.927921295166016, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -6.527944564819336, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -6.607351779937744, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -12.63137435913086, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": -12.4427490234375, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -3.7763655185699463, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -9.528964042663574, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -4.6869120597839355, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -10.90855598449707, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -6.655173301696777, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -3.270554304122925, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -16.982526779174805, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -15.353683471679688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -8.847289085388184, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -10.179303169250488, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -6.731151103973389, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -7.674241542816162, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -9.233016967773438, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -11.5830717086792, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -14.37897777557373, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -4.1582865715026855, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": 0.197475865483284, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -18.406869888305664, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -6.320181369781494, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -24.789236068725586, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -8.58946704864502, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -6.373545169830322, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -16.464635848999023, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -9.792702674865723, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -8.00907039642334, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": 6.568103790283203, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -1.1935948133468628, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -4.287923336029053, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -13.90717601776123, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -13.259078979492188, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -4.4597859382629395, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": 3.266550064086914, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -17.591632843017578, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -6.757795333862305, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -3.6606576442718506, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -0.4319865107536316, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -8.018631935119629, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -9.239262580871582, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": -5.867883682250977, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -16.606130599975586, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -11.81203842163086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -7.561521530151367, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": 3.4671599864959717, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -21.93998908996582, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -4.782626628875732, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -4.104213714599609, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -6.890751838684082, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -9.23733901977539, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -4.768161773681641, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -6.677367210388184, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -9.043994903564453, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -4.714869022369385, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -3.2620174884796143, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -5.250110149383545, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -6.488597393035889, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -3.883333683013916, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -5.378838062286377, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -8.393364906311035, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -4.350249767303467, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -10.24892520904541, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -5.905289649963379, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -13.357450485229492, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -16.178735733032227, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -15.908679008483887, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -7.344059944152832, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -7.44371223449707, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -9.754671096801758, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -14.778365135192871, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": -13.482151985168457, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -7.292673587799072, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -9.378966331481934, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -9.126514434814453, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": -4.56641960144043, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -4.477183818817139, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -6.549602031707764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -6.186005592346191, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -9.142590522766113, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -6.239355564117432, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": -2.2536373138427734, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": -1.894028902053833, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -8.125317573547363, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -6.698769569396973, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -9.687060356140137, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -5.876283168792725, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -15.55165958404541, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -11.94643783569336, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -9.460631370544434, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -11.773155212402344, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -11.088447570800781, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -3.3102426528930664, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -1.4685629606246948, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -7.10137414932251, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -17.07517433166504, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -9.918875694274902, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -2.0156307220458984, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -9.946962356567383, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -7.392494201660156, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -9.749910354614258, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -7.147546291351318, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -11.540006637573242, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -9.33851432800293, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -9.769523620605469, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -12.711801528930664, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -6.6422953605651855, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -7.653461456298828, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": 0.8141601085662842, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -0.6052043437957764, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -4.644975185394287, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": 5.55590295791626, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -19.888980865478516, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": 1.2527320384979248, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -4.81308650970459, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -9.619791030883789, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -12.583415985107422, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -1.2959754467010498, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -6.864170551300049, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -8.394363403320312, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -1.894271731376648, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -8.552262306213379, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -7.477956771850586, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -12.555445671081543, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -17.114042282104492, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -17.859159469604492, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -19.37428092956543, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -4.23969841003418, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -6.650465965270996, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -7.718262672424316, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -6.551194667816162, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 640, \"mu_intercept_per_group\": -7.141420841217041, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 641, \"mu_intercept_per_group\": -12.319287300109863, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 642, \"mu_intercept_per_group\": -1.9240094423294067, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 643, \"mu_intercept_per_group\": -12.14867877960205, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 644, \"mu_intercept_per_group\": -8.549842834472656, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 645, \"mu_intercept_per_group\": -4.7822747230529785, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 646, \"mu_intercept_per_group\": -7.511908054351807, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 647, \"mu_intercept_per_group\": -8.554618835449219, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 648, \"mu_intercept_per_group\": -6.192224025726318, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 649, \"mu_intercept_per_group\": -2.184715986251831, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 650, \"mu_intercept_per_group\": 0.327439546585083, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 651, \"mu_intercept_per_group\": -8.841228485107422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 652, \"mu_intercept_per_group\": -10.685248374938965, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 653, \"mu_intercept_per_group\": -11.242206573486328, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 654, \"mu_intercept_per_group\": -10.382344245910645, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 655, \"mu_intercept_per_group\": -5.185843467712402, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 656, \"mu_intercept_per_group\": -4.3155622482299805, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 657, \"mu_intercept_per_group\": -11.385210037231445, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 658, \"mu_intercept_per_group\": -15.944779396057129, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 659, \"mu_intercept_per_group\": -9.161582946777344, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 660, \"mu_intercept_per_group\": -7.693521976470947, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 661, \"mu_intercept_per_group\": -6.487646579742432, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 662, \"mu_intercept_per_group\": -6.708395004272461, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 663, \"mu_intercept_per_group\": -3.748321771621704, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 664, \"mu_intercept_per_group\": -3.1187522411346436, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 665, \"mu_intercept_per_group\": -5.392289161682129, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 666, \"mu_intercept_per_group\": -2.2252864837646484, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 667, \"mu_intercept_per_group\": -0.012133646756410599, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 668, \"mu_intercept_per_group\": -6.209344863891602, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 669, \"mu_intercept_per_group\": -4.447170257568359, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 670, \"mu_intercept_per_group\": 0.12659278512001038, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 671, \"mu_intercept_per_group\": -4.577426433563232, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 672, \"mu_intercept_per_group\": -8.053205490112305, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 673, \"mu_intercept_per_group\": -7.424107551574707, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 674, \"mu_intercept_per_group\": -7.840348243713379, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 675, \"mu_intercept_per_group\": -12.95202350616455, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 676, \"mu_intercept_per_group\": -2.3764352798461914, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 677, \"mu_intercept_per_group\": -7.701026916503906, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 678, \"mu_intercept_per_group\": 1.1807005405426025, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 679, \"mu_intercept_per_group\": -9.633260726928711, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 680, \"mu_intercept_per_group\": -8.008782386779785, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 681, \"mu_intercept_per_group\": -2.400926351547241, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 682, \"mu_intercept_per_group\": -16.178964614868164, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 683, \"mu_intercept_per_group\": -13.101844787597656, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 684, \"mu_intercept_per_group\": -8.684494972229004, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 685, \"mu_intercept_per_group\": -6.833575248718262, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 686, \"mu_intercept_per_group\": -3.6441476345062256, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 687, \"mu_intercept_per_group\": -3.5922977924346924, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 688, \"mu_intercept_per_group\": -18.850242614746094, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 689, \"mu_intercept_per_group\": 1.0820876359939575, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 690, \"mu_intercept_per_group\": -6.514820575714111, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 691, \"mu_intercept_per_group\": -1.3514366149902344, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 692, \"mu_intercept_per_group\": -1.5759904384613037, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 693, \"mu_intercept_per_group\": 2.053717613220215, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 694, \"mu_intercept_per_group\": -4.6263651847839355, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 695, \"mu_intercept_per_group\": -6.750999450683594, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 696, \"mu_intercept_per_group\": -4.758124351501465, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 697, \"mu_intercept_per_group\": -1.9505478143692017, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 698, \"mu_intercept_per_group\": -16.749841690063477, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 699, \"mu_intercept_per_group\": -13.986458778381348, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 700, \"mu_intercept_per_group\": -17.15596580505371, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 701, \"mu_intercept_per_group\": -17.973060607910156, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 702, \"mu_intercept_per_group\": -11.176142692565918, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 703, \"mu_intercept_per_group\": -0.8515474200248718, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 704, \"mu_intercept_per_group\": -16.14752769470215, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 705, \"mu_intercept_per_group\": -17.337581634521484, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 706, \"mu_intercept_per_group\": -5.1819167137146, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 707, \"mu_intercept_per_group\": -12.231256484985352, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 708, \"mu_intercept_per_group\": 1.0472511053085327, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 709, \"mu_intercept_per_group\": -26.541973114013672, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 710, \"mu_intercept_per_group\": -4.820431232452393, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 711, \"mu_intercept_per_group\": -17.555593490600586, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 712, \"mu_intercept_per_group\": -4.313548564910889, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 713, \"mu_intercept_per_group\": -12.815875053405762, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 714, \"mu_intercept_per_group\": -7.939393997192383, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 715, \"mu_intercept_per_group\": -9.014795303344727, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 716, \"mu_intercept_per_group\": -7.826602935791016, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 717, \"mu_intercept_per_group\": -1.84090256690979, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 718, \"mu_intercept_per_group\": -8.720623016357422, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 719, \"mu_intercept_per_group\": -13.187346458435059, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 720, \"mu_intercept_per_group\": -8.846368789672852, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 721, \"mu_intercept_per_group\": -6.637916564941406, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 722, \"mu_intercept_per_group\": -3.355745315551758, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 723, \"mu_intercept_per_group\": -2.7655088901519775, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 724, \"mu_intercept_per_group\": -4.8449811935424805, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 725, \"mu_intercept_per_group\": -3.848680257797241, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 726, \"mu_intercept_per_group\": -10.032918930053711, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 727, \"mu_intercept_per_group\": -3.0833189487457275, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 728, \"mu_intercept_per_group\": -9.624643325805664, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 729, \"mu_intercept_per_group\": -5.940707683563232, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 730, \"mu_intercept_per_group\": -7.710272789001465, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 731, \"mu_intercept_per_group\": -23.57373809814453, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 732, \"mu_intercept_per_group\": -15.726632118225098, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 733, \"mu_intercept_per_group\": -7.308401584625244, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 734, \"mu_intercept_per_group\": -9.822031021118164, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 735, \"mu_intercept_per_group\": -8.193119049072266, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 736, \"mu_intercept_per_group\": -1.6803587675094604, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 737, \"mu_intercept_per_group\": -14.743664741516113, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 738, \"mu_intercept_per_group\": -11.672747611999512, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 739, \"mu_intercept_per_group\": -8.721245765686035, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 740, \"mu_intercept_per_group\": -9.85912036895752, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 741, \"mu_intercept_per_group\": -1.3250946998596191, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 742, \"mu_intercept_per_group\": -6.714052677154541, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 743, \"mu_intercept_per_group\": -4.2093281745910645, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 744, \"mu_intercept_per_group\": -6.668892860412598, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 745, \"mu_intercept_per_group\": -3.4528956413269043, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 746, \"mu_intercept_per_group\": -6.977998733520508, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 747, \"mu_intercept_per_group\": -5.103305339813232, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 748, \"mu_intercept_per_group\": 0.21640686690807343, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 749, \"mu_intercept_per_group\": -2.2673940658569336, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 750, \"mu_intercept_per_group\": -1.6518634557724, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 751, \"mu_intercept_per_group\": -5.230224609375, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 752, \"mu_intercept_per_group\": -0.9623963832855225, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 753, \"mu_intercept_per_group\": -11.71789264678955, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 754, \"mu_intercept_per_group\": -3.776665210723877, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 755, \"mu_intercept_per_group\": -11.82597541809082, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 756, \"mu_intercept_per_group\": -12.082707405090332, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 757, \"mu_intercept_per_group\": -12.341635704040527, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 758, \"mu_intercept_per_group\": -14.834488868713379, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 759, \"mu_intercept_per_group\": -9.986968994140625, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 760, \"mu_intercept_per_group\": -10.320402145385742, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 2, \"draws\": 761, \"mu_intercept_per_group\": -13.905303955078125, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 2, \"draws\": 762, \"mu_intercept_per_group\": -16.491025924682617, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 2, \"draws\": 763, \"mu_intercept_per_group\": -5.7081732749938965, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 2, \"draws\": 764, \"mu_intercept_per_group\": -14.90152645111084, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 2, \"draws\": 765, \"mu_intercept_per_group\": -0.3089122772216797, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 2, \"draws\": 766, \"mu_intercept_per_group\": -15.320383071899414, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 2, \"draws\": 767, \"mu_intercept_per_group\": -4.846121788024902, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 2, \"draws\": 768, \"mu_intercept_per_group\": -6.406315326690674, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 2, \"draws\": 769, \"mu_intercept_per_group\": -10.758137702941895, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 2, \"draws\": 770, \"mu_intercept_per_group\": -7.8329854011535645, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 2, \"draws\": 771, \"mu_intercept_per_group\": 0.8221447467803955, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 2, \"draws\": 772, \"mu_intercept_per_group\": -21.661827087402344, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 2, \"draws\": 773, \"mu_intercept_per_group\": -12.66462230682373, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 2, \"draws\": 774, \"mu_intercept_per_group\": -14.172645568847656, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 2, \"draws\": 775, \"mu_intercept_per_group\": -8.050253868103027, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 2, \"draws\": 776, \"mu_intercept_per_group\": -11.800787925720215, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 2, \"draws\": 777, \"mu_intercept_per_group\": -21.02047348022461, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 2, \"draws\": 778, \"mu_intercept_per_group\": -7.51196813583374, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 2, \"draws\": 779, \"mu_intercept_per_group\": -8.911922454833984, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 2, \"draws\": 780, \"mu_intercept_per_group\": -10.23464298248291, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 2, \"draws\": 781, \"mu_intercept_per_group\": -2.848794460296631, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 2, \"draws\": 782, \"mu_intercept_per_group\": -3.9888498783111572, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 2, \"draws\": 783, \"mu_intercept_per_group\": -12.056135177612305, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 2, \"draws\": 784, \"mu_intercept_per_group\": -7.282134056091309, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 2, \"draws\": 785, \"mu_intercept_per_group\": -5.6719231605529785, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 2, \"draws\": 786, \"mu_intercept_per_group\": 0.6745861172676086, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 2, \"draws\": 787, \"mu_intercept_per_group\": -1.0155054330825806, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 2, \"draws\": 788, \"mu_intercept_per_group\": -8.687138557434082, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 2, \"draws\": 789, \"mu_intercept_per_group\": -7.499844074249268, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 2, \"draws\": 790, \"mu_intercept_per_group\": -2.866102933883667, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 2, \"draws\": 791, \"mu_intercept_per_group\": -3.8333287239074707, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 2, \"draws\": 792, \"mu_intercept_per_group\": -6.34598970413208, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 2, \"draws\": 793, \"mu_intercept_per_group\": -14.285922050476074, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 2, \"draws\": 794, \"mu_intercept_per_group\": -17.319591522216797, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 2, \"draws\": 795, \"mu_intercept_per_group\": -12.132493019104004, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 2, \"draws\": 796, \"mu_intercept_per_group\": -7.3018975257873535, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 2, \"draws\": 797, \"mu_intercept_per_group\": -10.934429168701172, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 2, \"draws\": 798, \"mu_intercept_per_group\": 1.3345128297805786, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 2, \"draws\": 799, \"mu_intercept_per_group\": -7.95594596862793, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": 1.1422832012176514, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": 3.4451889991760254, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -13.309249877929688, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -2.334221363067627, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -2.6834938526153564, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -1.050855040550232, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": -11.638349533081055, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -3.4021027088165283, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": -4.454543590545654, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -4.641628742218018, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": 1.0176398754119873, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": 1.382218837738037, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -4.815413475036621, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": 5.528326988220215, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": 8.008136749267578, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": 11.768983840942383, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -5.568403720855713, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -6.959604740142822, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -6.039422512054443, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": 2.300753116607666, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -5.080330848693848, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": -4.960811614990234, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -0.6755471229553223, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": 2.055466651916504, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": 15.956356048583984, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": 4.9173808097839355, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -14.728536605834961, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": -13.294828414916992, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -5.873209476470947, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": 2.3663792610168457, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -1.0872663259506226, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": 1.0575892925262451, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -0.23079244792461395, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -6.030643463134766, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -7.986595630645752, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -3.6445791721343994, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -1.7929785251617432, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -10.452860832214355, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -6.082972049713135, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -1.2904764413833618, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -0.5038827657699585, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -1.9818707704544067, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": -2.4391608238220215, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -3.6116600036621094, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": 1.880308985710144, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -1.596183180809021, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": 10.43369197845459, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": 10.978118896484375, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": 11.816225051879883, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": 7.06320858001709, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": 5.699960708618164, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.811556339263916, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": 7.416693687438965, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": 5.239987373352051, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -6.371124744415283, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -6.321715354919434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -0.8365016579627991, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -1.100523829460144, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -9.814924240112305, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -2.12493634223938, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.7239115238189697, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -6.467557430267334, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -9.944820404052734, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -9.137910842895508, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": 4.786907196044922, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": 7.342767715454102, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": 21.530065536499023, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -3.220067024230957, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -2.410952568054199, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -0.7614163756370544, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -3.118800163269043, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -7.121359348297119, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": 0.9711492657661438, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -9.067095756530762, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.610410690307617, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -1.9965918064117432, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -5.7381486892700195, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -5.407534599304199, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -3.1097052097320557, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -0.051551930606365204, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": 1.6425068378448486, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": 2.8682215213775635, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": -5.482365131378174, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.255630016326904, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -1.8998559713363647, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -4.396988391876221, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": 0.8396350145339966, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": 1.5524109601974487, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": 4.776217460632324, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": 11.44230842590332, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": 9.291142463684082, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": -5.650680065155029, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": 0.710728645324707, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -5.860079765319824, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": 3.1312332153320312, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": 1.5535598993301392, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -2.915241003036499, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": 0.9959485530853271, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": 8.354219436645508, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.838305950164795, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": -5.439314842224121, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": 4.786798477172852, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -1.9363937377929688, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -7.338453769683838, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": 0.36386746168136597, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": -10.497365951538086, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -8.698169708251953, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": 0.6599807143211365, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -4.565549373626709, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -4.984137535095215, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -3.4180290699005127, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -2.035233736038208, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": -2.8604378700256348, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": -3.704653263092041, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": 1.111017107963562, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -0.39979448914527893, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -6.098702430725098, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -1.463597059249878, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -0.000967649684753269, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": -2.249558448791504, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": -2.216856002807617, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": -4.691045761108398, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -0.8590145707130432, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -4.1990814208984375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -3.9876046180725098, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -0.9444401264190674, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -3.738778591156006, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": -9.33457088470459, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -1.212861180305481, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -9.126809120178223, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -16.431392669677734, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": 1.9312454462051392, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -6.761323928833008, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -2.729433536529541, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": 0.7777804732322693, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -6.178104877471924, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": 0.9076302647590637, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -6.937652587890625, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -2.5492546558380127, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -4.945709705352783, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -1.7667300701141357, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": 0.7200169563293457, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": 3.5294952392578125, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -4.999780178070068, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -2.732987642288208, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": 1.1399319171905518, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -0.09409604221582413, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -2.603269338607788, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": 2.263167381286621, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -2.1555821895599365, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": -4.189473628997803, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -1.4529013633728027, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": -2.817486524581909, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -0.8714385628700256, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -8.482097625732422, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": 4.959986686706543, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -6.086630344390869, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": 2.741875410079956, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -7.743535995483398, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": 11.827567100524902, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": 14.373174667358398, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -11.803725242614746, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": -17.219268798828125, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": 10.779607772827148, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": -7.521295070648193, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": 2.204723834991455, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": -0.06757959723472595, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -7.076362133026123, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -19.321819305419922, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": 10.665518760681152, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -15.639404296875, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": 7.635056018829346, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -0.4615268409252167, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": 8.905537605285645, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": 5.470874786376953, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -0.41181477904319763, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -3.8645167350769043, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": 2.6198697090148926, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -0.5493851900100708, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -2.6867988109588623, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -2.045103073120117, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -2.85786771774292, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -1.5691494941711426, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -6.313195705413818, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -5.157509803771973, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -1.6202298402786255, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": 0.9412631392478943, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -9.106287002563477, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -11.040139198303223, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": 5.320924758911133, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -1.043454885482788, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": 2.8296430110931396, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -3.5491135120391846, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -3.0336110591888428, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": 4.867432594299316, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -0.9833825826644897, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -0.5252104997634888, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": -5.145560264587402, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -4.320082187652588, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": 1.111548662185669, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -2.541640520095825, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -6.575405120849609, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -11.184614181518555, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -5.859685897827148, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -4.4939703941345215, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -6.390528202056885, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": 8.489559173583984, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -10.59765338897705, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -9.754304885864258, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -2.605734348297119, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": 3.5903382301330566, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -7.091739177703857, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -7.92171573638916, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": 0.17396149039268494, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -9.727476119995117, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": 3.487213373184204, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -2.6936447620391846, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": 12.155808448791504, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -3.0443296432495117, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -0.5025920271873474, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": 2.8304405212402344, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -10.801639556884766, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -0.5220856070518494, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -3.85499906539917, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -1.3167321681976318, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -6.445994853973389, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -6.1198835372924805, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": 4.902685165405273, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": 5.7540106773376465, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -5.082253456115723, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -3.7886149883270264, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -4.4853291511535645, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": 7.6265788078308105, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -1.692143201828003, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -4.007877349853516, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -3.221977710723877, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -1.347394585609436, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": 3.4872400760650635, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -6.5580620765686035, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": -5.686244010925293, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -1.484086275100708, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -6.134275436401367, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -3.998112201690674, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": 3.097943067550659, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -3.10587477684021, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -1.2060569524765015, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": 2.667961835861206, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -1.136277675628662, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": 0.020718803629279137, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": 2.6314878463745117, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -1.9009311199188232, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": -1.2595146894454956, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -1.4188594818115234, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": 0.3701774477958679, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -4.469882488250732, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -4.703858852386475, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": 2.9320223331451416, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": 3.490630865097046, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": -1.2078993320465088, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -4.197757244110107, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -6.318816661834717, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": 2.92828631401062, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -1.5768591165542603, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": 7.342698574066162, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -6.412532329559326, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": 3.4590110778808594, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": 5.967440605163574, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": 0.5187315940856934, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": 4.232466697692871, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -2.6163413524627686, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": 1.1103160381317139, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": -6.491605758666992, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -3.8196685314178467, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -2.652308702468872, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": 7.153045654296875, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -12.401137351989746, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -1.4257242679595947, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -3.7779064178466797, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": 5.371438026428223, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -10.941880226135254, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -11.144450187683105, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -3.7005515098571777, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -4.426377773284912, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -5.206786155700684, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": 8.41220474243164, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -3.45896053314209, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -2.978003740310669, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -1.7527974843978882, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -3.5697708129882812, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -7.499160289764404, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -2.673635244369507, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": -4.929272651672363, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -1.617139458656311, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -1.8594846725463867, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": -2.0745227336883545, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": 0.6467105746269226, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": 4.440384387969971, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": 1.7059365510940552, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -0.42386800050735474, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": -2.8983304500579834, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -3.9906091690063477, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -1.4967854022979736, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -2.459275960922241, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -0.5270119309425354, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -0.7536998391151428, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -4.541114807128906, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": 6.655881881713867, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -0.4428862929344177, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": 4.027284622192383, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -0.18719589710235596, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -5.053924560546875, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": -0.9571754336357117, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -4.632637977600098, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": 1.230791449546814, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -4.023431777954102, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -10.133399963378906, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -0.15544360876083374, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -5.1925859451293945, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": 10.034708976745605, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -11.376166343688965, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": -5.671952724456787, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -4.728982448577881, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -0.477090060710907, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -1.1253021955490112, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": 2.1307523250579834, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -4.218825817108154, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": 0.7177229523658752, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": 5.307969570159912, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -6.659838676452637, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": 0.8339402675628662, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -7.1644511222839355, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": 9.08468246459961, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": 8.221074104309082, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": 3.2874090671539307, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -10.034884452819824, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -7.14697790145874, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -5.812159061431885, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -9.020214080810547, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -0.0592881515622139, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -2.267007827758789, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": -2.3067283630371094, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": 2.1847925186157227, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": -8.609108924865723, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -7.968606472015381, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": 5.869666576385498, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -4.742668151855469, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": 2.67676043510437, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": -4.7433671951293945, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -5.591422080993652, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -4.894288539886475, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": 1.1010111570358276, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -10.362127304077148, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": 7.756590366363525, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": 10.190167427062988, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -2.9594478607177734, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -1.6523555517196655, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -8.56190299987793, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -2.955606460571289, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": 1.5201140642166138, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": 0.5285970568656921, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -0.9237287640571594, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -1.2570079565048218, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": -5.493432998657227, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -3.5231142044067383, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": 1.628109097480774, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": 0.5275156497955322, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": 5.90330696105957, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -7.689522743225098, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": 0.6258456707000732, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -8.762786865234375, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -5.9061994552612305, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -6.406050205230713, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -2.177804708480835, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -3.175398349761963, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.53462815284729, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.8630146980285645, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -3.1630401611328125, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -4.196714878082275, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -2.6307883262634277, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": 0.23636986315250397, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": 1.7251968383789062, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": -8.066803932189941, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -9.934847831726074, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": 10.237847328186035, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -16.784555435180664, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -14.604349136352539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -12.49198055267334, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -18.91082191467285, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -12.75493335723877, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": 8.327741622924805, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": -5.912790775299072, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -5.286569595336914, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -5.302486896514893, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -4.904359340667725, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -3.9771060943603516, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -2.971621513366699, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.789281845092773, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": 0.550115704536438, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -1.1442714929580688, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": 0.5929803252220154, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": -4.128983020782471, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": 0.654107928276062, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": 1.1824840307235718, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -4.839790344238281, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -3.5365540981292725, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.722402572631836, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": 3.623861074447632, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -1.5331995487213135, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -0.9055638909339905, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": -4.37939977645874, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -0.09710405766963959, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -4.23989725112915, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -5.184539318084717, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -1.9728769063949585, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": -5.851361274719238, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": 2.593122720718384, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": 3.2033915519714355, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -3.1738393306732178, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": 0.07471458613872528, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -5.293779373168945, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -0.15786832571029663, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": 7.1509528160095215, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -3.041566848754883, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -8.282413482666016, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": -8.749505043029785, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": 12.567148208618164, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -7.595125198364258, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -4.985073089599609, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -2.9983041286468506, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": 2.977707862854004, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -0.13216590881347656, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": 0.08115331083536148, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": 1.0226789712905884, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -6.061187744140625, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -12.322136878967285, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": 5.065090179443359, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": 7.918672561645508, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": 5.867305755615234, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": 2.042487621307373, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -0.6973666548728943, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -1.4755373001098633, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -0.40214118361473083, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": 1.972685694694519, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -5.049294948577881, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": 3.5060598850250244, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -3.3422980308532715, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": -2.1599979400634766, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -0.16590610146522522, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -0.675101637840271, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -1.7655251026153564, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": -3.0615193843841553, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": 0.9273499846458435, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -6.301034927368164, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -5.81266975402832, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -12.09800910949707, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -16.9748477935791, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -0.8389238119125366, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": 13.40527629852295, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": 4.561748027801514, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": 0.8433964848518372, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -6.979583263397217, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -0.5884028673171997, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -4.402454853057861, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -4.225096702575684, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -6.455096244812012, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -5.126056671142578, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -9.202210426330566, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -13.092423439025879, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": 2.330103874206543, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -3.111171245574951, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -1.5748965740203857, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": 6.025733470916748, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": -20.092267990112305, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -11.896636962890625, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": 0.13928580284118652, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": 8.409333229064941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -5.502542018890381, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -4.66280460357666, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -1.5036921501159668, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": 2.001307964324951, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": 5.179535865783691, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": 0.6891594529151917, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -3.987020254135132, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -3.130981683731079, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -8.0926513671875, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": 3.002039670944214, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -10.398992538452148, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -0.7789192795753479, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": 16.261219024658203, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -15.879326820373535, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -14.116984367370605, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -5.021420001983643, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": 0.48141056299209595, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": 3.443138360977173, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": -4.203012943267822, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": 1.2212390899658203, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": 2.878952741622925, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -4.4430155754089355, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -1.9320683479309082, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": 3.059864044189453, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": -1.5174566507339478, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -7.900796890258789, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -7.854007720947266, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": 5.19315242767334, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": 2.12386155128479, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": 2.578529119491577, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -1.7175145149230957, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -3.82033371925354, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": 0.0025268117897212505, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -5.460965156555176, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -0.6229301691055298, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -0.009420330636203289, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": 5.668510913848877, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -5.805806636810303, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -5.268351078033447, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": 3.3501031398773193, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": 2.2356791496276855, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -2.5880022048950195, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -6.686184883117676, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -7.809329509735107, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -5.405384540557861, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": 1.952531337738037, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -11.692564010620117, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -6.440998554229736, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -10.477301597595215, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": 7.941324234008789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": 9.543127059936523, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": 5.6837639808654785, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": 1.7521110773086548, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -5.787217140197754, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -7.043797969818115, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -8.691217422485352, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -3.84586238861084, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": 1.4004701375961304, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -1.488426685333252, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -6.012677192687988, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -1.4134918451309204, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.400400400161743, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": 0.3176666498184204, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -7.941269874572754, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -0.4374779462814331, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -5.062107563018799, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": 2.9750351905822754, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": 0.8638477325439453, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -1.4666558504104614, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": 5.508360862731934, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": 3.3465919494628906, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": 6.344620704650879, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": -2.2002763748168945, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -14.220636367797852, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": 6.004452705383301, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -19.313186645507812, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": 3.035220146179199, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -7.511860370635986, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": -1.2900664806365967, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -2.8503220081329346, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -6.260819435119629, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": -2.5331246852874756, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -8.642271995544434, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": 4.178277492523193, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": 2.3975954055786133, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -5.3959641456604, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -0.10079754143953323, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -4.879522323608398, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": 3.477522134780884, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -6.130655288696289, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": 1.7411397695541382, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": 9.138921737670898, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -10.642536163330078, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": 8.479148864746094, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": 6.1939873695373535, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": -11.953067779541016, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -9.57574462890625, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -12.450737953186035, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -1.5178221464157104, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": 0.982293963432312, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -4.705238342285156, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -1.3431538343429565, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -4.971939563751221, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -0.4891444742679596, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": 0.38888153433799744, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": 1.532944679260254, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -7.4955596923828125, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -10.090048789978027, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": 8.15038013458252, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": 7.267123699188232, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -2.7479090690612793, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": -9.160313606262207, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": -2.9178810119628906, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -1.0811572074890137, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -1.5299677848815918, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -3.080362558364868, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -6.4926676750183105, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -0.15025557577610016, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -5.4212188720703125, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": 0.12190693616867065, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -8.257290840148926, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -6.4581708908081055, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -1.8280775547027588, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -4.033593654632568, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": -2.4062139987945557, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -14.466475486755371, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": 3.689469575881958, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": 3.022028684616089, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -4.515467166900635, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -4.477755069732666, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -2.8041117191314697, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": 2.587585210800171, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": 6.183584213256836, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": 7.167823791503906, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": 9.330349922180176, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -0.7203639149665833, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -12.502355575561523, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": -10.53499984741211, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": 1.4793434143066406, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -9.836216926574707, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": 5.254878997802734, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -0.6041688323020935, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": 3.4832756519317627, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -3.310424327850342, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -6.958009719848633, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": 1.9582477807998657, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": 0.9501878023147583, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": 0.5971997380256653, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": 1.221201777458191, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -2.0772831439971924, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -5.599991321563721, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": 1.1452524662017822, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -3.9608592987060547, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": 2.485051155090332, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -6.193269729614258, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -5.742509841918945, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": 0.0498674251139164, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -13.879101753234863, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -14.36821460723877, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -18.042510986328125, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -3.22035813331604, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -1.0437861680984497, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": 0.015396964736282825, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -1.583577275276184, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 640, \"mu_intercept_per_group\": -2.0819149017333984, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 641, \"mu_intercept_per_group\": -0.7863612771034241, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 642, \"mu_intercept_per_group\": 7.002364635467529, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 643, \"mu_intercept_per_group\": 4.588798999786377, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 644, \"mu_intercept_per_group\": -10.203553199768066, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 645, \"mu_intercept_per_group\": 12.023187637329102, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 646, \"mu_intercept_per_group\": 6.173324108123779, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 647, \"mu_intercept_per_group\": 3.815366744995117, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 648, \"mu_intercept_per_group\": 1.77543306350708, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 649, \"mu_intercept_per_group\": 0.8806454539299011, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 650, \"mu_intercept_per_group\": 0.8425295352935791, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 651, \"mu_intercept_per_group\": -5.0908989906311035, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 652, \"mu_intercept_per_group\": -6.294406890869141, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 653, \"mu_intercept_per_group\": -4.240575790405273, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 654, \"mu_intercept_per_group\": 1.1153373718261719, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 655, \"mu_intercept_per_group\": -8.701765060424805, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 656, \"mu_intercept_per_group\": -8.359423637390137, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 657, \"mu_intercept_per_group\": -9.169832229614258, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 658, \"mu_intercept_per_group\": -4.485829830169678, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 659, \"mu_intercept_per_group\": -1.2002664804458618, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 660, \"mu_intercept_per_group\": -1.283840298652649, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 661, \"mu_intercept_per_group\": 0.8676854968070984, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 662, \"mu_intercept_per_group\": 1.0672951936721802, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 663, \"mu_intercept_per_group\": 4.966071605682373, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 664, \"mu_intercept_per_group\": -5.618011474609375, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 665, \"mu_intercept_per_group\": -3.85263729095459, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 666, \"mu_intercept_per_group\": 1.6280697584152222, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 667, \"mu_intercept_per_group\": 6.69218635559082, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 668, \"mu_intercept_per_group\": -1.8946659564971924, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 669, \"mu_intercept_per_group\": -3.206312417984009, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 670, \"mu_intercept_per_group\": -7.758072853088379, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 671, \"mu_intercept_per_group\": -8.816082000732422, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 672, \"mu_intercept_per_group\": -2.9414925575256348, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 673, \"mu_intercept_per_group\": 0.16837017238140106, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 674, \"mu_intercept_per_group\": -3.6111299991607666, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 675, \"mu_intercept_per_group\": -4.992269039154053, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 676, \"mu_intercept_per_group\": -0.8869007229804993, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 677, \"mu_intercept_per_group\": -3.622464656829834, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 678, \"mu_intercept_per_group\": -6.170212745666504, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 679, \"mu_intercept_per_group\": -8.245932579040527, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 680, \"mu_intercept_per_group\": -15.151115417480469, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 681, \"mu_intercept_per_group\": 5.21836519241333, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 682, \"mu_intercept_per_group\": -16.357988357543945, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 683, \"mu_intercept_per_group\": -1.631963849067688, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 684, \"mu_intercept_per_group\": -10.513628959655762, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 685, \"mu_intercept_per_group\": -9.62197494506836, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 686, \"mu_intercept_per_group\": -20.429683685302734, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 687, \"mu_intercept_per_group\": -21.109054565429688, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 688, \"mu_intercept_per_group\": -1.9177546501159668, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 689, \"mu_intercept_per_group\": -1.488953948020935, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 690, \"mu_intercept_per_group\": 1.6919147968292236, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 691, \"mu_intercept_per_group\": 2.763578176498413, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 692, \"mu_intercept_per_group\": -3.010648012161255, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 693, \"mu_intercept_per_group\": -6.339518070220947, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 694, \"mu_intercept_per_group\": 0.133871391415596, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 695, \"mu_intercept_per_group\": -2.2540857791900635, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 696, \"mu_intercept_per_group\": 1.3386919498443604, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 697, \"mu_intercept_per_group\": -0.2260308414697647, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 698, \"mu_intercept_per_group\": -8.835453987121582, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 699, \"mu_intercept_per_group\": 1.3694179058074951, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 700, \"mu_intercept_per_group\": 1.7521642446517944, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 701, \"mu_intercept_per_group\": -0.28043603897094727, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 702, \"mu_intercept_per_group\": -1.9403650760650635, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 703, \"mu_intercept_per_group\": -6.318399906158447, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 704, \"mu_intercept_per_group\": 13.841275215148926, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 705, \"mu_intercept_per_group\": 1.4841045141220093, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 706, \"mu_intercept_per_group\": 3.645707607269287, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 707, \"mu_intercept_per_group\": 1.5687335729599, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 708, \"mu_intercept_per_group\": -3.1403298377990723, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 709, \"mu_intercept_per_group\": -2.7531683444976807, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 710, \"mu_intercept_per_group\": -18.587854385375977, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 711, \"mu_intercept_per_group\": -5.753057479858398, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 712, \"mu_intercept_per_group\": 5.228336811065674, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 713, \"mu_intercept_per_group\": 3.0528054237365723, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 714, \"mu_intercept_per_group\": -6.099391937255859, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 715, \"mu_intercept_per_group\": -8.292634010314941, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 716, \"mu_intercept_per_group\": 1.57783842086792, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 717, \"mu_intercept_per_group\": 1.708120346069336, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 718, \"mu_intercept_per_group\": -1.237881064414978, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 719, \"mu_intercept_per_group\": -13.32564640045166, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 720, \"mu_intercept_per_group\": 2.978395938873291, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 721, \"mu_intercept_per_group\": -3.8427343368530273, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 722, \"mu_intercept_per_group\": 2.4600279331207275, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 723, \"mu_intercept_per_group\": 3.6240856647491455, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 724, \"mu_intercept_per_group\": 3.1564455032348633, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 725, \"mu_intercept_per_group\": 5.206112861633301, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 726, \"mu_intercept_per_group\": -10.339628219604492, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 727, \"mu_intercept_per_group\": 10.391362190246582, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 728, \"mu_intercept_per_group\": -13.145536422729492, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 729, \"mu_intercept_per_group\": -3.039750099182129, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 730, \"mu_intercept_per_group\": -1.8714406490325928, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 731, \"mu_intercept_per_group\": 2.5062243938446045, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 732, \"mu_intercept_per_group\": 2.355806827545166, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 733, \"mu_intercept_per_group\": 4.35094690322876, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 734, \"mu_intercept_per_group\": 2.01265811920166, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 735, \"mu_intercept_per_group\": -6.302050590515137, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 736, \"mu_intercept_per_group\": 1.2704237699508667, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 737, \"mu_intercept_per_group\": -6.088379859924316, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 738, \"mu_intercept_per_group\": 1.4410150051116943, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 739, \"mu_intercept_per_group\": -4.998089790344238, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 740, \"mu_intercept_per_group\": -1.0717111825942993, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 741, \"mu_intercept_per_group\": -2.8326401710510254, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 742, \"mu_intercept_per_group\": 0.5562751293182373, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 743, \"mu_intercept_per_group\": -4.102422714233398, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 744, \"mu_intercept_per_group\": -0.6741512417793274, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 745, \"mu_intercept_per_group\": -6.860042572021484, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 746, \"mu_intercept_per_group\": -7.127810001373291, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 747, \"mu_intercept_per_group\": -5.695292949676514, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 748, \"mu_intercept_per_group\": 8.79918384552002, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 749, \"mu_intercept_per_group\": 3.3661038875579834, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 750, \"mu_intercept_per_group\": -1.9716641902923584, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 751, \"mu_intercept_per_group\": 3.977968215942383, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 752, \"mu_intercept_per_group\": -4.175975799560547, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 753, \"mu_intercept_per_group\": -3.6886377334594727, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 754, \"mu_intercept_per_group\": -1.2347979545593262, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 755, \"mu_intercept_per_group\": -5.9835991859436035, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 756, \"mu_intercept_per_group\": -10.218194961547852, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 757, \"mu_intercept_per_group\": -4.862447261810303, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 758, \"mu_intercept_per_group\": -10.775684356689453, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 759, \"mu_intercept_per_group\": -3.4646146297454834, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 760, \"mu_intercept_per_group\": -2.4840354919433594, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 3, \"draws\": 761, \"mu_intercept_per_group\": -0.9740098714828491, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 3, \"draws\": 762, \"mu_intercept_per_group\": -3.4814372062683105, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 3, \"draws\": 763, \"mu_intercept_per_group\": -5.168466091156006, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 3, \"draws\": 764, \"mu_intercept_per_group\": -11.178720474243164, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 3, \"draws\": 765, \"mu_intercept_per_group\": -14.58297348022461, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 3, \"draws\": 766, \"mu_intercept_per_group\": -7.081275463104248, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 3, \"draws\": 767, \"mu_intercept_per_group\": 2.7455029487609863, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 3, \"draws\": 768, \"mu_intercept_per_group\": -0.04195941239595413, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 3, \"draws\": 769, \"mu_intercept_per_group\": -1.5294663906097412, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 3, \"draws\": 770, \"mu_intercept_per_group\": 9.213594436645508, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 3, \"draws\": 771, \"mu_intercept_per_group\": -4.530481815338135, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 3, \"draws\": 772, \"mu_intercept_per_group\": -8.007185935974121, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 3, \"draws\": 773, \"mu_intercept_per_group\": -8.879368782043457, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 3, \"draws\": 774, \"mu_intercept_per_group\": -8.491690635681152, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 3, \"draws\": 775, \"mu_intercept_per_group\": 5.7926249504089355, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 3, \"draws\": 776, \"mu_intercept_per_group\": -11.696650505065918, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 3, \"draws\": 777, \"mu_intercept_per_group\": -2.5717172622680664, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 3, \"draws\": 778, \"mu_intercept_per_group\": -1.936160683631897, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 3, \"draws\": 779, \"mu_intercept_per_group\": -4.924736499786377, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 3, \"draws\": 780, \"mu_intercept_per_group\": -9.15251636505127, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 3, \"draws\": 781, \"mu_intercept_per_group\": -0.9256086349487305, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 3, \"draws\": 782, \"mu_intercept_per_group\": -2.718745470046997, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 3, \"draws\": 783, \"mu_intercept_per_group\": 0.4050230085849762, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 3, \"draws\": 784, \"mu_intercept_per_group\": -6.642741680145264, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 3, \"draws\": 785, \"mu_intercept_per_group\": 3.859210252761841, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 3, \"draws\": 786, \"mu_intercept_per_group\": -5.522294521331787, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 3, \"draws\": 787, \"mu_intercept_per_group\": 7.714738845825195, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 3, \"draws\": 788, \"mu_intercept_per_group\": -5.8960394859313965, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 3, \"draws\": 789, \"mu_intercept_per_group\": -2.492332696914673, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 3, \"draws\": 790, \"mu_intercept_per_group\": 6.8780364990234375, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 3, \"draws\": 791, \"mu_intercept_per_group\": 6.295490741729736, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 3, \"draws\": 792, \"mu_intercept_per_group\": 3.3202102184295654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 3, \"draws\": 793, \"mu_intercept_per_group\": 0.27863284945487976, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 3, \"draws\": 794, \"mu_intercept_per_group\": -0.6200317144393921, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 3, \"draws\": 795, \"mu_intercept_per_group\": -0.4486876130104065, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 3, \"draws\": 796, \"mu_intercept_per_group\": -5.382551670074463, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 3, \"draws\": 797, \"mu_intercept_per_group\": 10.205591201782227, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 3, \"draws\": 798, \"mu_intercept_per_group\": -9.05825424194336, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 3, \"draws\": 799, \"mu_intercept_per_group\": 9.337186813354492, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": -10.222573280334473, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": 0.7351592779159546, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -4.840921878814697, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -2.0387380123138428, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": 1.2483538389205933, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -2.9457359313964844, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -5.501341819763184, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -8.34166431427002, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": -1.844313621520996, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -6.937033176422119, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": -3.4211442470550537, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": 0.9551476240158081, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -0.4594762623310089, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": -2.6546359062194824, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": -0.28176337480545044, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -2.703993797302246, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": 9.14089298248291, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": 6.106947422027588, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": 6.025209426879883, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -5.250345706939697, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": 6.868474960327148, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": -2.2628467082977295, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -11.139957427978516, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": 0.7120257616043091, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": 1.6031622886657715, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": -8.283370018005371, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": -1.4586102962493896, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": -1.5663509368896484, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -9.569623947143555, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": 3.1074273586273193, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": -1.128059983253479, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": 2.5137887001037598, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -1.8959046602249146, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -5.683225154876709, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -6.53802490234375, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -5.361851692199707, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -3.998962640762329, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -9.249808311462402, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -7.951653957366943, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": 6.277647495269775, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": 0.48686710000038147, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": -0.9286237955093384, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": 5.7846903800964355, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": 3.9058072566986084, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": 12.240160942077637, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": 7.2814507484436035, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -10.052249908447266, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": -10.43879222869873, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": 7.636048316955566, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": 9.484684944152832, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": 7.747954845428467, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -5.559622287750244, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -1.6774073839187622, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": 0.3476562798023224, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": -1.2113286256790161, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": 2.4230000972747803, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": 3.167386293411255, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": -1.7299370765686035, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -3.0267183780670166, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": 0.589921772480011, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -8.071708679199219, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -0.665273129940033, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -5.544233798980713, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": 0.5462062954902649, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -6.977456569671631, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -9.465309143066406, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": 2.9924938678741455, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": -0.47992295026779175, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": -0.25456222891807556, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -3.280860662460327, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": 1.5002942085266113, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -3.6058130264282227, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -0.7466505765914917, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -3.2043683528900146, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": -5.266552448272705, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": -12.962620735168457, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": -8.191950798034668, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": 1.2133440971374512, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -3.3012075424194336, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -4.116568088531494, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": 1.3200589418411255, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": 1.343465805053711, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -5.596874237060547, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -10.104131698608398, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": 3.3133914470672607, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": 5.00221061706543, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": 5.407783508300781, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -4.314720153808594, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": 18.991758346557617, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": -0.6752288937568665, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": -0.48365887999534607, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": -3.6919829845428467, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": 4.215518474578857, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -6.701752662658691, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": 4.814064979553223, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": 3.983412265777588, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -4.883889198303223, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -3.206291675567627, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": 3.3244102001190186, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": 5.707808971405029, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": 7.159797191619873, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -1.932453989982605, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": 3.110919713973999, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": -2.2059030532836914, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": 7.051965713500977, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": -4.265612602233887, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -12.290275573730469, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": 4.426063537597656, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": -2.242264747619629, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": -1.0556801557540894, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": -0.9302979111671448, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": -4.810073375701904, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": 1.5923924446105957, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": -3.728991746902466, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": 5.562324047088623, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": 3.485109329223633, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -0.3389970064163208, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -3.247162103652954, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": 1.2077232599258423, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": -1.7801531553268433, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": 0.6469892859458923, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": 0.7023070454597473, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -4.512775421142578, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -2.7560360431671143, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -1.5878812074661255, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -6.278449058532715, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -5.4340410232543945, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": -5.3703436851501465, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": 2.3976669311523438, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": -4.363067150115967, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -6.9952712059021, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -10.892335891723633, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": 3.478604793548584, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": 0.783741295337677, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": -4.214395523071289, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": 2.311872959136963, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -6.152163028717041, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": 3.9275498390197754, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": -7.379451274871826, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": 1.9290038347244263, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -5.134275913238525, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -2.58302640914917, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": 1.8919726610183716, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": 3.966975212097168, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -7.511531829833984, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -4.661186218261719, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": 4.783458232879639, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": 0.015353485941886902, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -2.604113817214966, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": 2.289116859436035, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -8.103594779968262, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": 2.359726667404175, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": -1.2524923086166382, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -3.437492847442627, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": 0.6847198605537415, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -1.9796546697616577, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": 5.471470355987549, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": -4.455415725708008, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": -2.1415693759918213, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": 5.087538719177246, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": 4.994999408721924, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": 3.9994425773620605, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": 3.4031996726989746, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -8.986064910888672, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": 3.3010106086730957, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -1.4659618139266968, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": 0.22813911736011505, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": 4.13400936126709, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -1.0655854940414429, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -5.3494873046875, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": 2.6429660320281982, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -2.794489622116089, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": 0.44388440251350403, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": 5.480645179748535, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": 2.0663249492645264, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": 3.190870761871338, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": 0.4560146629810333, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -1.3204753398895264, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": 4.639101505279541, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -2.3368122577667236, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": -0.12557123601436615, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -4.177392482757568, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -1.4043046236038208, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": 3.410184144973755, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": -4.618890762329102, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": 0.9706475734710693, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -5.469550132751465, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -10.25925350189209, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -5.198490142822266, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": 0.6035569906234741, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -4.91817045211792, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -1.833343744277954, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -1.9475245475769043, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -4.199075222015381, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -0.6295586228370667, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -7.06285285949707, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -7.332114219665527, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": -1.8951919078826904, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": -1.390397548675537, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": 5.134096145629883, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -3.130772352218628, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": -3.425441026687622, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -10.429344177246094, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -6.859905242919922, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -7.089567184448242, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -7.857722759246826, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -6.922474384307861, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": 0.9095247983932495, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": 1.1069105863571167, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -8.023462295532227, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -11.704340934753418, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": 5.241725921630859, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": 4.544750213623047, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -9.038421630859375, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -4.5517048835754395, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -2.0782558917999268, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": 4.884559154510498, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": -0.8930679559707642, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": 3.2035889625549316, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": 3.412111520767212, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": 6.3044891357421875, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -9.152482032775879, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": -0.036205701529979706, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -2.2955758571624756, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -11.870111465454102, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": 5.123497486114502, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -21.790081024169922, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -19.68638038635254, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -15.662795066833496, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": 10.203377723693848, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": 8.00701904296875, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": 5.623378276824951, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": 6.930778980255127, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": -2.4476048946380615, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": -4.406008720397949, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": -0.639160692691803, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -8.552936553955078, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -7.73972749710083, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": 1.669751524925232, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": -5.550314903259277, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -1.334588646888733, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -7.068094730377197, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -5.390186786651611, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": 1.802512764930725, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": 2.1883575916290283, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -2.4512076377868652, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": 0.2697095572948456, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": 2.4418365955352783, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": 3.1828649044036865, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -0.5853416919708252, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": -1.688409447669983, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": -0.321841835975647, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": 1.7025400400161743, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -5.3715972900390625, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -2.4557180404663086, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": -4.347818374633789, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -4.5496344566345215, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -3.889549732208252, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": -9.831265449523926, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -7.587305545806885, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -9.38453483581543, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": 11.450456619262695, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": 10.535062789916992, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -9.374042510986328, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -7.373213768005371, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -2.8359947204589844, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -3.4654200077056885, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": -1.794429898262024, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": 7.437652587890625, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": -3.163054943084717, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": 0.7324626445770264, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": 3.7192869186401367, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": 4.074527740478516, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": 3.914069890975952, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": 4.926583290100098, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": 1.005097508430481, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -6.599051475524902, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -13.909625053405762, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -14.652721405029297, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": 16.287742614746094, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": 15.183490753173828, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": 8.074374198913574, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": 7.079869747161865, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.352164268493652, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": 3.445081949234009, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": -0.13314545154571533, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": 0.12403306365013123, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": 3.615466833114624, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": 2.841648578643799, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": 6.290352821350098, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": -3.2495901584625244, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": -6.687504768371582, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": 1.56047523021698, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": -1.3200434446334839, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": -1.990303874015808, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": -0.9329994916915894, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": -0.19775116443634033, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": 4.739821434020996, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": 4.048184871673584, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": 0.6300459504127502, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": 0.37932610511779785, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": -1.1257051229476929, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": 0.17781753838062286, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.540189027786255, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -5.3517045974731445, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": 3.7807674407958984, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": 3.5766971111297607, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": 6.87188720703125, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": -0.2200179249048233, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": 4.251936435699463, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": 1.6953351497650146, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -1.2283800840377808, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": -5.675398349761963, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": 4.123122215270996, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -4.602899074554443, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": 2.192589044570923, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -5.83239221572876, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -5.904195785522461, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -6.1403422355651855, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": 2.6582698822021484, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -4.622495174407959, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -2.3200156688690186, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -10.623682975769043, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -15.656454086303711, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -11.915611267089844, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -7.29128885269165, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -9.28799057006836, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": -1.5844402313232422, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -9.355169296264648, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -9.797776222229004, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": 1.6542587280273438, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": 8.481145858764648, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": 4.470423221588135, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -1.3096708059310913, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -10.22557544708252, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -2.129939556121826, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": -3.6794984340667725, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": -2.065094470977783, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -3.083914041519165, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": 4.107353687286377, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": -1.0638706684112549, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": -1.496822714805603, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": -3.2917540073394775, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": 3.55251145362854, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": -2.9563403129577637, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": 4.9263505935668945, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": -9.568013191223145, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": -13.995607376098633, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": -4.618760108947754, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": 5.174973487854004, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -7.510647296905518, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": 5.256582260131836, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": -6.16785192489624, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": 2.0095841884613037, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": -0.8866797089576721, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": 1.922220230102539, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": 3.6239891052246094, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -8.089971542358398, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": 7.619902610778809, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -8.913562774658203, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": -8.175060272216797, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": -0.1956782341003418, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -1.8559167385101318, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": 2.4483916759490967, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": 2.8031749725341797, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": 1.4116320610046387, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": 1.2916738986968994, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": 0.016939561814069748, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -6.3288960456848145, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": -0.9084743857383728, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -2.4604382514953613, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -4.6587233543396, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -3.721674680709839, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -3.6613924503326416, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -7.367818355560303, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -2.456761598587036, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -0.811137855052948, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -3.5969862937927246, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": 3.7880971431732178, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": 2.0546035766601562, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": 3.7384068965911865, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -3.1992483139038086, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": 4.091832637786865, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": 3.10144305229187, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": 8.00448989868164, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -12.494241714477539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": -15.75905990600586, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": -15.911749839782715, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": -14.960686683654785, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": 7.879668712615967, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": -5.545164585113525, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -8.131694793701172, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": 6.875602722167969, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": 4.374419212341309, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": 6.496573448181152, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": -5.026095390319824, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -8.928727149963379, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -11.550392150878906, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -8.368969917297363, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -6.962975025177002, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": 6.889718055725098, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": 2.922802448272705, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": -4.909971237182617, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": -2.0281882286071777, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -0.21226929128170013, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -2.285454750061035, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -0.6161280274391174, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": 2.2025299072265625, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": -2.122138738632202, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": 4.103301525115967, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": -5.548608779907227, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": 2.7988741397857666, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -8.01515007019043, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": 0.42529040575027466, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": -3.6517932415008545, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": -0.5515525341033936, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": 2.0600452423095703, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": -1.0337955951690674, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": -1.0684521198272705, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -2.2774314880371094, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": -7.314043045043945, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -2.4525113105773926, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -4.27780818939209, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": 1.5510914325714111, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": -0.1506415456533432, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -3.740121841430664, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -5.2863545417785645, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": 5.354739665985107, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": 0.6194051504135132, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -4.08737850189209, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -2.1308741569519043, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -1.3846282958984375, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -2.911750555038452, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -9.480743408203125, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -1.6755708456039429, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -5.225432395935059, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": 4.965527057647705, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": 0.765901505947113, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -0.2432432472705841, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": 1.9107531309127808, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": 1.245962142944336, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -2.8260066509246826, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": 6.900586128234863, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -5.26108455657959, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": 2.28515625, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -4.239246845245361, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": 3.115494966506958, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -2.684730052947998, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -1.2988783121109009, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.9401421546936035, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -2.1803243160247803, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -3.8678042888641357, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": 1.2255836725234985, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": 0.8233058452606201, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": 6.4001641273498535, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -3.6718525886535645, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": 3.9332029819488525, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": 6.823799133300781, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -0.9171903133392334, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": -4.349397659301758, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": 1.7256262302398682, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -3.1465160846710205, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": 0.9560574889183044, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -3.488286256790161, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": 5.763370513916016, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -6.90833044052124, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": 0.5493221879005432, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -1.9435194730758667, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": -0.7900018692016602, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -7.044142246246338, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -6.870087146759033, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -6.215428352355957, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -0.42390817403793335, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -3.4466910362243652, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": 1.4385346174240112, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": 2.753023624420166, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": 2.7223126888275146, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": -6.31094217300415, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": 6.110436916351318, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": 6.438925743103027, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": 5.934630870819092, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": 4.618720054626465, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": -4.0582733154296875, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -8.378496170043945, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -9.8966646194458, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": 1.2092821598052979, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": -4.2657575607299805, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": 7.811222076416016, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": 1.8952081203460693, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": 2.6893508434295654, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": 5.602606296539307, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": 4.052567481994629, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -2.7636845111846924, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -1.1795055866241455, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -4.659461975097656, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": 7.605453968048096, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": -1.9424526691436768, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": 1.479622721672058, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": 4.631229877471924, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": 2.5250823497772217, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": 0.3759743273258209, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -8.323416709899902, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -1.308106780052185, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": -0.3469439446926117, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": -2.320566415786743, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": -1.714707612991333, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": 1.4244813919067383, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": 1.5334476232528687, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": 3.9070937633514404, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -9.991410255432129, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -0.1964610517024994, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": -2.2191975116729736, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -5.656458854675293, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -6.365799427032471, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -0.8335336446762085, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -1.2123515605926514, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": 6.899072647094727, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": 4.415450572967529, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -14.038524627685547, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -6.8309102058410645, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -1.3698656558990479, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -10.225632667541504, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": -2.8464319705963135, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": 0.6432567238807678, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -0.3441639244556427, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": -4.115943908691406, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": -4.275806903839111, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -1.2931828498840332, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -12.119006156921387, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -19.19034767150879, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": 2.8981902599334717, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": 2.008270263671875, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": 5.80705451965332, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": 1.1107293367385864, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -6.476484775543213, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -8.136292457580566, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": 0.5145658254623413, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -5.958985328674316, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": 1.2898212671279907, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -0.7434753775596619, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": -14.839637756347656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": 9.21174430847168, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -11.331006050109863, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -12.430768013000488, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": 3.0895018577575684, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": 0.7254382371902466, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": 2.220641851425171, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": 4.793663501739502, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": 0.6892642974853516, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -2.923584222793579, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": -5.301235198974609, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -2.648239850997925, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": -15.617238998413086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": 5.484040260314941, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": -0.8728763461112976, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -0.5054839253425598, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -0.6188060641288757, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -4.285893440246582, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -7.326533794403076, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -0.6164996027946472, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": 1.4153728485107422, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -9.29893684387207, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": -8.429384231567383, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": 5.165633201599121, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": -1.2580235004425049, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": 2.07047438621521, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": 0.11970026791095734, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": 3.7929165363311768, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -1.8149521350860596, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": 13.338642120361328, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": 6.8847150802612305, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -7.743525505065918, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -4.1702446937561035, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -5.477596282958984, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": -5.992972373962402, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": 2.686174154281616, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -5.086594104766846, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -8.534751892089844, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": 4.817463397979736, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -4.412678241729736, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -9.72543716430664, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -13.762779235839844, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": 4.749863147735596, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": -7.763848781585693, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": 9.345660209655762, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": 2.645254373550415, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -0.2019905000925064, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": 0.8105884790420532, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": 1.4256742000579834, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -3.2158706188201904, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": -0.8970597386360168, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": 0.28827059268951416, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -0.01489965058863163, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -7.373693943023682, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -0.13117434084415436, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -4.393489360809326, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -0.5609362125396729, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": 2.605276107788086, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": 2.394541025161743, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": 0.8525758385658264, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -4.941886901855469, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -4.616106986999512, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": 13.114214897155762, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -12.420550346374512, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": 2.9929749965667725, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": -0.11894222348928452, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -2.2654402256011963, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": 3.9687790870666504, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": 8.39231014251709, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": 19.870697021484375, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": 17.059907913208008, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": 0.5694618225097656, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": 5.5281548500061035, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": -3.6333203315734863, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": -10.495563507080078, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": 4.230743408203125, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": -5.583453178405762, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.991307497024536, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": 1.5501219034194946, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": 3.2045388221740723, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -6.84132194519043, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": 11.670865058898926, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -11.415975570678711, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -10.994959831237793, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -11.472407341003418, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -8.113114356994629, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": 4.982320308685303, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": 4.659554481506348, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -4.935208320617676, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": 9.936370849609375, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -10.630620956420898, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": -2.723560333251953, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -11.783170700073242, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -1.104187250137329, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -1.1529127359390259, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -7.889201641082764, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": 14.02910041809082, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": -5.565239906311035, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": -4.031822681427002, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": -1.7019822597503662, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 640, \"mu_intercept_per_group\": -0.26659125089645386, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 641, \"mu_intercept_per_group\": -4.296065330505371, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 642, \"mu_intercept_per_group\": -10.37691879272461, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 643, \"mu_intercept_per_group\": -18.959091186523438, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 644, \"mu_intercept_per_group\": 2.9422106742858887, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 645, \"mu_intercept_per_group\": -9.414095878601074, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 646, \"mu_intercept_per_group\": 5.117735385894775, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 647, \"mu_intercept_per_group\": 1.6604464054107666, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 648, \"mu_intercept_per_group\": 8.517123222351074, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 649, \"mu_intercept_per_group\": -5.795717239379883, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 650, \"mu_intercept_per_group\": -0.7973559498786926, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 651, \"mu_intercept_per_group\": 2.1765658855438232, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 652, \"mu_intercept_per_group\": -8.471039772033691, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 653, \"mu_intercept_per_group\": 2.805842638015747, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 654, \"mu_intercept_per_group\": 0.9290947318077087, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 655, \"mu_intercept_per_group\": -11.014189720153809, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 656, \"mu_intercept_per_group\": 4.851659774780273, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 657, \"mu_intercept_per_group\": -5.456446170806885, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 658, \"mu_intercept_per_group\": -7.925178527832031, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 659, \"mu_intercept_per_group\": 3.368788003921509, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 660, \"mu_intercept_per_group\": -2.5615501403808594, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 661, \"mu_intercept_per_group\": -0.13357359170913696, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 662, \"mu_intercept_per_group\": -1.440045952796936, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 663, \"mu_intercept_per_group\": -4.536013603210449, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 664, \"mu_intercept_per_group\": 3.1310298442840576, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 665, \"mu_intercept_per_group\": 3.234423875808716, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 666, \"mu_intercept_per_group\": -3.2979557514190674, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 667, \"mu_intercept_per_group\": -2.1722490787506104, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 668, \"mu_intercept_per_group\": -3.063098430633545, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 669, \"mu_intercept_per_group\": -0.7444708943367004, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 670, \"mu_intercept_per_group\": -2.700894355773926, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 671, \"mu_intercept_per_group\": -0.5761053562164307, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 672, \"mu_intercept_per_group\": 1.9821075201034546, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 673, \"mu_intercept_per_group\": 9.100384712219238, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 674, \"mu_intercept_per_group\": -8.743980407714844, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 675, \"mu_intercept_per_group\": -2.040138006210327, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 676, \"mu_intercept_per_group\": -2.3280317783355713, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 677, \"mu_intercept_per_group\": 1.358982801437378, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 678, \"mu_intercept_per_group\": -4.481082916259766, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 679, \"mu_intercept_per_group\": -0.7191506028175354, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 680, \"mu_intercept_per_group\": -3.6019070148468018, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 681, \"mu_intercept_per_group\": -7.443073749542236, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 682, \"mu_intercept_per_group\": -6.465905666351318, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 683, \"mu_intercept_per_group\": -7.507283687591553, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 684, \"mu_intercept_per_group\": -0.38660094141960144, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 685, \"mu_intercept_per_group\": 0.3696950376033783, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 686, \"mu_intercept_per_group\": -9.97179889678955, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 687, \"mu_intercept_per_group\": -9.013978958129883, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 688, \"mu_intercept_per_group\": 5.4107584953308105, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 689, \"mu_intercept_per_group\": -9.146997451782227, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 690, \"mu_intercept_per_group\": 9.48569107055664, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 691, \"mu_intercept_per_group\": -5.376854419708252, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 692, \"mu_intercept_per_group\": -6.184321880340576, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 693, \"mu_intercept_per_group\": -7.036289215087891, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 694, \"mu_intercept_per_group\": -7.786212921142578, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 695, \"mu_intercept_per_group\": -11.990128517150879, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 696, \"mu_intercept_per_group\": 10.64962387084961, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 697, \"mu_intercept_per_group\": 8.805665969848633, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 698, \"mu_intercept_per_group\": -13.136034965515137, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 699, \"mu_intercept_per_group\": -11.427478790283203, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 700, \"mu_intercept_per_group\": -11.816218376159668, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 701, \"mu_intercept_per_group\": -11.609723091125488, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 702, \"mu_intercept_per_group\": -4.233506202697754, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 703, \"mu_intercept_per_group\": 4.785616397857666, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 704, \"mu_intercept_per_group\": -4.93176794052124, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 705, \"mu_intercept_per_group\": -8.722419738769531, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 706, \"mu_intercept_per_group\": -2.6878652572631836, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 707, \"mu_intercept_per_group\": -6.328852653503418, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 708, \"mu_intercept_per_group\": 8.036919593811035, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 709, \"mu_intercept_per_group\": 0.8848922848701477, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 710, \"mu_intercept_per_group\": -11.791319847106934, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 711, \"mu_intercept_per_group\": -8.944643020629883, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 712, \"mu_intercept_per_group\": -3.957019567489624, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 713, \"mu_intercept_per_group\": -2.2577407360076904, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 714, \"mu_intercept_per_group\": -8.689230918884277, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 715, \"mu_intercept_per_group\": -3.3575379848480225, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 716, \"mu_intercept_per_group\": 3.798638343811035, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 717, \"mu_intercept_per_group\": 1.9333914518356323, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 718, \"mu_intercept_per_group\": -1.0012797117233276, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 719, \"mu_intercept_per_group\": -7.519647598266602, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 720, \"mu_intercept_per_group\": 1.144483208656311, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 721, \"mu_intercept_per_group\": -5.495861530303955, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 722, \"mu_intercept_per_group\": 7.084209442138672, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 723, \"mu_intercept_per_group\": 12.742281913757324, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 724, \"mu_intercept_per_group\": 9.369956016540527, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 725, \"mu_intercept_per_group\": 12.737908363342285, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 726, \"mu_intercept_per_group\": -6.68929386138916, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 727, \"mu_intercept_per_group\": 5.712256908416748, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 728, \"mu_intercept_per_group\": -7.096992015838623, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 729, \"mu_intercept_per_group\": -10.005788803100586, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 730, \"mu_intercept_per_group\": 5.818517684936523, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 731, \"mu_intercept_per_group\": -6.018786430358887, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 732, \"mu_intercept_per_group\": -0.7372608184814453, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 733, \"mu_intercept_per_group\": -2.1605422496795654, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 734, \"mu_intercept_per_group\": -9.852314949035645, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 735, \"mu_intercept_per_group\": -7.954211235046387, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 736, \"mu_intercept_per_group\": -0.5064754486083984, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 737, \"mu_intercept_per_group\": -4.683851718902588, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 738, \"mu_intercept_per_group\": -3.0086984634399414, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 739, \"mu_intercept_per_group\": -1.696182131767273, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 740, \"mu_intercept_per_group\": -6.719401836395264, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 741, \"mu_intercept_per_group\": 3.822751522064209, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 742, \"mu_intercept_per_group\": -4.209133148193359, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 743, \"mu_intercept_per_group\": -3.0948832035064697, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 744, \"mu_intercept_per_group\": 1.826290488243103, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 745, \"mu_intercept_per_group\": 2.9357244968414307, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 746, \"mu_intercept_per_group\": -6.093136787414551, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 747, \"mu_intercept_per_group\": -10.260705947875977, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 748, \"mu_intercept_per_group\": 8.261493682861328, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 749, \"mu_intercept_per_group\": 7.822362422943115, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 750, \"mu_intercept_per_group\": 4.961631774902344, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 751, \"mu_intercept_per_group\": -7.214239120483398, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 752, \"mu_intercept_per_group\": -6.27641487121582, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 753, \"mu_intercept_per_group\": 3.171701431274414, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 754, \"mu_intercept_per_group\": -4.702463626861572, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 755, \"mu_intercept_per_group\": 3.1011359691619873, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 756, \"mu_intercept_per_group\": 6.190070629119873, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 757, \"mu_intercept_per_group\": 4.508309364318848, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 758, \"mu_intercept_per_group\": -6.019010066986084, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 759, \"mu_intercept_per_group\": -2.8097918033599854, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 760, \"mu_intercept_per_group\": -4.367959499359131, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 4, \"draws\": 761, \"mu_intercept_per_group\": -2.824897050857544, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 4, \"draws\": 762, \"mu_intercept_per_group\": -3.17814564704895, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 4, \"draws\": 763, \"mu_intercept_per_group\": 3.206871509552002, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 4, \"draws\": 764, \"mu_intercept_per_group\": -2.970684766769409, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 4, \"draws\": 765, \"mu_intercept_per_group\": -5.780794620513916, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 4, \"draws\": 766, \"mu_intercept_per_group\": -1.0261821746826172, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 4, \"draws\": 767, \"mu_intercept_per_group\": 1.2663980722427368, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 4, \"draws\": 768, \"mu_intercept_per_group\": 1.2258639335632324, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 4, \"draws\": 769, \"mu_intercept_per_group\": -13.134469985961914, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 4, \"draws\": 770, \"mu_intercept_per_group\": 6.728440284729004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 4, \"draws\": 771, \"mu_intercept_per_group\": -5.930309295654297, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 4, \"draws\": 772, \"mu_intercept_per_group\": 2.635946273803711, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 4, \"draws\": 773, \"mu_intercept_per_group\": -11.658357620239258, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 4, \"draws\": 774, \"mu_intercept_per_group\": 5.645565032958984, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 4, \"draws\": 775, \"mu_intercept_per_group\": -13.9772367477417, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 4, \"draws\": 776, \"mu_intercept_per_group\": 6.683927059173584, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 4, \"draws\": 777, \"mu_intercept_per_group\": 3.967349052429199, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 4, \"draws\": 778, \"mu_intercept_per_group\": -2.4375128746032715, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 4, \"draws\": 779, \"mu_intercept_per_group\": 0.6895599365234375, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 4, \"draws\": 780, \"mu_intercept_per_group\": -0.7696780562400818, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 4, \"draws\": 781, \"mu_intercept_per_group\": -5.970967769622803, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 4, \"draws\": 782, \"mu_intercept_per_group\": 6.066479682922363, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 4, \"draws\": 783, \"mu_intercept_per_group\": -9.849822044372559, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 4, \"draws\": 784, \"mu_intercept_per_group\": 1.4375027418136597, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 4, \"draws\": 785, \"mu_intercept_per_group\": -2.4956202507019043, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 4, \"draws\": 786, \"mu_intercept_per_group\": 5.292853832244873, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 4, \"draws\": 787, \"mu_intercept_per_group\": -3.307516574859619, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 4, \"draws\": 788, \"mu_intercept_per_group\": 3.7796382904052734, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 4, \"draws\": 789, \"mu_intercept_per_group\": 4.240785121917725, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 4, \"draws\": 790, \"mu_intercept_per_group\": 11.235593795776367, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 4, \"draws\": 791, \"mu_intercept_per_group\": 10.83666706085205, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 4, \"draws\": 792, \"mu_intercept_per_group\": 2.236236810684204, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 4, \"draws\": 793, \"mu_intercept_per_group\": 0.5667391419410706, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 4, \"draws\": 794, \"mu_intercept_per_group\": -0.7058081030845642, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 4, \"draws\": 795, \"mu_intercept_per_group\": 7.67421817779541, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 4, \"draws\": 796, \"mu_intercept_per_group\": 2.026370048522949, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 4, \"draws\": 797, \"mu_intercept_per_group\": -1.2830697298049927, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 4, \"draws\": 798, \"mu_intercept_per_group\": 7.946447849273682, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 4, \"draws\": 799, \"mu_intercept_per_group\": 4.5653300285339355, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": -0.4936830699443817, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": 4.999171733856201, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": 0.6521782875061035, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": -1.6964330673217773, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": -1.5742603540420532, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": 5.283847808837891, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -11.31496810913086, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": -7.817002773284912, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": 0.5827797651290894, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": 0.2344091534614563, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": 6.792243003845215, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": -4.55280876159668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": 8.97771167755127, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": -4.939431667327881, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": -6.270378589630127, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": -1.8578853607177734, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": 8.810626029968262, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": 5.960352420806885, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": 5.344428539276123, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": 2.4586939811706543, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": 2.2995917797088623, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": 8.367406845092773, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": -6.627414226531982, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": -7.080750465393066, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": 5.021615028381348, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": 6.678419589996338, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": -7.590822219848633, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": 11.360928535461426, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": -5.0973334312438965, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": -0.12444468587636948, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": 0.7130396366119385, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": -1.6190998554229736, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": -0.8674359917640686, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": -1.1215295791625977, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": -5.713323593139648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": -0.21671302616596222, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": 5.190096855163574, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": 3.9520068168640137, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": -3.222916841506958, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": 3.779146194458008, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": 6.8436994552612305, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": -1.0128411054611206, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": 1.1723310947418213, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": 2.092717170715332, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": 2.262239456176758, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": 3.3816802501678467, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": 11.33073902130127, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": 11.15568733215332, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": 2.1022276878356934, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": 3.293247699737549, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": 8.383138656616211, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -11.438764572143555, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": 10.426858901977539, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": 2.6837852001190186, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": 1.2202776670455933, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": 3.7525627613067627, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": 6.483628273010254, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": -2.9187285900115967, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": 3.0211901664733887, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": -1.909820556640625, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": -2.5282647609710693, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": -1.0716947317123413, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": -0.8831166625022888, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": 3.354220390319824, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": -0.743996798992157, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": -0.5231768488883972, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": 8.232260704040527, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": 5.46297550201416, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": 4.69611120223999, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": 6.057387351989746, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": -4.416680335998535, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": 7.120400428771973, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": -7.168479919433594, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": -4.501968860626221, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": 8.21909236907959, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": 12.967597007751465, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": 8.842602729797363, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": -6.817704200744629, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": 0.530376672744751, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": 0.791788637638092, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": 2.006030321121216, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": 2.4872610569000244, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": -1.5326536893844604, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": 2.0414907932281494, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": -3.798283576965332, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": -1.8039244413375854, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": 2.816776752471924, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": 2.3101511001586914, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": 1.285831332206726, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": 14.7088041305542, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": 18.254072189331055, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": -7.443060398101807, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": 3.5992915630340576, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": 1.4925298690795898, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": 4.014184474945068, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": 2.11476731300354, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": 2.2457776069641113, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": 7.356701374053955, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": 10.132861137390137, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": -1.5818636417388916, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -2.462308168411255, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": 3.594944953918457, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": 1.8588958978652954, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": -0.5524792671203613, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": -0.6232576370239258, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": -13.410273551940918, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": -4.3677520751953125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": 1.3094727993011475, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -2.6252894401550293, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -4.273194313049316, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": 2.41314959526062, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": -2.153839111328125, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": 9.022931098937988, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": -7.887650966644287, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": 10.30448055267334, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": -9.876293182373047, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": 2.5861124992370605, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": 0.7091243863105774, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": 1.57363760471344, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": -0.503716230392456, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": 2.7997069358825684, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": 1.6879323720932007, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": -1.311571478843689, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": -2.7984085083007812, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": 0.46960511803627014, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": 7.710426330566406, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": 5.7630486488342285, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": -9.305146217346191, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": -2.0171682834625244, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": 3.2463467121124268, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -3.0720536708831787, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": -3.7099852561950684, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": -2.9686715602874756, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": 0.2306564897298813, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": 2.247824192047119, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": -1.3220113515853882, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": 0.9232107400894165, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": -0.6540190577507019, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": 1.9786392450332642, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": 0.9563783407211304, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": 0.7334156632423401, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": 2.3041305541992188, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": 0.6046547889709473, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": 8.854641914367676, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": -6.714970588684082, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -3.7840960025787354, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": 6.502985954284668, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": -1.8866745233535767, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": 7.441204071044922, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": -8.213418960571289, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": 11.891451835632324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": -0.8685718774795532, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": 3.430837631225586, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": 2.514370918273926, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": 0.09311062097549438, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": 1.293937087059021, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": 0.13305164873600006, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": 3.293895721435547, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": 4.343166828155518, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": 0.6446264386177063, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": 9.81774616241455, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": -2.293382406234741, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": -9.398703575134277, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": 0.90650874376297, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": 3.8641912937164307, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": -0.6476548910140991, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": 5.717311859130859, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": 11.154617309570312, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": 5.177521228790283, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": -5.699761867523193, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": 7.650353908538818, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": -3.251162052154541, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": 2.78304123878479, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": 8.93648624420166, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": 6.478943824768066, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": 2.8575520515441895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": 2.173811912536621, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": 0.5168248414993286, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": -0.9173110127449036, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": 1.0983010530471802, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": -1.128238320350647, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": 1.9474482536315918, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": 2.668318510055542, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": -2.6685452461242676, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": 2.5534586906433105, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": -9.7943115234375, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": -6.563799858093262, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -27.31961441040039, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -17.76662254333496, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": 8.505128860473633, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": 7.133119583129883, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": 8.601794242858887, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -2.6739165782928467, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": 2.1650185585021973, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": 4.0482635498046875, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": 9.812962532043457, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -3.7973835468292236, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": 3.87325382232666, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": 3.8319015502929688, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": 4.967145919799805, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": 3.728036403656006, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -8.574662208557129, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": 8.672873497009277, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": -7.8326802253723145, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": 12.981729507446289, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": 10.628742218017578, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": 0.11629725247621536, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": 5.866535186767578, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": 9.66776180267334, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -8.2392578125, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -8.03979778289795, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": 6.960459232330322, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": 8.417984962463379, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": -8.75178337097168, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -10.365260124206543, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": 12.472177505493164, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": -5.03244161605835, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": 5.089905738830566, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": 11.248644828796387, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": 9.39394474029541, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": 7.524884223937988, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": 3.66719388961792, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": 8.817556381225586, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -8.847822189331055, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": -1.8955214023590088, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -12.273404121398926, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": 4.217207431793213, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": -5.044497966766357, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": 2.819262742996216, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": 3.973588466644287, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": 4.765008926391602, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": 11.957687377929688, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": 3.02358078956604, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": 3.9243686199188232, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": 3.4044294357299805, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": -2.102890968322754, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": 0.602037250995636, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": -2.007368326187134, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -6.695186614990234, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": 11.105422973632812, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": -6.331599235534668, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": 5.3391571044921875, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": 2.7552473545074463, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": 8.030393600463867, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": -1.8643521070480347, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": 2.167123794555664, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": 9.887374877929688, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": 2.273650646209717, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": 1.265815019607544, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": 2.928429365158081, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": 10.590553283691406, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": 9.917350769042969, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": -4.333336353302002, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": -1.8468070030212402, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": -0.6399343013763428, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": 0.8221684098243713, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": -0.25098690390586853, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": 0.47165754437446594, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": 2.0731589794158936, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": 3.5841410160064697, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": 1.3557088375091553, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": 13.834127426147461, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": 14.456953048706055, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": -4.042296886444092, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": 6.682328701019287, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": -3.998976945877075, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": 4.560067176818848, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": 4.257584095001221, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": 0.5953791737556458, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": 8.030223846435547, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": 7.646004676818848, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": -3.9084184169769287, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": -3.7448387145996094, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": -8.0143461227417, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": -2.0092594623565674, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": 12.668036460876465, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": 9.397951126098633, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": 0.7062256932258606, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": 2.3495936393737793, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": 5.453965663909912, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": 6.526251316070557, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -9.583497047424316, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": -9.752381324768066, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": 8.808324813842773, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": -0.7570652961730957, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": -4.107381343841553, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": 7.210703372955322, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": -4.066314697265625, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": -5.4151611328125, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": -5.232656955718994, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": -1.9585570096969604, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": -3.251300573348999, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": -1.3458646535873413, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": 1.9364404678344727, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": -0.6752256155014038, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": -4.672120094299316, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": 0.4643610417842865, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": 7.394011974334717, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": 1.7245173454284668, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": 4.1162943840026855, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": 1.4681015014648438, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": 0.9539467692375183, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": -0.36705145239830017, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": 4.102670669555664, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": 6.861858367919922, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": -4.539209365844727, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": 4.347302436828613, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": 2.8213248252868652, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": 9.329455375671387, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": 1.9890902042388916, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": 0.6505970358848572, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": 2.8247857093811035, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": 3.5750627517700195, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": -1.6562188863754272, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": 3.6209089756011963, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": 0.9198087453842163, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -0.28500208258628845, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": -0.8128213882446289, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": 6.068824768066406, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": -0.8334502577781677, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": -3.7099437713623047, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": 1.714191198348999, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": 2.0969502925872803, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": 9.183207511901855, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": 10.86903190612793, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": 4.680744171142578, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": 2.815725088119507, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": -0.5970062017440796, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": 4.627745628356934, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": 3.6387157440185547, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": 2.4396767616271973, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": 5.886763572692871, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": 4.537914752960205, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": 6.9371337890625, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": -2.9177708625793457, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": 10.82784366607666, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": 8.419905662536621, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": 5.09188175201416, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": 0.40666913986206055, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": 8.009431838989258, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": -0.05580255761742592, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": 0.024308281019330025, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": 1.5205624103546143, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": 4.1790876388549805, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": 0.2244865894317627, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": 5.782747268676758, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": -7.930447101593018, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": 0.3207881450653076, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": 2.813279151916504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -5.610894680023193, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": 7.947093486785889, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -11.681249618530273, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": 15.034317016601562, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": 0.03979386016726494, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": 14.939435958862305, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": 13.074028968811035, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": 2.1421730518341064, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": -1.7453669309616089, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": 4.593339920043945, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": 5.567477226257324, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": 5.255597114562988, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": -4.950255393981934, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": 10.510313034057617, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": 4.427967071533203, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": -0.597438395023346, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": 11.320734024047852, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": 8.22661304473877, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": -5.545265197753906, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": -8.789752006530762, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": 5.041116714477539, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": -6.190657138824463, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": 2.533984661102295, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -9.193230628967285, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -7.052367210388184, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -4.734168529510498, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -4.440606594085693, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": -3.8006691932678223, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": 1.5238863229751587, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": -1.5220943689346313, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": -0.6359741687774658, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": -7.656125068664551, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": 9.146346092224121, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": 3.1164391040802, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": 8.489348411560059, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": 1.6961735486984253, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": 8.293295860290527, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": 5.431253433227539, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": 7.830577373504639, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": 8.568206787109375, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": -7.505928993225098, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": 2.1178689002990723, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": 2.7821342945098877, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": 5.693019390106201, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": 6.2944440841674805, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": 9.706086158752441, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": -10.40073299407959, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": -3.227675437927246, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": 2.30842924118042, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": -1.5283007621765137, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": -0.5001562833786011, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": 9.165095329284668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": 1.4900716543197632, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": -0.8814666867256165, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": -2.0296337604522705, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": 1.3305256366729736, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": 5.04124641418457, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": -4.7146782875061035, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": 5.809991359710693, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": 5.043154239654541, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": -1.7293035984039307, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": 3.3898768424987793, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": -0.8397834300994873, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": 5.915778636932373, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": 1.9669221639633179, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": 3.1190719604492188, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": -0.2337658703327179, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": 6.688932418823242, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": -2.4702565670013428, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": 2.3119709491729736, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": -3.015862464904785, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": -5.686969757080078, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": 4.881800174713135, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": -6.422973155975342, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": 9.18946647644043, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": 9.735956192016602, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": -12.410496711730957, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": 11.598301887512207, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": -2.832165479660034, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": -3.3463351726531982, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": 3.6924684047698975, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": 4.8262858390808105, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": 4.859366416931152, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": 4.933337211608887, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": 5.615426063537598, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": 7.1026291847229, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": -2.526503562927246, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": 14.279303550720215, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": 14.049449920654297, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": 10.146956443786621, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": -1.6144288778305054, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": -3.103341817855835, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": -10.78703498840332, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": -2.24977445602417, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": 7.7816481590271, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": 2.440359115600586, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": 0.9812870025634766, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": 0.7519392371177673, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": 10.234559059143066, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": -0.4684623181819916, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": 4.018322467803955, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": 3.347318410873413, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": -5.998703956604004, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": 4.131516933441162, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": -3.956796884536743, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": 2.4501700401306152, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": -7.225014686584473, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": 1.4161245822906494, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": 2.6986114978790283, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": 7.647429943084717, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": 3.9245128631591797, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": -7.178640365600586, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": 6.069210052490234, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": -7.366247653961182, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": -3.059081792831421, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": -4.277634620666504, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": -4.914758682250977, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": -2.5589759349823, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -6.704737663269043, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": 5.098209857940674, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -10.468371391296387, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": -5.892239093780518, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": 2.5162999629974365, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": 3.7081711292266846, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": 3.8927412033081055, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": -1.7580379247665405, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -2.632122039794922, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": 11.085421562194824, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": -2.4329164028167725, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": 2.66679048538208, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": 1.0495461225509644, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": 0.8502023816108704, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": -5.250965118408203, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": 6.950047492980957, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": -4.0179057121276855, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": -1.5065183639526367, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": 3.951291799545288, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": -2.1402275562286377, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": 7.854623317718506, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": -2.683741807937622, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": 14.440917015075684, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": 13.877155303955078, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": 11.458995819091797, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": -3.9448370933532715, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": -2.7637362480163574, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": 1.6091384887695312, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": 10.039451599121094, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": -5.605895519256592, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": 18.840381622314453, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": 4.888682842254639, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": -0.08786775171756744, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": -2.7071421146392822, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": 1.2054929733276367, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": 5.187563896179199, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -2.718552827835083, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": 1.6928390264511108, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": 2.8258514404296875, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": -0.6238449215888977, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": 5.984460830688477, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": 0.01763044111430645, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": 5.762425422668457, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": -3.868269205093384, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": -2.518726110458374, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": 2.960270881652832, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": -3.5001561641693115, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": 7.296746730804443, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": 1.4127551317214966, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": -2.601768970489502, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": -1.4885532855987549, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": -1.7040915489196777, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -6.998692989349365, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": 2.1867520809173584, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -9.845512390136719, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": 1.1358827352523804, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": 4.276721477508545, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -1.0788450241088867, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": -1.8729008436203003, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": -0.6531848907470703, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": -4.406121730804443, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": -3.4420886039733887, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -12.418782234191895, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": 6.173922061920166, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": -8.29879093170166, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": 11.020665168762207, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": 6.808164119720459, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": 5.0015058517456055, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": -1.2744996547698975, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": 0.6806426644325256, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -7.457321643829346, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": -5.819141387939453, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": 0.915133535861969, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": -1.2011756896972656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": 6.034015655517578, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -11.381556510925293, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": -7.319867134094238, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": 3.155782461166382, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": 7.666479110717773, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": 7.782724857330322, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": 0.21381761133670807, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": 12.560585975646973, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": -2.7401819229125977, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": 0.6657583713531494, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -3.632479667663574, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": 5.7790045738220215, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": -2.5474801063537598, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": 1.1199679374694824, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": -0.8119602799415588, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": 0.2681579887866974, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": 0.7113875150680542, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": -1.5859010219573975, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": 4.05252742767334, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": 2.554129123687744, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": 3.6585235595703125, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": 1.2316629886627197, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": -0.2994779050350189, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": 5.4572930335998535, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": -4.310985565185547, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": -0.5814806222915649, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": -4.7760329246521, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": 14.579337120056152, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": -4.133450031280518, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": -4.106779098510742, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": 6.196764945983887, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": 3.545785665512085, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": 8.385534286499023, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": 0.5849117636680603, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": 5.525136470794678, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": -6.678565979003906, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -8.455256462097168, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": 8.006284713745117, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -4.586374759674072, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": -4.955859184265137, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": -6.421501636505127, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": 3.928562879562378, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": -4.06256628036499, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": 10.368810653686523, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": 5.356241703033447, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": -2.9610393047332764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": 0.6189560890197754, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": 3.154837131500244, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": -0.1340140551328659, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": 7.543446063995361, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": 1.466381549835205, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": 3.515272855758667, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": 2.2773630619049072, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": -2.729767322540283, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": 4.216533184051514, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": -5.651655197143555, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": -3.35032057762146, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": 7.401084899902344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": 4.6678242683410645, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": -0.03037027269601822, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": -4.2660136222839355, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": 1.8521217107772827, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": 0.3156644403934479, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": 1.9550424814224243, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": 9.87182331085205, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": -3.2301228046417236, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": 10.981620788574219, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": 8.075916290283203, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": 3.7643399238586426, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": 0.19077926874160767, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": 3.4784345626831055, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": 4.375865459442139, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": 1.0993521213531494, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": -8.167473793029785, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": 4.648540019989014, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": 0.35695895552635193, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": -2.8153913021087646, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": -2.977693796157837, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": -1.1377506256103516, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": 0.04873131215572357, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": 3.1761634349823, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": -0.020863207057118416, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": 1.351028561592102, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": 12.045791625976562, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": -0.5252058506011963, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -18.708921432495117, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": -12.27900505065918, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": 11.218646049499512, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": -7.135178089141846, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": 6.958343982696533, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": 5.1873908042907715, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": 1.2365093231201172, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -4.957011699676514, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -5.30355978012085, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": -5.12799072265625, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": 6.813993453979492, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": -4.477818965911865, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": -5.169980049133301, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": -2.9529480934143066, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 640, \"mu_intercept_per_group\": -7.506115913391113, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 641, \"mu_intercept_per_group\": 4.841949939727783, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 642, \"mu_intercept_per_group\": -5.881920337677002, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 643, \"mu_intercept_per_group\": 16.809703826904297, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 644, \"mu_intercept_per_group\": 2.511122941970825, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 645, \"mu_intercept_per_group\": 0.4887118637561798, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 646, \"mu_intercept_per_group\": 0.8064342737197876, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 647, \"mu_intercept_per_group\": 1.4259870052337646, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 648, \"mu_intercept_per_group\": 1.4857269525527954, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 649, \"mu_intercept_per_group\": 8.055587768554688, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 650, \"mu_intercept_per_group\": 12.786767959594727, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 651, \"mu_intercept_per_group\": 2.306870460510254, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 652, \"mu_intercept_per_group\": -6.979279518127441, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 653, \"mu_intercept_per_group\": -0.41045838594436646, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 654, \"mu_intercept_per_group\": -0.3673120439052582, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 655, \"mu_intercept_per_group\": 4.506551742553711, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 656, \"mu_intercept_per_group\": 6.2370924949646, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 657, \"mu_intercept_per_group\": -0.3215402066707611, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 658, \"mu_intercept_per_group\": 5.281808376312256, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 659, \"mu_intercept_per_group\": -2.4257640838623047, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 660, \"mu_intercept_per_group\": -0.3196414113044739, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 661, \"mu_intercept_per_group\": 3.8381330966949463, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 662, \"mu_intercept_per_group\": 3.275034189224243, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 663, \"mu_intercept_per_group\": 4.178934097290039, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 664, \"mu_intercept_per_group\": -3.322736978530884, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 665, \"mu_intercept_per_group\": -2.479078769683838, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 666, \"mu_intercept_per_group\": 3.148167371749878, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 667, \"mu_intercept_per_group\": 7.899265766143799, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 668, \"mu_intercept_per_group\": -3.881068706512451, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 669, \"mu_intercept_per_group\": 3.0566978454589844, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 670, \"mu_intercept_per_group\": -1.6932018995285034, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 671, \"mu_intercept_per_group\": 0.5915698409080505, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 672, \"mu_intercept_per_group\": 4.123375415802002, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 673, \"mu_intercept_per_group\": 6.35595178604126, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 674, \"mu_intercept_per_group\": -3.740208864212036, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 675, \"mu_intercept_per_group\": -3.8673324584960938, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 676, \"mu_intercept_per_group\": 2.7119503021240234, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 677, \"mu_intercept_per_group\": -1.8882607221603394, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 678, \"mu_intercept_per_group\": -2.162415027618408, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 679, \"mu_intercept_per_group\": -0.3742189109325409, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 680, \"mu_intercept_per_group\": -2.5472350120544434, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 681, \"mu_intercept_per_group\": 1.0873957872390747, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 682, \"mu_intercept_per_group\": -1.8083175420761108, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 683, \"mu_intercept_per_group\": -6.07248592376709, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 684, \"mu_intercept_per_group\": 4.208353519439697, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 685, \"mu_intercept_per_group\": 4.22807502746582, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 686, \"mu_intercept_per_group\": 13.54815673828125, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 687, \"mu_intercept_per_group\": 12.544894218444824, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 688, \"mu_intercept_per_group\": 1.6133661270141602, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 689, \"mu_intercept_per_group\": 3.921630382537842, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 690, \"mu_intercept_per_group\": 2.686460018157959, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 691, \"mu_intercept_per_group\": 7.2498884201049805, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 692, \"mu_intercept_per_group\": 10.887166976928711, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 693, \"mu_intercept_per_group\": 16.479183197021484, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 694, \"mu_intercept_per_group\": -0.018748529255390167, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 695, \"mu_intercept_per_group\": -0.6615126729011536, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 696, \"mu_intercept_per_group\": 8.400014877319336, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 697, \"mu_intercept_per_group\": 6.954907417297363, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 698, \"mu_intercept_per_group\": -8.435911178588867, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 699, \"mu_intercept_per_group\": -10.450371742248535, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 700, \"mu_intercept_per_group\": -13.0982084274292, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 701, \"mu_intercept_per_group\": -7.1084208488464355, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 702, \"mu_intercept_per_group\": 0.5757467150688171, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 703, \"mu_intercept_per_group\": 6.972298622131348, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 704, \"mu_intercept_per_group\": -2.0960466861724854, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 705, \"mu_intercept_per_group\": 11.447457313537598, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 706, \"mu_intercept_per_group\": -6.721770763397217, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 707, \"mu_intercept_per_group\": -10.405341148376465, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 708, \"mu_intercept_per_group\": 16.467519760131836, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 709, \"mu_intercept_per_group\": 3.6985721588134766, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 710, \"mu_intercept_per_group\": -2.596336841583252, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 711, \"mu_intercept_per_group\": 1.6006039381027222, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 712, \"mu_intercept_per_group\": 11.543874740600586, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 713, \"mu_intercept_per_group\": 4.0602850914001465, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 714, \"mu_intercept_per_group\": -5.451816082000732, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 715, \"mu_intercept_per_group\": -0.4832264482975006, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 716, \"mu_intercept_per_group\": -0.1277807354927063, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 717, \"mu_intercept_per_group\": 9.382996559143066, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 718, \"mu_intercept_per_group\": 2.7434017658233643, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 719, \"mu_intercept_per_group\": -13.703967094421387, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 720, \"mu_intercept_per_group\": 11.376761436462402, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 721, \"mu_intercept_per_group\": -8.271041870117188, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 722, \"mu_intercept_per_group\": 5.795229911804199, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 723, \"mu_intercept_per_group\": -4.5389933586120605, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 724, \"mu_intercept_per_group\": -0.5400820374488831, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 725, \"mu_intercept_per_group\": -0.4254120886325836, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 726, \"mu_intercept_per_group\": 3.012491464614868, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 727, \"mu_intercept_per_group\": -1.6920281648635864, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 728, \"mu_intercept_per_group\": 2.6638760566711426, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 729, \"mu_intercept_per_group\": 7.623227596282959, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 730, \"mu_intercept_per_group\": -3.2628395557403564, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 731, \"mu_intercept_per_group\": 3.5190138816833496, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 732, \"mu_intercept_per_group\": 4.912494659423828, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 733, \"mu_intercept_per_group\": 2.229353427886963, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 734, \"mu_intercept_per_group\": -2.8037805557250977, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 735, \"mu_intercept_per_group\": 4.959327220916748, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 736, \"mu_intercept_per_group\": -4.8769683837890625, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 737, \"mu_intercept_per_group\": 4.81979513168335, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 738, \"mu_intercept_per_group\": -2.942124605178833, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 739, \"mu_intercept_per_group\": 0.570166826248169, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 740, \"mu_intercept_per_group\": -7.019355297088623, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 741, \"mu_intercept_per_group\": 4.785904884338379, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 742, \"mu_intercept_per_group\": -0.14491762220859528, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 743, \"mu_intercept_per_group\": 2.900390625, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 744, \"mu_intercept_per_group\": -3.1168389320373535, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 745, \"mu_intercept_per_group\": -3.2361035346984863, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 746, \"mu_intercept_per_group\": 5.309395790100098, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 747, \"mu_intercept_per_group\": 0.4705502390861511, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 748, \"mu_intercept_per_group\": 4.199631690979004, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 749, \"mu_intercept_per_group\": -2.6365833282470703, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 750, \"mu_intercept_per_group\": 5.085790634155273, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 751, \"mu_intercept_per_group\": -13.19575023651123, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 752, \"mu_intercept_per_group\": -4.775232791900635, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 753, \"mu_intercept_per_group\": 8.22763442993164, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 754, \"mu_intercept_per_group\": -5.417640209197998, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 755, \"mu_intercept_per_group\": 3.015061378479004, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 756, \"mu_intercept_per_group\": -1.2819138765335083, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 757, \"mu_intercept_per_group\": -0.46969661116600037, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 758, \"mu_intercept_per_group\": -2.6609880924224854, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 759, \"mu_intercept_per_group\": 2.6079695224761963, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 760, \"mu_intercept_per_group\": 0.9872055053710938, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 5, \"draws\": 761, \"mu_intercept_per_group\": 2.336440086364746, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 5, \"draws\": 762, \"mu_intercept_per_group\": 6.431071758270264, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 5, \"draws\": 763, \"mu_intercept_per_group\": -8.56132984161377, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 5, \"draws\": 764, \"mu_intercept_per_group\": -6.293648719787598, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 5, \"draws\": 765, \"mu_intercept_per_group\": 1.003957748413086, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 5, \"draws\": 766, \"mu_intercept_per_group\": 5.770401477813721, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 5, \"draws\": 767, \"mu_intercept_per_group\": -11.149538040161133, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 5, \"draws\": 768, \"mu_intercept_per_group\": -11.574239730834961, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 5, \"draws\": 769, \"mu_intercept_per_group\": -0.7626160979270935, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 5, \"draws\": 770, \"mu_intercept_per_group\": 6.175403594970703, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 5, \"draws\": 771, \"mu_intercept_per_group\": -6.830533504486084, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 5, \"draws\": 772, \"mu_intercept_per_group\": 5.845097541809082, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 5, \"draws\": 773, \"mu_intercept_per_group\": -4.2466254234313965, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 5, \"draws\": 774, \"mu_intercept_per_group\": -7.769762992858887, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 5, \"draws\": 775, \"mu_intercept_per_group\": -11.193673133850098, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 5, \"draws\": 776, \"mu_intercept_per_group\": 11.781404495239258, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 5, \"draws\": 777, \"mu_intercept_per_group\": -3.0879199504852295, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 5, \"draws\": 778, \"mu_intercept_per_group\": 2.3158674240112305, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 5, \"draws\": 779, \"mu_intercept_per_group\": 0.16726243495941162, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 5, \"draws\": 780, \"mu_intercept_per_group\": 1.4833091497421265, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 5, \"draws\": 781, \"mu_intercept_per_group\": 6.84270715713501, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 5, \"draws\": 782, \"mu_intercept_per_group\": 4.334469318389893, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 5, \"draws\": 783, \"mu_intercept_per_group\": -4.612475395202637, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 5, \"draws\": 784, \"mu_intercept_per_group\": 4.77070951461792, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 5, \"draws\": 785, \"mu_intercept_per_group\": 4.148092746734619, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 5, \"draws\": 786, \"mu_intercept_per_group\": 3.746044158935547, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 5, \"draws\": 787, \"mu_intercept_per_group\": 1.091285228729248, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 5, \"draws\": 788, \"mu_intercept_per_group\": 7.053884506225586, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 5, \"draws\": 789, \"mu_intercept_per_group\": 6.179688930511475, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 5, \"draws\": 790, \"mu_intercept_per_group\": 0.5649715065956116, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 5, \"draws\": 791, \"mu_intercept_per_group\": 1.1186014413833618, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 5, \"draws\": 792, \"mu_intercept_per_group\": 3.0303378105163574, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 5, \"draws\": 793, \"mu_intercept_per_group\": -0.02562352456152439, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 5, \"draws\": 794, \"mu_intercept_per_group\": -1.4256608486175537, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 5, \"draws\": 795, \"mu_intercept_per_group\": -0.9958571791648865, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 5, \"draws\": 796, \"mu_intercept_per_group\": -7.086660861968994, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 5, \"draws\": 797, \"mu_intercept_per_group\": 0.7649232745170593, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 5, \"draws\": 798, \"mu_intercept_per_group\": 10.123893737792969, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 5, \"draws\": 799, \"mu_intercept_per_group\": 5.146012306213379, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 6.37800407409668, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 14.657581329345703, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 2.7958216667175293, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 6.326478004455566, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 8.790563583374023, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 12.298267364501953, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": -0.6363531351089478, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": -1.6876857280731201, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 2.2299373149871826, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": -1.037280559539795, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 12.031730651855469, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 15.604928016662598, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 2.234408378601074, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 19.13079261779785, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 13.048595428466797, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 9.782146453857422, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 23.940692901611328, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 17.576452255249023, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 16.891254425048828, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 2.0913727283477783, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 12.74721908569336, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 15.554927825927734, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 7.008159637451172, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 0.5297897458076477, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": -5.370870113372803, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": -3.994481086730957, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 13.420904159545898, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 6.839694023132324, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 15.62886905670166, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 15.634469032287598, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 3.7431771755218506, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 9.442510604858398, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 3.235412120819092, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": -0.009158127009868622, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 7.253016471862793, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 8.9336576461792, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 5.424819469451904, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 7.15634298324585, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 6.180077075958252, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 10.72684097290039, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 11.890353202819824, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 7.474733352661133, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 10.881460189819336, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 11.45950698852539, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 17.818603515625, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 17.873416900634766, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 14.556384086608887, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 14.053670883178711, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 16.005577087402344, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 12.597241401672363, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 18.503889083862305, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 16.201860427856445, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 13.740428924560547, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 7.90291166305542, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 11.19510269165039, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 6.94672155380249, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 6.028234481811523, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 13.192073822021484, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 6.797860622406006, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 11.186580657958984, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 7.806375026702881, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 4.5859832763671875, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 3.5664408206939697, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 11.656661033630371, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 6.3669753074646, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 6.91317081451416, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 15.8410062789917, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 13.86631965637207, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 13.010332107543945, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 11.788223266601562, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 8.941932678222656, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 1.099101185798645, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 15.243159294128418, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 4.105511665344238, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 13.89879035949707, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 16.440013885498047, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 11.504037857055664, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 6.29906702041626, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 12.811902046203613, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 9.99511432647705, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 8.57177734375, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 5.0281853675842285, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 8.839679718017578, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 3.568502902984619, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 13.581151008605957, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 14.884998321533203, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 13.430789947509766, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 17.065746307373047, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 8.434178352355957, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 16.63286590576172, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 17.54259490966797, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 11.752270698547363, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 7.332230567932129, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 24.714874267578125, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 4.795590877532959, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 7.172306537628174, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 14.201985359191895, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 19.431533813476562, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 17.595199584960938, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 4.940769195556641, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 6.646292209625244, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 12.10807991027832, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 20.925168991088867, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 17.2150936126709, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 15.789444923400879, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": -0.5448676943778992, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 10.840235710144043, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 3.77411150932312, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 9.024848937988281, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 8.971269607543945, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 6.913607597351074, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 7.734762668609619, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 8.881319999694824, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 14.19491958618164, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 6.7448530197143555, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 18.282974243164062, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 2.9279086589813232, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 5.77211856842041, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 3.1763241291046143, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 12.246147155761719, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 8.492447853088379, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 7.793917179107666, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 3.3679537773132324, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 7.766360282897949, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 8.348556518554688, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 11.928165435791016, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 2.9560039043426514, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 6.947440147399902, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 6.06493616104126, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 7.14630126953125, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 14.731822967529297, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": -5.351778507232666, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 17.632570266723633, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 15.330568313598633, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 5.837926864624023, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 5.051054000854492, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 2.8629238605499268, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 13.25622844696045, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 6.890820503234863, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 17.45374870300293, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 4.656808853149414, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 5.447736740112305, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 10.446636199951172, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 17.325050354003906, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 4.206713676452637, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 9.519606590270996, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 4.474648952484131, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 8.139266014099121, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 9.792088508605957, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 7.3324737548828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 9.299038887023926, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 21.717971801757812, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": -3.0196897983551025, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 2.3027780055999756, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 16.383344650268555, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 5.840900421142578, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 16.744478225708008, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 1.3772361278533936, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 16.889774322509766, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 3.7015507221221924, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 8.963178634643555, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 23.01374626159668, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 28.747516632080078, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 3.696038246154785, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 18.486228942871094, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 9.797303199768066, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 3.586526393890381, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 6.628138542175293, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 5.736710071563721, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 18.295204162597656, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 4.394664764404297, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 10.175525665283203, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 8.979989051818848, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 12.775808334350586, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 15.53598690032959, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 10.567465782165527, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 6.854046821594238, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 9.789966583251953, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 8.406659126281738, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 9.414752006530762, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 8.134831428527832, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 5.053690433502197, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 12.37542724609375, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 19.121780395507812, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 8.219120025634766, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": -4.113567352294922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 12.86084270477295, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 6.4124274253845215, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 14.1568603515625, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 6.179751873016357, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 6.407765865325928, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 4.514246940612793, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 9.066909790039062, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 8.447477340698242, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": -0.7427571415901184, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 2.9169552326202393, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 5.465841770172119, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 7.129478454589844, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 7.043885707855225, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 18.49075698852539, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 5.5466132164001465, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 9.107548713684082, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": -0.9509438872337341, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 8.018399238586426, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 16.792940139770508, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 15.597270965576172, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 12.17685604095459, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 11.676979064941406, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 13.785839080810547, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 1.019270896911621, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": -0.9723620414733887, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 15.839048385620117, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 15.420255661010742, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 8.705223083496094, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 8.651837348937988, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.884833335876465, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 18.371557235717773, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 19.368759155273438, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 21.158721923828125, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 21.188085556030273, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 9.712406158447266, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 3.391413450241089, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 9.882966995239258, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 6.421112537384033, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 10.008955955505371, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": -3.7429559230804443, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 9.174446105957031, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 3.8171348571777344, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": -7.909400939941406, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 23.378190994262695, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 22.460115432739258, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 14.530881881713867, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 17.945173263549805, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 11.54576587677002, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.558603286743164, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 10.420690536499023, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 7.529940605163574, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.042562961578369, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 10.79625129699707, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 17.17136001586914, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 3.307905673980713, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 10.444380760192871, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 11.840070724487305, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 7.593770503997803, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 13.43736457824707, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 2.7093143463134766, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 7.846211910247803, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 9.694792747497559, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 13.173310279846191, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 11.132068634033203, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 12.776078224182129, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 12.271164894104004, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 8.114533424377441, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 10.828557014465332, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 13.942134857177734, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 13.534577369689941, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 9.729780197143555, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 8.994977951049805, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 10.113740921020508, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 6.392364501953125, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 9.727726936340332, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 17.571500778198242, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 18.674175262451172, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 9.110492706298828, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 7.621195316314697, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 21.381479263305664, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 15.83483600616455, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 15.66517448425293, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 12.354133605957031, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 18.962139129638672, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 18.399394989013672, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 9.42381477355957, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 12.00529956817627, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 14.56803035736084, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 12.271184921264648, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 12.291250228881836, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 12.071014404296875, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 15.146749496459961, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 17.343830108642578, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": -1.333060622215271, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 4.346193313598633, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 8.044883728027344, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 8.11178970336914, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 10.069868087768555, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 11.644989013671875, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 16.928489685058594, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 4.277830600738525, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 11.038383483886719, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 5.344930171966553, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 1.1706016063690186, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 6.807243347167969, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 3.9913034439086914, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 4.187417984008789, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 3.5455243587493896, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 8.3716459274292, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 8.537477493286133, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 14.718498229980469, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 16.58214569091797, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 14.316944122314453, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 9.237370491027832, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 8.002992630004883, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 6.624277114868164, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 4.020396709442139, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 11.198153495788574, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 9.070198059082031, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 8.491692543029785, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 17.469974517822266, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 11.335356712341309, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 17.74886703491211, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 9.17672348022461, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 13.998625755310059, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 8.742243766784668, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 2.12756609916687, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 17.68233871459961, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 4.9308319091796875, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 12.931241035461426, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 1.631303071975708, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 3.1112074851989746, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 10.88212776184082, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 10.226880073547363, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 3.8558602333068848, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 5.853753089904785, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 5.873215198516846, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 10.582910537719727, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 15.885552406311035, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 15.327390670776367, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 15.514052391052246, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 7.55764102935791, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 18.369102478027344, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 5.824795722961426, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 15.2969970703125, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 10.23908519744873, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 8.089719772338867, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 8.985725402832031, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 9.877602577209473, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 2.4321155548095703, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 3.6842031478881836, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 3.603825807571411, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 14.202850341796875, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 1.3368322849273682, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 14.970987319946289, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 15.470149040222168, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 8.07016658782959, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 9.706025123596191, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.609657287597656, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 8.33421516418457, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 8.960545539855957, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 8.190251350402832, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 5.345642566680908, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 16.278417587280273, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 9.505990028381348, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.281876564025879, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 15.586712837219238, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 19.380855560302734, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 22.9998722076416, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 21.67023277282715, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 7.986322402954102, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 7.836185932159424, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 13.142619132995605, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 5.911583423614502, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 6.9293131828308105, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 5.969613075256348, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 7.467096328735352, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 16.103960037231445, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 16.114681243896484, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 13.09213924407959, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 13.893994331359863, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 8.880234718322754, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 9.530762672424316, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 6.0966315269470215, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 4.595323085784912, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 2.449854612350464, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": -0.11971868574619293, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": -0.2585868835449219, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": -0.2848990857601166, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 3.782630681991577, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 3.4688425064086914, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 5.765459060668945, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 6.903364181518555, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 4.840702056884766, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 7.454947471618652, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 11.113530158996582, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 10.848203659057617, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 17.729427337646484, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 11.753292083740234, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 9.986661911010742, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": -7.832437038421631, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": -3.5750222206115723, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 0.8440127968788147, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 15.552513122558594, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 6.221508026123047, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 12.048630714416504, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 2.756791114807129, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 10.313526153564453, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 11.103602409362793, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 11.494327545166016, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": -3.0313894748687744, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": -1.2790906429290771, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": -2.8456315994262695, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 1.3038175106048584, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 10.289814949035645, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 10.481236457824707, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 7.539891719818115, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 9.063453674316406, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 5.2259440422058105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 7.041718006134033, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 6.661810874938965, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 4.747824192047119, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 8.413098335266113, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 16.330535888671875, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 1.163423776626587, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 16.63500213623047, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 14.909673690795898, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 6.084036350250244, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 5.330334663391113, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 10.525945663452148, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 6.898045063018799, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 4.190566062927246, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 2.7932097911834717, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 11.941429138183594, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 14.172198295593262, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 11.211122512817383, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 11.090378761291504, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 7.951909065246582, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 7.437392234802246, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 12.96187973022461, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 18.34876823425293, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 15.859905242919922, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 15.521785736083984, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 14.366753578186035, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 16.387638092041016, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 19.00131607055664, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 17.261402130126953, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 20.201961517333984, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 14.736574172973633, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 8.490274429321289, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 19.20979118347168, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 14.432631492614746, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 12.758526802062988, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 10.280341148376465, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 3.8434054851531982, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 4.33111572265625, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 12.005300521850586, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 13.142613410949707, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 16.458255767822266, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 7.13403844833374, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 11.828633308410645, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 21.70359992980957, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 1.3618173599243164, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 12.378552436828613, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 15.441965103149414, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 2.402390241622925, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 6.716982841491699, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 4.186927795410156, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 10.02583122253418, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 11.852301597595215, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 16.920223236083984, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 9.352701187133789, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 12.044156074523926, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 3.900907516479492, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 9.73930835723877, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 5.769766807556152, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 11.501866340637207, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 10.019037246704102, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 8.516297340393066, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 11.029529571533203, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.796485424041748, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 4.365727424621582, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.171832084655762, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 11.5953369140625, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 9.907891273498535, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 11.074311256408691, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 16.388078689575195, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 10.061064720153809, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 6.634213447570801, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 13.056344985961914, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 9.078526496887207, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 6.434875965118408, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 12.41024398803711, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 12.15449047088623, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 12.135732650756836, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 11.424830436706543, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 6.585651397705078, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 11.337423324584961, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 5.740451335906982, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 8.813603401184082, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 13.212648391723633, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 8.048795700073242, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 13.886929512023926, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 12.967419624328613, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 10.155488014221191, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 10.331839561462402, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 9.788475036621094, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 9.635385513305664, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 1.454776644706726, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 24.48976707458496, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 10.624290466308594, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 0.38632020354270935, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 5.080892086029053, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 8.836256980895996, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 10.883007049560547, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 2.214138984680176, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 0.55355304479599, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 11.85208797454834, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 15.452204704284668, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 15.978493690490723, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 17.14012908935547, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 19.22150993347168, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 6.54447603225708, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 11.839815139770508, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 9.87878704071045, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 11.059840202331543, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 13.870463371276855, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 6.411136627197266, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 10.61187744140625, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": -1.4397786855697632, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 6.009209632873535, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 6.391894817352295, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 7.629478931427002, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 17.496248245239258, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 0.5062999725341797, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 19.641016006469727, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": -0.46578502655029297, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 2.3438477516174316, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 5.278593063354492, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 11.609603881835938, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 10.233970642089844, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 5.613235950469971, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 5.573513031005859, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 13.94971752166748, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 1.6410958766937256, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 11.310317039489746, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 15.228354454040527, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 18.357946395874023, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 8.508772850036621, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 7.611819267272949, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 6.46488094329834, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 15.272871971130371, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 8.657197952270508, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 9.182524681091309, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 2.5536835193634033, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 7.748277187347412, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": -0.5391780734062195, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 5.00656270980835, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 15.768522262573242, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 16.949798583984375, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 11.616355895996094, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 5.791330337524414, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 24.58285903930664, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 3.07306170463562, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 8.841790199279785, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 6.011405944824219, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 16.98671531677246, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 4.259638786315918, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 15.975602149963379, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 7.204800605773926, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 8.972975730895996, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 7.0830559730529785, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 13.438091278076172, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 13.647506713867188, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 10.081512451171875, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 5.370123386383057, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 4.815537929534912, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 9.213953971862793, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 10.0669527053833, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 4.305802822113037, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 11.277573585510254, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 6.878101825714111, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 18.96354866027832, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 5.82699728012085, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 5.001354694366455, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 15.142876625061035, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 12.358677864074707, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 14.71912956237793, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 12.808987617492676, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.95818042755127, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 13.814603805541992, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 10.320548057556152, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 8.806737899780273, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 6.535454273223877, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 7.609572887420654, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 0.3184982240200043, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 14.00516128540039, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 11.082520484924316, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 13.876301765441895, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 11.884879112243652, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 2.0137856006622314, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 14.816924095153809, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 12.356063842773438, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 7.032673358917236, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 16.042600631713867, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 14.192509651184082, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 4.965102672576904, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 5.56322717666626, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 12.508365631103516, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 5.104037761688232, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 12.051085472106934, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 11.058951377868652, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 8.062950134277344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 6.636124610900879, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 5.17345666885376, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 10.239788055419922, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 8.55694580078125, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 15.09982681274414, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 8.833052635192871, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 20.978830337524414, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 6.275857448577881, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 16.890836715698242, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 23.01714324951172, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 22.67757225036621, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 20.975807189941406, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 2.482130765914917, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 10.07733154296875, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 13.909623146057129, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 1.9945781230926514, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 14.202008247375488, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 7.961235046386719, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 10.419793128967285, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 5.2984619140625, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 3.3702874183654785, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 8.156440734863281, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 19.221630096435547, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 4.177761077880859, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 0.9088281393051147, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": -9.801112174987793, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": -4.177274227142334, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 6.679325103759766, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 9.05578327178955, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 10.858011245727539, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 18.257614135742188, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 6.315979480743408, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 8.230443954467773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 0.6772663593292236, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 18.805233001708984, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 18.02728843688965, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 12.855727195739746, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 10.447681427001953, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 12.989734649658203, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 10.456489562988281, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 5.5458149909973145, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 640, \"mu_intercept_per_group\": 6.737189769744873, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 641, \"mu_intercept_per_group\": 9.193177223205566, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 642, \"mu_intercept_per_group\": 12.069136619567871, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 643, \"mu_intercept_per_group\": 6.221860408782959, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 644, \"mu_intercept_per_group\": 13.383099555969238, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 645, \"mu_intercept_per_group\": 16.529314041137695, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 646, \"mu_intercept_per_group\": 15.19991397857666, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 647, \"mu_intercept_per_group\": 11.386703491210938, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 648, \"mu_intercept_per_group\": 15.04826545715332, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 649, \"mu_intercept_per_group\": 4.552347660064697, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 650, \"mu_intercept_per_group\": 3.780327558517456, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 651, \"mu_intercept_per_group\": 5.112100601196289, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 652, \"mu_intercept_per_group\": 11.999035835266113, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 653, \"mu_intercept_per_group\": 13.317060470581055, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 654, \"mu_intercept_per_group\": 7.893313407897949, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 655, \"mu_intercept_per_group\": 12.060137748718262, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 656, \"mu_intercept_per_group\": 9.420783042907715, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 657, \"mu_intercept_per_group\": 8.989302635192871, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 658, \"mu_intercept_per_group\": 15.081155776977539, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 659, \"mu_intercept_per_group\": 6.784265041351318, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 660, \"mu_intercept_per_group\": 12.24379825592041, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 661, \"mu_intercept_per_group\": 2.469707727432251, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 662, \"mu_intercept_per_group\": 3.566190004348755, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 663, \"mu_intercept_per_group\": 8.301640510559082, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 664, \"mu_intercept_per_group\": 5.845261573791504, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 665, \"mu_intercept_per_group\": 4.558312892913818, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 666, \"mu_intercept_per_group\": 3.4723405838012695, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 667, \"mu_intercept_per_group\": 11.847676277160645, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 668, \"mu_intercept_per_group\": 11.610284805297852, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 669, \"mu_intercept_per_group\": 2.2657830715179443, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 670, \"mu_intercept_per_group\": 10.631192207336426, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 671, \"mu_intercept_per_group\": 13.213122367858887, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 672, \"mu_intercept_per_group\": 13.68525505065918, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 673, \"mu_intercept_per_group\": 10.926741600036621, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 674, \"mu_intercept_per_group\": 14.190625190734863, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 675, \"mu_intercept_per_group\": 5.748699188232422, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 676, \"mu_intercept_per_group\": 14.493550300598145, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 677, \"mu_intercept_per_group\": 10.242263793945312, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 678, \"mu_intercept_per_group\": 9.60313892364502, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 679, \"mu_intercept_per_group\": 16.792964935302734, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 680, \"mu_intercept_per_group\": 13.379315376281738, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 681, \"mu_intercept_per_group\": 1.0710054636001587, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 682, \"mu_intercept_per_group\": 15.035201072692871, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 683, \"mu_intercept_per_group\": -0.387957900762558, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 684, \"mu_intercept_per_group\": 15.181492805480957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 685, \"mu_intercept_per_group\": 16.71505355834961, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 686, \"mu_intercept_per_group\": 11.101946830749512, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 687, \"mu_intercept_per_group\": 12.336786270141602, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 688, \"mu_intercept_per_group\": 6.484126091003418, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 689, \"mu_intercept_per_group\": 15.515594482421875, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 690, \"mu_intercept_per_group\": 7.741927146911621, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 691, \"mu_intercept_per_group\": 17.842140197753906, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 692, \"mu_intercept_per_group\": 11.315420150756836, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 693, \"mu_intercept_per_group\": 16.897253036499023, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 694, \"mu_intercept_per_group\": -1.6949474811553955, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 695, \"mu_intercept_per_group\": -5.276398658752441, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 696, \"mu_intercept_per_group\": 25.23772621154785, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 697, \"mu_intercept_per_group\": 23.200729370117188, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 698, \"mu_intercept_per_group\": 2.4280004501342773, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 699, \"mu_intercept_per_group\": 6.299410343170166, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 700, \"mu_intercept_per_group\": 5.133821964263916, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 701, \"mu_intercept_per_group\": 1.0711069107055664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 702, \"mu_intercept_per_group\": 10.13552188873291, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 703, \"mu_intercept_per_group\": 6.255331039428711, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 704, \"mu_intercept_per_group\": 25.757722854614258, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 705, \"mu_intercept_per_group\": 6.712465763092041, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 706, \"mu_intercept_per_group\": 10.238642692565918, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 707, \"mu_intercept_per_group\": 10.30508041381836, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 708, \"mu_intercept_per_group\": 17.740585327148438, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 709, \"mu_intercept_per_group\": 17.416980743408203, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 710, \"mu_intercept_per_group\": 2.7176008224487305, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 711, \"mu_intercept_per_group\": 9.658129692077637, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 712, \"mu_intercept_per_group\": 20.566896438598633, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 713, \"mu_intercept_per_group\": 15.501233100891113, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 714, \"mu_intercept_per_group\": 9.931512832641602, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 715, \"mu_intercept_per_group\": 4.31850528717041, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 716, \"mu_intercept_per_group\": 8.438852310180664, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 717, \"mu_intercept_per_group\": 5.479158878326416, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 718, \"mu_intercept_per_group\": 13.189408302307129, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 719, \"mu_intercept_per_group\": -0.5001488924026489, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 720, \"mu_intercept_per_group\": 18.273456573486328, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 721, \"mu_intercept_per_group\": 9.747213363647461, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 722, \"mu_intercept_per_group\": 9.510597229003906, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 723, \"mu_intercept_per_group\": 16.200960159301758, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 724, \"mu_intercept_per_group\": 13.500121116638184, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 725, \"mu_intercept_per_group\": 12.953968048095703, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 726, \"mu_intercept_per_group\": 7.8639631271362305, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 727, \"mu_intercept_per_group\": 5.070074081420898, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 728, \"mu_intercept_per_group\": 15.302668571472168, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 729, \"mu_intercept_per_group\": 7.512243270874023, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 730, \"mu_intercept_per_group\": 11.778135299682617, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 731, \"mu_intercept_per_group\": 1.2225472927093506, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 732, \"mu_intercept_per_group\": 6.62372350692749, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 733, \"mu_intercept_per_group\": 5.657873630523682, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 734, \"mu_intercept_per_group\": 5.344048500061035, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 735, \"mu_intercept_per_group\": 8.548877716064453, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 736, \"mu_intercept_per_group\": 9.904463768005371, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 737, \"mu_intercept_per_group\": 19.767704010009766, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 738, \"mu_intercept_per_group\": 10.717267036437988, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 739, \"mu_intercept_per_group\": 10.820258140563965, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 740, \"mu_intercept_per_group\": 2.6831698417663574, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 741, \"mu_intercept_per_group\": 9.101056098937988, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 742, \"mu_intercept_per_group\": 2.4662649631500244, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 743, \"mu_intercept_per_group\": 10.721576690673828, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 744, \"mu_intercept_per_group\": 8.200984001159668, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 745, \"mu_intercept_per_group\": 15.698253631591797, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 746, \"mu_intercept_per_group\": 9.935863494873047, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 747, \"mu_intercept_per_group\": 17.09223175048828, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 748, \"mu_intercept_per_group\": 9.965093612670898, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 749, \"mu_intercept_per_group\": 21.839853286743164, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 750, \"mu_intercept_per_group\": 23.14823341369629, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 751, \"mu_intercept_per_group\": 6.278114318847656, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 752, \"mu_intercept_per_group\": 6.992970943450928, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 753, \"mu_intercept_per_group\": 8.06745433807373, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 754, \"mu_intercept_per_group\": 7.554111957550049, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 755, \"mu_intercept_per_group\": 12.436790466308594, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 756, \"mu_intercept_per_group\": 13.463346481323242, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 757, \"mu_intercept_per_group\": 11.4485445022583, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 758, \"mu_intercept_per_group\": 6.842139720916748, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 759, \"mu_intercept_per_group\": 11.513456344604492, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 760, \"mu_intercept_per_group\": 11.867603302001953, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 6, \"draws\": 761, \"mu_intercept_per_group\": 9.222723007202148, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 6, \"draws\": 762, \"mu_intercept_per_group\": 13.940552711486816, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 6, \"draws\": 763, \"mu_intercept_per_group\": 13.071642875671387, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 6, \"draws\": 764, \"mu_intercept_per_group\": 16.73880958557129, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 6, \"draws\": 765, \"mu_intercept_per_group\": 9.071429252624512, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 6, \"draws\": 766, \"mu_intercept_per_group\": 17.341548919677734, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 6, \"draws\": 767, \"mu_intercept_per_group\": -0.18725790083408356, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 6, \"draws\": 768, \"mu_intercept_per_group\": 1.9522686004638672, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 6, \"draws\": 769, \"mu_intercept_per_group\": 14.188538551330566, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 6, \"draws\": 770, \"mu_intercept_per_group\": 6.566876411437988, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 6, \"draws\": 771, \"mu_intercept_per_group\": 3.8686840534210205, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 6, \"draws\": 772, \"mu_intercept_per_group\": 12.66661262512207, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 6, \"draws\": 773, \"mu_intercept_per_group\": 9.155329704284668, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 6, \"draws\": 774, \"mu_intercept_per_group\": 4.318933963775635, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 6, \"draws\": 775, \"mu_intercept_per_group\": 0.6530895233154297, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 6, \"draws\": 776, \"mu_intercept_per_group\": 19.313690185546875, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 6, \"draws\": 777, \"mu_intercept_per_group\": 11.354860305786133, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 6, \"draws\": 778, \"mu_intercept_per_group\": 8.88536548614502, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 6, \"draws\": 779, \"mu_intercept_per_group\": 13.623076438903809, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 6, \"draws\": 780, \"mu_intercept_per_group\": 8.875946998596191, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 6, \"draws\": 781, \"mu_intercept_per_group\": 17.30560874938965, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 6, \"draws\": 782, \"mu_intercept_per_group\": 14.880852699279785, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 6, \"draws\": 783, \"mu_intercept_per_group\": -0.4047471284866333, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 6, \"draws\": 784, \"mu_intercept_per_group\": 8.562387466430664, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 6, \"draws\": 785, \"mu_intercept_per_group\": 9.902952194213867, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 6, \"draws\": 786, \"mu_intercept_per_group\": 7.32205057144165, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 6, \"draws\": 787, \"mu_intercept_per_group\": 8.498106956481934, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 6, \"draws\": 788, \"mu_intercept_per_group\": 7.786909103393555, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 6, \"draws\": 789, \"mu_intercept_per_group\": 9.666537284851074, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 6, \"draws\": 790, \"mu_intercept_per_group\": 10.754192352294922, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 6, \"draws\": 791, \"mu_intercept_per_group\": 9.705094337463379, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 6, \"draws\": 792, \"mu_intercept_per_group\": 8.534967422485352, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 6, \"draws\": 793, \"mu_intercept_per_group\": 23.202211380004883, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 6, \"draws\": 794, \"mu_intercept_per_group\": 15.786867141723633, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 6, \"draws\": 795, \"mu_intercept_per_group\": 15.403228759765625, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 6, \"draws\": 796, \"mu_intercept_per_group\": 11.287784576416016, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 6, \"draws\": 797, \"mu_intercept_per_group\": 8.130427360534668, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 6, \"draws\": 798, \"mu_intercept_per_group\": 21.378206253051758, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 6, \"draws\": 799, \"mu_intercept_per_group\": 10.32075023651123, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 13.365216255187988, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 15.986224174499512, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 13.506922721862793, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 12.583298683166504, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 13.145959854125977, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 10.314718246459961, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 11.695979118347168, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 1.184268832206726, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 6.262317180633545, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 6.309609889984131, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 21.440279006958008, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 17.677780151367188, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 7.256966590881348, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 19.48111343383789, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 15.224678039550781, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 16.807680130004883, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 17.123653411865234, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 15.230988502502441, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 15.25283432006836, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 4.390932559967041, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 20.541927337646484, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 18.01485252380371, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 10.836176872253418, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 1.6970674991607666, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 15.565256118774414, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 6.240877628326416, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 4.461719512939453, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 21.099756240844727, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 12.546746253967285, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 8.020142555236816, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 6.100507736206055, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 8.693058967590332, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 5.853026390075684, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 8.21872329711914, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 6.160982608795166, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 9.93838119506836, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 7.362545967102051, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 13.141714096069336, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 10.554520606994629, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 10.737625122070312, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 6.138772964477539, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 11.563729286193848, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 15.39007568359375, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 18.455303192138672, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 20.07542610168457, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 21.19367790222168, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 24.960893630981445, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 24.519468307495117, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 0.24309951066970825, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 0.8245984315872192, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 5.754743576049805, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 15.474645614624023, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 14.499691009521484, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 15.87287712097168, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 9.5660982131958, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 11.276510238647461, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 9.343570709228516, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 14.340816497802734, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 10.232099533081055, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 11.092317581176758, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 8.64330768585205, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 6.819952487945557, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 10.860028266906738, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 8.841946601867676, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 29.787004470825195, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 27.973697662353516, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 25.696727752685547, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 22.549034118652344, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 22.398578643798828, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 2.423912763595581, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 12.322992324829102, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 22.30177879333496, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 5.9411940574646, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 12.70667552947998, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 6.396772384643555, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 15.689356803894043, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 13.98384952545166, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 11.223548889160156, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 9.327942848205566, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 9.253957748413086, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 14.580586433410645, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 11.812888145446777, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 6.036093235015869, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 9.360658645629883, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 13.683189392089844, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 3.668138027191162, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 20.079404830932617, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 19.732669830322266, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": -7.2844624519348145, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 19.907825469970703, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 17.325971603393555, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 16.28411865234375, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 10.153678894042969, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 28.808917999267578, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 4.39420223236084, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 4.0098161697387695, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 20.725873947143555, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 5.349339485168457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 13.390400886535645, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 25.936500549316406, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 27.692113876342773, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 0.6892843246459961, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 7.705946922302246, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 8.074809074401855, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 8.449516296386719, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 10.009151458740234, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 13.588265419006348, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 8.753445625305176, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 7.985311985015869, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 7.765178680419922, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 12.855842590332031, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 5.831816673278809, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 19.002710342407227, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 7.596777439117432, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 18.083946228027344, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 18.949031829833984, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 16.835479736328125, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 3.3367068767547607, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 8.004900932312012, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 8.072371482849121, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 9.917716026306152, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 9.116827964782715, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 7.921419143676758, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 6.825031280517578, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 6.757511615753174, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 11.041048049926758, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 13.748991012573242, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 5.216953754425049, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 7.218094825744629, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 4.133030891418457, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 8.278654098510742, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 10.353484153747559, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 8.205766677856445, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 9.113909721374512, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 13.435678482055664, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 7.472805500030518, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 6.2927374839782715, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 12.961935997009277, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 13.134321212768555, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 3.311103582382202, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 20.138322830200195, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 15.088541030883789, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 7.937490463256836, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 24.575151443481445, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 1.3120315074920654, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 8.991385459899902, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 7.200927734375, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 9.841200828552246, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 8.015582084655762, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 8.205357551574707, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 13.542074203491211, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 11.515954971313477, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 16.647682189941406, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 15.563435554504395, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 2.6132571697235107, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 25.538162231445312, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 5.821999549865723, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 16.785518646240234, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 13.999275207519531, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 15.952714920043945, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 21.79082489013672, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 13.224407196044922, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 13.463597297668457, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 17.405467987060547, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 15.356319427490234, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 10.860158920288086, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 11.327224731445312, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 12.218438148498535, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 7.225792407989502, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 15.116665840148926, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 12.125268936157227, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 20.32888412475586, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 11.944461822509766, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 19.531972885131836, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 15.50171947479248, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 14.030842781066895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 8.110709190368652, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 11.908056259155273, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 6.210599422454834, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 11.965696334838867, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 8.917381286621094, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 7.367876052856445, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 20.438995361328125, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 8.617547035217285, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 12.958555221557617, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 14.83244514465332, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 18.258625030517578, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 8.951822280883789, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 11.939066886901855, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 15.721117973327637, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 16.21558952331543, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 15.323904991149902, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 17.336997985839844, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 11.583391189575195, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 11.544178009033203, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 7.748281002044678, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 9.992754936218262, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 4.86784029006958, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 4.973636627197266, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 21.17041015625, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 8.69924545288086, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.4944429397583, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 8.063563346862793, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 7.062926769256592, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 19.731889724731445, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 18.291259765625, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 8.747230529785156, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 18.810197830200195, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 15.205920219421387, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 11.039413452148438, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 12.377477645874023, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 11.87043285369873, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 14.266119956970215, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 4.876817226409912, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 4.9253435134887695, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 16.296428680419922, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 9.956404685974121, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 27.900943756103516, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 19.01661491394043, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 19.096683502197266, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 8.70776081085205, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 6.189742088317871, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 10.95691967010498, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 14.771323204040527, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 9.063048362731934, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 3.1430015563964844, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 18.078941345214844, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 23.35120964050293, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 25.607166290283203, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 4.532476425170898, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 8.57311725616455, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 9.384215354919434, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 18.20131492614746, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 16.084205627441406, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 12.738502502441406, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 11.328948020935059, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 10.262983322143555, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 4.377212047576904, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 17.15158462524414, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 17.101268768310547, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 10.145792007446289, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.732828140258789, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 11.779470443725586, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 16.50186538696289, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 10.43493938446045, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 11.151856422424316, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 16.47918701171875, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 12.971174240112305, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 13.91413688659668, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 15.176945686340332, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 7.0839128494262695, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 7.607177257537842, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 11.361753463745117, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 3.4405832290649414, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 11.53730583190918, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 12.28682804107666, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 10.009668350219727, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 8.554157257080078, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 21.14964485168457, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 12.436086654663086, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 11.749343872070312, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 21.76825523376465, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 22.942338943481445, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 9.235554695129395, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 6.003686904907227, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 9.031157493591309, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 8.527295112609863, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 14.437241554260254, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 19.985258102416992, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 13.9501953125, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 16.466049194335938, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.188323020935059, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 3.650052785873413, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": -0.5641259551048279, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 6.5888471603393555, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 11.593375205993652, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 12.203052520751953, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 8.825818061828613, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 3.8262438774108887, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 19.703861236572266, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 13.764286994934082, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 18.42430305480957, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 22.307876586914062, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 4.6359429359436035, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 20.210790634155273, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 8.959261894226074, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 11.98414421081543, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 7.425361633300781, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 9.654972076416016, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 9.502685546875, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 6.0089263916015625, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 0.37518641352653503, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 8.947497367858887, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 1.1788791418075562, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 13.108702659606934, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 15.722833633422852, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 17.616113662719727, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 18.214561462402344, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 18.49821662902832, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 15.843475341796875, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 12.071490287780762, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 7.961061954498291, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 7.763580322265625, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 8.794839859008789, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 8.805477142333984, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 15.065488815307617, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 19.071840286254883, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 15.21051025390625, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 17.50092315673828, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 10.562623023986816, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 12.626243591308594, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.377864837646484, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 3.399231433868408, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 19.375444412231445, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 6.916561603546143, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 11.265032768249512, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 7.75400972366333, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 8.189379692077637, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 14.990594863891602, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 11.744601249694824, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 15.621774673461914, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 14.313191413879395, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 13.430397033691406, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 13.630142211914062, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 3.9672305583953857, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 20.56456756591797, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 17.591711044311523, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 10.485973358154297, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 15.693488121032715, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 15.7683744430542, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 8.538536071777344, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 7.237646579742432, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 11.395334243774414, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 18.211868286132812, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": -3.2171363830566406, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 9.60183334350586, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 9.18093490600586, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 10.53969955444336, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 14.215615272521973, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 14.209391593933105, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 12.1614990234375, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 15.070243835449219, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.062638282775879, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 13.224609375, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 12.972430229187012, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 12.639427185058594, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 15.804996490478516, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 10.741495132446289, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 15.48204517364502, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 18.317256927490234, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 9.277792930603027, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 16.801820755004883, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 13.283445358276367, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 28.56692886352539, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 18.216144561767578, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 15.145745277404785, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 18.28443717956543, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 4.058918476104736, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 21.306411743164062, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 8.525124549865723, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 8.66665267944336, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 8.395552635192871, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 9.192790985107422, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 19.66211700439453, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 12.06894302368164, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 21.557912826538086, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 16.0334529876709, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 9.502646446228027, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": -7.473568439483643, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 27.26302146911621, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 5.679250717163086, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 3.9864566326141357, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 4.962776184082031, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 5.602456092834473, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 3.574613571166992, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 6.0953803062438965, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 4.117492198944092, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 4.3790388107299805, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 12.84201431274414, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 12.414887428283691, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 10.326018333435059, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 15.752734184265137, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 6.478569984436035, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 25.24509620666504, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 15.745749473571777, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 19.16963768005371, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 9.519261360168457, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 4.866501808166504, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 5.31254243850708, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 13.689255714416504, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 14.95084285736084, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 13.250029563903809, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 10.449140548706055, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 12.422623634338379, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 14.220320701599121, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 13.78234577178955, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 8.764466285705566, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 17.219280242919922, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 18.36520004272461, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 15.676915168762207, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 13.910944938659668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 14.644582748413086, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 11.859487533569336, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 12.685654640197754, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 5.6109538078308105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 5.270198345184326, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 14.604692459106445, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 13.351242065429688, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 14.131821632385254, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 11.933043479919434, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 9.581589698791504, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 11.551580429077148, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 13.48715877532959, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 17.530794143676758, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 23.088489532470703, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 10.952017784118652, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 7.797173023223877, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 7.918060779571533, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 3.837857961654663, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 14.90882682800293, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.232527732849121, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 11.916237831115723, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 11.307418823242188, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 10.764622688293457, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 12.162664413452148, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 11.911325454711914, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 6.723698616027832, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 18.798871994018555, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 20.45260238647461, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 12.415254592895508, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 11.33404541015625, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 16.511070251464844, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 22.255979537963867, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 7.811313629150391, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 9.574859619140625, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 16.238346099853516, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 16.363250732421875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 22.377403259277344, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 23.27312469482422, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 7.275153636932373, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 12.187787055969238, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 13.263769149780273, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 19.850170135498047, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 10.637458801269531, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 21.424161911010742, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 2.3877055644989014, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 17.00070571899414, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 16.119211196899414, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 4.714224338531494, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 9.48280143737793, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 11.932138442993164, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 11.462850570678711, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 4.972246170043945, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 11.98072624206543, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 17.432313919067383, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 24.201007843017578, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 1.2842515707015991, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 17.438961029052734, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.19468879699707, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 8.123538970947266, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 9.121965408325195, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 9.764420509338379, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 15.511746406555176, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 16.831241607666016, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 14.679157257080078, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 15.384532928466797, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 12.670796394348145, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 14.077652931213379, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 9.785552978515625, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 20.56226921081543, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 13.46574878692627, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 9.305739402770996, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 5.643798828125, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 10.33972454071045, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 14.556548118591309, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 24.412067413330078, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 8.456341743469238, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 17.468503952026367, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 12.381575584411621, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 18.401273727416992, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 20.803680419921875, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 16.706371307373047, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 7.785616874694824, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 5.340003490447998, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 5.669518947601318, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 11.059185981750488, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 16.556629180908203, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 16.046810150146484, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 21.35782814025879, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 12.369587898254395, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 15.511539459228516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 5.071626663208008, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 15.501636505126953, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 7.410902500152588, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 18.73247718811035, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 16.048852920532227, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 18.88574981689453, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 10.08126449584961, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 15.35366153717041, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 11.917501449584961, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 9.132963180541992, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 10.450651168823242, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 13.810266494750977, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 2.6890766620635986, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": -1.9913395643234253, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": -0.07536953687667847, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 10.385358810424805, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 13.682313919067383, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 8.612662315368652, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 21.080904006958008, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 2.9666049480438232, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 8.247576713562012, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 5.297784328460693, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 10.691640853881836, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 11.432547569274902, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 3.5715322494506836, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 8.139065742492676, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 7.719079971313477, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 10.299744606018066, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 10.130926132202148, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 11.452608108520508, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 10.793584823608398, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 8.838262557983398, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 7.482108116149902, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 11.77778148651123, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 5.817020893096924, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 13.539782524108887, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 2.742051601409912, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 2.0724174976348877, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": -3.768800735473633, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 21.81544303894043, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 4.7506608963012695, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 19.60413360595703, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 11.72191333770752, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 8.40286636352539, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 7.327067852020264, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 9.15285587310791, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 14.349908828735352, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 8.631303787231445, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 11.943130493164062, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 10.730412483215332, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 16.227359771728516, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 8.550874710083008, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 11.79819107055664, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 14.002288818359375, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 16.46881675720215, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 11.568902015686035, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 17.494281768798828, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 14.894147872924805, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 1.7984572649002075, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 12.85037899017334, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 8.293396949768066, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 18.77876853942871, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 6.6899333000183105, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 11.464505195617676, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 19.049238204956055, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 5.571662902832031, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 6.56072998046875, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 19.446683883666992, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 15.765954971313477, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 12.330999374389648, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 9.6436128616333, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 9.47997760772705, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 10.60527515411377, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.060279846191406, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 9.786256790161133, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 15.614481925964355, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 12.415962219238281, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 16.422975540161133, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 20.262948989868164, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 17.315725326538086, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 8.132803916931152, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 21.46075439453125, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 9.42358684539795, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 19.435306549072266, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 14.325714111328125, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 14.777213096618652, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 22.450634002685547, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 9.621647834777832, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 14.37435245513916, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 18.603113174438477, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 16.760051727294922, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 7.971218585968018, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 20.94237518310547, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 7.376929759979248, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 10.206183433532715, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 11.28425407409668, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 15.896408081054688, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 15.541982650756836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 8.340100288391113, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 17.229333877563477, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 17.312515258789062, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 9.402052879333496, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 8.678874969482422, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 9.498290061950684, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 11.953205108642578, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 10.073935508728027, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 16.469165802001953, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 15.24312686920166, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 17.935504913330078, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 9.6416015625, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 18.07929801940918, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 18.751453399658203, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 9.810301780700684, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 11.524846076965332, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.80354881286621, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 8.866294860839844, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 16.29786491394043, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 17.726667404174805, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 14.024088859558105, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 13.828648567199707, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 24.777212142944336, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 21.65932273864746, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 19.464895248413086, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 4.741896629333496, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 16.82868003845215, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.196017265319824, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 17.72896957397461, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 16.28904151916504, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 16.36051368713379, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 20.730735778808594, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 10.248053550720215, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 13.69138240814209, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 15.790809631347656, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 10.307531356811523, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 7.823513507843018, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 18.52081871032715, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 14.538589477539062, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 13.096989631652832, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 18.64503288269043, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 11.959044456481934, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 6.970203399658203, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 9.345170974731445, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 2.3109419345855713, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 3.450174331665039, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 1.402164101600647, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 19.996816635131836, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 5.368474006652832, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 8.667400360107422, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 8.736454963684082, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 640, \"mu_intercept_per_group\": 6.383976936340332, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 641, \"mu_intercept_per_group\": 17.02939796447754, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 642, \"mu_intercept_per_group\": 15.558263778686523, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 643, \"mu_intercept_per_group\": 11.166762351989746, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 644, \"mu_intercept_per_group\": 17.25875473022461, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 645, \"mu_intercept_per_group\": 10.982369422912598, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 646, \"mu_intercept_per_group\": 9.999495506286621, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 647, \"mu_intercept_per_group\": 6.820811748504639, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 648, \"mu_intercept_per_group\": 10.358931541442871, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 649, \"mu_intercept_per_group\": 23.390565872192383, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 650, \"mu_intercept_per_group\": 23.66953468322754, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 651, \"mu_intercept_per_group\": 24.429710388183594, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 652, \"mu_intercept_per_group\": 0.06105119735002518, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 653, \"mu_intercept_per_group\": 2.505930185317993, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 654, \"mu_intercept_per_group\": 11.448205947875977, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 655, \"mu_intercept_per_group\": 7.88395357131958, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 656, \"mu_intercept_per_group\": 14.944862365722656, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 657, \"mu_intercept_per_group\": 9.908576011657715, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 658, \"mu_intercept_per_group\": 8.306763648986816, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 659, \"mu_intercept_per_group\": 2.9190523624420166, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 660, \"mu_intercept_per_group\": 11.979454040527344, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 661, \"mu_intercept_per_group\": 8.05868911743164, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 662, \"mu_intercept_per_group\": 7.530640602111816, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 663, \"mu_intercept_per_group\": 9.62185001373291, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 664, \"mu_intercept_per_group\": 7.768664836883545, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 665, \"mu_intercept_per_group\": 7.691366672515869, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 666, \"mu_intercept_per_group\": 6.324993133544922, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 667, \"mu_intercept_per_group\": 15.22071361541748, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 668, \"mu_intercept_per_group\": 4.694248199462891, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 669, \"mu_intercept_per_group\": 5.925929069519043, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 670, \"mu_intercept_per_group\": 12.40772819519043, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 671, \"mu_intercept_per_group\": 6.877628326416016, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 672, \"mu_intercept_per_group\": 20.603790283203125, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 673, \"mu_intercept_per_group\": 20.2160587310791, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 674, \"mu_intercept_per_group\": 10.677534103393555, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 675, \"mu_intercept_per_group\": 9.891088485717773, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 676, \"mu_intercept_per_group\": 14.76111888885498, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 677, \"mu_intercept_per_group\": 5.17296028137207, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 678, \"mu_intercept_per_group\": 21.503398895263672, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 679, \"mu_intercept_per_group\": 13.5818452835083, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 680, \"mu_intercept_per_group\": 11.979031562805176, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 681, \"mu_intercept_per_group\": 13.752204895019531, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 682, \"mu_intercept_per_group\": 6.729361534118652, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 683, \"mu_intercept_per_group\": 14.156052589416504, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 684, \"mu_intercept_per_group\": 12.361424446105957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 685, \"mu_intercept_per_group\": 10.60273551940918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 686, \"mu_intercept_per_group\": 17.63189125061035, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 687, \"mu_intercept_per_group\": 17.9906005859375, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 688, \"mu_intercept_per_group\": 17.58872413635254, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 689, \"mu_intercept_per_group\": 10.29228687286377, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 690, \"mu_intercept_per_group\": 16.375364303588867, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 691, \"mu_intercept_per_group\": 11.047507286071777, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 692, \"mu_intercept_per_group\": 14.359484672546387, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 693, \"mu_intercept_per_group\": 13.661771774291992, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 694, \"mu_intercept_per_group\": 18.88800621032715, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 695, \"mu_intercept_per_group\": 17.933658599853516, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 696, \"mu_intercept_per_group\": 14.136847496032715, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 697, \"mu_intercept_per_group\": 14.391809463500977, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 698, \"mu_intercept_per_group\": 9.188444137573242, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 699, \"mu_intercept_per_group\": 2.5345370769500732, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 700, \"mu_intercept_per_group\": -1.8914897441864014, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 701, \"mu_intercept_per_group\": 11.63975715637207, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 702, \"mu_intercept_per_group\": 12.190738677978516, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 703, \"mu_intercept_per_group\": 13.46512222290039, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 704, \"mu_intercept_per_group\": 14.594451904296875, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 705, \"mu_intercept_per_group\": 26.660480499267578, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 706, \"mu_intercept_per_group\": -1.8297244310379028, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 707, \"mu_intercept_per_group\": 18.88283920288086, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 708, \"mu_intercept_per_group\": 13.798812866210938, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 709, \"mu_intercept_per_group\": 6.7603912353515625, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 710, \"mu_intercept_per_group\": 26.519031524658203, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 711, \"mu_intercept_per_group\": 9.139301300048828, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 712, \"mu_intercept_per_group\": 23.089824676513672, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 713, \"mu_intercept_per_group\": 17.76047134399414, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 714, \"mu_intercept_per_group\": 6.20468807220459, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 715, \"mu_intercept_per_group\": 10.100860595703125, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 716, \"mu_intercept_per_group\": 7.2865166664123535, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 717, \"mu_intercept_per_group\": 20.1359806060791, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 718, \"mu_intercept_per_group\": 10.927922248840332, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 719, \"mu_intercept_per_group\": 9.282352447509766, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 720, \"mu_intercept_per_group\": 10.734169006347656, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 721, \"mu_intercept_per_group\": 8.391326904296875, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 722, \"mu_intercept_per_group\": 12.880885124206543, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 723, \"mu_intercept_per_group\": 12.003371238708496, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 724, \"mu_intercept_per_group\": 14.61378002166748, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 725, \"mu_intercept_per_group\": 12.166694641113281, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 726, \"mu_intercept_per_group\": 15.044477462768555, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 727, \"mu_intercept_per_group\": 10.959748268127441, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 728, \"mu_intercept_per_group\": 14.52094554901123, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 729, \"mu_intercept_per_group\": 8.486616134643555, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 730, \"mu_intercept_per_group\": 15.75002384185791, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 731, \"mu_intercept_per_group\": 14.097485542297363, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 732, \"mu_intercept_per_group\": 2.0235254764556885, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 733, \"mu_intercept_per_group\": 3.8014142513275146, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 734, \"mu_intercept_per_group\": -0.5554197430610657, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 735, \"mu_intercept_per_group\": 17.080961227416992, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 736, \"mu_intercept_per_group\": 5.849990367889404, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 737, \"mu_intercept_per_group\": 19.19090461730957, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 738, \"mu_intercept_per_group\": 10.918693542480469, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 739, \"mu_intercept_per_group\": 13.553671836853027, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 740, \"mu_intercept_per_group\": 4.7978081703186035, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 741, \"mu_intercept_per_group\": 9.526103019714355, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 742, \"mu_intercept_per_group\": 6.554520130157471, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 743, \"mu_intercept_per_group\": 12.684871673583984, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 744, \"mu_intercept_per_group\": 9.742919921875, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 745, \"mu_intercept_per_group\": 19.76345443725586, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 746, \"mu_intercept_per_group\": 10.143475532531738, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 747, \"mu_intercept_per_group\": 17.446884155273438, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 748, \"mu_intercept_per_group\": 18.710128784179688, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 749, \"mu_intercept_per_group\": 14.642775535583496, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 750, \"mu_intercept_per_group\": 19.100881576538086, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 751, \"mu_intercept_per_group\": 8.402298927307129, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 752, \"mu_intercept_per_group\": 10.15411376953125, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 753, \"mu_intercept_per_group\": 6.538330554962158, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 754, \"mu_intercept_per_group\": 12.712666511535645, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 755, \"mu_intercept_per_group\": 7.455203533172607, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 756, \"mu_intercept_per_group\": 3.2716078758239746, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 757, \"mu_intercept_per_group\": 4.844691276550293, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 758, \"mu_intercept_per_group\": 17.15043067932129, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 759, \"mu_intercept_per_group\": 9.833940505981445, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 760, \"mu_intercept_per_group\": 8.629639625549316, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 7, \"draws\": 761, \"mu_intercept_per_group\": 8.8025541305542, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 7, \"draws\": 762, \"mu_intercept_per_group\": 13.855545043945312, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 7, \"draws\": 763, \"mu_intercept_per_group\": 17.514272689819336, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 7, \"draws\": 764, \"mu_intercept_per_group\": 14.950531959533691, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 7, \"draws\": 765, \"mu_intercept_per_group\": 15.36071491241455, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 7, \"draws\": 766, \"mu_intercept_per_group\": 17.131275177001953, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 7, \"draws\": 767, \"mu_intercept_per_group\": 6.334132671356201, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 7, \"draws\": 768, \"mu_intercept_per_group\": 4.500664234161377, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 7, \"draws\": 769, \"mu_intercept_per_group\": 31.4747314453125, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 7, \"draws\": 770, \"mu_intercept_per_group\": 5.083420753479004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 7, \"draws\": 771, \"mu_intercept_per_group\": 6.722559928894043, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 7, \"draws\": 772, \"mu_intercept_per_group\": 9.143126487731934, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 7, \"draws\": 773, \"mu_intercept_per_group\": 18.33839988708496, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 7, \"draws\": 774, \"mu_intercept_per_group\": 1.0376254320144653, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 7, \"draws\": 775, \"mu_intercept_per_group\": 24.4460391998291, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 7, \"draws\": 776, \"mu_intercept_per_group\": 3.071709394454956, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 7, \"draws\": 777, \"mu_intercept_per_group\": 11.179348945617676, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 7, \"draws\": 778, \"mu_intercept_per_group\": 11.647317886352539, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 7, \"draws\": 779, \"mu_intercept_per_group\": 11.261837005615234, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 7, \"draws\": 780, \"mu_intercept_per_group\": 14.204532623291016, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 7, \"draws\": 781, \"mu_intercept_per_group\": 10.796290397644043, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 7, \"draws\": 782, \"mu_intercept_per_group\": 12.963516235351562, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 7, \"draws\": 783, \"mu_intercept_per_group\": 6.624403953552246, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 7, \"draws\": 784, \"mu_intercept_per_group\": 20.135610580444336, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 7, \"draws\": 785, \"mu_intercept_per_group\": 11.501521110534668, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 7, \"draws\": 786, \"mu_intercept_per_group\": 9.679304122924805, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 7, \"draws\": 787, \"mu_intercept_per_group\": 9.904572486877441, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 7, \"draws\": 788, \"mu_intercept_per_group\": 11.821760177612305, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 7, \"draws\": 789, \"mu_intercept_per_group\": 10.323616027832031, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 7, \"draws\": 790, \"mu_intercept_per_group\": 15.954474449157715, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 7, \"draws\": 791, \"mu_intercept_per_group\": 17.040075302124023, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 7, \"draws\": 792, \"mu_intercept_per_group\": 13.847721099853516, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 7, \"draws\": 793, \"mu_intercept_per_group\": 16.707489013671875, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 7, \"draws\": 794, \"mu_intercept_per_group\": 11.388129234313965, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 7, \"draws\": 795, \"mu_intercept_per_group\": 10.363701820373535, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 7, \"draws\": 796, \"mu_intercept_per_group\": 16.580825805664062, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 7, \"draws\": 797, \"mu_intercept_per_group\": 7.494189739227295, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 7, \"draws\": 798, \"mu_intercept_per_group\": 26.840944290161133, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 7, \"draws\": 799, \"mu_intercept_per_group\": 16.009048461914062, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# TODO diff_y is missing from data_and posterior\n",
    "# chart_power_difference_box\n",
    "window.data_and_posterior.rename({'Power': 'Power diff'}, axis=1, inplace=True)\n",
    "# window.plot(x=':O',independent_axes=True).properties(title='Posterior')\n",
    "window.chart"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "In this chart:\n",
    "\n",
    "- The blue dot is the mean of posterior\n",
    "\n",
    "- The black line is the 94% highest density interval\n",
    "\n",
    "- The boxplot is made from difference between groups in the data (no fitting)\n",
    "\n",
    "- Left Y scale is for posterior, right for data"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Compare to non-bayesian approaches\n",
    "### Off-the-shelf OLS ANOVA"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "ANOVA does not pick up the effect of stim as significant:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Log_power~stim\n",
      "           sum_sq    df     F  PR(>F)\n",
      "stim        0.10   1.0  5.24    0.04\n",
      "Residual    0.27  14.0   NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window = LMERegression(df=df, y='Log power', treatment='stim', group='mouse')\n",
    "window.fit_anova();"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Log_power~stim\n",
      "           sum_sq     df      F  PR(>F)\n",
      "stim        3.08    1.0  29.89     0.0\n",
      "Residual   49.22  478.0    NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window = LMERegression(df=df, y='Log power', treatment='stim')\n",
    "window.fit_anova();"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Power~stim\n",
      "              sum_sq    df     F  PR(>F)\n",
      "stim      105693.30   1.0  3.32    0.09\n",
      "Residual  445450.52  14.0   NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window = LMERegression(df=df, y='Power', treatment='stim', group='mouse')\n",
    "window.fit_anova();"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Power~stim\n",
      "                 sum_sq     df     F  PR(>F)\n",
      "stim      3.170799e+06    1.0  3.29    0.07\n",
      "Residual  4.600841e+08  478.0   NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window = LMERegression(df=df, y='Power', treatment='stim')\n",
    "window.fit_anova();"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "Including mouse as predictor helps, and we get no interaction:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Log_power ~ stim + mouse + mouse*stim\n",
      "             sum_sq     df      F  PR(>F)\n",
      "mouse         7.05    7.0  11.39    0.00\n",
      "stim          3.08    1.0  34.84    0.00\n",
      "mouse:stim    1.18    7.0   1.91    0.07\n",
      "Residual     41.00  464.0    NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window.fit_anova(formula='Log_power ~ stim + mouse + mouse*stim');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "#### OLS ANOVA with heteroscedasticity correction"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Power ~ stim + mouse \n",
      "                 sum_sq     df     F  PR(>F)\n",
      "mouse     1.355281e+07    7.0  2.02    0.05\n",
      "stim      3.111346e+06    1.0  3.24    0.07\n",
      "Residual  4.524906e+08  471.0   NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window.fit_anova(formula='Power ~ stim + mouse ', robust=\"hc3\");"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Log_power ~ stim +mouse\n",
      "           sum_sq     df      F  PR(>F)\n",
      "mouse       6.80    7.0  10.86     0.0\n",
      "stim        3.02    1.0  33.73     0.0\n",
      "Residual   42.18  471.0    NaN     NaN\n"
     ]
    }
   ],
   "source": [
    "window.fit_anova(formula='Log_power ~ stim +mouse', robust=\"hc3\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "A linear mixed-effect model shows the effect of stim (slope) as significant. It includes intercepts of mouse, which also vary significantly:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Using formula Log_power ~  C(stim, Treatment) + (1 | mouse)\n",
      "                         Coef. Std.Err.       z  P>|z| [0.025 0.975]\n",
      "Intercept                1.920    0.036  52.896  0.000  1.849  1.991\n",
      "C(stim, Treatment)[T.1]  0.160    0.027   5.863  0.000  0.107  0.214\n",
      "1 | mouse                0.051    0.007   6.963  0.000  0.037  0.065\n",
      "Group Var                0.001    0.004                             \n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/home/m/venvs/jb1/lib/python3.9/site-packages/statsmodels/regression/mixed_linear_model.py:2237: ConvergenceWarning: The MLE may be on the boundary of the parameter space.\n",
      "  warnings.warn(msg, ConvergenceWarning)\n"
     ]
    }
   ],
   "source": [
    "# Initialize:\n",
    "window = LMERegression(df=df, y='Log power', treatment='stim', group='mouse')\n",
    "window.fit(add_data=False);"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-9a883d57a0fc4dc78dbe6b977ea2283b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-9a883d57a0fc4dc78dbe6b977ea2283b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-9a883d57a0fc4dc78dbe6b977ea2283b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}, \"title\": \"\\u0394 Log_power\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}}}}], \"data\": {\"name\": \"data-4b9cbfc1c4897c0672d6a06e25fe8ad5\"}, \"title\": \"LME\", \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-4b9cbfc1c4897c0672d6a06e25fe8ad5\": [{\"index\": \"C(stim, Treatment)[T.1]\", \"center interval\": 0.16, \"Std.Err.\": 0.027, \"z\": 5.863, \"p\": 0.0, \"higher interval\": 0.107, \"lower interval\": 0.214, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 17,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "chart_power_difference_lme = window.plot().properties(title='LME')\n",
    "chart_power_difference_lme"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Compare LME and Bayesian slopes side by side"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-1fd97e9a83ce40558c03351654678819\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-1fd97e9a83ce40558c03351654678819\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-1fd97e9a83ce40558c03351654678819\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"hconcat\": [{\"layer\": [{\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\"}, {\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}, \"title\": \"\\u0394 Log_power\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}}}}], \"data\": {\"name\": \"data-4b9cbfc1c4897c0672d6a06e25fe8ad5\"}, \"title\": \"LME\"}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-7b75ead138b5701714ef21e640a42f5e\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 237.74384705687086, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 166.46023493627612, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": 102.02669332812849, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": 273.27981160465947, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 25.7188242111219, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -69.5886318431294, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -79.3676220517491, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": 644.1470615759551, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-335274e0c5848c5eb146b4572e80f925\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -5.040781497955322, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -3.2319483757019043, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -14.338045120239258, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -9.673306465148926, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -4.925235748291016, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -12.546177864074707, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -11.706274032592773, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -14.756869316101074, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -12.631892204284668, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -16.163843154907227, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -4.770541191101074, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -6.212677478790283, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -9.943546295166016, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -8.178187370300293, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -8.886363983154297, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.480189323425293, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -10.987234115600586, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -10.944351196289062, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -11.506084442138672, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -1.8251782655715942, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -12.498072624206543, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -12.514010429382324, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -17.6185245513916, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -5.716065406799316, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -12.775249481201172, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -3.373499870300293, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -10.66567611694336, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -3.174480676651001, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -6.656539440155029, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -5.057694435119629, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -6.132038593292236, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -6.260168075561523, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -6.267385959625244, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -18.276689529418945, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -14.591009140014648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -6.426440715789795, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -14.020872116088867, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -8.92737102508545, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -8.799839973449707, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -10.442145347595215, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -11.592804908752441, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -1.3473926782608032, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -4.051822662353516, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -5.211493015289307, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -4.1107282638549805, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -2.415545701980591, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -16.093782424926758, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -17.072484970092773, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -20.167388916015625, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -23.8348388671875, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": -7.981138229370117, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -0.04728800058364868, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -8.871659278869629, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -9.35479736328125, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -3.8808343410491943, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -6.361900329589844, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -7.999002456665039, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -5.894481658935547, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -13.972681045532227, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -13.822797775268555, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -3.046886682510376, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -16.953060150146484, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -3.695838451385498, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -14.566791534423828, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -13.50625991821289, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -18.355134963989258, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -2.4528801441192627, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -7.53265905380249, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -6.505617618560791, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -12.704715728759766, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -1.9597692489624023, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -12.978065490722656, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -8.506797790527344, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -5.759369850158691, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": -25.789400100708008, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -22.311338424682617, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -8.781279563903809, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -13.314993858337402, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -1.3805243968963623, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -1.0229171514511108, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -7.584434986114502, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -7.566932678222656, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -7.094293117523193, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -11.389894485473633, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -8.709399223327637, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -10.357560157775879, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -16.34046173095703, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": 0.6019138693809509, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -1.9741706848144531, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -7.676919937133789, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -11.231236457824707, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -1.5288472175598145, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -16.779338836669922, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -4.3895158767700195, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -18.84963035583496, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -17.951358795166016, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -5.909987926483154, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -12.995099067687988, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -14.546140670776367, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -12.310595512390137, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -12.568388938903809, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -11.030439376831055, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -11.577783584594727, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -19.112316131591797, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -12.155937194824219, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -13.99992561340332, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -7.133065223693848, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -11.40817642211914, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -7.663388252258301, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -7.15134859085083, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -11.182429313659668, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -6.685650825500488, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -13.261324882507324, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -8.376654624938965, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -8.474446296691895, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -11.404654502868652, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -15.137195587158203, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -2.7283873558044434, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -5.247433662414551, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -9.17174243927002, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -3.0005855560302734, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -4.599752902984619, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -9.993454933166504, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -8.326324462890625, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -6.7738237380981445, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -18.34370994567871, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -16.528854370117188, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -6.6535491943359375, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -11.81106185913086, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -16.69459342956543, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -14.064314842224121, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -9.772653579711914, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -11.23830509185791, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -4.780694961547852, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -14.838922500610352, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -5.256370544433594, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -9.29879093170166, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -13.37845230102539, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -10.741788864135742, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -7.814037799835205, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -8.544958114624023, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -5.639056205749512, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -2.9378082752227783, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -8.153556823730469, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -14.391047477722168, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -4.369668960571289, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -2.46347713470459, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -3.629565954208374, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -10.348349571228027, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -4.948489665985107, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -12.884615898132324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -5.245946407318115, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -6.670903205871582, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -8.891148567199707, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -9.279622077941895, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -8.383540153503418, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -4.247647762298584, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -12.485112190246582, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -5.546526908874512, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -10.073062896728516, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -10.178902626037598, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -13.806653022766113, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -13.627968788146973, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -15.624517440795898, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -17.04638671875, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -8.39765453338623, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -9.610179901123047, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -12.103351593017578, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -19.356971740722656, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -2.4488518238067627, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -17.13677215576172, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -5.408355236053467, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -7.60662317276001, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": 0.21036642789840698, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -4.18886661529541, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -1.2615326642990112, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -6.848775863647461, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -9.153616905212402, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -2.357057571411133, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -7.682571887969971, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -3.3885879516601562, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -11.814712524414062, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -6.619076251983643, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -12.91315746307373, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -8.867708206176758, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -14.581746101379395, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -19.71653175354004, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -19.991769790649414, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -21.214252471923828, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -6.644197940826416, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -10.407630920410156, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -11.46703052520752, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -8.729238510131836, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -7.291738510131836, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -8.144486427307129, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.621789932250977, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -9.452020645141602, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -2.7215309143066406, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -3.036237955093384, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -19.85153579711914, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -12.849891662597656, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -6.997928142547607, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -10.627803802490234, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -5.472050189971924, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -16.494998931884766, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -16.4442138671875, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -5.7470502853393555, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -8.932648658752441, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -8.577373504638672, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -8.965713500976562, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -11.161826133728027, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -7.89268684387207, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -7.564478397369385, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -13.452535629272461, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -14.08469295501709, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -2.954566717147827, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -11.441118240356445, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -6.81473970413208, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -2.3359830379486084, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -3.075653553009033, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -11.325859069824219, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -4.258692264556885, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -4.423980712890625, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -13.428261756896973, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -11.3971586227417, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -13.256096839904785, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.62111234664917, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -4.03687047958374, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -11.875662803649902, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -7.4272379875183105, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -7.029792308807373, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -9.917837142944336, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -6.4340691566467285, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -8.416629791259766, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -9.764811515808105, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -13.684724807739258, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -9.332736015319824, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -5.513200759887695, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -5.412356853485107, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -10.102581977844238, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -9.726181030273438, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -8.257014274597168, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -3.624953508377075, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -2.589315891265869, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -8.779748916625977, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -6.400252342224121, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -8.629778861999512, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -16.5101318359375, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -17.6689453125, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": -4.915207386016846, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -6.15136194229126, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -6.802655220031738, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -7.658843517303467, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -9.336639404296875, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -6.3743815422058105, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -3.255826711654663, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -12.883275985717773, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -16.258590698242188, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -16.643815994262695, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -5.674232482910156, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -10.518762588500977, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -11.083512306213379, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -5.980678081512451, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -2.541947364807129, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -20.78319549560547, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -3.921635150909424, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": 0.5861846804618835, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -11.339868545532227, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -0.389615923166275, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -12.612652778625488, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -10.362377166748047, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -1.3020634651184082, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -14.657515525817871, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.195693016052246, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -13.869643211364746, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -14.57094669342041, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -13.50912857055664, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -8.952861785888672, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -8.80617904663086, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -3.6185855865478516, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -10.87226390838623, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -12.242692947387695, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -15.20461368560791, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -9.234443664550781, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -7.426700592041016, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -13.220755577087402, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -5.277491569519043, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -8.162809371948242, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -7.106990337371826, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -8.721697807312012, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -10.575236320495605, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -9.488320350646973, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -6.3274407386779785, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -8.079594612121582, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -8.850040435791016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -4.494203090667725, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -8.342353820800781, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -7.779570579528809, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -5.749445915222168, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -3.8445205688476562, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -9.672994613647461, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -2.8184850215911865, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -5.3096466064453125, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -9.379035949707031, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -8.699469566345215, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -6.1675639152526855, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.189728736877441, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -5.6182026863098145, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -2.484952211380005, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -4.12829065322876, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -11.519996643066406, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -7.22760009765625, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -4.460574626922607, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -14.75634479522705, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -1.8370130062103271, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -4.823190212249756, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -17.70157814025879, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -17.373361587524414, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -18.10245132446289, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -3.457681655883789, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -8.75065803527832, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -16.165645599365234, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -22.6804141998291, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -19.911861419677734, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -22.61591148376465, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -11.622304916381836, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": 0.998124361038208, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -6.8948655128479, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -4.078651428222656, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -7.3026604652404785, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -11.44503116607666, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -17.5340576171875, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -16.409536361694336, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -5.208342552185059, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -10.778684616088867, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -17.12391471862793, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -15.53206729888916, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -24.478370666503906, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -3.444739818572998, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -8.01969051361084, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -6.329585552215576, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -4.347865581512451, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -12.938542366027832, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -9.006197929382324, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -5.012093544006348, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -4.965196132659912, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -15.606342315673828, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -5.539521217346191, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -5.314929962158203, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -1.2871633768081665, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -14.534015655517578, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -4.73247766494751, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -11.297335624694824, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": 0.9405475854873657, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.757895469665527, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -10.374063491821289, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -16.98774528503418, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -8.18375015258789, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -4.701827526092529, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -11.026098251342773, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -10.939376831054688, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -2.6122803688049316, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -12.174870491027832, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -6.430441856384277, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -10.59070873260498, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -3.260490655899048, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -3.310577154159546, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -11.701184272766113, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -16.167146682739258, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -6.8973283767700195, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -19.691875457763672, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -11.031414985656738, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -5.411973476409912, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -3.844919443130493, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -5.477871417999268, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -9.450149536132812, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -7.657480239868164, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -13.941293716430664, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -9.572578430175781, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -8.065054893493652, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -4.444667339324951, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -6.401512145996094, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -7.924699306488037, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": 0.7744003534317017, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -24.4804630279541, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -39.773441314697266, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -31.81466293334961, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -20.902446746826172, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -17.315820693969727, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": 5.48476505279541, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -1.5803248882293701, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -18.618637084960938, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -8.642467498779297, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -11.297926902770996, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -15.921405792236328, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -6.936874866485596, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -0.2094547003507614, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -18.638042449951172, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -14.544658660888672, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -12.04907512664795, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -5.024633407592773, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -3.489513635635376, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -9.497099876403809, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -8.240531921386719, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -6.346133232116699, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -14.385534286499023, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -12.13107681274414, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -10.018568992614746, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -5.1738667488098145, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -10.29282283782959, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -9.026412963867188, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -4.315159320831299, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -6.5509257316589355, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -19.04126739501953, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -16.34767723083496, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -2.5898938179016113, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -3.3687591552734375, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -7.322995662689209, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -2.7231345176696777, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -10.025606155395508, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -3.8277714252471924, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -14.222061157226562, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -7.5450663566589355, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -9.19723892211914, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -9.410855293273926, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -1.858840823173523, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -9.601522445678711, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -23.54803466796875, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -23.492151260375977, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -2.0137908458709717, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -7.213013648986816, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -5.775428295135498, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -5.777145862579346, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -17.992870330810547, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -19.222583770751953, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -3.606680393218994, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -7.077849388122559, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -7.946872234344482, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -7.342119216918945, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -7.215571880340576, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -9.698287010192871, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -11.335079193115234, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -5.650229454040527, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -6.336968898773193, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -3.8731679916381836, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -11.074392318725586, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -3.630917549133301, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -6.614351749420166, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -8.51510238647461, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -2.4186511039733887, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -1.1323734521865845, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -18.85658073425293, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -3.8716964721679688, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -9.455548286437988, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -13.154111862182617, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -2.69400691986084, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -16.04335594177246, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -15.140952110290527, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -16.074392318725586, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -10.598502159118652, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -4.471084117889404, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -9.135819435119629, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -6.191133499145508, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -0.926066517829895, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -12.166131973266602, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -12.361000061035156, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -16.498821258544922, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -17.714357376098633, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -15.189769744873047, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -18.966697692871094, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -10.010828018188477, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -9.98740291595459, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -5.75197172164917, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -15.284516334533691, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -5.489589214324951, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -12.943856239318848, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -0.22668716311454773, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -15.675498008728027, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -6.588681221008301, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -7.812132835388184, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -6.533406734466553, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -8.366008758544922, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -6.541745662689209, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -7.343019485473633, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -2.4424896240234375, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -23.04140281677246, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -0.7497562766075134, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -4.742270469665527, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": 1.0736088752746582, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": 0.024408448487520218, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -2.8643569946289062, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -8.307125091552734, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -8.772392272949219, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -0.5112401843070984, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -6.886197090148926, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -6.327877998352051, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -12.50365924835205, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -11.757549285888672, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -1.3050986528396606, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -13.721922874450684, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -12.205488204956055, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -15.0798978805542, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -3.8415820598602295, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -9.192111015319824, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -7.257448673248291, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -6.073168754577637, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -6.093765735626221, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -9.180815696716309, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -14.790719032287598, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -8.083637237548828, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -16.844039916992188, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -15.44870376586914, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -7.9280314445495605, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -15.37336254119873, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": 0.20836150646209717, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -9.434063911437988, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -10.677699089050293, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -13.1483154296875, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -8.331754684448242, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -11.413102149963379, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -10.736640930175781, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -20.958683013916016, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -3.8055968284606934, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -5.030653953552246, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -13.732660293579102, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -12.01431655883789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -14.626978874206543, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -14.44836711883545, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -11.47911548614502, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -15.735791206359863, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -13.227349281311035, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -3.8430216312408447, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -10.357236862182617, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -8.008966445922852, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -6.926792144775391, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -7.791112899780273, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -6.468642711639404, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -9.571223258972168, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -3.7362332344055176, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -10.967222213745117, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -18.106294631958008, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -16.127092361450195, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -10.687830924987793, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -8.566162109375, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -4.050730228424072, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": 1.3152552843093872, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -2.0139448642730713, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -4.341344833374023, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -8.37908935546875, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -22.976163864135742, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -10.430059432983398, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -14.850079536437988, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -20.197887420654297, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -6.68999719619751, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -2.815863847732544, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -17.887845993041992, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -3.541370153427124, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -3.542423963546753, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -6.5178399085998535, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -6.637992858886719, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": -1.2293953895568848, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -17.230424880981445, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -11.51131534576416, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -8.765068054199219, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -6.458959102630615, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -5.430912017822266, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -3.6724812984466553, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -3.493516206741333, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -11.444568634033203, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -9.342259407043457, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -9.024116516113281, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -7.584840297698975, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -19.061552047729492, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -10.222793579101562, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -14.651355743408203, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -14.484232902526855, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -0.38055333495140076, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": 2.191359043121338, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -16.867826461791992, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -5.231989860534668, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -4.299243927001953, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -1.6465952396392822, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -18.220346450805664, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -6.526581287384033, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -9.6726713180542, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -9.635215759277344, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -13.181056022644043, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -5.687668323516846, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -16.44668197631836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -3.8459317684173584, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -10.190849304199219, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -11.476523399353027, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -5.591184616088867, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -5.949356555938721, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -5.420851230621338, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -14.403029441833496, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -10.093840599060059, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -18.961095809936523, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -11.777244567871094, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -13.17252254486084, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -12.879655838012695, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": 0.7822245359420776, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -10.36086654663086, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -28.181034088134766, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": 0.6640376448631287, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -17.449878692626953, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -13.05380916595459, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": 0.5147354602813721, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -0.6536664962768555, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": 2.406078338623047, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": 6.2492570877075195, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -16.29853057861328, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -14.67895221710205, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -14.72924518585205, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -7.888645172119141, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -13.071282386779785, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -5.036900043487549, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -16.05565071105957, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -7.945497035980225, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -12.781723022460938, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -11.250772476196289, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -5.3124680519104, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -11.05871868133545, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -13.738811492919922, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -5.289099216461182, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -2.5719308853149414, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": 4.691713809967041, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": 1.5101555585861206, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -16.513256072998047, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": 4.7369537353515625, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -16.79252052307129, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -17.795873641967773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -17.840864181518555, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -11.204030990600586, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -11.924735069274902, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -19.330913543701172, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -21.98118782043457, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -3.0958797931671143, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -2.735022783279419, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -10.548039436340332, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 640, \"mu_intercept_per_group\": -1.3955962657928467, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 641, \"mu_intercept_per_group\": -17.113033294677734, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 642, \"mu_intercept_per_group\": -11.39327621459961, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 643, \"mu_intercept_per_group\": -12.532562255859375, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 644, \"mu_intercept_per_group\": -8.902205467224121, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 645, \"mu_intercept_per_group\": -16.35418128967285, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 646, \"mu_intercept_per_group\": -18.42349624633789, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 647, \"mu_intercept_per_group\": -20.9619083404541, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 648, \"mu_intercept_per_group\": -18.798307418823242, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 649, \"mu_intercept_per_group\": 4.921034812927246, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 650, \"mu_intercept_per_group\": 2.829319953918457, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 651, \"mu_intercept_per_group\": -19.05095672607422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 652, \"mu_intercept_per_group\": -5.474806785583496, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 653, \"mu_intercept_per_group\": -4.922374725341797, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 654, \"mu_intercept_per_group\": -10.816702842712402, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 655, \"mu_intercept_per_group\": 0.6563606858253479, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 656, \"mu_intercept_per_group\": -11.115660667419434, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 657, \"mu_intercept_per_group\": -9.447301864624023, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 658, \"mu_intercept_per_group\": -13.556966781616211, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 659, \"mu_intercept_per_group\": -11.097416877746582, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 660, \"mu_intercept_per_group\": -5.995758533477783, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 661, \"mu_intercept_per_group\": -2.3554229736328125, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 662, \"mu_intercept_per_group\": -3.1295342445373535, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 663, \"mu_intercept_per_group\": -4.682866096496582, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 664, \"mu_intercept_per_group\": -3.5213005542755127, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 665, \"mu_intercept_per_group\": -4.978518486022949, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 666, \"mu_intercept_per_group\": -3.724959135055542, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 667, \"mu_intercept_per_group\": -6.1379313468933105, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 668, \"mu_intercept_per_group\": -4.124699115753174, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 669, \"mu_intercept_per_group\": -8.214367866516113, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 670, \"mu_intercept_per_group\": 1.0553821325302124, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 671, \"mu_intercept_per_group\": -11.239164352416992, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 672, \"mu_intercept_per_group\": -6.925349235534668, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 673, \"mu_intercept_per_group\": -6.511587619781494, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 674, \"mu_intercept_per_group\": -11.621158599853516, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 675, \"mu_intercept_per_group\": -10.887262344360352, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 676, \"mu_intercept_per_group\": -7.85366678237915, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 677, \"mu_intercept_per_group\": -9.883703231811523, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 678, \"mu_intercept_per_group\": -5.222884654998779, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 679, \"mu_intercept_per_group\": -7.691766262054443, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 680, \"mu_intercept_per_group\": -3.4161531925201416, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 681, \"mu_intercept_per_group\": -23.19988250732422, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 682, \"mu_intercept_per_group\": 0.4955381453037262, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 683, \"mu_intercept_per_group\": -19.23976707458496, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 684, \"mu_intercept_per_group\": -15.268034934997559, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 685, \"mu_intercept_per_group\": -15.744549751281738, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 686, \"mu_intercept_per_group\": -13.575891494750977, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 687, \"mu_intercept_per_group\": -12.361751556396484, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 688, \"mu_intercept_per_group\": -15.737735748291016, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 689, \"mu_intercept_per_group\": -3.832686424255371, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 690, \"mu_intercept_per_group\": -6.5279645919799805, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 691, \"mu_intercept_per_group\": -4.437520980834961, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 692, \"mu_intercept_per_group\": -3.609692096710205, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 693, \"mu_intercept_per_group\": 5.752180576324463, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 694, \"mu_intercept_per_group\": -6.594266414642334, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 695, \"mu_intercept_per_group\": -8.382157325744629, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 696, \"mu_intercept_per_group\": -5.280394077301025, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 697, \"mu_intercept_per_group\": -3.3657338619232178, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 698, \"mu_intercept_per_group\": -13.693631172180176, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 699, \"mu_intercept_per_group\": -15.320185661315918, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 700, \"mu_intercept_per_group\": -16.62302589416504, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 701, \"mu_intercept_per_group\": -14.20588207244873, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 702, \"mu_intercept_per_group\": -14.253565788269043, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 703, \"mu_intercept_per_group\": -1.8492915630340576, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 704, \"mu_intercept_per_group\": -9.212831497192383, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 705, \"mu_intercept_per_group\": -7.338194847106934, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 706, \"mu_intercept_per_group\": -14.641120910644531, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 707, \"mu_intercept_per_group\": -16.60073471069336, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 708, \"mu_intercept_per_group\": -1.3629611730575562, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 709, \"mu_intercept_per_group\": -7.777461051940918, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 710, \"mu_intercept_per_group\": -1.8500031232833862, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 711, \"mu_intercept_per_group\": -22.09663200378418, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 712, \"mu_intercept_per_group\": 0.018531644716858864, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 713, \"mu_intercept_per_group\": 3.0248255729675293, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 714, \"mu_intercept_per_group\": -7.417457580566406, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 715, \"mu_intercept_per_group\": -6.956211090087891, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 716, \"mu_intercept_per_group\": -8.928647994995117, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 717, \"mu_intercept_per_group\": -0.22857104241847992, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 718, \"mu_intercept_per_group\": -6.185298442840576, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 719, \"mu_intercept_per_group\": -16.681169509887695, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 720, \"mu_intercept_per_group\": -5.962151050567627, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 721, \"mu_intercept_per_group\": -6.805093288421631, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 722, \"mu_intercept_per_group\": -11.011396408081055, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 723, \"mu_intercept_per_group\": -9.850343704223633, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 724, \"mu_intercept_per_group\": -10.407118797302246, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 725, \"mu_intercept_per_group\": -10.117226600646973, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 726, \"mu_intercept_per_group\": -5.316917419433594, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 727, \"mu_intercept_per_group\": -6.945923328399658, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 728, \"mu_intercept_per_group\": -9.492375373840332, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 729, \"mu_intercept_per_group\": -8.86750602722168, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 730, \"mu_intercept_per_group\": -7.798107624053955, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 731, \"mu_intercept_per_group\": -12.682540893554688, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 732, \"mu_intercept_per_group\": -12.547581672668457, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 733, \"mu_intercept_per_group\": -18.491785049438477, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 734, \"mu_intercept_per_group\": -8.545707702636719, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 735, \"mu_intercept_per_group\": -17.687284469604492, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 736, \"mu_intercept_per_group\": -5.70229434967041, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 737, \"mu_intercept_per_group\": -13.548932075500488, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 738, \"mu_intercept_per_group\": -9.389627456665039, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 739, \"mu_intercept_per_group\": -15.26278305053711, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 740, \"mu_intercept_per_group\": -1.2251851558685303, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 741, \"mu_intercept_per_group\": -11.610944747924805, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 742, \"mu_intercept_per_group\": -1.3939104080200195, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 743, \"mu_intercept_per_group\": -1.9360616207122803, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 744, \"mu_intercept_per_group\": -10.431615829467773, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 745, \"mu_intercept_per_group\": -8.211955070495605, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 746, \"mu_intercept_per_group\": -13.654766082763672, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 747, \"mu_intercept_per_group\": -2.444514513015747, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 748, \"mu_intercept_per_group\": -9.148351669311523, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 749, \"mu_intercept_per_group\": -1.5807955265045166, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 750, \"mu_intercept_per_group\": -15.372639656066895, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 751, \"mu_intercept_per_group\": -5.23089075088501, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 752, \"mu_intercept_per_group\": -14.592620849609375, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 753, \"mu_intercept_per_group\": -9.639511108398438, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 754, \"mu_intercept_per_group\": -9.418307304382324, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 755, \"mu_intercept_per_group\": -3.8247220516204834, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 756, \"mu_intercept_per_group\": -5.8500590324401855, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 757, \"mu_intercept_per_group\": -5.908278465270996, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 758, \"mu_intercept_per_group\": -14.808974266052246, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 759, \"mu_intercept_per_group\": -9.69106388092041, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 0, \"draws\": 760, \"mu_intercept_per_group\": -8.039718627929688, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 0, \"draws\": 761, \"mu_intercept_per_group\": -6.686943531036377, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 0, \"draws\": 762, \"mu_intercept_per_group\": -6.237182140350342, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 0, \"draws\": 763, \"mu_intercept_per_group\": -15.060968399047852, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 0, \"draws\": 764, \"mu_intercept_per_group\": -0.531229555606842, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 0, \"draws\": 765, \"mu_intercept_per_group\": -4.671209812164307, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 0, \"draws\": 766, \"mu_intercept_per_group\": -15.774847030639648, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 0, \"draws\": 767, \"mu_intercept_per_group\": -16.489418029785156, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 0, \"draws\": 768, \"mu_intercept_per_group\": -13.781782150268555, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 0, \"draws\": 769, \"mu_intercept_per_group\": -13.473760604858398, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 0, \"draws\": 770, \"mu_intercept_per_group\": -0.21044935286045074, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 0, \"draws\": 771, \"mu_intercept_per_group\": -15.083337783813477, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 0, \"draws\": 772, \"mu_intercept_per_group\": -4.676630973815918, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 0, \"draws\": 773, \"mu_intercept_per_group\": -12.31003189086914, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 0, \"draws\": 774, \"mu_intercept_per_group\": -6.071263790130615, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 0, \"draws\": 775, \"mu_intercept_per_group\": -12.3790864944458, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 0, \"draws\": 776, \"mu_intercept_per_group\": -10.242154121398926, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 0, \"draws\": 777, \"mu_intercept_per_group\": -14.512199401855469, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 0, \"draws\": 778, \"mu_intercept_per_group\": -6.676771640777588, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 0, \"draws\": 779, \"mu_intercept_per_group\": -9.669127464294434, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 0, \"draws\": 780, \"mu_intercept_per_group\": -11.874094009399414, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 0, \"draws\": 781, \"mu_intercept_per_group\": 0.7495285272598267, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 0, \"draws\": 782, \"mu_intercept_per_group\": -11.307819366455078, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 0, \"draws\": 783, \"mu_intercept_per_group\": -11.859552383422852, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 0, \"draws\": 784, \"mu_intercept_per_group\": -6.786609649658203, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 0, \"draws\": 785, \"mu_intercept_per_group\": -4.8037872314453125, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 0, \"draws\": 786, \"mu_intercept_per_group\": -1.0827637910842896, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 0, \"draws\": 787, \"mu_intercept_per_group\": -9.0177583694458, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 0, \"draws\": 788, \"mu_intercept_per_group\": -2.8852615356445312, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 0, \"draws\": 789, \"mu_intercept_per_group\": -2.3375611305236816, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 0, \"draws\": 790, \"mu_intercept_per_group\": -5.916977882385254, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 0, \"draws\": 791, \"mu_intercept_per_group\": -5.5406341552734375, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 0, \"draws\": 792, \"mu_intercept_per_group\": -5.125442028045654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 0, \"draws\": 793, \"mu_intercept_per_group\": -9.392108917236328, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 0, \"draws\": 794, \"mu_intercept_per_group\": 5.721161365509033, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 0, \"draws\": 795, \"mu_intercept_per_group\": -3.4059906005859375, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 0, \"draws\": 796, \"mu_intercept_per_group\": -5.1101531982421875, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 0, \"draws\": 797, \"mu_intercept_per_group\": -15.806418418884277, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 0, \"draws\": 798, \"mu_intercept_per_group\": 4.5742669105529785, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 0, \"draws\": 799, \"mu_intercept_per_group\": -16.5518798828125, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -8.463964462280273, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -5.522490978240967, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -8.630327224731445, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -7.021143913269043, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -2.774968385696411, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -10.757180213928223, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -8.160569190979004, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -10.12001895904541, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -4.824865341186523, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -8.315885543823242, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -5.182793140411377, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -10.113337516784668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -7.616043567657471, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -7.081296443939209, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -8.140750885009766, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -11.904815673828125, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -11.351101875305176, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -4.601489067077637, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -5.248831748962402, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -6.81367301940918, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -2.246152639389038, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -5.514193058013916, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -11.95570182800293, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -3.89855694770813, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": 4.90255069732666, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": 13.422053337097168, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": 6.911807537078857, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -5.5922770500183105, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -6.857975482940674, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -2.1050865650177, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -6.132362365722656, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -2.787949323654175, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -7.256302833557129, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -15.257880210876465, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -5.019294738769531, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -16.966064453125, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -8.912954330444336, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -14.777284622192383, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -5.526966571807861, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -4.6448774337768555, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": 2.525085687637329, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -15.121261596679688, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -3.2543210983276367, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -4.027781963348389, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -3.056781053543091, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -4.625176906585693, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": 2.2165396213531494, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": 1.1302454471588135, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -8.88571548461914, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -12.499415397644043, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -5.258360385894775, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -1.1019741296768188, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -2.7254743576049805, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -4.00599479675293, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -7.0142059326171875, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -4.741383075714111, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -2.4022116661071777, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -7.611382961273193, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -7.375605583190918, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -13.864294052124023, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": 1.5573049783706665, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -18.688922882080078, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -3.8896350860595703, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -2.6664626598358154, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -5.915189266204834, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -11.641724586486816, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -24.968902587890625, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": 3.673384428024292, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": 3.2681491374969482, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -5.521426200866699, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -9.135942459106445, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -9.367850303649902, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -8.582090377807617, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -12.789557456970215, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -7.178985595703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -3.3624579906463623, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -3.7026774883270264, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -20.197704315185547, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -2.000335216522217, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": 0.3444068729877472, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -6.717190742492676, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -5.477149486541748, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -11.214262008666992, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -16.399005889892578, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -1.7473465204238892, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -1.0917484760284424, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -3.080193519592285, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": 0.8146815299987793, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": 4.521572113037109, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.99426555633545, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -9.336772918701172, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -5.096127033233643, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -18.555667877197266, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": 8.260923385620117, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -19.096702575683594, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -19.96316146850586, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -1.9338761568069458, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -7.733426570892334, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -11.19599723815918, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -3.0945422649383545, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -4.423023700714111, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -14.207892417907715, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -10.578598976135254, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -6.583150863647461, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -18.78107452392578, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -5.156072616577148, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -13.016656875610352, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -3.282268524169922, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -1.4693411588668823, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -1.5940797328948975, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -8.228626251220703, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -7.249871253967285, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -5.003849029541016, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -6.709216117858887, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -5.370258808135986, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -6.2389020919799805, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -4.802653789520264, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -3.672044515609741, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -2.5114827156066895, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -6.614682197570801, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -1.314194679260254, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -7.518023490905762, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -5.575322151184082, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -4.340911865234375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -6.025227069854736, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -11.910261154174805, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -13.2202730178833, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -10.20504379272461, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -10.171121597290039, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -7.420294761657715, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -8.76205062866211, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -8.214826583862305, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -1.5067857503890991, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -2.995762348175049, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -10.4031982421875, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -5.307545185089111, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -6.915334701538086, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -6.712177276611328, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -11.415205001831055, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -15.197175979614258, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -5.711830139160156, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -1.4785627126693726, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -3.285017490386963, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -5.481128215789795, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -11.936737060546875, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": 0.36717545986175537, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -4.167700290679932, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": 0.07449424266815186, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -7.763571262359619, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -5.035675048828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -9.300844192504883, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": 3.1366419792175293, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -12.75354290008545, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -12.582444190979004, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -2.3910295963287354, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -12.289669036865234, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -2.905604362487793, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -7.637528896331787, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -5.888548851013184, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -9.943721771240234, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -7.501426696777344, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -5.770092487335205, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -1.948828935623169, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -15.492814064025879, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": 4.272012233734131, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -7.3533501625061035, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -7.2175164222717285, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -14.558330535888672, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -16.98981285095215, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": 4.297924995422363, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -19.546592712402344, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -8.8070650100708, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -4.942563056945801, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": 0.48789316415786743, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -2.812572479248047, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -1.250403881072998, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": 0.201321542263031, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -5.401147842407227, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -8.158730506896973, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -4.766443729400635, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -10.177217483520508, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -1.0570824146270752, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -17.689987182617188, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -9.77273941040039, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -7.371433734893799, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": 2.80295991897583, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": 3.2416961193084717, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": 0.44132789969444275, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -2.6126503944396973, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -9.670760154724121, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -8.313094139099121, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -10.328643798828125, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -9.322820663452148, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -12.268668174743652, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -10.417738914489746, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -11.325778007507324, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -11.268610000610352, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -2.5182535648345947, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -2.6109728813171387, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -11.761697769165039, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -1.9480599164962769, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -15.995800971984863, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -7.968087196350098, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -12.817194938659668, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -7.802563190460205, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -2.0851564407348633, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -9.967320442199707, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -2.524480104446411, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -1.9567384719848633, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -6.825958728790283, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -3.56683611869812, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -10.835593223571777, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -8.808893203735352, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -6.46396017074585, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -10.878059387207031, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -2.6873679161071777, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -6.742923259735107, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -9.391840934753418, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": 1.4834914207458496, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -0.8790526390075684, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -16.255952835083008, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -14.247909545898438, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -5.371616363525391, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -5.0700883865356445, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -7.676242828369141, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -9.607836723327637, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -22.520721435546875, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -9.707636833190918, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -18.860963821411133, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": 2.2030763626098633, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": 2.202141523361206, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -0.7342286109924316, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -7.996046543121338, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -8.649276733398438, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -6.344440460205078, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -4.691237926483154, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -7.299112796783447, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -5.575038433074951, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -3.972187042236328, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -9.599820137023926, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -8.358413696289062, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -5.024391174316406, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -5.716562747955322, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -3.77807879447937, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -5.500432014465332, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -7.615743160247803, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -4.611034393310547, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -10.824134826660156, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -9.529510498046875, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -6.8019843101501465, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -7.914368152618408, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -6.4699482917785645, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -5.027370929718018, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -3.10154128074646, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": 0.27238428592681885, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -11.068960189819336, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -1.8688381910324097, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -1.5642330646514893, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": 2.16567063331604, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -4.079339027404785, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -0.5596898794174194, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -13.810405731201172, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -2.4614691734313965, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -4.566840171813965, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -9.446951866149902, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -6.827064037322998, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": 2.2277393341064453, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -5.073843479156494, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -0.4736955165863037, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -9.838051795959473, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -5.923642158508301, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -7.2732462882995605, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -2.9811365604400635, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -5.687343597412109, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -7.497012138366699, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -6.166018962860107, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": 1.1129947900772095, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -2.388124942779541, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -4.539252758026123, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -17.606914520263672, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -6.165983200073242, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -3.742136001586914, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -3.639493703842163, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -5.823246955871582, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -12.123866081237793, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -7.763772010803223, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -6.970352649688721, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -0.6010066866874695, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -2.378098249435425, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -5.7572832107543945, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -11.822481155395508, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -4.5131025314331055, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -7.647518634796143, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -5.036931037902832, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -8.063419342041016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -8.231720924377441, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -10.115706443786621, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": 11.774689674377441, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": 1.6975617408752441, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -0.44665879011154175, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -5.412267208099365, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -4.182696342468262, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -1.9100764989852905, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -8.234150886535645, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -8.763331413269043, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -5.511397361755371, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -9.85831356048584, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -12.8724946975708, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": 7.688490867614746, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -12.401480674743652, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": 4.287363529205322, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -11.154162406921387, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -9.18152141571045, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -5.775693416595459, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -6.747610569000244, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -7.762335300445557, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -8.072798728942871, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -7.486238479614258, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -12.458937644958496, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -3.4186317920684814, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -5.2962493896484375, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -4.723546981811523, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -2.6898562908172607, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -3.6324923038482666, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -13.080504417419434, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -6.417844772338867, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -1.665814995765686, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -4.46502161026001, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -14.899575233459473, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -10.645574569702148, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -3.14841628074646, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -13.237945556640625, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -12.312538146972656, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -7.097439765930176, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -14.861870765686035, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -11.7489652633667, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -11.972259521484375, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -10.411721229553223, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -11.556038856506348, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -1.303446888923645, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -8.312260627746582, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -11.57768726348877, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -13.761001586914062, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -6.086140155792236, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -5.489706039428711, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -2.0879509449005127, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -13.66417407989502, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -10.065771102905273, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -5.447312355041504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -9.46387004852295, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -5.7930755615234375, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.894649505615234, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -4.028882026672363, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -1.6248077154159546, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -13.211878776550293, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -12.292472839355469, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -6.505354404449463, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -9.881367683410645, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -0.13978375494480133, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -10.650283813476562, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -9.862833023071289, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -5.99295711517334, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -3.788276433944702, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -4.967767715454102, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -10.58394718170166, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": 1.6004167795181274, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -0.0031337225809693336, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -12.571540832519531, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -11.773927688598633, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -6.5745062828063965, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -6.903250694274902, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -4.94040060043335, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -11.601109504699707, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -12.11928653717041, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -3.1288840770721436, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -9.122939109802246, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -11.455864906311035, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -7.932468891143799, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -5.82853889465332, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -5.114236831665039, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -2.7878990173339844, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -4.554833889007568, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -13.072132110595703, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": 5.590129375457764, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -20.363454818725586, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -34.7641716003418, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -15.950664520263672, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -10.630252838134766, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -13.557367324829102, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": 2.0046355724334717, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -12.566685676574707, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -7.294683933258057, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -12.405985832214355, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -8.00912094116211, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -8.846941947937012, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.363330841064453, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -3.7095868587493896, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -4.117101669311523, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -6.945756435394287, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -8.627290725708008, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -1.4066123962402344, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -14.80611801147461, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -5.313531875610352, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -7.835374355316162, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -4.99541711807251, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -4.97422981262207, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -5.330106735229492, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -8.303894996643066, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": 2.135199546813965, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -16.06319808959961, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": 0.7605302333831787, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -13.170872688293457, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -15.687202453613281, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -1.7165426015853882, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -5.136164665222168, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -4.370528697967529, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -4.880247592926025, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -1.911839246749878, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -9.556730270385742, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -0.8126273155212402, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -6.101413726806641, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.357921600341797, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -13.671849250793457, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -3.5299882888793945, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -4.885555267333984, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -8.022061347961426, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -2.0411484241485596, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -9.610355377197266, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -1.847278118133545, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -11.80907154083252, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -8.462021827697754, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -4.326870441436768, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -5.468924522399902, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -6.299935817718506, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -13.798683166503906, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -3.594536304473877, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -8.656484603881836, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -6.9296417236328125, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -7.686049938201904, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -12.964165687561035, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -7.580221176147461, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -7.629336833953857, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -7.874495029449463, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -3.870492458343506, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -15.039116859436035, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -3.3166422843933105, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -10.479406356811523, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -10.407120704650879, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -3.1247706413269043, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -9.59276294708252, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -8.741473197937012, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -2.6316232681274414, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -10.259936332702637, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -16.08149528503418, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -22.595226287841797, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -13.521262168884277, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -15.243318557739258, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -8.26047420501709, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -5.657673358917236, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -3.0963892936706543, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -10.927461624145508, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -1.3937886953353882, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -12.800820350646973, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -2.9563820362091064, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": 3.0324513912200928, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -1.3185973167419434, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -10.170413970947266, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -8.437788009643555, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -29.883220672607422, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -2.5528335571289062, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -5.943991184234619, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.220870971679688, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -10.247591972351074, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -11.83267593383789, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -1.1434195041656494, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -3.710218906402588, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -4.687295913696289, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -6.169580936431885, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -12.876049041748047, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -7.897989749908447, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -7.6432037353515625, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -3.8371458053588867, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -7.476674556732178, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -6.591335773468018, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -2.628870964050293, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -19.54383087158203, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": 3.079812526702881, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": 3.0599868297576904, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -4.361057758331299, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -13.445945739746094, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -8.224185943603516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -5.457669258117676, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -7.8514838218688965, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -14.69129467010498, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -4.073327541351318, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -10.719621658325195, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -3.484194040298462, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -21.873950958251953, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -12.562688827514648, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -14.433303833007812, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -11.538043022155762, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -5.583098411560059, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -6.319106101989746, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -4.117209434509277, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -4.087664604187012, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -5.711300373077393, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -6.448568344116211, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -9.299012184143066, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -1.6976025104522705, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -10.521522521972656, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -9.352278709411621, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -14.279708862304688, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -11.237142562866211, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -3.7602996826171875, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -14.102614402770996, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": 1.834031581878662, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -6.776103496551514, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -7.349850654602051, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -11.03607177734375, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -10.871505737304688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -10.033157348632812, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -10.515748977661133, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -10.465447425842285, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -11.220648765563965, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -9.48349380493164, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -19.80289077758789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -18.929874420166016, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -15.037124633789062, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -15.797110557556152, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -11.973806381225586, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -11.365989685058594, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -14.679963111877441, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -11.842629432678223, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -2.3008553981781006, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -5.299274444580078, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -9.47567081451416, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -8.240625381469727, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -6.985145568847656, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -1.8116092681884766, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -14.579553604125977, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -0.15882565081119537, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -11.052987098693848, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -10.534075736999512, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -12.461343765258789, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -3.4963104724884033, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -3.2063283920288086, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -4.655256271362305, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": 3.90130352973938, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -9.238557815551758, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -12.395340919494629, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -10.23513412475586, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -10.9961576461792, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -9.297804832458496, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -8.414896965026855, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -11.95994758605957, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -2.9788801670074463, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -11.210237503051758, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -9.273188591003418, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -6.25204610824585, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -9.3336181640625, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -7.024564266204834, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -4.346048831939697, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -4.706249237060547, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -7.968608379364014, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -1.565627932548523, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -6.640815258026123, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -5.302150249481201, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -6.941023349761963, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -1.2704907655715942, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -7.112493515014648, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -8.465219497680664, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -5.155795097351074, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -6.536206245422363, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -9.535880088806152, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -10.2841157913208, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -8.211404800415039, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -8.24379825592041, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -8.449947357177734, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -10.331687927246094, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -16.199155807495117, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -13.972550392150879, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -18.041168212890625, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -3.4920613765716553, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -7.985953330993652, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -7.014187335968018, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -1.605649471282959, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -8.235715866088867, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -5.29293155670166, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -9.228889465332031, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -4.049346446990967, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -10.81877613067627, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -14.659221649169922, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -4.774314880371094, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -8.7986478805542, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -4.895114898681641, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -10.780174255371094, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -8.298257827758789, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -13.849451065063477, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -2.4056859016418457, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -3.175271987915039, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": 0.10836401581764221, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -14.298521041870117, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -9.087770462036133, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -10.402381896972656, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -9.93741512298584, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -10.765823364257812, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -6.67334508895874, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -4.509544372558594, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -9.220878601074219, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -4.86932897567749, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": 4.452273368835449, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -3.046302080154419, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -9.8165922164917, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -12.620911598205566, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -5.204877853393555, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -11.999639511108398, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -2.291882038116455, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -10.168539047241211, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -16.272212982177734, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -15.966462135314941, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -8.96129322052002, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -8.631392478942871, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": 3.074772834777832, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": 0.14587892591953278, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -12.751314163208008, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -13.256711959838867, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -10.27218246459961, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -7.958676815032959, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -5.983311176300049, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -4.754218578338623, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -7.612178325653076, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -10.645689010620117, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -0.6197846531867981, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -20.461259841918945, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -20.499818801879883, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -20.013587951660156, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -14.218558311462402, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": 2.9418017864227295, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": 0.09507820010185242, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": 0.4870001971721649, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 640, \"mu_intercept_per_group\": -6.998203754425049, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 641, \"mu_intercept_per_group\": -12.70267105102539, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 642, \"mu_intercept_per_group\": -12.564757347106934, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 643, \"mu_intercept_per_group\": -13.075398445129395, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 644, \"mu_intercept_per_group\": -14.863747596740723, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 645, \"mu_intercept_per_group\": -2.4183244705200195, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 646, \"mu_intercept_per_group\": -0.7938307523727417, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 647, \"mu_intercept_per_group\": -7.049498558044434, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 648, \"mu_intercept_per_group\": -5.135613918304443, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 649, \"mu_intercept_per_group\": -3.4538235664367676, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 650, \"mu_intercept_per_group\": -3.8301169872283936, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 651, \"mu_intercept_per_group\": -8.055845260620117, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 652, \"mu_intercept_per_group\": -10.992918014526367, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 653, \"mu_intercept_per_group\": -3.1368653774261475, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 654, \"mu_intercept_per_group\": -2.5501515865325928, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 655, \"mu_intercept_per_group\": -7.712600231170654, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 656, \"mu_intercept_per_group\": -8.44206714630127, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 657, \"mu_intercept_per_group\": -14.379984855651855, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 658, \"mu_intercept_per_group\": -11.493062973022461, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 659, \"mu_intercept_per_group\": -3.9389209747314453, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 660, \"mu_intercept_per_group\": -6.9828081130981445, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 661, \"mu_intercept_per_group\": -9.729299545288086, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 662, \"mu_intercept_per_group\": -9.274621963500977, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 663, \"mu_intercept_per_group\": -8.24915599822998, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 664, \"mu_intercept_per_group\": 1.9177732467651367, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 665, \"mu_intercept_per_group\": 0.6679157614707947, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 666, \"mu_intercept_per_group\": -6.791961193084717, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 667, \"mu_intercept_per_group\": -9.511539459228516, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 668, \"mu_intercept_per_group\": -8.007267951965332, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 669, \"mu_intercept_per_group\": -3.350052833557129, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 670, \"mu_intercept_per_group\": -3.5129752159118652, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 671, \"mu_intercept_per_group\": -6.794730186462402, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 672, \"mu_intercept_per_group\": 3.360326051712036, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 673, \"mu_intercept_per_group\": -1.6963112354278564, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 674, \"mu_intercept_per_group\": -11.35863208770752, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 675, \"mu_intercept_per_group\": -9.890142440795898, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 676, \"mu_intercept_per_group\": -6.259748458862305, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 677, \"mu_intercept_per_group\": -4.0634942054748535, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 678, \"mu_intercept_per_group\": -3.5187900066375732, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 679, \"mu_intercept_per_group\": -8.828516006469727, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 680, \"mu_intercept_per_group\": -5.272643566131592, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 681, \"mu_intercept_per_group\": -5.677806854248047, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 682, \"mu_intercept_per_group\": -11.633842468261719, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 683, \"mu_intercept_per_group\": -6.39860725402832, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 684, \"mu_intercept_per_group\": -15.06329345703125, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 685, \"mu_intercept_per_group\": -13.745234489440918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 686, \"mu_intercept_per_group\": -13.775030136108398, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 687, \"mu_intercept_per_group\": -10.523633003234863, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 688, \"mu_intercept_per_group\": -13.00391674041748, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 689, \"mu_intercept_per_group\": -0.534116268157959, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 690, \"mu_intercept_per_group\": -9.273967742919922, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 691, \"mu_intercept_per_group\": -1.7329838275909424, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 692, \"mu_intercept_per_group\": -0.6396942734718323, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 693, \"mu_intercept_per_group\": -7.303791046142578, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 694, \"mu_intercept_per_group\": -12.832805633544922, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 695, \"mu_intercept_per_group\": -12.848074913024902, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 696, \"mu_intercept_per_group\": 0.7132947444915771, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 697, \"mu_intercept_per_group\": -0.01631096377968788, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 698, \"mu_intercept_per_group\": -15.826177597045898, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 699, \"mu_intercept_per_group\": -14.799540519714355, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 700, \"mu_intercept_per_group\": -15.701089859008789, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 701, \"mu_intercept_per_group\": -25.847299575805664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 702, \"mu_intercept_per_group\": -15.596050262451172, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 703, \"mu_intercept_per_group\": -3.0136518478393555, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 704, \"mu_intercept_per_group\": -10.249879837036133, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 705, \"mu_intercept_per_group\": -3.0909831523895264, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 706, \"mu_intercept_per_group\": -11.727210998535156, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 707, \"mu_intercept_per_group\": -2.4828298091888428, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 708, \"mu_intercept_per_group\": -9.143221855163574, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 709, \"mu_intercept_per_group\": -8.30216121673584, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 710, \"mu_intercept_per_group\": -15.986251831054688, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 711, \"mu_intercept_per_group\": 3.363057851791382, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 712, \"mu_intercept_per_group\": -14.843551635742188, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 713, \"mu_intercept_per_group\": -9.049310684204102, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 714, \"mu_intercept_per_group\": -11.122550964355469, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 715, \"mu_intercept_per_group\": -10.008472442626953, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 716, \"mu_intercept_per_group\": -4.341726779937744, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 717, \"mu_intercept_per_group\": -6.1400651931762695, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 718, \"mu_intercept_per_group\": -10.843049049377441, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 719, \"mu_intercept_per_group\": -16.954082489013672, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 720, \"mu_intercept_per_group\": -1.3038560152053833, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 721, \"mu_intercept_per_group\": -3.9746432304382324, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 722, \"mu_intercept_per_group\": -15.726155281066895, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 723, \"mu_intercept_per_group\": -18.059703826904297, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 724, \"mu_intercept_per_group\": -15.85275936126709, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 725, \"mu_intercept_per_group\": -15.225875854492188, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 726, \"mu_intercept_per_group\": -0.8269123435020447, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 727, \"mu_intercept_per_group\": -8.880156517028809, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 728, \"mu_intercept_per_group\": -4.952438831329346, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 729, \"mu_intercept_per_group\": 2.1097402572631836, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 730, \"mu_intercept_per_group\": -19.530475616455078, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 731, \"mu_intercept_per_group\": -12.512855529785156, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 732, \"mu_intercept_per_group\": -11.262587547302246, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 733, \"mu_intercept_per_group\": -5.691250801086426, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 734, \"mu_intercept_per_group\": -5.709987163543701, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 735, \"mu_intercept_per_group\": -13.027153015136719, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 736, \"mu_intercept_per_group\": -4.580695152282715, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 737, \"mu_intercept_per_group\": -5.58447790145874, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 738, \"mu_intercept_per_group\": -7.456693649291992, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 739, \"mu_intercept_per_group\": -4.1011481285095215, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 740, \"mu_intercept_per_group\": -7.866563320159912, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 741, \"mu_intercept_per_group\": -2.8816299438476562, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 742, \"mu_intercept_per_group\": -3.1140661239624023, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 743, \"mu_intercept_per_group\": -7.392512798309326, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 744, \"mu_intercept_per_group\": -0.40461915731430054, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 745, \"mu_intercept_per_group\": -13.69776439666748, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 746, \"mu_intercept_per_group\": -2.8043599128723145, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 747, \"mu_intercept_per_group\": -5.48544454574585, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 748, \"mu_intercept_per_group\": -6.651001930236816, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 749, \"mu_intercept_per_group\": -0.7668727040290833, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 750, \"mu_intercept_per_group\": -13.935588836669922, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 751, \"mu_intercept_per_group\": -18.877792358398438, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 752, \"mu_intercept_per_group\": -13.951913833618164, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 753, \"mu_intercept_per_group\": 1.7729135751724243, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 754, \"mu_intercept_per_group\": -10.468303680419922, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 755, \"mu_intercept_per_group\": -5.0220441818237305, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 756, \"mu_intercept_per_group\": 1.5663807392120361, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 757, \"mu_intercept_per_group\": 4.801385402679443, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 758, \"mu_intercept_per_group\": -19.007904052734375, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 759, \"mu_intercept_per_group\": -4.879411220550537, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 760, \"mu_intercept_per_group\": -4.549781799316406, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 1, \"draws\": 761, \"mu_intercept_per_group\": -2.94614577293396, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 1, \"draws\": 762, \"mu_intercept_per_group\": -4.423861980438232, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 1, \"draws\": 763, \"mu_intercept_per_group\": -7.034924507141113, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 1, \"draws\": 764, \"mu_intercept_per_group\": 1.8200410604476929, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 1, \"draws\": 765, \"mu_intercept_per_group\": -8.238364219665527, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 1, \"draws\": 766, \"mu_intercept_per_group\": -7.395601749420166, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 1, \"draws\": 767, \"mu_intercept_per_group\": -20.068384170532227, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 1, \"draws\": 768, \"mu_intercept_per_group\": -17.523784637451172, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 1, \"draws\": 769, \"mu_intercept_per_group\": -11.089550018310547, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 1, \"draws\": 770, \"mu_intercept_per_group\": -2.1942050457000732, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 1, \"draws\": 771, \"mu_intercept_per_group\": -9.11524486541748, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 1, \"draws\": 772, \"mu_intercept_per_group\": -7.53018856048584, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 1, \"draws\": 773, \"mu_intercept_per_group\": -16.917530059814453, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 1, \"draws\": 774, \"mu_intercept_per_group\": -7.4532928466796875, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 1, \"draws\": 775, \"mu_intercept_per_group\": -8.408575057983398, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 1, \"draws\": 776, \"mu_intercept_per_group\": -10.65970230102539, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 1, \"draws\": 777, \"mu_intercept_per_group\": -11.440478324890137, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 1, \"draws\": 778, \"mu_intercept_per_group\": -3.9567081928253174, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 1, \"draws\": 779, \"mu_intercept_per_group\": -3.3428282737731934, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 1, \"draws\": 780, \"mu_intercept_per_group\": -3.787095546722412, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 1, \"draws\": 781, \"mu_intercept_per_group\": -5.192613124847412, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 1, \"draws\": 782, \"mu_intercept_per_group\": -1.9134330749511719, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 1, \"draws\": 783, \"mu_intercept_per_group\": -15.909469604492188, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 1, \"draws\": 784, \"mu_intercept_per_group\": -4.824670791625977, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 1, \"draws\": 785, \"mu_intercept_per_group\": -3.8470840454101562, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 1, \"draws\": 786, \"mu_intercept_per_group\": -10.330160140991211, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 1, \"draws\": 787, \"mu_intercept_per_group\": -2.9051589965820312, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 1, \"draws\": 788, \"mu_intercept_per_group\": -1.402732014656067, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 1, \"draws\": 789, \"mu_intercept_per_group\": -1.9129210710525513, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 1, \"draws\": 790, \"mu_intercept_per_group\": -2.001810312271118, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 1, \"draws\": 791, \"mu_intercept_per_group\": -1.3983904123306274, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 1, \"draws\": 792, \"mu_intercept_per_group\": -2.998652219772339, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 1, \"draws\": 793, \"mu_intercept_per_group\": -5.212745666503906, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 1, \"draws\": 794, \"mu_intercept_per_group\": -5.740200042724609, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 1, \"draws\": 795, \"mu_intercept_per_group\": -13.511787414550781, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 1, \"draws\": 796, \"mu_intercept_per_group\": -11.45315933227539, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 1, \"draws\": 797, \"mu_intercept_per_group\": 0.3158457577228546, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 1, \"draws\": 798, \"mu_intercept_per_group\": -7.817399978637695, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 1, \"draws\": 799, \"mu_intercept_per_group\": -5.6703596115112305, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": 3.732858419418335, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -14.74763298034668, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -0.7920447587966919, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -9.022059440612793, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": 0.6570751070976257, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -15.827178001403809, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": 1.0846809148788452, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -9.276813507080078, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -8.951321601867676, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -6.864566326141357, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -1.9341707229614258, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -2.0510671138763428, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -10.089612007141113, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -10.680008888244629, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -8.804644584655762, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -6.305605888366699, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": 0.3000829219818115, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -1.7551122903823853, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -2.3900818824768066, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -7.888637065887451, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -2.895343542098999, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": 1.3380863666534424, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -23.78074073791504, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -11.098406791687012, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -3.1819076538085938, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -4.800429344177246, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": 3.4133005142211914, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -4.96135139465332, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -2.690692663192749, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -2.0235795974731445, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -4.189643383026123, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -8.388700485229492, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -8.43273639678955, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -7.213374614715576, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -15.214789390563965, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -9.292546272277832, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": -2.4623196125030518, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -4.815928936004639, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -10.999615669250488, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -2.146559476852417, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": -0.2502283751964569, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -11.01223373413086, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": 0.8173249959945679, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": 1.2063239812850952, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -7.440464973449707, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": -2.0382120609283447, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -8.468244552612305, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": -10.96498966217041, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": -3.679169178009033, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": -1.5366096496582031, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -15.801124572753906, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -13.245361328125, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -1.2482539415359497, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -1.9702545404434204, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -10.261996269226074, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -6.809752464294434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -4.980435371398926, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -1.1392760276794434, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -14.793569564819336, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -9.13333797454834, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -12.414731979370117, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -6.6255903244018555, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -7.025851726531982, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -5.728945732116699, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -33.51395034790039, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -25.522985458374023, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -9.523961067199707, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -4.857399940490723, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -5.243505001068115, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -8.11296272277832, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -4.921431064605713, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -7.549405574798584, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -10.010002136230469, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -12.585983276367188, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -12.470001220703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -13.422882080078125, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -7.613100528717041, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -13.645598411560059, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": 1.5563081502914429, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -0.2708023190498352, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -3.8437490463256836, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -10.29825496673584, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -2.2668702602386475, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -18.09571075439453, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -2.0356709957122803, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -8.436660766601562, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -11.393402099609375, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -0.09373881667852402, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -7.675854682922363, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -10.161646842956543, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -5.003331184387207, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -5.881323337554932, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -15.590445518493652, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.46782112121582, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -6.074382305145264, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -9.703702926635742, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -11.3945894241333, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -22.94749641418457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -9.107547760009766, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -5.638185501098633, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -7.5632805824279785, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -5.779253005981445, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -12.833268165588379, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -24.00741195678711, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": -17.91518783569336, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -6.520063877105713, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -17.20440673828125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -0.8397051692008972, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -6.851493835449219, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -6.914797306060791, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -3.951817035675049, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -9.044754028320312, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -3.339143991470337, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -11.259417533874512, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -1.629762053489685, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -10.254329681396484, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -8.390010833740234, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -4.76670503616333, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -4.235963821411133, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -3.3014323711395264, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -3.503049373626709, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -1.417212963104248, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -12.009513854980469, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -2.5017096996307373, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -1.5731955766677856, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -15.161019325256348, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -11.574864387512207, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -5.0208420753479, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -11.90736198425293, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -10.829822540283203, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -3.8257577419281006, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -14.482948303222656, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -1.8139958381652832, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": 2.497969388961792, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": -16.498340606689453, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -0.2805044651031494, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -11.179259300231934, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -2.3191945552825928, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -16.078134536743164, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -8.03470230102539, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -7.668808937072754, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -6.628554821014404, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -9.30042839050293, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -4.862789630889893, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -13.12014102935791, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -4.942154407501221, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -1.706308364868164, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.927155017852783, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -5.129053592681885, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -5.170759677886963, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -9.57567024230957, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": 0.7154896855354309, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -10.724403381347656, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -6.5022735595703125, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -11.366816520690918, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -2.3977396488189697, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -2.8498568534851074, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -11.582931518554688, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -6.644885540008545, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -9.830425262451172, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -7.095962047576904, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -5.265265464782715, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -0.462955117225647, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -7.801544189453125, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -5.688144683837891, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -7.555182933807373, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -11.031906127929688, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -12.016904830932617, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -12.225738525390625, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -6.396834850311279, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -8.859726905822754, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -12.181182861328125, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -1.3500686883926392, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -0.9643192291259766, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": 5.729019641876221, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -7.027344226837158, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -8.903620719909668, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -11.632333755493164, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -7.708724021911621, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -4.908493995666504, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -2.233981132507324, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -11.19131851196289, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -3.624091863632202, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -8.907787322998047, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -10.99387264251709, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -13.788372039794922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -8.753623962402344, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -4.643501281738281, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -3.7619428634643555, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -13.322681427001953, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -13.632486343383789, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -13.1654691696167, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -21.33490753173828, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -20.72462272644043, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -8.248591423034668, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -11.590217590332031, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -0.4311475455760956, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -6.358354091644287, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -5.212062835693359, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -11.44992733001709, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -8.220882415771484, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -9.12226676940918, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -19.992965698242188, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.073141574859619, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -8.739863395690918, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -6.4528117179870605, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -1.6325939893722534, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -10.420852661132812, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -7.879732608795166, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -5.497306823730469, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -9.596871376037598, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -5.04962158203125, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -5.920009613037109, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -14.4966402053833, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -12.751287460327148, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -2.2573904991149902, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -7.686809539794922, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -4.8248610496521, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -1.765623927116394, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -3.668644428253174, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -11.203539848327637, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -5.001384258270264, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -5.6280837059021, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -8.435948371887207, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -16.05109405517578, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -11.728601455688477, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -10.938681602478027, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -12.06391716003418, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -9.29641342163086, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -8.03704833984375, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": -9.065410614013672, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -4.80192232131958, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": -1.2938531637191772, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": -9.983661651611328, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -8.687374114990234, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -8.76640796661377, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -13.491843223571777, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -14.784497261047363, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -7.058042049407959, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -8.410482406616211, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": -7.969771862030029, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": -5.700320720672607, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -8.23973274230957, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -6.37434720993042, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -4.339025974273682, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -12.471747398376465, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": 2.5074687004089355, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -7.676962375640869, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -9.073676109313965, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -3.8976588249206543, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -9.184854507446289, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -8.97800350189209, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": 0.567714512348175, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -9.884993553161621, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -2.6615822315216064, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -4.578339099884033, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -4.606342792510986, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -3.4974441528320312, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -7.455306529998779, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -8.015759468078613, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -6.008310794830322, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -9.581665992736816, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -18.30813217163086, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -5.676492691040039, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -5.461687088012695, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -10.037436485290527, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -5.408499240875244, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -3.463329315185547, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -8.462669372558594, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -0.7396417856216431, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": 0.3627697825431824, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -8.535021781921387, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -14.763421058654785, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -12.69399356842041, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -5.960251808166504, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -15.310663223266602, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -11.386277198791504, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": -0.6379175186157227, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": 2.479771614074707, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -27.945741653442383, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -25.226280212402344, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -25.83666229248047, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -25.84488868713379, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": -3.639381170272827, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -3.4970641136169434, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -8.06601619720459, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -1.5408661365509033, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -8.879176139831543, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -5.490477085113525, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": 0.7783665657043457, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": -5.810604572296143, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -6.816895008087158, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": -5.717819690704346, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": -3.2649192810058594, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -7.394350051879883, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -5.316237449645996, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -4.33823823928833, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -3.374006748199463, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -3.690908670425415, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -3.286393642425537, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -6.020491600036621, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -3.8602819442749023, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -3.8057656288146973, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -11.836518287658691, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -11.771985054016113, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -2.775174379348755, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -8.22934627532959, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -5.914505481719971, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": 0.35630086064338684, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -8.621039390563965, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": 0.03868190944194794, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -7.187379360198975, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -2.533694267272949, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -13.379923820495605, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -2.356395721435547, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -8.24489974975586, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -9.023186683654785, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -10.784841537475586, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -13.656123161315918, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -3.4743764400482178, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -7.933475971221924, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -11.61305046081543, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -12.829791069030762, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -13.294774055480957, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -0.8171144723892212, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -8.221381187438965, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -6.305694580078125, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -1.9388025999069214, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -8.794182777404785, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -14.92114543914795, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": 1.2037016153335571, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -0.29571962356567383, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -2.143641233444214, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": 0.28064489364624023, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -11.181112289428711, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -17.93585777282715, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -16.54886245727539, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -14.920042037963867, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -4.039874076843262, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -2.210084915161133, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -6.806283473968506, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -8.500036239624023, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -10.403523445129395, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -12.121692657470703, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -1.4248536825180054, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -6.124846935272217, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -9.547216415405273, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -7.770440101623535, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": -1.1363286972045898, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -5.304030895233154, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -16.298486709594727, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": 0.6669440269470215, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -12.736757278442383, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -0.40219584107398987, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -11.14700698852539, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -10.505026817321777, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -13.417987823486328, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -4.444047927856445, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -5.558975696563721, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -6.314434051513672, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -5.409777641296387, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -12.233269691467285, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": 2.4941351413726807, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -8.505087852478027, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -11.589695930480957, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": 2.68093204498291, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -2.3584933280944824, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -10.62534236907959, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -11.387564659118652, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -6.608433246612549, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -11.981107711791992, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -8.635040283203125, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -5.843832015991211, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.792159557342529, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -9.92165756225586, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -0.5195949077606201, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -0.48983699083328247, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -8.744340896606445, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -4.345973968505859, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -7.0246405601501465, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -8.06035041809082, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -3.0483062267303467, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -7.415585041046143, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -4.294566631317139, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -7.638671875, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -5.52531099319458, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": -22.398527145385742, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -26.254108428955078, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -22.66168212890625, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": 11.287065505981445, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -18.271297454833984, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": 5.90974760055542, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -20.47370147705078, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": -21.0311222076416, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -24.008012771606445, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": 3.4749786853790283, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -5.57877254486084, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": 7.922347545623779, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": 3.74188494682312, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -1.6988954544067383, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -5.097616672515869, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -8.846117973327637, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": 0.1722397655248642, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -11.248380661010742, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -5.576571464538574, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -11.188019752502441, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -7.977139472961426, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -7.824069499969482, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -6.561493873596191, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -4.329862117767334, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -9.109274864196777, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -2.5585813522338867, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -3.9632863998413086, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -8.33236312866211, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": -12.320808410644531, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -5.167570114135742, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -0.7097181081771851, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -6.286855697631836, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -3.0909993648529053, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -9.099831581115723, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -9.916319847106934, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -3.4401278495788574, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -10.867147445678711, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -3.1852986812591553, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -2.7473909854888916, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -8.0872163772583, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -6.562880992889404, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": -4.1757941246032715, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -7.16696834564209, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -10.26915168762207, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -9.438253402709961, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -9.75649356842041, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -10.471683502197266, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -6.7206597328186035, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -7.505468368530273, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -12.156686782836914, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -8.14764404296875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -12.892260551452637, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -7.857025146484375, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -5.481618404388428, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -7.646692752838135, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -8.294184684753418, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -6.671442031860352, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -5.029989719390869, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -6.067749977111816, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -8.702014923095703, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -1.9200150966644287, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": 2.897442579269409, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -6.439794540405273, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -9.116233825683594, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -8.189045906066895, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -7.817679405212402, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -8.17243480682373, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -7.344018936157227, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -9.187037467956543, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -11.351550102233887, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -6.207816123962402, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -12.242033004760742, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -8.850366592407227, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -7.808396339416504, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -6.700761795043945, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -4.922554969787598, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -7.77886962890625, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -8.31988525390625, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -12.699518203735352, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": 0.7110630869865417, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -5.795843124389648, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -9.777260780334473, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -12.110445976257324, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -0.4430992007255554, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -6.092288970947266, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -14.46850872039795, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": -13.915558815002441, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -11.345191955566406, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -9.869769096374512, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -14.827057838439941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": 2.4836864471435547, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -17.392253875732422, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -1.5566017627716064, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -4.168797969818115, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -6.886236190795898, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -2.3287723064422607, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": -9.082579612731934, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -8.306184768676758, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -10.162294387817383, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -6.873996257781982, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -10.086308479309082, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -8.069391250610352, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -10.074687004089355, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -17.203676223754883, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -15.812134742736816, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -10.763212203979492, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -3.6097567081451416, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -7.371165752410889, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -10.116365432739258, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": 2.3381083011627197, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -15.05810832977295, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -3.4082698822021484, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -8.308154106140137, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -9.934334754943848, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -4.966827869415283, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -13.838757514953613, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -8.109692573547363, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -2.6857166290283203, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -12.619490623474121, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -12.56435489654541, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -10.434200286865234, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -6.927921295166016, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -6.527944564819336, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -6.607351779937744, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -12.63137435913086, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": -12.4427490234375, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -3.7763655185699463, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -9.528964042663574, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -4.6869120597839355, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -10.90855598449707, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -6.655173301696777, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -3.270554304122925, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -16.982526779174805, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -15.353683471679688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -8.847289085388184, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -10.179303169250488, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -6.731151103973389, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -7.674241542816162, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -9.233016967773438, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -11.5830717086792, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -14.37897777557373, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -4.1582865715026855, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": 0.197475865483284, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -18.406869888305664, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -6.320181369781494, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -24.789236068725586, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -8.58946704864502, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -6.373545169830322, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -16.464635848999023, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -9.792702674865723, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -8.00907039642334, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": 6.568103790283203, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -1.1935948133468628, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -4.287923336029053, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -13.90717601776123, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -13.259078979492188, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -4.4597859382629395, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": 3.266550064086914, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -17.591632843017578, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -6.757795333862305, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -3.6606576442718506, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -0.4319865107536316, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -8.018631935119629, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -9.239262580871582, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": -5.867883682250977, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -16.606130599975586, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -11.81203842163086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -7.561521530151367, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": 3.4671599864959717, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -21.93998908996582, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -4.782626628875732, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -4.104213714599609, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -6.890751838684082, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -9.23733901977539, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -4.768161773681641, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -6.677367210388184, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -9.043994903564453, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -4.714869022369385, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -3.2620174884796143, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -5.250110149383545, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -6.488597393035889, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -3.883333683013916, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -5.378838062286377, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -8.393364906311035, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -4.350249767303467, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -10.24892520904541, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -5.905289649963379, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -13.357450485229492, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -16.178735733032227, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -15.908679008483887, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -7.344059944152832, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -7.44371223449707, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -9.754671096801758, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -14.778365135192871, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": -13.482151985168457, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -7.292673587799072, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -9.378966331481934, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -9.126514434814453, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": -4.56641960144043, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -4.477183818817139, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -6.549602031707764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -6.186005592346191, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -9.142590522766113, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -6.239355564117432, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": -2.2536373138427734, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": -1.894028902053833, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -8.125317573547363, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -6.698769569396973, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -9.687060356140137, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -5.876283168792725, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -15.55165958404541, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -11.94643783569336, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -9.460631370544434, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -11.773155212402344, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -11.088447570800781, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -3.3102426528930664, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -1.4685629606246948, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -7.10137414932251, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -17.07517433166504, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -9.918875694274902, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -2.0156307220458984, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -9.946962356567383, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -7.392494201660156, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -9.749910354614258, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -7.147546291351318, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -11.540006637573242, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -9.33851432800293, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -9.769523620605469, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -12.711801528930664, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -6.6422953605651855, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -7.653461456298828, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": 0.8141601085662842, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -0.6052043437957764, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -4.644975185394287, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": 5.55590295791626, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -19.888980865478516, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": 1.2527320384979248, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -4.81308650970459, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -9.619791030883789, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -12.583415985107422, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -1.2959754467010498, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -6.864170551300049, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -8.394363403320312, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -1.894271731376648, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -8.552262306213379, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -7.477956771850586, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -12.555445671081543, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -17.114042282104492, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -17.859159469604492, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -19.37428092956543, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -4.23969841003418, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -6.650465965270996, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -7.718262672424316, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -6.551194667816162, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 640, \"mu_intercept_per_group\": -7.141420841217041, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 641, \"mu_intercept_per_group\": -12.319287300109863, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 642, \"mu_intercept_per_group\": -1.9240094423294067, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 643, \"mu_intercept_per_group\": -12.14867877960205, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 644, \"mu_intercept_per_group\": -8.549842834472656, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 645, \"mu_intercept_per_group\": -4.7822747230529785, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 646, \"mu_intercept_per_group\": -7.511908054351807, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 647, \"mu_intercept_per_group\": -8.554618835449219, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 648, \"mu_intercept_per_group\": -6.192224025726318, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 649, \"mu_intercept_per_group\": -2.184715986251831, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 650, \"mu_intercept_per_group\": 0.327439546585083, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 651, \"mu_intercept_per_group\": -8.841228485107422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 652, \"mu_intercept_per_group\": -10.685248374938965, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 653, \"mu_intercept_per_group\": -11.242206573486328, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 654, \"mu_intercept_per_group\": -10.382344245910645, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 655, \"mu_intercept_per_group\": -5.185843467712402, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 656, \"mu_intercept_per_group\": -4.3155622482299805, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 657, \"mu_intercept_per_group\": -11.385210037231445, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 658, \"mu_intercept_per_group\": -15.944779396057129, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 659, \"mu_intercept_per_group\": -9.161582946777344, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 660, \"mu_intercept_per_group\": -7.693521976470947, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 661, \"mu_intercept_per_group\": -6.487646579742432, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 662, \"mu_intercept_per_group\": -6.708395004272461, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 663, \"mu_intercept_per_group\": -3.748321771621704, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 664, \"mu_intercept_per_group\": -3.1187522411346436, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 665, \"mu_intercept_per_group\": -5.392289161682129, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 666, \"mu_intercept_per_group\": -2.2252864837646484, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 667, \"mu_intercept_per_group\": -0.012133646756410599, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 668, \"mu_intercept_per_group\": -6.209344863891602, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 669, \"mu_intercept_per_group\": -4.447170257568359, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 670, \"mu_intercept_per_group\": 0.12659278512001038, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 671, \"mu_intercept_per_group\": -4.577426433563232, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 672, \"mu_intercept_per_group\": -8.053205490112305, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 673, \"mu_intercept_per_group\": -7.424107551574707, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 674, \"mu_intercept_per_group\": -7.840348243713379, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 675, \"mu_intercept_per_group\": -12.95202350616455, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 676, \"mu_intercept_per_group\": -2.3764352798461914, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 677, \"mu_intercept_per_group\": -7.701026916503906, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 678, \"mu_intercept_per_group\": 1.1807005405426025, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 679, \"mu_intercept_per_group\": -9.633260726928711, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 680, \"mu_intercept_per_group\": -8.008782386779785, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 681, \"mu_intercept_per_group\": -2.400926351547241, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 682, \"mu_intercept_per_group\": -16.178964614868164, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 683, \"mu_intercept_per_group\": -13.101844787597656, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 684, \"mu_intercept_per_group\": -8.684494972229004, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 685, \"mu_intercept_per_group\": -6.833575248718262, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 686, \"mu_intercept_per_group\": -3.6441476345062256, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 687, \"mu_intercept_per_group\": -3.5922977924346924, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 688, \"mu_intercept_per_group\": -18.850242614746094, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 689, \"mu_intercept_per_group\": 1.0820876359939575, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 690, \"mu_intercept_per_group\": -6.514820575714111, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 691, \"mu_intercept_per_group\": -1.3514366149902344, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 692, \"mu_intercept_per_group\": -1.5759904384613037, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 693, \"mu_intercept_per_group\": 2.053717613220215, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 694, \"mu_intercept_per_group\": -4.6263651847839355, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 695, \"mu_intercept_per_group\": -6.750999450683594, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 696, \"mu_intercept_per_group\": -4.758124351501465, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 697, \"mu_intercept_per_group\": -1.9505478143692017, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 698, \"mu_intercept_per_group\": -16.749841690063477, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 699, \"mu_intercept_per_group\": -13.986458778381348, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 700, \"mu_intercept_per_group\": -17.15596580505371, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 701, \"mu_intercept_per_group\": -17.973060607910156, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 702, \"mu_intercept_per_group\": -11.176142692565918, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 703, \"mu_intercept_per_group\": -0.8515474200248718, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 704, \"mu_intercept_per_group\": -16.14752769470215, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 705, \"mu_intercept_per_group\": -17.337581634521484, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 706, \"mu_intercept_per_group\": -5.1819167137146, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 707, \"mu_intercept_per_group\": -12.231256484985352, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 708, \"mu_intercept_per_group\": 1.0472511053085327, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 709, \"mu_intercept_per_group\": -26.541973114013672, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 710, \"mu_intercept_per_group\": -4.820431232452393, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 711, \"mu_intercept_per_group\": -17.555593490600586, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 712, \"mu_intercept_per_group\": -4.313548564910889, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 713, \"mu_intercept_per_group\": -12.815875053405762, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 714, \"mu_intercept_per_group\": -7.939393997192383, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 715, \"mu_intercept_per_group\": -9.014795303344727, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 716, \"mu_intercept_per_group\": -7.826602935791016, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 717, \"mu_intercept_per_group\": -1.84090256690979, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 718, \"mu_intercept_per_group\": -8.720623016357422, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 719, \"mu_intercept_per_group\": -13.187346458435059, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 720, \"mu_intercept_per_group\": -8.846368789672852, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 721, \"mu_intercept_per_group\": -6.637916564941406, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 722, \"mu_intercept_per_group\": -3.355745315551758, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 723, \"mu_intercept_per_group\": -2.7655088901519775, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 724, \"mu_intercept_per_group\": -4.8449811935424805, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 725, \"mu_intercept_per_group\": -3.848680257797241, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 726, \"mu_intercept_per_group\": -10.032918930053711, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 727, \"mu_intercept_per_group\": -3.0833189487457275, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 728, \"mu_intercept_per_group\": -9.624643325805664, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 729, \"mu_intercept_per_group\": -5.940707683563232, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 730, \"mu_intercept_per_group\": -7.710272789001465, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 731, \"mu_intercept_per_group\": -23.57373809814453, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 732, \"mu_intercept_per_group\": -15.726632118225098, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 733, \"mu_intercept_per_group\": -7.308401584625244, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 734, \"mu_intercept_per_group\": -9.822031021118164, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 735, \"mu_intercept_per_group\": -8.193119049072266, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 736, \"mu_intercept_per_group\": -1.6803587675094604, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 737, \"mu_intercept_per_group\": -14.743664741516113, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 738, \"mu_intercept_per_group\": -11.672747611999512, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 739, \"mu_intercept_per_group\": -8.721245765686035, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 740, \"mu_intercept_per_group\": -9.85912036895752, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 741, \"mu_intercept_per_group\": -1.3250946998596191, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 742, \"mu_intercept_per_group\": -6.714052677154541, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 743, \"mu_intercept_per_group\": -4.2093281745910645, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 744, \"mu_intercept_per_group\": -6.668892860412598, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 745, \"mu_intercept_per_group\": -3.4528956413269043, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 746, \"mu_intercept_per_group\": -6.977998733520508, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 747, \"mu_intercept_per_group\": -5.103305339813232, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 748, \"mu_intercept_per_group\": 0.21640686690807343, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 749, \"mu_intercept_per_group\": -2.2673940658569336, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 750, \"mu_intercept_per_group\": -1.6518634557724, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 751, \"mu_intercept_per_group\": -5.230224609375, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 752, \"mu_intercept_per_group\": -0.9623963832855225, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 753, \"mu_intercept_per_group\": -11.71789264678955, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 754, \"mu_intercept_per_group\": -3.776665210723877, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 755, \"mu_intercept_per_group\": -11.82597541809082, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 756, \"mu_intercept_per_group\": -12.082707405090332, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 757, \"mu_intercept_per_group\": -12.341635704040527, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 758, \"mu_intercept_per_group\": -14.834488868713379, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 759, \"mu_intercept_per_group\": -9.986968994140625, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 760, \"mu_intercept_per_group\": -10.320402145385742, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 2, \"draws\": 761, \"mu_intercept_per_group\": -13.905303955078125, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 2, \"draws\": 762, \"mu_intercept_per_group\": -16.491025924682617, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 2, \"draws\": 763, \"mu_intercept_per_group\": -5.7081732749938965, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 2, \"draws\": 764, \"mu_intercept_per_group\": -14.90152645111084, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 2, \"draws\": 765, \"mu_intercept_per_group\": -0.3089122772216797, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 2, \"draws\": 766, \"mu_intercept_per_group\": -15.320383071899414, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 2, \"draws\": 767, \"mu_intercept_per_group\": -4.846121788024902, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 2, \"draws\": 768, \"mu_intercept_per_group\": -6.406315326690674, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 2, \"draws\": 769, \"mu_intercept_per_group\": -10.758137702941895, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 2, \"draws\": 770, \"mu_intercept_per_group\": -7.8329854011535645, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 2, \"draws\": 771, \"mu_intercept_per_group\": 0.8221447467803955, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 2, \"draws\": 772, \"mu_intercept_per_group\": -21.661827087402344, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 2, \"draws\": 773, \"mu_intercept_per_group\": -12.66462230682373, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 2, \"draws\": 774, \"mu_intercept_per_group\": -14.172645568847656, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 2, \"draws\": 775, \"mu_intercept_per_group\": -8.050253868103027, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 2, \"draws\": 776, \"mu_intercept_per_group\": -11.800787925720215, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 2, \"draws\": 777, \"mu_intercept_per_group\": -21.02047348022461, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 2, \"draws\": 778, \"mu_intercept_per_group\": -7.51196813583374, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 2, \"draws\": 779, \"mu_intercept_per_group\": -8.911922454833984, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 2, \"draws\": 780, \"mu_intercept_per_group\": -10.23464298248291, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 2, \"draws\": 781, \"mu_intercept_per_group\": -2.848794460296631, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 2, \"draws\": 782, \"mu_intercept_per_group\": -3.9888498783111572, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 2, \"draws\": 783, \"mu_intercept_per_group\": -12.056135177612305, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 2, \"draws\": 784, \"mu_intercept_per_group\": -7.282134056091309, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 2, \"draws\": 785, \"mu_intercept_per_group\": -5.6719231605529785, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 2, \"draws\": 786, \"mu_intercept_per_group\": 0.6745861172676086, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 2, \"draws\": 787, \"mu_intercept_per_group\": -1.0155054330825806, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 2, \"draws\": 788, \"mu_intercept_per_group\": -8.687138557434082, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 2, \"draws\": 789, \"mu_intercept_per_group\": -7.499844074249268, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 2, \"draws\": 790, \"mu_intercept_per_group\": -2.866102933883667, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 2, \"draws\": 791, \"mu_intercept_per_group\": -3.8333287239074707, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 2, \"draws\": 792, \"mu_intercept_per_group\": -6.34598970413208, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 2, \"draws\": 793, \"mu_intercept_per_group\": -14.285922050476074, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 2, \"draws\": 794, \"mu_intercept_per_group\": -17.319591522216797, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 2, \"draws\": 795, \"mu_intercept_per_group\": -12.132493019104004, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 2, \"draws\": 796, \"mu_intercept_per_group\": -7.3018975257873535, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 2, \"draws\": 797, \"mu_intercept_per_group\": -10.934429168701172, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 2, \"draws\": 798, \"mu_intercept_per_group\": 1.3345128297805786, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 2, \"draws\": 799, \"mu_intercept_per_group\": -7.95594596862793, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": 1.1422832012176514, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": 3.4451889991760254, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -13.309249877929688, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -2.334221363067627, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -2.6834938526153564, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -1.050855040550232, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": -11.638349533081055, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -3.4021027088165283, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": -4.454543590545654, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -4.641628742218018, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": 1.0176398754119873, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": 1.382218837738037, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -4.815413475036621, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": 5.528326988220215, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": 8.008136749267578, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": 11.768983840942383, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -5.568403720855713, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -6.959604740142822, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -6.039422512054443, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": 2.300753116607666, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -5.080330848693848, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": -4.960811614990234, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -0.6755471229553223, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": 2.055466651916504, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": 15.956356048583984, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": 4.9173808097839355, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -14.728536605834961, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": -13.294828414916992, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -5.873209476470947, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": 2.3663792610168457, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -1.0872663259506226, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": 1.0575892925262451, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -0.23079244792461395, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -6.030643463134766, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -7.986595630645752, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -3.6445791721343994, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -1.7929785251617432, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -10.452860832214355, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -6.082972049713135, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -1.2904764413833618, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -0.5038827657699585, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -1.9818707704544067, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": -2.4391608238220215, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -3.6116600036621094, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": 1.880308985710144, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -1.596183180809021, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": 10.43369197845459, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": 10.978118896484375, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": 11.816225051879883, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": 7.06320858001709, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": 5.699960708618164, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.811556339263916, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": 7.416693687438965, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": 5.239987373352051, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -6.371124744415283, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -6.321715354919434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -0.8365016579627991, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -1.100523829460144, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -9.814924240112305, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -2.12493634223938, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.7239115238189697, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -6.467557430267334, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -9.944820404052734, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -9.137910842895508, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": 4.786907196044922, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": 7.342767715454102, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": 21.530065536499023, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -3.220067024230957, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -2.410952568054199, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -0.7614163756370544, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -3.118800163269043, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -7.121359348297119, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": 0.9711492657661438, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -9.067095756530762, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.610410690307617, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -1.9965918064117432, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -5.7381486892700195, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -5.407534599304199, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -3.1097052097320557, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -0.051551930606365204, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": 1.6425068378448486, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": 2.8682215213775635, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": -5.482365131378174, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.255630016326904, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -1.8998559713363647, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -4.396988391876221, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": 0.8396350145339966, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": 1.5524109601974487, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": 4.776217460632324, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": 11.44230842590332, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": 9.291142463684082, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": -5.650680065155029, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": 0.710728645324707, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -5.860079765319824, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": 3.1312332153320312, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": 1.5535598993301392, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -2.915241003036499, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": 0.9959485530853271, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": 8.354219436645508, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.838305950164795, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": -5.439314842224121, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": 4.786798477172852, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -1.9363937377929688, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -7.338453769683838, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": 0.36386746168136597, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": -10.497365951538086, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -8.698169708251953, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": 0.6599807143211365, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -4.565549373626709, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -4.984137535095215, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -3.4180290699005127, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -2.035233736038208, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": -2.8604378700256348, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": -3.704653263092041, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": 1.111017107963562, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -0.39979448914527893, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -6.098702430725098, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -1.463597059249878, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -0.000967649684753269, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": -2.249558448791504, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": -2.216856002807617, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": -4.691045761108398, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -0.8590145707130432, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -4.1990814208984375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -3.9876046180725098, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -0.9444401264190674, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -3.738778591156006, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": -9.33457088470459, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -1.212861180305481, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -9.126809120178223, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -16.431392669677734, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": 1.9312454462051392, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -6.761323928833008, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -2.729433536529541, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": 0.7777804732322693, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -6.178104877471924, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": 0.9076302647590637, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -6.937652587890625, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -2.5492546558380127, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -4.945709705352783, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -1.7667300701141357, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": 0.7200169563293457, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": 3.5294952392578125, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -4.999780178070068, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -2.732987642288208, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": 1.1399319171905518, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -0.09409604221582413, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -2.603269338607788, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": 2.263167381286621, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -2.1555821895599365, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": -4.189473628997803, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -1.4529013633728027, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": -2.817486524581909, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -0.8714385628700256, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -8.482097625732422, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": 4.959986686706543, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -6.086630344390869, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": 2.741875410079956, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -7.743535995483398, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": 11.827567100524902, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": 14.373174667358398, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -11.803725242614746, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": -17.219268798828125, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": 10.779607772827148, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": -7.521295070648193, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": 2.204723834991455, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": -0.06757959723472595, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -7.076362133026123, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -19.321819305419922, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": 10.665518760681152, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -15.639404296875, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": 7.635056018829346, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -0.4615268409252167, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": 8.905537605285645, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": 5.470874786376953, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -0.41181477904319763, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -3.8645167350769043, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": 2.6198697090148926, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -0.5493851900100708, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -2.6867988109588623, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -2.045103073120117, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -2.85786771774292, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -1.5691494941711426, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -6.313195705413818, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -5.157509803771973, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -1.6202298402786255, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": 0.9412631392478943, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -9.106287002563477, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -11.040139198303223, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": 5.320924758911133, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -1.043454885482788, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": 2.8296430110931396, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -3.5491135120391846, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -3.0336110591888428, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": 4.867432594299316, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -0.9833825826644897, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -0.5252104997634888, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": -5.145560264587402, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -4.320082187652588, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": 1.111548662185669, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -2.541640520095825, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -6.575405120849609, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -11.184614181518555, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -5.859685897827148, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -4.4939703941345215, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -6.390528202056885, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": 8.489559173583984, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -10.59765338897705, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -9.754304885864258, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -2.605734348297119, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": 3.5903382301330566, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -7.091739177703857, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -7.92171573638916, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": 0.17396149039268494, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -9.727476119995117, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": 3.487213373184204, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -2.6936447620391846, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": 12.155808448791504, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -3.0443296432495117, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -0.5025920271873474, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": 2.8304405212402344, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -10.801639556884766, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -0.5220856070518494, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -3.85499906539917, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -1.3167321681976318, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -6.445994853973389, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -6.1198835372924805, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": 4.902685165405273, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": 5.7540106773376465, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -5.082253456115723, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -3.7886149883270264, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -4.4853291511535645, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": 7.6265788078308105, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -1.692143201828003, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -4.007877349853516, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -3.221977710723877, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -1.347394585609436, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": 3.4872400760650635, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -6.5580620765686035, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": -5.686244010925293, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -1.484086275100708, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -6.134275436401367, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -3.998112201690674, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": 3.097943067550659, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -3.10587477684021, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -1.2060569524765015, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": 2.667961835861206, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -1.136277675628662, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": 0.020718803629279137, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": 2.6314878463745117, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -1.9009311199188232, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": -1.2595146894454956, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -1.4188594818115234, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": 0.3701774477958679, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -4.469882488250732, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -4.703858852386475, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": 2.9320223331451416, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": 3.490630865097046, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": -1.2078993320465088, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -4.197757244110107, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -6.318816661834717, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": 2.92828631401062, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -1.5768591165542603, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": 7.342698574066162, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -6.412532329559326, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": 3.4590110778808594, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": 5.967440605163574, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": 0.5187315940856934, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": 4.232466697692871, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -2.6163413524627686, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": 1.1103160381317139, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": -6.491605758666992, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -3.8196685314178467, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -2.652308702468872, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": 7.153045654296875, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -12.401137351989746, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -1.4257242679595947, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -3.7779064178466797, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": 5.371438026428223, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -10.941880226135254, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -11.144450187683105, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -3.7005515098571777, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -4.426377773284912, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -5.206786155700684, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": 8.41220474243164, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -3.45896053314209, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -2.978003740310669, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -1.7527974843978882, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -3.5697708129882812, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -7.499160289764404, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -2.673635244369507, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": -4.929272651672363, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -1.617139458656311, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -1.8594846725463867, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": -2.0745227336883545, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": 0.6467105746269226, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": 4.440384387969971, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": 1.7059365510940552, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -0.42386800050735474, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": -2.8983304500579834, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -3.9906091690063477, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -1.4967854022979736, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -2.459275960922241, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -0.5270119309425354, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -0.7536998391151428, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -4.541114807128906, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": 6.655881881713867, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -0.4428862929344177, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": 4.027284622192383, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -0.18719589710235596, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -5.053924560546875, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": -0.9571754336357117, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -4.632637977600098, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": 1.230791449546814, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -4.023431777954102, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -10.133399963378906, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -0.15544360876083374, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -5.1925859451293945, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": 10.034708976745605, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -11.376166343688965, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": -5.671952724456787, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -4.728982448577881, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -0.477090060710907, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -1.1253021955490112, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": 2.1307523250579834, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -4.218825817108154, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": 0.7177229523658752, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": 5.307969570159912, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -6.659838676452637, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": 0.8339402675628662, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -7.1644511222839355, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": 9.08468246459961, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": 8.221074104309082, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": 3.2874090671539307, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -10.034884452819824, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -7.14697790145874, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -5.812159061431885, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -9.020214080810547, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -0.0592881515622139, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -2.267007827758789, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": -2.3067283630371094, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": 2.1847925186157227, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": -8.609108924865723, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -7.968606472015381, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": 5.869666576385498, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -4.742668151855469, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": 2.67676043510437, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": -4.7433671951293945, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -5.591422080993652, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -4.894288539886475, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": 1.1010111570358276, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -10.362127304077148, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": 7.756590366363525, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": 10.190167427062988, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -2.9594478607177734, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -1.6523555517196655, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -8.56190299987793, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -2.955606460571289, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": 1.5201140642166138, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": 0.5285970568656921, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -0.9237287640571594, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -1.2570079565048218, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": -5.493432998657227, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -3.5231142044067383, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": 1.628109097480774, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": 0.5275156497955322, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": 5.90330696105957, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -7.689522743225098, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": 0.6258456707000732, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -8.762786865234375, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -5.9061994552612305, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -6.406050205230713, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -2.177804708480835, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -3.175398349761963, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.53462815284729, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.8630146980285645, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -3.1630401611328125, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -4.196714878082275, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -2.6307883262634277, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": 0.23636986315250397, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": 1.7251968383789062, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": -8.066803932189941, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -9.934847831726074, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": 10.237847328186035, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -16.784555435180664, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -14.604349136352539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -12.49198055267334, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -18.91082191467285, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -12.75493335723877, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": 8.327741622924805, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": -5.912790775299072, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -5.286569595336914, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -5.302486896514893, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -4.904359340667725, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -3.9771060943603516, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -2.971621513366699, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.789281845092773, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": 0.550115704536438, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -1.1442714929580688, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": 0.5929803252220154, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": -4.128983020782471, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": 0.654107928276062, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": 1.1824840307235718, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -4.839790344238281, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -3.5365540981292725, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.722402572631836, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": 3.623861074447632, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -1.5331995487213135, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -0.9055638909339905, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": -4.37939977645874, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -0.09710405766963959, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -4.23989725112915, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -5.184539318084717, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -1.9728769063949585, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": -5.851361274719238, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": 2.593122720718384, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": 3.2033915519714355, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -3.1738393306732178, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": 0.07471458613872528, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -5.293779373168945, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -0.15786832571029663, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": 7.1509528160095215, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -3.041566848754883, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -8.282413482666016, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": -8.749505043029785, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": 12.567148208618164, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -7.595125198364258, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -4.985073089599609, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -2.9983041286468506, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": 2.977707862854004, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -0.13216590881347656, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": 0.08115331083536148, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": 1.0226789712905884, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -6.061187744140625, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -12.322136878967285, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": 5.065090179443359, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": 7.918672561645508, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": 5.867305755615234, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": 2.042487621307373, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -0.6973666548728943, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -1.4755373001098633, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -0.40214118361473083, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": 1.972685694694519, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -5.049294948577881, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": 3.5060598850250244, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -3.3422980308532715, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": -2.1599979400634766, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -0.16590610146522522, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -0.675101637840271, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -1.7655251026153564, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": -3.0615193843841553, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": 0.9273499846458435, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -6.301034927368164, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -5.81266975402832, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -12.09800910949707, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -16.9748477935791, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -0.8389238119125366, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": 13.40527629852295, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": 4.561748027801514, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": 0.8433964848518372, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -6.979583263397217, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -0.5884028673171997, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -4.402454853057861, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -4.225096702575684, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -6.455096244812012, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -5.126056671142578, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -9.202210426330566, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -13.092423439025879, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": 2.330103874206543, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -3.111171245574951, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -1.5748965740203857, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": 6.025733470916748, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": -20.092267990112305, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -11.896636962890625, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": 0.13928580284118652, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": 8.409333229064941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -5.502542018890381, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -4.66280460357666, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -1.5036921501159668, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": 2.001307964324951, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": 5.179535865783691, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": 0.6891594529151917, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -3.987020254135132, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -3.130981683731079, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -8.0926513671875, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": 3.002039670944214, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -10.398992538452148, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -0.7789192795753479, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": 16.261219024658203, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -15.879326820373535, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -14.116984367370605, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -5.021420001983643, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": 0.48141056299209595, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": 3.443138360977173, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": -4.203012943267822, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": 1.2212390899658203, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": 2.878952741622925, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -4.4430155754089355, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -1.9320683479309082, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": 3.059864044189453, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": -1.5174566507339478, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -7.900796890258789, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -7.854007720947266, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": 5.19315242767334, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": 2.12386155128479, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": 2.578529119491577, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -1.7175145149230957, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -3.82033371925354, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": 0.0025268117897212505, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -5.460965156555176, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -0.6229301691055298, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -0.009420330636203289, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": 5.668510913848877, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -5.805806636810303, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -5.268351078033447, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": 3.3501031398773193, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": 2.2356791496276855, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -2.5880022048950195, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -6.686184883117676, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -7.809329509735107, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -5.405384540557861, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": 1.952531337738037, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -11.692564010620117, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -6.440998554229736, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -10.477301597595215, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": 7.941324234008789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": 9.543127059936523, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": 5.6837639808654785, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": 1.7521110773086548, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -5.787217140197754, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -7.043797969818115, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -8.691217422485352, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -3.84586238861084, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": 1.4004701375961304, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -1.488426685333252, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -6.012677192687988, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -1.4134918451309204, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.400400400161743, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": 0.3176666498184204, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -7.941269874572754, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -0.4374779462814331, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -5.062107563018799, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": 2.9750351905822754, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": 0.8638477325439453, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -1.4666558504104614, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": 5.508360862731934, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": 3.3465919494628906, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": 6.344620704650879, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": -2.2002763748168945, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -14.220636367797852, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": 6.004452705383301, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -19.313186645507812, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": 3.035220146179199, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -7.511860370635986, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": -1.2900664806365967, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -2.8503220081329346, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -6.260819435119629, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": -2.5331246852874756, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -8.642271995544434, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": 4.178277492523193, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": 2.3975954055786133, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -5.3959641456604, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -0.10079754143953323, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -4.879522323608398, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": 3.477522134780884, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -6.130655288696289, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": 1.7411397695541382, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": 9.138921737670898, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -10.642536163330078, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": 8.479148864746094, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": 6.1939873695373535, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": -11.953067779541016, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -9.57574462890625, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -12.450737953186035, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -1.5178221464157104, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": 0.982293963432312, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -4.705238342285156, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -1.3431538343429565, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -4.971939563751221, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -0.4891444742679596, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": 0.38888153433799744, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": 1.532944679260254, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -7.4955596923828125, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -10.090048789978027, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": 8.15038013458252, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": 7.267123699188232, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -2.7479090690612793, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": -9.160313606262207, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": -2.9178810119628906, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -1.0811572074890137, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -1.5299677848815918, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -3.080362558364868, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -6.4926676750183105, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -0.15025557577610016, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -5.4212188720703125, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": 0.12190693616867065, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -8.257290840148926, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -6.4581708908081055, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -1.8280775547027588, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -4.033593654632568, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": -2.4062139987945557, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -14.466475486755371, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": 3.689469575881958, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": 3.022028684616089, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -4.515467166900635, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -4.477755069732666, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -2.8041117191314697, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": 2.587585210800171, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": 6.183584213256836, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": 7.167823791503906, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": 9.330349922180176, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -0.7203639149665833, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -12.502355575561523, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": -10.53499984741211, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": 1.4793434143066406, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -9.836216926574707, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": 5.254878997802734, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -0.6041688323020935, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": 3.4832756519317627, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -3.310424327850342, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -6.958009719848633, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": 1.9582477807998657, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": 0.9501878023147583, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": 0.5971997380256653, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": 1.221201777458191, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -2.0772831439971924, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -5.599991321563721, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": 1.1452524662017822, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -3.9608592987060547, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": 2.485051155090332, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -6.193269729614258, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -5.742509841918945, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": 0.0498674251139164, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -13.879101753234863, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -14.36821460723877, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -18.042510986328125, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -3.22035813331604, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -1.0437861680984497, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": 0.015396964736282825, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -1.583577275276184, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 640, \"mu_intercept_per_group\": -2.0819149017333984, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 641, \"mu_intercept_per_group\": -0.7863612771034241, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 642, \"mu_intercept_per_group\": 7.002364635467529, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 643, \"mu_intercept_per_group\": 4.588798999786377, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 644, \"mu_intercept_per_group\": -10.203553199768066, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 645, \"mu_intercept_per_group\": 12.023187637329102, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 646, \"mu_intercept_per_group\": 6.173324108123779, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 647, \"mu_intercept_per_group\": 3.815366744995117, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 648, \"mu_intercept_per_group\": 1.77543306350708, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 649, \"mu_intercept_per_group\": 0.8806454539299011, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 650, \"mu_intercept_per_group\": 0.8425295352935791, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 651, \"mu_intercept_per_group\": -5.0908989906311035, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 652, \"mu_intercept_per_group\": -6.294406890869141, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 653, \"mu_intercept_per_group\": -4.240575790405273, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 654, \"mu_intercept_per_group\": 1.1153373718261719, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 655, \"mu_intercept_per_group\": -8.701765060424805, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 656, \"mu_intercept_per_group\": -8.359423637390137, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 657, \"mu_intercept_per_group\": -9.169832229614258, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 658, \"mu_intercept_per_group\": -4.485829830169678, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 659, \"mu_intercept_per_group\": -1.2002664804458618, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 660, \"mu_intercept_per_group\": -1.283840298652649, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 661, \"mu_intercept_per_group\": 0.8676854968070984, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 662, \"mu_intercept_per_group\": 1.0672951936721802, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 663, \"mu_intercept_per_group\": 4.966071605682373, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 664, \"mu_intercept_per_group\": -5.618011474609375, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 665, \"mu_intercept_per_group\": -3.85263729095459, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 666, \"mu_intercept_per_group\": 1.6280697584152222, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 667, \"mu_intercept_per_group\": 6.69218635559082, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 668, \"mu_intercept_per_group\": -1.8946659564971924, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 669, \"mu_intercept_per_group\": -3.206312417984009, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 670, \"mu_intercept_per_group\": -7.758072853088379, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 671, \"mu_intercept_per_group\": -8.816082000732422, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 672, \"mu_intercept_per_group\": -2.9414925575256348, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 673, \"mu_intercept_per_group\": 0.16837017238140106, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 674, \"mu_intercept_per_group\": -3.6111299991607666, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 675, \"mu_intercept_per_group\": -4.992269039154053, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 676, \"mu_intercept_per_group\": -0.8869007229804993, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 677, \"mu_intercept_per_group\": -3.622464656829834, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 678, \"mu_intercept_per_group\": -6.170212745666504, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 679, \"mu_intercept_per_group\": -8.245932579040527, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 680, \"mu_intercept_per_group\": -15.151115417480469, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 681, \"mu_intercept_per_group\": 5.21836519241333, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 682, \"mu_intercept_per_group\": -16.357988357543945, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 683, \"mu_intercept_per_group\": -1.631963849067688, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 684, \"mu_intercept_per_group\": -10.513628959655762, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 685, \"mu_intercept_per_group\": -9.62197494506836, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 686, \"mu_intercept_per_group\": -20.429683685302734, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 687, \"mu_intercept_per_group\": -21.109054565429688, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 688, \"mu_intercept_per_group\": -1.9177546501159668, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 689, \"mu_intercept_per_group\": -1.488953948020935, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 690, \"mu_intercept_per_group\": 1.6919147968292236, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 691, \"mu_intercept_per_group\": 2.763578176498413, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 692, \"mu_intercept_per_group\": -3.010648012161255, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 693, \"mu_intercept_per_group\": -6.339518070220947, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 694, \"mu_intercept_per_group\": 0.133871391415596, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 695, \"mu_intercept_per_group\": -2.2540857791900635, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 696, \"mu_intercept_per_group\": 1.3386919498443604, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 697, \"mu_intercept_per_group\": -0.2260308414697647, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 698, \"mu_intercept_per_group\": -8.835453987121582, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 699, \"mu_intercept_per_group\": 1.3694179058074951, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 700, \"mu_intercept_per_group\": 1.7521642446517944, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 701, \"mu_intercept_per_group\": -0.28043603897094727, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 702, \"mu_intercept_per_group\": -1.9403650760650635, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 703, \"mu_intercept_per_group\": -6.318399906158447, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 704, \"mu_intercept_per_group\": 13.841275215148926, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 705, \"mu_intercept_per_group\": 1.4841045141220093, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 706, \"mu_intercept_per_group\": 3.645707607269287, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 707, \"mu_intercept_per_group\": 1.5687335729599, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 708, \"mu_intercept_per_group\": -3.1403298377990723, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 709, \"mu_intercept_per_group\": -2.7531683444976807, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 710, \"mu_intercept_per_group\": -18.587854385375977, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 711, \"mu_intercept_per_group\": -5.753057479858398, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 712, \"mu_intercept_per_group\": 5.228336811065674, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 713, \"mu_intercept_per_group\": 3.0528054237365723, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 714, \"mu_intercept_per_group\": -6.099391937255859, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 715, \"mu_intercept_per_group\": -8.292634010314941, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 716, \"mu_intercept_per_group\": 1.57783842086792, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 717, \"mu_intercept_per_group\": 1.708120346069336, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 718, \"mu_intercept_per_group\": -1.237881064414978, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 719, \"mu_intercept_per_group\": -13.32564640045166, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 720, \"mu_intercept_per_group\": 2.978395938873291, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 721, \"mu_intercept_per_group\": -3.8427343368530273, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 722, \"mu_intercept_per_group\": 2.4600279331207275, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 723, \"mu_intercept_per_group\": 3.6240856647491455, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 724, \"mu_intercept_per_group\": 3.1564455032348633, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 725, \"mu_intercept_per_group\": 5.206112861633301, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 726, \"mu_intercept_per_group\": -10.339628219604492, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 727, \"mu_intercept_per_group\": 10.391362190246582, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 728, \"mu_intercept_per_group\": -13.145536422729492, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 729, \"mu_intercept_per_group\": -3.039750099182129, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 730, \"mu_intercept_per_group\": -1.8714406490325928, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 731, \"mu_intercept_per_group\": 2.5062243938446045, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 732, \"mu_intercept_per_group\": 2.355806827545166, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 733, \"mu_intercept_per_group\": 4.35094690322876, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 734, \"mu_intercept_per_group\": 2.01265811920166, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 735, \"mu_intercept_per_group\": -6.302050590515137, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 736, \"mu_intercept_per_group\": 1.2704237699508667, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 737, \"mu_intercept_per_group\": -6.088379859924316, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 738, \"mu_intercept_per_group\": 1.4410150051116943, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 739, \"mu_intercept_per_group\": -4.998089790344238, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 740, \"mu_intercept_per_group\": -1.0717111825942993, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 741, \"mu_intercept_per_group\": -2.8326401710510254, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 742, \"mu_intercept_per_group\": 0.5562751293182373, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 743, \"mu_intercept_per_group\": -4.102422714233398, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 744, \"mu_intercept_per_group\": -0.6741512417793274, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 745, \"mu_intercept_per_group\": -6.860042572021484, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 746, \"mu_intercept_per_group\": -7.127810001373291, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 747, \"mu_intercept_per_group\": -5.695292949676514, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 748, \"mu_intercept_per_group\": 8.79918384552002, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 749, \"mu_intercept_per_group\": 3.3661038875579834, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 750, \"mu_intercept_per_group\": -1.9716641902923584, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 751, \"mu_intercept_per_group\": 3.977968215942383, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 752, \"mu_intercept_per_group\": -4.175975799560547, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 753, \"mu_intercept_per_group\": -3.6886377334594727, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 754, \"mu_intercept_per_group\": -1.2347979545593262, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 755, \"mu_intercept_per_group\": -5.9835991859436035, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 756, \"mu_intercept_per_group\": -10.218194961547852, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 757, \"mu_intercept_per_group\": -4.862447261810303, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 758, \"mu_intercept_per_group\": -10.775684356689453, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 759, \"mu_intercept_per_group\": -3.4646146297454834, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 760, \"mu_intercept_per_group\": -2.4840354919433594, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 3, \"draws\": 761, \"mu_intercept_per_group\": -0.9740098714828491, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 3, \"draws\": 762, \"mu_intercept_per_group\": -3.4814372062683105, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 3, \"draws\": 763, \"mu_intercept_per_group\": -5.168466091156006, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 3, \"draws\": 764, \"mu_intercept_per_group\": -11.178720474243164, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 3, \"draws\": 765, \"mu_intercept_per_group\": -14.58297348022461, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 3, \"draws\": 766, \"mu_intercept_per_group\": -7.081275463104248, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 3, \"draws\": 767, \"mu_intercept_per_group\": 2.7455029487609863, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 3, \"draws\": 768, \"mu_intercept_per_group\": -0.04195941239595413, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 3, \"draws\": 769, \"mu_intercept_per_group\": -1.5294663906097412, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 3, \"draws\": 770, \"mu_intercept_per_group\": 9.213594436645508, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 3, \"draws\": 771, \"mu_intercept_per_group\": -4.530481815338135, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 3, \"draws\": 772, \"mu_intercept_per_group\": -8.007185935974121, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 3, \"draws\": 773, \"mu_intercept_per_group\": -8.879368782043457, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 3, \"draws\": 774, \"mu_intercept_per_group\": -8.491690635681152, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 3, \"draws\": 775, \"mu_intercept_per_group\": 5.7926249504089355, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 3, \"draws\": 776, \"mu_intercept_per_group\": -11.696650505065918, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 3, \"draws\": 777, \"mu_intercept_per_group\": -2.5717172622680664, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 3, \"draws\": 778, \"mu_intercept_per_group\": -1.936160683631897, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 3, \"draws\": 779, \"mu_intercept_per_group\": -4.924736499786377, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 3, \"draws\": 780, \"mu_intercept_per_group\": -9.15251636505127, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 3, \"draws\": 781, \"mu_intercept_per_group\": -0.9256086349487305, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 3, \"draws\": 782, \"mu_intercept_per_group\": -2.718745470046997, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 3, \"draws\": 783, \"mu_intercept_per_group\": 0.4050230085849762, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 3, \"draws\": 784, \"mu_intercept_per_group\": -6.642741680145264, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 3, \"draws\": 785, \"mu_intercept_per_group\": 3.859210252761841, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 3, \"draws\": 786, \"mu_intercept_per_group\": -5.522294521331787, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 3, \"draws\": 787, \"mu_intercept_per_group\": 7.714738845825195, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 3, \"draws\": 788, \"mu_intercept_per_group\": -5.8960394859313965, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 3, \"draws\": 789, \"mu_intercept_per_group\": -2.492332696914673, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 3, \"draws\": 790, \"mu_intercept_per_group\": 6.8780364990234375, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 3, \"draws\": 791, \"mu_intercept_per_group\": 6.295490741729736, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 3, \"draws\": 792, \"mu_intercept_per_group\": 3.3202102184295654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 3, \"draws\": 793, \"mu_intercept_per_group\": 0.27863284945487976, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 3, \"draws\": 794, \"mu_intercept_per_group\": -0.6200317144393921, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 3, \"draws\": 795, \"mu_intercept_per_group\": -0.4486876130104065, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 3, \"draws\": 796, \"mu_intercept_per_group\": -5.382551670074463, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 3, \"draws\": 797, \"mu_intercept_per_group\": 10.205591201782227, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 3, \"draws\": 798, \"mu_intercept_per_group\": -9.05825424194336, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 3, \"draws\": 799, \"mu_intercept_per_group\": 9.337186813354492, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": -10.222573280334473, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": 0.7351592779159546, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -4.840921878814697, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -2.0387380123138428, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": 1.2483538389205933, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -2.9457359313964844, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -5.501341819763184, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -8.34166431427002, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": -1.844313621520996, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -6.937033176422119, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": -3.4211442470550537, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": 0.9551476240158081, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -0.4594762623310089, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": -2.6546359062194824, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": -0.28176337480545044, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -2.703993797302246, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": 9.14089298248291, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": 6.106947422027588, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": 6.025209426879883, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -5.250345706939697, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": 6.868474960327148, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": -2.2628467082977295, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -11.139957427978516, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": 0.7120257616043091, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": 1.6031622886657715, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": -8.283370018005371, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": -1.4586102962493896, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": -1.5663509368896484, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -9.569623947143555, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": 3.1074273586273193, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": -1.128059983253479, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": 2.5137887001037598, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -1.8959046602249146, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -5.683225154876709, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -6.53802490234375, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -5.361851692199707, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -3.998962640762329, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -9.249808311462402, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -7.951653957366943, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": 6.277647495269775, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": 0.48686710000038147, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": -0.9286237955093384, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": 5.7846903800964355, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": 3.9058072566986084, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": 12.240160942077637, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": 7.2814507484436035, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -10.052249908447266, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": -10.43879222869873, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": 7.636048316955566, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": 9.484684944152832, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": 7.747954845428467, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -5.559622287750244, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -1.6774073839187622, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": 0.3476562798023224, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": -1.2113286256790161, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": 2.4230000972747803, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": 3.167386293411255, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": -1.7299370765686035, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -3.0267183780670166, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": 0.589921772480011, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -8.071708679199219, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -0.665273129940033, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -5.544233798980713, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": 0.5462062954902649, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -6.977456569671631, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -9.465309143066406, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": 2.9924938678741455, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": -0.47992295026779175, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": -0.25456222891807556, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -3.280860662460327, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": 1.5002942085266113, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -3.6058130264282227, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -0.7466505765914917, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -3.2043683528900146, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": -5.266552448272705, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": -12.962620735168457, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": -8.191950798034668, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": 1.2133440971374512, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -3.3012075424194336, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -4.116568088531494, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": 1.3200589418411255, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": 1.343465805053711, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -5.596874237060547, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -10.104131698608398, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": 3.3133914470672607, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": 5.00221061706543, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": 5.407783508300781, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -4.314720153808594, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": 18.991758346557617, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": -0.6752288937568665, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": -0.48365887999534607, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": -3.6919829845428467, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": 4.215518474578857, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -6.701752662658691, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": 4.814064979553223, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": 3.983412265777588, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -4.883889198303223, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -3.206291675567627, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": 3.3244102001190186, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": 5.707808971405029, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": 7.159797191619873, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -1.932453989982605, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": 3.110919713973999, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": -2.2059030532836914, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": 7.051965713500977, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": -4.265612602233887, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -12.290275573730469, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": 4.426063537597656, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": -2.242264747619629, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": -1.0556801557540894, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": -0.9302979111671448, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": -4.810073375701904, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": 1.5923924446105957, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": -3.728991746902466, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": 5.562324047088623, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": 3.485109329223633, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -0.3389970064163208, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -3.247162103652954, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": 1.2077232599258423, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": -1.7801531553268433, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": 0.6469892859458923, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": 0.7023070454597473, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -4.512775421142578, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -2.7560360431671143, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -1.5878812074661255, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -6.278449058532715, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -5.4340410232543945, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": -5.3703436851501465, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": 2.3976669311523438, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": -4.363067150115967, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -6.9952712059021, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -10.892335891723633, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": 3.478604793548584, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": 0.783741295337677, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": -4.214395523071289, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": 2.311872959136963, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -6.152163028717041, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": 3.9275498390197754, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": -7.379451274871826, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": 1.9290038347244263, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -5.134275913238525, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -2.58302640914917, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": 1.8919726610183716, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": 3.966975212097168, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -7.511531829833984, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -4.661186218261719, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": 4.783458232879639, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": 0.015353485941886902, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -2.604113817214966, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": 2.289116859436035, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -8.103594779968262, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": 2.359726667404175, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": -1.2524923086166382, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -3.437492847442627, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": 0.6847198605537415, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -1.9796546697616577, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": 5.471470355987549, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": -4.455415725708008, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": -2.1415693759918213, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": 5.087538719177246, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": 4.994999408721924, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": 3.9994425773620605, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": 3.4031996726989746, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -8.986064910888672, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": 3.3010106086730957, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -1.4659618139266968, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": 0.22813911736011505, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": 4.13400936126709, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -1.0655854940414429, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -5.3494873046875, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": 2.6429660320281982, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -2.794489622116089, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": 0.44388440251350403, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": 5.480645179748535, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": 2.0663249492645264, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": 3.190870761871338, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": 0.4560146629810333, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -1.3204753398895264, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": 4.639101505279541, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -2.3368122577667236, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": -0.12557123601436615, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -4.177392482757568, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -1.4043046236038208, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": 3.410184144973755, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": -4.618890762329102, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": 0.9706475734710693, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -5.469550132751465, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -10.25925350189209, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -5.198490142822266, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": 0.6035569906234741, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -4.91817045211792, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -1.833343744277954, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -1.9475245475769043, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -4.199075222015381, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -0.6295586228370667, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -7.06285285949707, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -7.332114219665527, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": -1.8951919078826904, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": -1.390397548675537, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": 5.134096145629883, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -3.130772352218628, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": -3.425441026687622, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -10.429344177246094, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -6.859905242919922, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -7.089567184448242, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -7.857722759246826, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -6.922474384307861, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": 0.9095247983932495, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": 1.1069105863571167, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -8.023462295532227, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -11.704340934753418, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": 5.241725921630859, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": 4.544750213623047, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -9.038421630859375, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -4.5517048835754395, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -2.0782558917999268, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": 4.884559154510498, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": -0.8930679559707642, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": 3.2035889625549316, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": 3.412111520767212, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": 6.3044891357421875, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -9.152482032775879, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": -0.036205701529979706, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -2.2955758571624756, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -11.870111465454102, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": 5.123497486114502, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -21.790081024169922, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -19.68638038635254, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -15.662795066833496, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": 10.203377723693848, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": 8.00701904296875, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": 5.623378276824951, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": 6.930778980255127, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": -2.4476048946380615, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": -4.406008720397949, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": -0.639160692691803, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -8.552936553955078, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -7.73972749710083, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": 1.669751524925232, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": -5.550314903259277, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -1.334588646888733, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -7.068094730377197, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -5.390186786651611, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": 1.802512764930725, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": 2.1883575916290283, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -2.4512076377868652, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": 0.2697095572948456, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": 2.4418365955352783, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": 3.1828649044036865, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -0.5853416919708252, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": -1.688409447669983, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": -0.321841835975647, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": 1.7025400400161743, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -5.3715972900390625, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -2.4557180404663086, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": -4.347818374633789, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -4.5496344566345215, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -3.889549732208252, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": -9.831265449523926, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -7.587305545806885, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -9.38453483581543, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": 11.450456619262695, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": 10.535062789916992, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -9.374042510986328, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -7.373213768005371, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -2.8359947204589844, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -3.4654200077056885, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": -1.794429898262024, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": 7.437652587890625, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": -3.163054943084717, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": 0.7324626445770264, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": 3.7192869186401367, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": 4.074527740478516, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": 3.914069890975952, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": 4.926583290100098, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": 1.005097508430481, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -6.599051475524902, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -13.909625053405762, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -14.652721405029297, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": 16.287742614746094, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": 15.183490753173828, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": 8.074374198913574, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": 7.079869747161865, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.352164268493652, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": 3.445081949234009, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": -0.13314545154571533, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": 0.12403306365013123, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": 3.615466833114624, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": 2.841648578643799, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": 6.290352821350098, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": -3.2495901584625244, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": -6.687504768371582, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": 1.56047523021698, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": -1.3200434446334839, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": -1.990303874015808, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": -0.9329994916915894, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": -0.19775116443634033, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": 4.739821434020996, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": 4.048184871673584, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": 0.6300459504127502, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": 0.37932610511779785, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": -1.1257051229476929, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": 0.17781753838062286, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.540189027786255, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -5.3517045974731445, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": 3.7807674407958984, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": 3.5766971111297607, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": 6.87188720703125, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": -0.2200179249048233, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": 4.251936435699463, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": 1.6953351497650146, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -1.2283800840377808, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": -5.675398349761963, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": 4.123122215270996, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -4.602899074554443, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": 2.192589044570923, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -5.83239221572876, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -5.904195785522461, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -6.1403422355651855, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": 2.6582698822021484, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -4.622495174407959, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -2.3200156688690186, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -10.623682975769043, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -15.656454086303711, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -11.915611267089844, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -7.29128885269165, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -9.28799057006836, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": -1.5844402313232422, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -9.355169296264648, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -9.797776222229004, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": 1.6542587280273438, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": 8.481145858764648, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": 4.470423221588135, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -1.3096708059310913, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -10.22557544708252, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -2.129939556121826, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": -3.6794984340667725, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": -2.065094470977783, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -3.083914041519165, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": 4.107353687286377, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": -1.0638706684112549, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": -1.496822714805603, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": -3.2917540073394775, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": 3.55251145362854, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": -2.9563403129577637, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": 4.9263505935668945, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": -9.568013191223145, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": -13.995607376098633, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": -4.618760108947754, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": 5.174973487854004, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -7.510647296905518, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": 5.256582260131836, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": -6.16785192489624, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": 2.0095841884613037, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": -0.8866797089576721, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": 1.922220230102539, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": 3.6239891052246094, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -8.089971542358398, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": 7.619902610778809, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -8.913562774658203, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": -8.175060272216797, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": -0.1956782341003418, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -1.8559167385101318, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": 2.4483916759490967, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": 2.8031749725341797, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": 1.4116320610046387, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": 1.2916738986968994, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": 0.016939561814069748, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -6.3288960456848145, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": -0.9084743857383728, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -2.4604382514953613, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -4.6587233543396, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -3.721674680709839, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -3.6613924503326416, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -7.367818355560303, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -2.456761598587036, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -0.811137855052948, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -3.5969862937927246, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": 3.7880971431732178, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": 2.0546035766601562, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": 3.7384068965911865, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -3.1992483139038086, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": 4.091832637786865, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": 3.10144305229187, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": 8.00448989868164, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -12.494241714477539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": -15.75905990600586, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": -15.911749839782715, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": -14.960686683654785, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": 7.879668712615967, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": -5.545164585113525, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -8.131694793701172, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": 6.875602722167969, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": 4.374419212341309, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": 6.496573448181152, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": -5.026095390319824, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -8.928727149963379, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -11.550392150878906, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -8.368969917297363, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -6.962975025177002, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": 6.889718055725098, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": 2.922802448272705, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": -4.909971237182617, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": -2.0281882286071777, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -0.21226929128170013, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -2.285454750061035, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -0.6161280274391174, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": 2.2025299072265625, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": -2.122138738632202, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": 4.103301525115967, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": -5.548608779907227, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": 2.7988741397857666, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -8.01515007019043, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": 0.42529040575027466, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": -3.6517932415008545, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": -0.5515525341033936, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": 2.0600452423095703, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": -1.0337955951690674, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": -1.0684521198272705, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -2.2774314880371094, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": -7.314043045043945, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -2.4525113105773926, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -4.27780818939209, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": 1.5510914325714111, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": -0.1506415456533432, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -3.740121841430664, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -5.2863545417785645, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": 5.354739665985107, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": 0.6194051504135132, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -4.08737850189209, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -2.1308741569519043, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -1.3846282958984375, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -2.911750555038452, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -9.480743408203125, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -1.6755708456039429, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -5.225432395935059, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": 4.965527057647705, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": 0.765901505947113, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -0.2432432472705841, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": 1.9107531309127808, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": 1.245962142944336, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -2.8260066509246826, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": 6.900586128234863, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -5.26108455657959, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": 2.28515625, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -4.239246845245361, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": 3.115494966506958, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -2.684730052947998, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -1.2988783121109009, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.9401421546936035, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -2.1803243160247803, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -3.8678042888641357, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": 1.2255836725234985, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": 0.8233058452606201, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": 6.4001641273498535, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -3.6718525886535645, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": 3.9332029819488525, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": 6.823799133300781, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -0.9171903133392334, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": -4.349397659301758, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": 1.7256262302398682, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -3.1465160846710205, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": 0.9560574889183044, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -3.488286256790161, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": 5.763370513916016, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -6.90833044052124, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": 0.5493221879005432, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -1.9435194730758667, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": -0.7900018692016602, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -7.044142246246338, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -6.870087146759033, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -6.215428352355957, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -0.42390817403793335, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -3.4466910362243652, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": 1.4385346174240112, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": 2.753023624420166, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": 2.7223126888275146, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": -6.31094217300415, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": 6.110436916351318, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": 6.438925743103027, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": 5.934630870819092, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": 4.618720054626465, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": -4.0582733154296875, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -8.378496170043945, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -9.8966646194458, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": 1.2092821598052979, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": -4.2657575607299805, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": 7.811222076416016, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": 1.8952081203460693, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": 2.6893508434295654, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": 5.602606296539307, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": 4.052567481994629, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -2.7636845111846924, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -1.1795055866241455, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -4.659461975097656, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": 7.605453968048096, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": -1.9424526691436768, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": 1.479622721672058, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": 4.631229877471924, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": 2.5250823497772217, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": 0.3759743273258209, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -8.323416709899902, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -1.308106780052185, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": -0.3469439446926117, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": -2.320566415786743, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": -1.714707612991333, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": 1.4244813919067383, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": 1.5334476232528687, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": 3.9070937633514404, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -9.991410255432129, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -0.1964610517024994, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": -2.2191975116729736, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -5.656458854675293, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -6.365799427032471, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -0.8335336446762085, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -1.2123515605926514, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": 6.899072647094727, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": 4.415450572967529, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -14.038524627685547, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -6.8309102058410645, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -1.3698656558990479, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -10.225632667541504, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": -2.8464319705963135, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": 0.6432567238807678, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -0.3441639244556427, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": -4.115943908691406, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": -4.275806903839111, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -1.2931828498840332, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -12.119006156921387, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -19.19034767150879, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": 2.8981902599334717, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": 2.008270263671875, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": 5.80705451965332, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": 1.1107293367385864, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -6.476484775543213, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -8.136292457580566, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": 0.5145658254623413, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -5.958985328674316, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": 1.2898212671279907, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -0.7434753775596619, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": -14.839637756347656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": 9.21174430847168, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -11.331006050109863, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -12.430768013000488, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": 3.0895018577575684, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": 0.7254382371902466, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": 2.220641851425171, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": 4.793663501739502, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": 0.6892642974853516, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -2.923584222793579, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": -5.301235198974609, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -2.648239850997925, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": -15.617238998413086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": 5.484040260314941, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": -0.8728763461112976, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -0.5054839253425598, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -0.6188060641288757, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -4.285893440246582, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -7.326533794403076, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -0.6164996027946472, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": 1.4153728485107422, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -9.29893684387207, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": -8.429384231567383, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": 5.165633201599121, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": -1.2580235004425049, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": 2.07047438621521, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": 0.11970026791095734, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": 3.7929165363311768, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -1.8149521350860596, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": 13.338642120361328, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": 6.8847150802612305, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -7.743525505065918, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -4.1702446937561035, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -5.477596282958984, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": -5.992972373962402, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": 2.686174154281616, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -5.086594104766846, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -8.534751892089844, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": 4.817463397979736, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -4.412678241729736, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -9.72543716430664, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -13.762779235839844, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": 4.749863147735596, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": -7.763848781585693, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": 9.345660209655762, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": 2.645254373550415, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -0.2019905000925064, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": 0.8105884790420532, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": 1.4256742000579834, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -3.2158706188201904, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": -0.8970597386360168, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": 0.28827059268951416, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -0.01489965058863163, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -7.373693943023682, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -0.13117434084415436, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -4.393489360809326, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -0.5609362125396729, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": 2.605276107788086, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": 2.394541025161743, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": 0.8525758385658264, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -4.941886901855469, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -4.616106986999512, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": 13.114214897155762, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -12.420550346374512, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": 2.9929749965667725, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": -0.11894222348928452, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -2.2654402256011963, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": 3.9687790870666504, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": 8.39231014251709, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": 19.870697021484375, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": 17.059907913208008, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": 0.5694618225097656, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": 5.5281548500061035, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": -3.6333203315734863, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": -10.495563507080078, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": 4.230743408203125, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": -5.583453178405762, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.991307497024536, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": 1.5501219034194946, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": 3.2045388221740723, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -6.84132194519043, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": 11.670865058898926, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -11.415975570678711, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -10.994959831237793, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -11.472407341003418, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -8.113114356994629, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": 4.982320308685303, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": 4.659554481506348, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -4.935208320617676, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": 9.936370849609375, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -10.630620956420898, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": -2.723560333251953, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -11.783170700073242, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -1.104187250137329, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -1.1529127359390259, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -7.889201641082764, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": 14.02910041809082, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": -5.565239906311035, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": -4.031822681427002, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": -1.7019822597503662, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 640, \"mu_intercept_per_group\": -0.26659125089645386, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 641, \"mu_intercept_per_group\": -4.296065330505371, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 642, \"mu_intercept_per_group\": -10.37691879272461, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 643, \"mu_intercept_per_group\": -18.959091186523438, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 644, \"mu_intercept_per_group\": 2.9422106742858887, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 645, \"mu_intercept_per_group\": -9.414095878601074, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 646, \"mu_intercept_per_group\": 5.117735385894775, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 647, \"mu_intercept_per_group\": 1.6604464054107666, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 648, \"mu_intercept_per_group\": 8.517123222351074, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 649, \"mu_intercept_per_group\": -5.795717239379883, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 650, \"mu_intercept_per_group\": -0.7973559498786926, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 651, \"mu_intercept_per_group\": 2.1765658855438232, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 652, \"mu_intercept_per_group\": -8.471039772033691, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 653, \"mu_intercept_per_group\": 2.805842638015747, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 654, \"mu_intercept_per_group\": 0.9290947318077087, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 655, \"mu_intercept_per_group\": -11.014189720153809, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 656, \"mu_intercept_per_group\": 4.851659774780273, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 657, \"mu_intercept_per_group\": -5.456446170806885, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 658, \"mu_intercept_per_group\": -7.925178527832031, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 659, \"mu_intercept_per_group\": 3.368788003921509, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 660, \"mu_intercept_per_group\": -2.5615501403808594, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 661, \"mu_intercept_per_group\": -0.13357359170913696, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 662, \"mu_intercept_per_group\": -1.440045952796936, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 663, \"mu_intercept_per_group\": -4.536013603210449, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 664, \"mu_intercept_per_group\": 3.1310298442840576, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 665, \"mu_intercept_per_group\": 3.234423875808716, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 666, \"mu_intercept_per_group\": -3.2979557514190674, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 667, \"mu_intercept_per_group\": -2.1722490787506104, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 668, \"mu_intercept_per_group\": -3.063098430633545, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 669, \"mu_intercept_per_group\": -0.7444708943367004, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 670, \"mu_intercept_per_group\": -2.700894355773926, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 671, \"mu_intercept_per_group\": -0.5761053562164307, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 672, \"mu_intercept_per_group\": 1.9821075201034546, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 673, \"mu_intercept_per_group\": 9.100384712219238, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 674, \"mu_intercept_per_group\": -8.743980407714844, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 675, \"mu_intercept_per_group\": -2.040138006210327, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 676, \"mu_intercept_per_group\": -2.3280317783355713, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 677, \"mu_intercept_per_group\": 1.358982801437378, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 678, \"mu_intercept_per_group\": -4.481082916259766, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 679, \"mu_intercept_per_group\": -0.7191506028175354, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 680, \"mu_intercept_per_group\": -3.6019070148468018, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 681, \"mu_intercept_per_group\": -7.443073749542236, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 682, \"mu_intercept_per_group\": -6.465905666351318, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 683, \"mu_intercept_per_group\": -7.507283687591553, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 684, \"mu_intercept_per_group\": -0.38660094141960144, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 685, \"mu_intercept_per_group\": 0.3696950376033783, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 686, \"mu_intercept_per_group\": -9.97179889678955, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 687, \"mu_intercept_per_group\": -9.013978958129883, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 688, \"mu_intercept_per_group\": 5.4107584953308105, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 689, \"mu_intercept_per_group\": -9.146997451782227, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 690, \"mu_intercept_per_group\": 9.48569107055664, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 691, \"mu_intercept_per_group\": -5.376854419708252, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 692, \"mu_intercept_per_group\": -6.184321880340576, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 693, \"mu_intercept_per_group\": -7.036289215087891, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 694, \"mu_intercept_per_group\": -7.786212921142578, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 695, \"mu_intercept_per_group\": -11.990128517150879, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 696, \"mu_intercept_per_group\": 10.64962387084961, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 697, \"mu_intercept_per_group\": 8.805665969848633, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 698, \"mu_intercept_per_group\": -13.136034965515137, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 699, \"mu_intercept_per_group\": -11.427478790283203, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 700, \"mu_intercept_per_group\": -11.816218376159668, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 701, \"mu_intercept_per_group\": -11.609723091125488, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 702, \"mu_intercept_per_group\": -4.233506202697754, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 703, \"mu_intercept_per_group\": 4.785616397857666, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 704, \"mu_intercept_per_group\": -4.93176794052124, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 705, \"mu_intercept_per_group\": -8.722419738769531, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 706, \"mu_intercept_per_group\": -2.6878652572631836, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 707, \"mu_intercept_per_group\": -6.328852653503418, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 708, \"mu_intercept_per_group\": 8.036919593811035, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 709, \"mu_intercept_per_group\": 0.8848922848701477, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 710, \"mu_intercept_per_group\": -11.791319847106934, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 711, \"mu_intercept_per_group\": -8.944643020629883, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 712, \"mu_intercept_per_group\": -3.957019567489624, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 713, \"mu_intercept_per_group\": -2.2577407360076904, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 714, \"mu_intercept_per_group\": -8.689230918884277, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 715, \"mu_intercept_per_group\": -3.3575379848480225, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 716, \"mu_intercept_per_group\": 3.798638343811035, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 717, \"mu_intercept_per_group\": 1.9333914518356323, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 718, \"mu_intercept_per_group\": -1.0012797117233276, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 719, \"mu_intercept_per_group\": -7.519647598266602, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 720, \"mu_intercept_per_group\": 1.144483208656311, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 721, \"mu_intercept_per_group\": -5.495861530303955, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 722, \"mu_intercept_per_group\": 7.084209442138672, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 723, \"mu_intercept_per_group\": 12.742281913757324, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 724, \"mu_intercept_per_group\": 9.369956016540527, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 725, \"mu_intercept_per_group\": 12.737908363342285, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 726, \"mu_intercept_per_group\": -6.68929386138916, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 727, \"mu_intercept_per_group\": 5.712256908416748, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 728, \"mu_intercept_per_group\": -7.096992015838623, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 729, \"mu_intercept_per_group\": -10.005788803100586, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 730, \"mu_intercept_per_group\": 5.818517684936523, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 731, \"mu_intercept_per_group\": -6.018786430358887, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 732, \"mu_intercept_per_group\": -0.7372608184814453, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 733, \"mu_intercept_per_group\": -2.1605422496795654, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 734, \"mu_intercept_per_group\": -9.852314949035645, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 735, \"mu_intercept_per_group\": -7.954211235046387, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 736, \"mu_intercept_per_group\": -0.5064754486083984, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 737, \"mu_intercept_per_group\": -4.683851718902588, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 738, \"mu_intercept_per_group\": -3.0086984634399414, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 739, \"mu_intercept_per_group\": -1.696182131767273, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 740, \"mu_intercept_per_group\": -6.719401836395264, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 741, \"mu_intercept_per_group\": 3.822751522064209, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 742, \"mu_intercept_per_group\": -4.209133148193359, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 743, \"mu_intercept_per_group\": -3.0948832035064697, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 744, \"mu_intercept_per_group\": 1.826290488243103, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 745, \"mu_intercept_per_group\": 2.9357244968414307, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 746, \"mu_intercept_per_group\": -6.093136787414551, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 747, \"mu_intercept_per_group\": -10.260705947875977, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 748, \"mu_intercept_per_group\": 8.261493682861328, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 749, \"mu_intercept_per_group\": 7.822362422943115, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 750, \"mu_intercept_per_group\": 4.961631774902344, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 751, \"mu_intercept_per_group\": -7.214239120483398, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 752, \"mu_intercept_per_group\": -6.27641487121582, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 753, \"mu_intercept_per_group\": 3.171701431274414, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 754, \"mu_intercept_per_group\": -4.702463626861572, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 755, \"mu_intercept_per_group\": 3.1011359691619873, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 756, \"mu_intercept_per_group\": 6.190070629119873, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 757, \"mu_intercept_per_group\": 4.508309364318848, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 758, \"mu_intercept_per_group\": -6.019010066986084, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 759, \"mu_intercept_per_group\": -2.8097918033599854, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 760, \"mu_intercept_per_group\": -4.367959499359131, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 4, \"draws\": 761, \"mu_intercept_per_group\": -2.824897050857544, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 4, \"draws\": 762, \"mu_intercept_per_group\": -3.17814564704895, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 4, \"draws\": 763, \"mu_intercept_per_group\": 3.206871509552002, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 4, \"draws\": 764, \"mu_intercept_per_group\": -2.970684766769409, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 4, \"draws\": 765, \"mu_intercept_per_group\": -5.780794620513916, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 4, \"draws\": 766, \"mu_intercept_per_group\": -1.0261821746826172, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 4, \"draws\": 767, \"mu_intercept_per_group\": 1.2663980722427368, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 4, \"draws\": 768, \"mu_intercept_per_group\": 1.2258639335632324, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 4, \"draws\": 769, \"mu_intercept_per_group\": -13.134469985961914, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 4, \"draws\": 770, \"mu_intercept_per_group\": 6.728440284729004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 4, \"draws\": 771, \"mu_intercept_per_group\": -5.930309295654297, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 4, \"draws\": 772, \"mu_intercept_per_group\": 2.635946273803711, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 4, \"draws\": 773, \"mu_intercept_per_group\": -11.658357620239258, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 4, \"draws\": 774, \"mu_intercept_per_group\": 5.645565032958984, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 4, \"draws\": 775, \"mu_intercept_per_group\": -13.9772367477417, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 4, \"draws\": 776, \"mu_intercept_per_group\": 6.683927059173584, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 4, \"draws\": 777, \"mu_intercept_per_group\": 3.967349052429199, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 4, \"draws\": 778, \"mu_intercept_per_group\": -2.4375128746032715, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 4, \"draws\": 779, \"mu_intercept_per_group\": 0.6895599365234375, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 4, \"draws\": 780, \"mu_intercept_per_group\": -0.7696780562400818, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 4, \"draws\": 781, \"mu_intercept_per_group\": -5.970967769622803, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 4, \"draws\": 782, \"mu_intercept_per_group\": 6.066479682922363, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 4, \"draws\": 783, \"mu_intercept_per_group\": -9.849822044372559, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 4, \"draws\": 784, \"mu_intercept_per_group\": 1.4375027418136597, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 4, \"draws\": 785, \"mu_intercept_per_group\": -2.4956202507019043, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 4, \"draws\": 786, \"mu_intercept_per_group\": 5.292853832244873, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 4, \"draws\": 787, \"mu_intercept_per_group\": -3.307516574859619, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 4, \"draws\": 788, \"mu_intercept_per_group\": 3.7796382904052734, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 4, \"draws\": 789, \"mu_intercept_per_group\": 4.240785121917725, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 4, \"draws\": 790, \"mu_intercept_per_group\": 11.235593795776367, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 4, \"draws\": 791, \"mu_intercept_per_group\": 10.83666706085205, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 4, \"draws\": 792, \"mu_intercept_per_group\": 2.236236810684204, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 4, \"draws\": 793, \"mu_intercept_per_group\": 0.5667391419410706, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 4, \"draws\": 794, \"mu_intercept_per_group\": -0.7058081030845642, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 4, \"draws\": 795, \"mu_intercept_per_group\": 7.67421817779541, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 4, \"draws\": 796, \"mu_intercept_per_group\": 2.026370048522949, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 4, \"draws\": 797, \"mu_intercept_per_group\": -1.2830697298049927, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 4, \"draws\": 798, \"mu_intercept_per_group\": 7.946447849273682, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 4, \"draws\": 799, \"mu_intercept_per_group\": 4.5653300285339355, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": -0.4936830699443817, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": 4.999171733856201, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": 0.6521782875061035, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": -1.6964330673217773, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": -1.5742603540420532, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": 5.283847808837891, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -11.31496810913086, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": -7.817002773284912, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": 0.5827797651290894, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": 0.2344091534614563, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": 6.792243003845215, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": -4.55280876159668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": 8.97771167755127, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": -4.939431667327881, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": -6.270378589630127, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": -1.8578853607177734, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": 8.810626029968262, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": 5.960352420806885, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": 5.344428539276123, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": 2.4586939811706543, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": 2.2995917797088623, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": 8.367406845092773, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": -6.627414226531982, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": -7.080750465393066, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": 5.021615028381348, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": 6.678419589996338, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": -7.590822219848633, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": 11.360928535461426, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": -5.0973334312438965, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": -0.12444468587636948, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": 0.7130396366119385, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": -1.6190998554229736, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": -0.8674359917640686, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": -1.1215295791625977, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": -5.713323593139648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": -0.21671302616596222, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": 5.190096855163574, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": 3.9520068168640137, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": -3.222916841506958, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": 3.779146194458008, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": 6.8436994552612305, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": -1.0128411054611206, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": 1.1723310947418213, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": 2.092717170715332, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": 2.262239456176758, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": 3.3816802501678467, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": 11.33073902130127, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": 11.15568733215332, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": 2.1022276878356934, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": 3.293247699737549, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": 8.383138656616211, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -11.438764572143555, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": 10.426858901977539, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": 2.6837852001190186, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": 1.2202776670455933, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": 3.7525627613067627, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": 6.483628273010254, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": -2.9187285900115967, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": 3.0211901664733887, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": -1.909820556640625, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": -2.5282647609710693, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": -1.0716947317123413, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": -0.8831166625022888, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": 3.354220390319824, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": -0.743996798992157, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": -0.5231768488883972, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": 8.232260704040527, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": 5.46297550201416, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": 4.69611120223999, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": 6.057387351989746, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": -4.416680335998535, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": 7.120400428771973, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": -7.168479919433594, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": -4.501968860626221, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": 8.21909236907959, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": 12.967597007751465, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": 8.842602729797363, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": -6.817704200744629, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": 0.530376672744751, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": 0.791788637638092, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": 2.006030321121216, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": 2.4872610569000244, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": -1.5326536893844604, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": 2.0414907932281494, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": -3.798283576965332, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": -1.8039244413375854, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": 2.816776752471924, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": 2.3101511001586914, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": 1.285831332206726, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": 14.7088041305542, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": 18.254072189331055, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": -7.443060398101807, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": 3.5992915630340576, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": 1.4925298690795898, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": 4.014184474945068, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": 2.11476731300354, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": 2.2457776069641113, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": 7.356701374053955, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": 10.132861137390137, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": -1.5818636417388916, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -2.462308168411255, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": 3.594944953918457, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": 1.8588958978652954, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": -0.5524792671203613, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": -0.6232576370239258, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": -13.410273551940918, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": -4.3677520751953125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": 1.3094727993011475, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -2.6252894401550293, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -4.273194313049316, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": 2.41314959526062, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": -2.153839111328125, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": 9.022931098937988, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": -7.887650966644287, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": 10.30448055267334, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": -9.876293182373047, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": 2.5861124992370605, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": 0.7091243863105774, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": 1.57363760471344, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": -0.503716230392456, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": 2.7997069358825684, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": 1.6879323720932007, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": -1.311571478843689, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": -2.7984085083007812, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": 0.46960511803627014, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": 7.710426330566406, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": 5.7630486488342285, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": -9.305146217346191, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": -2.0171682834625244, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": 3.2463467121124268, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -3.0720536708831787, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": -3.7099852561950684, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": -2.9686715602874756, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": 0.2306564897298813, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": 2.247824192047119, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": -1.3220113515853882, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": 0.9232107400894165, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": -0.6540190577507019, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": 1.9786392450332642, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": 0.9563783407211304, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": 0.7334156632423401, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": 2.3041305541992188, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": 0.6046547889709473, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": 8.854641914367676, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": -6.714970588684082, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -3.7840960025787354, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": 6.502985954284668, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": -1.8866745233535767, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": 7.441204071044922, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": -8.213418960571289, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": 11.891451835632324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": -0.8685718774795532, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": 3.430837631225586, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": 2.514370918273926, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": 0.09311062097549438, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": 1.293937087059021, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": 0.13305164873600006, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": 3.293895721435547, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": 4.343166828155518, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": 0.6446264386177063, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": 9.81774616241455, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": -2.293382406234741, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": -9.398703575134277, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": 0.90650874376297, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": 3.8641912937164307, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": -0.6476548910140991, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": 5.717311859130859, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": 11.154617309570312, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": 5.177521228790283, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": -5.699761867523193, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": 7.650353908538818, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": -3.251162052154541, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": 2.78304123878479, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": 8.93648624420166, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": 6.478943824768066, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": 2.8575520515441895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": 2.173811912536621, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": 0.5168248414993286, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": -0.9173110127449036, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": 1.0983010530471802, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": -1.128238320350647, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": 1.9474482536315918, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": 2.668318510055542, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": -2.6685452461242676, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": 2.5534586906433105, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": -9.7943115234375, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": -6.563799858093262, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -27.31961441040039, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -17.76662254333496, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": 8.505128860473633, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": 7.133119583129883, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": 8.601794242858887, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -2.6739165782928467, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": 2.1650185585021973, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": 4.0482635498046875, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": 9.812962532043457, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -3.7973835468292236, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": 3.87325382232666, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": 3.8319015502929688, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": 4.967145919799805, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": 3.728036403656006, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -8.574662208557129, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": 8.672873497009277, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": -7.8326802253723145, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": 12.981729507446289, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": 10.628742218017578, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": 0.11629725247621536, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": 5.866535186767578, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": 9.66776180267334, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -8.2392578125, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -8.03979778289795, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": 6.960459232330322, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": 8.417984962463379, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": -8.75178337097168, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -10.365260124206543, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": 12.472177505493164, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": -5.03244161605835, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": 5.089905738830566, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": 11.248644828796387, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": 9.39394474029541, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": 7.524884223937988, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": 3.66719388961792, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": 8.817556381225586, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -8.847822189331055, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": -1.8955214023590088, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -12.273404121398926, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": 4.217207431793213, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": -5.044497966766357, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": 2.819262742996216, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": 3.973588466644287, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": 4.765008926391602, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": 11.957687377929688, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": 3.02358078956604, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": 3.9243686199188232, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": 3.4044294357299805, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": -2.102890968322754, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": 0.602037250995636, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": -2.007368326187134, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -6.695186614990234, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": 11.105422973632812, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": -6.331599235534668, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": 5.3391571044921875, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": 2.7552473545074463, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": 8.030393600463867, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": -1.8643521070480347, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": 2.167123794555664, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": 9.887374877929688, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": 2.273650646209717, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": 1.265815019607544, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": 2.928429365158081, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": 10.590553283691406, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": 9.917350769042969, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": -4.333336353302002, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": -1.8468070030212402, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": -0.6399343013763428, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": 0.8221684098243713, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": -0.25098690390586853, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": 0.47165754437446594, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": 2.0731589794158936, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": 3.5841410160064697, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": 1.3557088375091553, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": 13.834127426147461, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": 14.456953048706055, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": -4.042296886444092, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": 6.682328701019287, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": -3.998976945877075, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": 4.560067176818848, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": 4.257584095001221, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": 0.5953791737556458, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": 8.030223846435547, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": 7.646004676818848, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": -3.9084184169769287, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": -3.7448387145996094, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": -8.0143461227417, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": -2.0092594623565674, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": 12.668036460876465, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": 9.397951126098633, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": 0.7062256932258606, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": 2.3495936393737793, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": 5.453965663909912, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": 6.526251316070557, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -9.583497047424316, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": -9.752381324768066, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": 8.808324813842773, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": -0.7570652961730957, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": -4.107381343841553, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": 7.210703372955322, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": -4.066314697265625, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": -5.4151611328125, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": -5.232656955718994, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": -1.9585570096969604, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": -3.251300573348999, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": -1.3458646535873413, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": 1.9364404678344727, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": -0.6752256155014038, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": -4.672120094299316, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": 0.4643610417842865, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": 7.394011974334717, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": 1.7245173454284668, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": 4.1162943840026855, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": 1.4681015014648438, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": 0.9539467692375183, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": -0.36705145239830017, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": 4.102670669555664, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": 6.861858367919922, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": -4.539209365844727, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": 4.347302436828613, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": 2.8213248252868652, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": 9.329455375671387, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": 1.9890902042388916, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": 0.6505970358848572, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": 2.8247857093811035, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": 3.5750627517700195, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": -1.6562188863754272, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": 3.6209089756011963, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": 0.9198087453842163, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -0.28500208258628845, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": -0.8128213882446289, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": 6.068824768066406, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": -0.8334502577781677, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": -3.7099437713623047, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": 1.714191198348999, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": 2.0969502925872803, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": 9.183207511901855, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": 10.86903190612793, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": 4.680744171142578, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": 2.815725088119507, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": -0.5970062017440796, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": 4.627745628356934, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": 3.6387157440185547, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": 2.4396767616271973, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": 5.886763572692871, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": 4.537914752960205, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": 6.9371337890625, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": -2.9177708625793457, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": 10.82784366607666, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": 8.419905662536621, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": 5.09188175201416, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": 0.40666913986206055, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": 8.009431838989258, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": -0.05580255761742592, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": 0.024308281019330025, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": 1.5205624103546143, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": 4.1790876388549805, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": 0.2244865894317627, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": 5.782747268676758, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": -7.930447101593018, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": 0.3207881450653076, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": 2.813279151916504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -5.610894680023193, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": 7.947093486785889, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -11.681249618530273, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": 15.034317016601562, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": 0.03979386016726494, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": 14.939435958862305, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": 13.074028968811035, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": 2.1421730518341064, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": -1.7453669309616089, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": 4.593339920043945, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": 5.567477226257324, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": 5.255597114562988, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": -4.950255393981934, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": 10.510313034057617, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": 4.427967071533203, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": -0.597438395023346, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": 11.320734024047852, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": 8.22661304473877, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": -5.545265197753906, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": -8.789752006530762, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": 5.041116714477539, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": -6.190657138824463, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": 2.533984661102295, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -9.193230628967285, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -7.052367210388184, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -4.734168529510498, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -4.440606594085693, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": -3.8006691932678223, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": 1.5238863229751587, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": -1.5220943689346313, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": -0.6359741687774658, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": -7.656125068664551, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": 9.146346092224121, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": 3.1164391040802, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": 8.489348411560059, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": 1.6961735486984253, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": 8.293295860290527, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": 5.431253433227539, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": 7.830577373504639, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": 8.568206787109375, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": -7.505928993225098, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": 2.1178689002990723, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": 2.7821342945098877, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": 5.693019390106201, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": 6.2944440841674805, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": 9.706086158752441, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": -10.40073299407959, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": -3.227675437927246, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": 2.30842924118042, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": -1.5283007621765137, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": -0.5001562833786011, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": 9.165095329284668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": 1.4900716543197632, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": -0.8814666867256165, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": -2.0296337604522705, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": 1.3305256366729736, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": 5.04124641418457, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": -4.7146782875061035, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": 5.809991359710693, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": 5.043154239654541, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": -1.7293035984039307, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": 3.3898768424987793, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": -0.8397834300994873, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": 5.915778636932373, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": 1.9669221639633179, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": 3.1190719604492188, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": -0.2337658703327179, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": 6.688932418823242, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": -2.4702565670013428, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": 2.3119709491729736, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": -3.015862464904785, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": -5.686969757080078, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": 4.881800174713135, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": -6.422973155975342, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": 9.18946647644043, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": 9.735956192016602, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": -12.410496711730957, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": 11.598301887512207, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": -2.832165479660034, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": -3.3463351726531982, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": 3.6924684047698975, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": 4.8262858390808105, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": 4.859366416931152, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": 4.933337211608887, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": 5.615426063537598, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": 7.1026291847229, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": -2.526503562927246, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": 14.279303550720215, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": 14.049449920654297, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": 10.146956443786621, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": -1.6144288778305054, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": -3.103341817855835, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": -10.78703498840332, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": -2.24977445602417, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": 7.7816481590271, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": 2.440359115600586, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": 0.9812870025634766, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": 0.7519392371177673, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": 10.234559059143066, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": -0.4684623181819916, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": 4.018322467803955, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": 3.347318410873413, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": -5.998703956604004, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": 4.131516933441162, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": -3.956796884536743, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": 2.4501700401306152, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": -7.225014686584473, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": 1.4161245822906494, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": 2.6986114978790283, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": 7.647429943084717, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": 3.9245128631591797, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": -7.178640365600586, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": 6.069210052490234, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": -7.366247653961182, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": -3.059081792831421, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": -4.277634620666504, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": -4.914758682250977, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": -2.5589759349823, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -6.704737663269043, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": 5.098209857940674, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -10.468371391296387, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": -5.892239093780518, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": 2.5162999629974365, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": 3.7081711292266846, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": 3.8927412033081055, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": -1.7580379247665405, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -2.632122039794922, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": 11.085421562194824, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": -2.4329164028167725, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": 2.66679048538208, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": 1.0495461225509644, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": 0.8502023816108704, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": -5.250965118408203, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": 6.950047492980957, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": -4.0179057121276855, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": -1.5065183639526367, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": 3.951291799545288, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": -2.1402275562286377, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": 7.854623317718506, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": -2.683741807937622, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": 14.440917015075684, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": 13.877155303955078, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": 11.458995819091797, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": -3.9448370933532715, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": -2.7637362480163574, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": 1.6091384887695312, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": 10.039451599121094, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": -5.605895519256592, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": 18.840381622314453, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": 4.888682842254639, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": -0.08786775171756744, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": -2.7071421146392822, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": 1.2054929733276367, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": 5.187563896179199, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -2.718552827835083, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": 1.6928390264511108, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": 2.8258514404296875, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": -0.6238449215888977, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": 5.984460830688477, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": 0.01763044111430645, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": 5.762425422668457, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": -3.868269205093384, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": -2.518726110458374, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": 2.960270881652832, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": -3.5001561641693115, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": 7.296746730804443, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": 1.4127551317214966, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": -2.601768970489502, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": -1.4885532855987549, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": -1.7040915489196777, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -6.998692989349365, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": 2.1867520809173584, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -9.845512390136719, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": 1.1358827352523804, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": 4.276721477508545, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -1.0788450241088867, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": -1.8729008436203003, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": -0.6531848907470703, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": -4.406121730804443, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": -3.4420886039733887, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -12.418782234191895, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": 6.173922061920166, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": -8.29879093170166, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": 11.020665168762207, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": 6.808164119720459, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": 5.0015058517456055, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": -1.2744996547698975, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": 0.6806426644325256, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -7.457321643829346, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": -5.819141387939453, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": 0.915133535861969, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": -1.2011756896972656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": 6.034015655517578, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -11.381556510925293, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": -7.319867134094238, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": 3.155782461166382, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": 7.666479110717773, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": 7.782724857330322, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": 0.21381761133670807, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": 12.560585975646973, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": -2.7401819229125977, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": 0.6657583713531494, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -3.632479667663574, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": 5.7790045738220215, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": -2.5474801063537598, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": 1.1199679374694824, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": -0.8119602799415588, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": 0.2681579887866974, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": 0.7113875150680542, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": -1.5859010219573975, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": 4.05252742767334, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": 2.554129123687744, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": 3.6585235595703125, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": 1.2316629886627197, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": -0.2994779050350189, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": 5.4572930335998535, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": -4.310985565185547, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": -0.5814806222915649, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": -4.7760329246521, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": 14.579337120056152, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": -4.133450031280518, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": -4.106779098510742, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": 6.196764945983887, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": 3.545785665512085, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": 8.385534286499023, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": 0.5849117636680603, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": 5.525136470794678, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": -6.678565979003906, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -8.455256462097168, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": 8.006284713745117, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -4.586374759674072, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": -4.955859184265137, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": -6.421501636505127, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": 3.928562879562378, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": -4.06256628036499, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": 10.368810653686523, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": 5.356241703033447, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": -2.9610393047332764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": 0.6189560890197754, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": 3.154837131500244, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": -0.1340140551328659, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": 7.543446063995361, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": 1.466381549835205, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": 3.515272855758667, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": 2.2773630619049072, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": -2.729767322540283, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": 4.216533184051514, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": -5.651655197143555, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": -3.35032057762146, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": 7.401084899902344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": 4.6678242683410645, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": -0.03037027269601822, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": -4.2660136222839355, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": 1.8521217107772827, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": 0.3156644403934479, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": 1.9550424814224243, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": 9.87182331085205, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": -3.2301228046417236, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": 10.981620788574219, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": 8.075916290283203, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": 3.7643399238586426, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": 0.19077926874160767, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": 3.4784345626831055, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": 4.375865459442139, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": 1.0993521213531494, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": -8.167473793029785, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": 4.648540019989014, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": 0.35695895552635193, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": -2.8153913021087646, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": -2.977693796157837, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": -1.1377506256103516, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": 0.04873131215572357, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": 3.1761634349823, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": -0.020863207057118416, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": 1.351028561592102, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": 12.045791625976562, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": -0.5252058506011963, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -18.708921432495117, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": -12.27900505065918, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": 11.218646049499512, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": -7.135178089141846, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": 6.958343982696533, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": 5.1873908042907715, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": 1.2365093231201172, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -4.957011699676514, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -5.30355978012085, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": -5.12799072265625, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": 6.813993453979492, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": -4.477818965911865, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": -5.169980049133301, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": -2.9529480934143066, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 640, \"mu_intercept_per_group\": -7.506115913391113, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 641, \"mu_intercept_per_group\": 4.841949939727783, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 642, \"mu_intercept_per_group\": -5.881920337677002, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 643, \"mu_intercept_per_group\": 16.809703826904297, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 644, \"mu_intercept_per_group\": 2.511122941970825, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 645, \"mu_intercept_per_group\": 0.4887118637561798, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 646, \"mu_intercept_per_group\": 0.8064342737197876, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 647, \"mu_intercept_per_group\": 1.4259870052337646, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 648, \"mu_intercept_per_group\": 1.4857269525527954, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 649, \"mu_intercept_per_group\": 8.055587768554688, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 650, \"mu_intercept_per_group\": 12.786767959594727, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 651, \"mu_intercept_per_group\": 2.306870460510254, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 652, \"mu_intercept_per_group\": -6.979279518127441, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 653, \"mu_intercept_per_group\": -0.41045838594436646, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 654, \"mu_intercept_per_group\": -0.3673120439052582, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 655, \"mu_intercept_per_group\": 4.506551742553711, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 656, \"mu_intercept_per_group\": 6.2370924949646, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 657, \"mu_intercept_per_group\": -0.3215402066707611, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 658, \"mu_intercept_per_group\": 5.281808376312256, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 659, \"mu_intercept_per_group\": -2.4257640838623047, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 660, \"mu_intercept_per_group\": -0.3196414113044739, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 661, \"mu_intercept_per_group\": 3.8381330966949463, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 662, \"mu_intercept_per_group\": 3.275034189224243, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 663, \"mu_intercept_per_group\": 4.178934097290039, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 664, \"mu_intercept_per_group\": -3.322736978530884, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 665, \"mu_intercept_per_group\": -2.479078769683838, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 666, \"mu_intercept_per_group\": 3.148167371749878, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 667, \"mu_intercept_per_group\": 7.899265766143799, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 668, \"mu_intercept_per_group\": -3.881068706512451, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 669, \"mu_intercept_per_group\": 3.0566978454589844, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 670, \"mu_intercept_per_group\": -1.6932018995285034, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 671, \"mu_intercept_per_group\": 0.5915698409080505, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 672, \"mu_intercept_per_group\": 4.123375415802002, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 673, \"mu_intercept_per_group\": 6.35595178604126, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 674, \"mu_intercept_per_group\": -3.740208864212036, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 675, \"mu_intercept_per_group\": -3.8673324584960938, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 676, \"mu_intercept_per_group\": 2.7119503021240234, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 677, \"mu_intercept_per_group\": -1.8882607221603394, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 678, \"mu_intercept_per_group\": -2.162415027618408, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 679, \"mu_intercept_per_group\": -0.3742189109325409, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 680, \"mu_intercept_per_group\": -2.5472350120544434, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 681, \"mu_intercept_per_group\": 1.0873957872390747, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 682, \"mu_intercept_per_group\": -1.8083175420761108, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 683, \"mu_intercept_per_group\": -6.07248592376709, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 684, \"mu_intercept_per_group\": 4.208353519439697, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 685, \"mu_intercept_per_group\": 4.22807502746582, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 686, \"mu_intercept_per_group\": 13.54815673828125, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 687, \"mu_intercept_per_group\": 12.544894218444824, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 688, \"mu_intercept_per_group\": 1.6133661270141602, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 689, \"mu_intercept_per_group\": 3.921630382537842, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 690, \"mu_intercept_per_group\": 2.686460018157959, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 691, \"mu_intercept_per_group\": 7.2498884201049805, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 692, \"mu_intercept_per_group\": 10.887166976928711, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 693, \"mu_intercept_per_group\": 16.479183197021484, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 694, \"mu_intercept_per_group\": -0.018748529255390167, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 695, \"mu_intercept_per_group\": -0.6615126729011536, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 696, \"mu_intercept_per_group\": 8.400014877319336, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 697, \"mu_intercept_per_group\": 6.954907417297363, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 698, \"mu_intercept_per_group\": -8.435911178588867, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 699, \"mu_intercept_per_group\": -10.450371742248535, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 700, \"mu_intercept_per_group\": -13.0982084274292, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 701, \"mu_intercept_per_group\": -7.1084208488464355, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 702, \"mu_intercept_per_group\": 0.5757467150688171, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 703, \"mu_intercept_per_group\": 6.972298622131348, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 704, \"mu_intercept_per_group\": -2.0960466861724854, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 705, \"mu_intercept_per_group\": 11.447457313537598, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 706, \"mu_intercept_per_group\": -6.721770763397217, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 707, \"mu_intercept_per_group\": -10.405341148376465, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 708, \"mu_intercept_per_group\": 16.467519760131836, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 709, \"mu_intercept_per_group\": 3.6985721588134766, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 710, \"mu_intercept_per_group\": -2.596336841583252, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 711, \"mu_intercept_per_group\": 1.6006039381027222, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 712, \"mu_intercept_per_group\": 11.543874740600586, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 713, \"mu_intercept_per_group\": 4.0602850914001465, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 714, \"mu_intercept_per_group\": -5.451816082000732, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 715, \"mu_intercept_per_group\": -0.4832264482975006, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 716, \"mu_intercept_per_group\": -0.1277807354927063, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 717, \"mu_intercept_per_group\": 9.382996559143066, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 718, \"mu_intercept_per_group\": 2.7434017658233643, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 719, \"mu_intercept_per_group\": -13.703967094421387, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 720, \"mu_intercept_per_group\": 11.376761436462402, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 721, \"mu_intercept_per_group\": -8.271041870117188, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 722, \"mu_intercept_per_group\": 5.795229911804199, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 723, \"mu_intercept_per_group\": -4.5389933586120605, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 724, \"mu_intercept_per_group\": -0.5400820374488831, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 725, \"mu_intercept_per_group\": -0.4254120886325836, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 726, \"mu_intercept_per_group\": 3.012491464614868, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 727, \"mu_intercept_per_group\": -1.6920281648635864, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 728, \"mu_intercept_per_group\": 2.6638760566711426, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 729, \"mu_intercept_per_group\": 7.623227596282959, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 730, \"mu_intercept_per_group\": -3.2628395557403564, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 731, \"mu_intercept_per_group\": 3.5190138816833496, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 732, \"mu_intercept_per_group\": 4.912494659423828, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 733, \"mu_intercept_per_group\": 2.229353427886963, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 734, \"mu_intercept_per_group\": -2.8037805557250977, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 735, \"mu_intercept_per_group\": 4.959327220916748, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 736, \"mu_intercept_per_group\": -4.8769683837890625, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 737, \"mu_intercept_per_group\": 4.81979513168335, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 738, \"mu_intercept_per_group\": -2.942124605178833, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 739, \"mu_intercept_per_group\": 0.570166826248169, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 740, \"mu_intercept_per_group\": -7.019355297088623, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 741, \"mu_intercept_per_group\": 4.785904884338379, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 742, \"mu_intercept_per_group\": -0.14491762220859528, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 743, \"mu_intercept_per_group\": 2.900390625, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 744, \"mu_intercept_per_group\": -3.1168389320373535, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 745, \"mu_intercept_per_group\": -3.2361035346984863, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 746, \"mu_intercept_per_group\": 5.309395790100098, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 747, \"mu_intercept_per_group\": 0.4705502390861511, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 748, \"mu_intercept_per_group\": 4.199631690979004, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 749, \"mu_intercept_per_group\": -2.6365833282470703, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 750, \"mu_intercept_per_group\": 5.085790634155273, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 751, \"mu_intercept_per_group\": -13.19575023651123, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 752, \"mu_intercept_per_group\": -4.775232791900635, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 753, \"mu_intercept_per_group\": 8.22763442993164, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 754, \"mu_intercept_per_group\": -5.417640209197998, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 755, \"mu_intercept_per_group\": 3.015061378479004, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 756, \"mu_intercept_per_group\": -1.2819138765335083, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 757, \"mu_intercept_per_group\": -0.46969661116600037, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 758, \"mu_intercept_per_group\": -2.6609880924224854, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 759, \"mu_intercept_per_group\": 2.6079695224761963, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 760, \"mu_intercept_per_group\": 0.9872055053710938, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 5, \"draws\": 761, \"mu_intercept_per_group\": 2.336440086364746, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 5, \"draws\": 762, \"mu_intercept_per_group\": 6.431071758270264, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 5, \"draws\": 763, \"mu_intercept_per_group\": -8.56132984161377, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 5, \"draws\": 764, \"mu_intercept_per_group\": -6.293648719787598, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 5, \"draws\": 765, \"mu_intercept_per_group\": 1.003957748413086, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 5, \"draws\": 766, \"mu_intercept_per_group\": 5.770401477813721, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 5, \"draws\": 767, \"mu_intercept_per_group\": -11.149538040161133, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 5, \"draws\": 768, \"mu_intercept_per_group\": -11.574239730834961, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 5, \"draws\": 769, \"mu_intercept_per_group\": -0.7626160979270935, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 5, \"draws\": 770, \"mu_intercept_per_group\": 6.175403594970703, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 5, \"draws\": 771, \"mu_intercept_per_group\": -6.830533504486084, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 5, \"draws\": 772, \"mu_intercept_per_group\": 5.845097541809082, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 5, \"draws\": 773, \"mu_intercept_per_group\": -4.2466254234313965, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 5, \"draws\": 774, \"mu_intercept_per_group\": -7.769762992858887, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 5, \"draws\": 775, \"mu_intercept_per_group\": -11.193673133850098, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 5, \"draws\": 776, \"mu_intercept_per_group\": 11.781404495239258, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 5, \"draws\": 777, \"mu_intercept_per_group\": -3.0879199504852295, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 5, \"draws\": 778, \"mu_intercept_per_group\": 2.3158674240112305, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 5, \"draws\": 779, \"mu_intercept_per_group\": 0.16726243495941162, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 5, \"draws\": 780, \"mu_intercept_per_group\": 1.4833091497421265, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 5, \"draws\": 781, \"mu_intercept_per_group\": 6.84270715713501, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 5, \"draws\": 782, \"mu_intercept_per_group\": 4.334469318389893, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 5, \"draws\": 783, \"mu_intercept_per_group\": -4.612475395202637, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 5, \"draws\": 784, \"mu_intercept_per_group\": 4.77070951461792, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 5, \"draws\": 785, \"mu_intercept_per_group\": 4.148092746734619, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 5, \"draws\": 786, \"mu_intercept_per_group\": 3.746044158935547, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 5, \"draws\": 787, \"mu_intercept_per_group\": 1.091285228729248, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 5, \"draws\": 788, \"mu_intercept_per_group\": 7.053884506225586, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 5, \"draws\": 789, \"mu_intercept_per_group\": 6.179688930511475, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 5, \"draws\": 790, \"mu_intercept_per_group\": 0.5649715065956116, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 5, \"draws\": 791, \"mu_intercept_per_group\": 1.1186014413833618, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 5, \"draws\": 792, \"mu_intercept_per_group\": 3.0303378105163574, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 5, \"draws\": 793, \"mu_intercept_per_group\": -0.02562352456152439, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 5, \"draws\": 794, \"mu_intercept_per_group\": -1.4256608486175537, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 5, \"draws\": 795, \"mu_intercept_per_group\": -0.9958571791648865, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 5, \"draws\": 796, \"mu_intercept_per_group\": -7.086660861968994, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 5, \"draws\": 797, \"mu_intercept_per_group\": 0.7649232745170593, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 5, \"draws\": 798, \"mu_intercept_per_group\": 10.123893737792969, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 5, \"draws\": 799, \"mu_intercept_per_group\": 5.146012306213379, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 6.37800407409668, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 14.657581329345703, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 2.7958216667175293, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 6.326478004455566, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 8.790563583374023, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 12.298267364501953, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": -0.6363531351089478, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": -1.6876857280731201, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 2.2299373149871826, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": -1.037280559539795, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 12.031730651855469, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 15.604928016662598, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 2.234408378601074, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 19.13079261779785, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 13.048595428466797, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 9.782146453857422, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 23.940692901611328, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 17.576452255249023, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 16.891254425048828, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 2.0913727283477783, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 12.74721908569336, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 15.554927825927734, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 7.008159637451172, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 0.5297897458076477, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": -5.370870113372803, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": -3.994481086730957, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 13.420904159545898, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 6.839694023132324, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 15.62886905670166, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 15.634469032287598, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 3.7431771755218506, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 9.442510604858398, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 3.235412120819092, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": -0.009158127009868622, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 7.253016471862793, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 8.9336576461792, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 5.424819469451904, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 7.15634298324585, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 6.180077075958252, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 10.72684097290039, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 11.890353202819824, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 7.474733352661133, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 10.881460189819336, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 11.45950698852539, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 17.818603515625, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 17.873416900634766, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 14.556384086608887, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 14.053670883178711, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 16.005577087402344, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 12.597241401672363, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 18.503889083862305, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 16.201860427856445, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 13.740428924560547, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 7.90291166305542, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 11.19510269165039, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 6.94672155380249, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 6.028234481811523, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 13.192073822021484, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 6.797860622406006, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 11.186580657958984, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 7.806375026702881, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 4.5859832763671875, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 3.5664408206939697, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 11.656661033630371, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 6.3669753074646, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 6.91317081451416, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 15.8410062789917, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 13.86631965637207, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 13.010332107543945, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 11.788223266601562, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 8.941932678222656, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 1.099101185798645, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 15.243159294128418, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 4.105511665344238, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 13.89879035949707, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 16.440013885498047, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 11.504037857055664, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 6.29906702041626, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 12.811902046203613, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 9.99511432647705, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 8.57177734375, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 5.0281853675842285, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 8.839679718017578, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 3.568502902984619, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 13.581151008605957, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 14.884998321533203, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 13.430789947509766, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 17.065746307373047, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 8.434178352355957, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 16.63286590576172, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 17.54259490966797, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 11.752270698547363, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 7.332230567932129, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 24.714874267578125, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 4.795590877532959, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 7.172306537628174, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 14.201985359191895, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 19.431533813476562, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 17.595199584960938, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 4.940769195556641, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 6.646292209625244, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 12.10807991027832, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 20.925168991088867, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 17.2150936126709, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 15.789444923400879, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": -0.5448676943778992, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 10.840235710144043, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 3.77411150932312, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 9.024848937988281, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 8.971269607543945, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 6.913607597351074, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 7.734762668609619, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 8.881319999694824, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 14.19491958618164, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 6.7448530197143555, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 18.282974243164062, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 2.9279086589813232, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 5.77211856842041, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 3.1763241291046143, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 12.246147155761719, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 8.492447853088379, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 7.793917179107666, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 3.3679537773132324, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 7.766360282897949, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 8.348556518554688, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 11.928165435791016, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 2.9560039043426514, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 6.947440147399902, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 6.06493616104126, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 7.14630126953125, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 14.731822967529297, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": -5.351778507232666, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 17.632570266723633, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 15.330568313598633, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 5.837926864624023, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 5.051054000854492, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 2.8629238605499268, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 13.25622844696045, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 6.890820503234863, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 17.45374870300293, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 4.656808853149414, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 5.447736740112305, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 10.446636199951172, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 17.325050354003906, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 4.206713676452637, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 9.519606590270996, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 4.474648952484131, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 8.139266014099121, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 9.792088508605957, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 7.3324737548828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 9.299038887023926, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 21.717971801757812, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": -3.0196897983551025, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 2.3027780055999756, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 16.383344650268555, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 5.840900421142578, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 16.744478225708008, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 1.3772361278533936, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 16.889774322509766, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 3.7015507221221924, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 8.963178634643555, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 23.01374626159668, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 28.747516632080078, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 3.696038246154785, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 18.486228942871094, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 9.797303199768066, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 3.586526393890381, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 6.628138542175293, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 5.736710071563721, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 18.295204162597656, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 4.394664764404297, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 10.175525665283203, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 8.979989051818848, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 12.775808334350586, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 15.53598690032959, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 10.567465782165527, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 6.854046821594238, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 9.789966583251953, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 8.406659126281738, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 9.414752006530762, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 8.134831428527832, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 5.053690433502197, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 12.37542724609375, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 19.121780395507812, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 8.219120025634766, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": -4.113567352294922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 12.86084270477295, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 6.4124274253845215, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 14.1568603515625, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 6.179751873016357, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 6.407765865325928, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 4.514246940612793, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 9.066909790039062, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 8.447477340698242, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": -0.7427571415901184, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 2.9169552326202393, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 5.465841770172119, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 7.129478454589844, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 7.043885707855225, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 18.49075698852539, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 5.5466132164001465, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 9.107548713684082, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": -0.9509438872337341, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 8.018399238586426, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 16.792940139770508, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 15.597270965576172, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 12.17685604095459, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 11.676979064941406, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 13.785839080810547, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 1.019270896911621, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": -0.9723620414733887, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 15.839048385620117, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 15.420255661010742, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 8.705223083496094, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 8.651837348937988, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.884833335876465, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 18.371557235717773, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 19.368759155273438, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 21.158721923828125, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 21.188085556030273, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 9.712406158447266, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 3.391413450241089, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 9.882966995239258, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 6.421112537384033, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 10.008955955505371, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": -3.7429559230804443, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 9.174446105957031, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 3.8171348571777344, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": -7.909400939941406, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 23.378190994262695, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 22.460115432739258, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 14.530881881713867, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 17.945173263549805, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 11.54576587677002, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.558603286743164, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 10.420690536499023, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 7.529940605163574, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.042562961578369, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 10.79625129699707, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 17.17136001586914, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 3.307905673980713, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 10.444380760192871, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 11.840070724487305, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 7.593770503997803, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 13.43736457824707, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 2.7093143463134766, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 7.846211910247803, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 9.694792747497559, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 13.173310279846191, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 11.132068634033203, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 12.776078224182129, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 12.271164894104004, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 8.114533424377441, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 10.828557014465332, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 13.942134857177734, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 13.534577369689941, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 9.729780197143555, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 8.994977951049805, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 10.113740921020508, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 6.392364501953125, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 9.727726936340332, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 17.571500778198242, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 18.674175262451172, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 9.110492706298828, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 7.621195316314697, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 21.381479263305664, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 15.83483600616455, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 15.66517448425293, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 12.354133605957031, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 18.962139129638672, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 18.399394989013672, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 9.42381477355957, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 12.00529956817627, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 14.56803035736084, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 12.271184921264648, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 12.291250228881836, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 12.071014404296875, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 15.146749496459961, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 17.343830108642578, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": -1.333060622215271, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 4.346193313598633, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 8.044883728027344, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 8.11178970336914, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 10.069868087768555, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 11.644989013671875, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 16.928489685058594, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 4.277830600738525, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 11.038383483886719, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 5.344930171966553, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 1.1706016063690186, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 6.807243347167969, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 3.9913034439086914, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 4.187417984008789, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 3.5455243587493896, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 8.3716459274292, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 8.537477493286133, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 14.718498229980469, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 16.58214569091797, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 14.316944122314453, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 9.237370491027832, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 8.002992630004883, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 6.624277114868164, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 4.020396709442139, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 11.198153495788574, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 9.070198059082031, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 8.491692543029785, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 17.469974517822266, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 11.335356712341309, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 17.74886703491211, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 9.17672348022461, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 13.998625755310059, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 8.742243766784668, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 2.12756609916687, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 17.68233871459961, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 4.9308319091796875, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 12.931241035461426, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 1.631303071975708, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 3.1112074851989746, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 10.88212776184082, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 10.226880073547363, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 3.8558602333068848, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 5.853753089904785, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 5.873215198516846, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 10.582910537719727, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 15.885552406311035, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 15.327390670776367, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 15.514052391052246, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 7.55764102935791, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 18.369102478027344, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 5.824795722961426, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 15.2969970703125, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 10.23908519744873, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 8.089719772338867, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 8.985725402832031, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 9.877602577209473, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 2.4321155548095703, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 3.6842031478881836, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 3.603825807571411, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 14.202850341796875, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 1.3368322849273682, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 14.970987319946289, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 15.470149040222168, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 8.07016658782959, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 9.706025123596191, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.609657287597656, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 8.33421516418457, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 8.960545539855957, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 8.190251350402832, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 5.345642566680908, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 16.278417587280273, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 9.505990028381348, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.281876564025879, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 15.586712837219238, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 19.380855560302734, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 22.9998722076416, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 21.67023277282715, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 7.986322402954102, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 7.836185932159424, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 13.142619132995605, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 5.911583423614502, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 6.9293131828308105, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 5.969613075256348, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 7.467096328735352, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 16.103960037231445, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 16.114681243896484, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 13.09213924407959, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 13.893994331359863, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 8.880234718322754, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 9.530762672424316, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 6.0966315269470215, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 4.595323085784912, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 2.449854612350464, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": -0.11971868574619293, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": -0.2585868835449219, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": -0.2848990857601166, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 3.782630681991577, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 3.4688425064086914, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 5.765459060668945, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 6.903364181518555, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 4.840702056884766, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 7.454947471618652, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 11.113530158996582, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 10.848203659057617, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 17.729427337646484, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 11.753292083740234, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 9.986661911010742, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": -7.832437038421631, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": -3.5750222206115723, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 0.8440127968788147, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 15.552513122558594, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 6.221508026123047, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 12.048630714416504, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 2.756791114807129, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 10.313526153564453, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 11.103602409362793, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 11.494327545166016, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": -3.0313894748687744, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": -1.2790906429290771, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": -2.8456315994262695, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 1.3038175106048584, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 10.289814949035645, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 10.481236457824707, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 7.539891719818115, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 9.063453674316406, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 5.2259440422058105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 7.041718006134033, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 6.661810874938965, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 4.747824192047119, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 8.413098335266113, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 16.330535888671875, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 1.163423776626587, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 16.63500213623047, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 14.909673690795898, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 6.084036350250244, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 5.330334663391113, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 10.525945663452148, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 6.898045063018799, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 4.190566062927246, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 2.7932097911834717, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 11.941429138183594, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 14.172198295593262, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 11.211122512817383, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 11.090378761291504, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 7.951909065246582, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 7.437392234802246, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 12.96187973022461, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 18.34876823425293, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 15.859905242919922, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 15.521785736083984, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 14.366753578186035, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 16.387638092041016, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 19.00131607055664, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 17.261402130126953, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 20.201961517333984, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 14.736574172973633, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 8.490274429321289, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 19.20979118347168, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 14.432631492614746, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 12.758526802062988, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 10.280341148376465, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 3.8434054851531982, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 4.33111572265625, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 12.005300521850586, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 13.142613410949707, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 16.458255767822266, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 7.13403844833374, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 11.828633308410645, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 21.70359992980957, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 1.3618173599243164, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 12.378552436828613, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 15.441965103149414, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 2.402390241622925, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 6.716982841491699, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 4.186927795410156, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 10.02583122253418, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 11.852301597595215, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 16.920223236083984, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 9.352701187133789, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 12.044156074523926, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 3.900907516479492, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 9.73930835723877, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 5.769766807556152, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 11.501866340637207, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 10.019037246704102, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 8.516297340393066, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 11.029529571533203, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.796485424041748, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 4.365727424621582, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.171832084655762, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 11.5953369140625, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 9.907891273498535, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 11.074311256408691, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 16.388078689575195, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 10.061064720153809, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 6.634213447570801, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 13.056344985961914, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 9.078526496887207, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 6.434875965118408, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 12.41024398803711, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 12.15449047088623, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 12.135732650756836, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 11.424830436706543, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 6.585651397705078, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 11.337423324584961, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 5.740451335906982, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 8.813603401184082, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 13.212648391723633, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 8.048795700073242, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 13.886929512023926, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 12.967419624328613, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 10.155488014221191, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 10.331839561462402, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 9.788475036621094, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 9.635385513305664, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 1.454776644706726, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 24.48976707458496, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 10.624290466308594, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 0.38632020354270935, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 5.080892086029053, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 8.836256980895996, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 10.883007049560547, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 2.214138984680176, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 0.55355304479599, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 11.85208797454834, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 15.452204704284668, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 15.978493690490723, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 17.14012908935547, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 19.22150993347168, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 6.54447603225708, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 11.839815139770508, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 9.87878704071045, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 11.059840202331543, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 13.870463371276855, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 6.411136627197266, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 10.61187744140625, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": -1.4397786855697632, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 6.009209632873535, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 6.391894817352295, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 7.629478931427002, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 17.496248245239258, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 0.5062999725341797, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 19.641016006469727, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": -0.46578502655029297, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 2.3438477516174316, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 5.278593063354492, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 11.609603881835938, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 10.233970642089844, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 5.613235950469971, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 5.573513031005859, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 13.94971752166748, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 1.6410958766937256, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 11.310317039489746, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 15.228354454040527, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 18.357946395874023, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 8.508772850036621, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 7.611819267272949, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 6.46488094329834, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 15.272871971130371, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 8.657197952270508, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 9.182524681091309, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 2.5536835193634033, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 7.748277187347412, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": -0.5391780734062195, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 5.00656270980835, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 15.768522262573242, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 16.949798583984375, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 11.616355895996094, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 5.791330337524414, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 24.58285903930664, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 3.07306170463562, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 8.841790199279785, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 6.011405944824219, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 16.98671531677246, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 4.259638786315918, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 15.975602149963379, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 7.204800605773926, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 8.972975730895996, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 7.0830559730529785, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 13.438091278076172, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 13.647506713867188, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 10.081512451171875, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 5.370123386383057, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 4.815537929534912, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 9.213953971862793, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 10.0669527053833, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 4.305802822113037, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 11.277573585510254, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 6.878101825714111, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 18.96354866027832, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 5.82699728012085, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 5.001354694366455, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 15.142876625061035, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 12.358677864074707, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 14.71912956237793, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 12.808987617492676, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.95818042755127, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 13.814603805541992, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 10.320548057556152, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 8.806737899780273, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 6.535454273223877, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 7.609572887420654, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 0.3184982240200043, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 14.00516128540039, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 11.082520484924316, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 13.876301765441895, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 11.884879112243652, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 2.0137856006622314, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 14.816924095153809, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 12.356063842773438, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 7.032673358917236, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 16.042600631713867, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 14.192509651184082, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 4.965102672576904, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 5.56322717666626, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 12.508365631103516, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 5.104037761688232, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 12.051085472106934, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 11.058951377868652, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 8.062950134277344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 6.636124610900879, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 5.17345666885376, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 10.239788055419922, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 8.55694580078125, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 15.09982681274414, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 8.833052635192871, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 20.978830337524414, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 6.275857448577881, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 16.890836715698242, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 23.01714324951172, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 22.67757225036621, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 20.975807189941406, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 2.482130765914917, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 10.07733154296875, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 13.909623146057129, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 1.9945781230926514, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 14.202008247375488, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 7.961235046386719, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 10.419793128967285, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 5.2984619140625, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 3.3702874183654785, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 8.156440734863281, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 19.221630096435547, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 4.177761077880859, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 0.9088281393051147, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": -9.801112174987793, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": -4.177274227142334, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 6.679325103759766, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 9.05578327178955, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 10.858011245727539, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 18.257614135742188, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 6.315979480743408, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 8.230443954467773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 0.6772663593292236, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 18.805233001708984, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 18.02728843688965, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 12.855727195739746, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 10.447681427001953, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 12.989734649658203, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 10.456489562988281, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 5.5458149909973145, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 640, \"mu_intercept_per_group\": 6.737189769744873, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 641, \"mu_intercept_per_group\": 9.193177223205566, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 642, \"mu_intercept_per_group\": 12.069136619567871, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 643, \"mu_intercept_per_group\": 6.221860408782959, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 644, \"mu_intercept_per_group\": 13.383099555969238, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 645, \"mu_intercept_per_group\": 16.529314041137695, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 646, \"mu_intercept_per_group\": 15.19991397857666, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 647, \"mu_intercept_per_group\": 11.386703491210938, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 648, \"mu_intercept_per_group\": 15.04826545715332, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 649, \"mu_intercept_per_group\": 4.552347660064697, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 650, \"mu_intercept_per_group\": 3.780327558517456, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 651, \"mu_intercept_per_group\": 5.112100601196289, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 652, \"mu_intercept_per_group\": 11.999035835266113, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 653, \"mu_intercept_per_group\": 13.317060470581055, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 654, \"mu_intercept_per_group\": 7.893313407897949, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 655, \"mu_intercept_per_group\": 12.060137748718262, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 656, \"mu_intercept_per_group\": 9.420783042907715, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 657, \"mu_intercept_per_group\": 8.989302635192871, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 658, \"mu_intercept_per_group\": 15.081155776977539, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 659, \"mu_intercept_per_group\": 6.784265041351318, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 660, \"mu_intercept_per_group\": 12.24379825592041, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 661, \"mu_intercept_per_group\": 2.469707727432251, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 662, \"mu_intercept_per_group\": 3.566190004348755, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 663, \"mu_intercept_per_group\": 8.301640510559082, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 664, \"mu_intercept_per_group\": 5.845261573791504, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 665, \"mu_intercept_per_group\": 4.558312892913818, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 666, \"mu_intercept_per_group\": 3.4723405838012695, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 667, \"mu_intercept_per_group\": 11.847676277160645, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 668, \"mu_intercept_per_group\": 11.610284805297852, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 669, \"mu_intercept_per_group\": 2.2657830715179443, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 670, \"mu_intercept_per_group\": 10.631192207336426, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 671, \"mu_intercept_per_group\": 13.213122367858887, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 672, \"mu_intercept_per_group\": 13.68525505065918, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 673, \"mu_intercept_per_group\": 10.926741600036621, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 674, \"mu_intercept_per_group\": 14.190625190734863, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 675, \"mu_intercept_per_group\": 5.748699188232422, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 676, \"mu_intercept_per_group\": 14.493550300598145, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 677, \"mu_intercept_per_group\": 10.242263793945312, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 678, \"mu_intercept_per_group\": 9.60313892364502, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 679, \"mu_intercept_per_group\": 16.792964935302734, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 680, \"mu_intercept_per_group\": 13.379315376281738, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 681, \"mu_intercept_per_group\": 1.0710054636001587, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 682, \"mu_intercept_per_group\": 15.035201072692871, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 683, \"mu_intercept_per_group\": -0.387957900762558, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 684, \"mu_intercept_per_group\": 15.181492805480957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 685, \"mu_intercept_per_group\": 16.71505355834961, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 686, \"mu_intercept_per_group\": 11.101946830749512, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 687, \"mu_intercept_per_group\": 12.336786270141602, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 688, \"mu_intercept_per_group\": 6.484126091003418, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 689, \"mu_intercept_per_group\": 15.515594482421875, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 690, \"mu_intercept_per_group\": 7.741927146911621, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 691, \"mu_intercept_per_group\": 17.842140197753906, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 692, \"mu_intercept_per_group\": 11.315420150756836, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 693, \"mu_intercept_per_group\": 16.897253036499023, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 694, \"mu_intercept_per_group\": -1.6949474811553955, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 695, \"mu_intercept_per_group\": -5.276398658752441, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 696, \"mu_intercept_per_group\": 25.23772621154785, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 697, \"mu_intercept_per_group\": 23.200729370117188, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 698, \"mu_intercept_per_group\": 2.4280004501342773, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 699, \"mu_intercept_per_group\": 6.299410343170166, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 700, \"mu_intercept_per_group\": 5.133821964263916, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 701, \"mu_intercept_per_group\": 1.0711069107055664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 702, \"mu_intercept_per_group\": 10.13552188873291, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 703, \"mu_intercept_per_group\": 6.255331039428711, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 704, \"mu_intercept_per_group\": 25.757722854614258, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 705, \"mu_intercept_per_group\": 6.712465763092041, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 706, \"mu_intercept_per_group\": 10.238642692565918, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 707, \"mu_intercept_per_group\": 10.30508041381836, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 708, \"mu_intercept_per_group\": 17.740585327148438, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 709, \"mu_intercept_per_group\": 17.416980743408203, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 710, \"mu_intercept_per_group\": 2.7176008224487305, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 711, \"mu_intercept_per_group\": 9.658129692077637, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 712, \"mu_intercept_per_group\": 20.566896438598633, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 713, \"mu_intercept_per_group\": 15.501233100891113, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 714, \"mu_intercept_per_group\": 9.931512832641602, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 715, \"mu_intercept_per_group\": 4.31850528717041, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 716, \"mu_intercept_per_group\": 8.438852310180664, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 717, \"mu_intercept_per_group\": 5.479158878326416, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 718, \"mu_intercept_per_group\": 13.189408302307129, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 719, \"mu_intercept_per_group\": -0.5001488924026489, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 720, \"mu_intercept_per_group\": 18.273456573486328, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 721, \"mu_intercept_per_group\": 9.747213363647461, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 722, \"mu_intercept_per_group\": 9.510597229003906, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 723, \"mu_intercept_per_group\": 16.200960159301758, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 724, \"mu_intercept_per_group\": 13.500121116638184, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 725, \"mu_intercept_per_group\": 12.953968048095703, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 726, \"mu_intercept_per_group\": 7.8639631271362305, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 727, \"mu_intercept_per_group\": 5.070074081420898, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 728, \"mu_intercept_per_group\": 15.302668571472168, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 729, \"mu_intercept_per_group\": 7.512243270874023, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 730, \"mu_intercept_per_group\": 11.778135299682617, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 731, \"mu_intercept_per_group\": 1.2225472927093506, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 732, \"mu_intercept_per_group\": 6.62372350692749, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 733, \"mu_intercept_per_group\": 5.657873630523682, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 734, \"mu_intercept_per_group\": 5.344048500061035, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 735, \"mu_intercept_per_group\": 8.548877716064453, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 736, \"mu_intercept_per_group\": 9.904463768005371, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 737, \"mu_intercept_per_group\": 19.767704010009766, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 738, \"mu_intercept_per_group\": 10.717267036437988, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 739, \"mu_intercept_per_group\": 10.820258140563965, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 740, \"mu_intercept_per_group\": 2.6831698417663574, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 741, \"mu_intercept_per_group\": 9.101056098937988, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 742, \"mu_intercept_per_group\": 2.4662649631500244, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 743, \"mu_intercept_per_group\": 10.721576690673828, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 744, \"mu_intercept_per_group\": 8.200984001159668, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 745, \"mu_intercept_per_group\": 15.698253631591797, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 746, \"mu_intercept_per_group\": 9.935863494873047, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 747, \"mu_intercept_per_group\": 17.09223175048828, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 748, \"mu_intercept_per_group\": 9.965093612670898, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 749, \"mu_intercept_per_group\": 21.839853286743164, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 750, \"mu_intercept_per_group\": 23.14823341369629, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 751, \"mu_intercept_per_group\": 6.278114318847656, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 752, \"mu_intercept_per_group\": 6.992970943450928, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 753, \"mu_intercept_per_group\": 8.06745433807373, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 754, \"mu_intercept_per_group\": 7.554111957550049, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 755, \"mu_intercept_per_group\": 12.436790466308594, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 756, \"mu_intercept_per_group\": 13.463346481323242, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 757, \"mu_intercept_per_group\": 11.4485445022583, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 758, \"mu_intercept_per_group\": 6.842139720916748, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 759, \"mu_intercept_per_group\": 11.513456344604492, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 760, \"mu_intercept_per_group\": 11.867603302001953, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 6, \"draws\": 761, \"mu_intercept_per_group\": 9.222723007202148, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 6, \"draws\": 762, \"mu_intercept_per_group\": 13.940552711486816, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 6, \"draws\": 763, \"mu_intercept_per_group\": 13.071642875671387, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 6, \"draws\": 764, \"mu_intercept_per_group\": 16.73880958557129, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 6, \"draws\": 765, \"mu_intercept_per_group\": 9.071429252624512, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 6, \"draws\": 766, \"mu_intercept_per_group\": 17.341548919677734, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 6, \"draws\": 767, \"mu_intercept_per_group\": -0.18725790083408356, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 6, \"draws\": 768, \"mu_intercept_per_group\": 1.9522686004638672, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 6, \"draws\": 769, \"mu_intercept_per_group\": 14.188538551330566, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 6, \"draws\": 770, \"mu_intercept_per_group\": 6.566876411437988, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 6, \"draws\": 771, \"mu_intercept_per_group\": 3.8686840534210205, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 6, \"draws\": 772, \"mu_intercept_per_group\": 12.66661262512207, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 6, \"draws\": 773, \"mu_intercept_per_group\": 9.155329704284668, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 6, \"draws\": 774, \"mu_intercept_per_group\": 4.318933963775635, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 6, \"draws\": 775, \"mu_intercept_per_group\": 0.6530895233154297, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 6, \"draws\": 776, \"mu_intercept_per_group\": 19.313690185546875, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 6, \"draws\": 777, \"mu_intercept_per_group\": 11.354860305786133, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 6, \"draws\": 778, \"mu_intercept_per_group\": 8.88536548614502, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 6, \"draws\": 779, \"mu_intercept_per_group\": 13.623076438903809, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 6, \"draws\": 780, \"mu_intercept_per_group\": 8.875946998596191, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 6, \"draws\": 781, \"mu_intercept_per_group\": 17.30560874938965, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 6, \"draws\": 782, \"mu_intercept_per_group\": 14.880852699279785, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 6, \"draws\": 783, \"mu_intercept_per_group\": -0.4047471284866333, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 6, \"draws\": 784, \"mu_intercept_per_group\": 8.562387466430664, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 6, \"draws\": 785, \"mu_intercept_per_group\": 9.902952194213867, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 6, \"draws\": 786, \"mu_intercept_per_group\": 7.32205057144165, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 6, \"draws\": 787, \"mu_intercept_per_group\": 8.498106956481934, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 6, \"draws\": 788, \"mu_intercept_per_group\": 7.786909103393555, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 6, \"draws\": 789, \"mu_intercept_per_group\": 9.666537284851074, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 6, \"draws\": 790, \"mu_intercept_per_group\": 10.754192352294922, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 6, \"draws\": 791, \"mu_intercept_per_group\": 9.705094337463379, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 6, \"draws\": 792, \"mu_intercept_per_group\": 8.534967422485352, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 6, \"draws\": 793, \"mu_intercept_per_group\": 23.202211380004883, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 6, \"draws\": 794, \"mu_intercept_per_group\": 15.786867141723633, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 6, \"draws\": 795, \"mu_intercept_per_group\": 15.403228759765625, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 6, \"draws\": 796, \"mu_intercept_per_group\": 11.287784576416016, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 6, \"draws\": 797, \"mu_intercept_per_group\": 8.130427360534668, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 6, \"draws\": 798, \"mu_intercept_per_group\": 21.378206253051758, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 6, \"draws\": 799, \"mu_intercept_per_group\": 10.32075023651123, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 13.365216255187988, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 15.986224174499512, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 13.506922721862793, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 12.583298683166504, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 13.145959854125977, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 10.314718246459961, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 11.695979118347168, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 1.184268832206726, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 6.262317180633545, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 6.309609889984131, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 21.440279006958008, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 17.677780151367188, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 7.256966590881348, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 19.48111343383789, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 15.224678039550781, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 16.807680130004883, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 17.123653411865234, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 15.230988502502441, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 15.25283432006836, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 4.390932559967041, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 20.541927337646484, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 18.01485252380371, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 10.836176872253418, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 1.6970674991607666, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 15.565256118774414, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 6.240877628326416, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 4.461719512939453, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 21.099756240844727, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 12.546746253967285, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 8.020142555236816, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 6.100507736206055, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 8.693058967590332, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 5.853026390075684, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 8.21872329711914, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 6.160982608795166, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 9.93838119506836, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 7.362545967102051, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 13.141714096069336, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 10.554520606994629, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 10.737625122070312, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 6.138772964477539, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 11.563729286193848, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 15.39007568359375, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 18.455303192138672, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 20.07542610168457, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 21.19367790222168, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 24.960893630981445, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 24.519468307495117, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 0.24309951066970825, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 0.8245984315872192, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 5.754743576049805, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 15.474645614624023, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 14.499691009521484, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 15.87287712097168, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 9.5660982131958, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 11.276510238647461, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 9.343570709228516, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 14.340816497802734, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 10.232099533081055, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 11.092317581176758, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 8.64330768585205, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 6.819952487945557, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 10.860028266906738, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 8.841946601867676, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 29.787004470825195, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 27.973697662353516, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 25.696727752685547, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 22.549034118652344, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 22.398578643798828, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 2.423912763595581, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 12.322992324829102, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 22.30177879333496, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 5.9411940574646, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 12.70667552947998, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 6.396772384643555, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 15.689356803894043, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 13.98384952545166, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 11.223548889160156, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 9.327942848205566, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 9.253957748413086, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 14.580586433410645, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 11.812888145446777, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 6.036093235015869, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 9.360658645629883, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 13.683189392089844, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 3.668138027191162, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 20.079404830932617, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 19.732669830322266, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": -7.2844624519348145, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 19.907825469970703, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 17.325971603393555, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 16.28411865234375, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 10.153678894042969, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 28.808917999267578, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 4.39420223236084, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 4.0098161697387695, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 20.725873947143555, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 5.349339485168457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 13.390400886535645, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 25.936500549316406, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 27.692113876342773, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 0.6892843246459961, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 7.705946922302246, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 8.074809074401855, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 8.449516296386719, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 10.009151458740234, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 13.588265419006348, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 8.753445625305176, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 7.985311985015869, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 7.765178680419922, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 12.855842590332031, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 5.831816673278809, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 19.002710342407227, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 7.596777439117432, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 18.083946228027344, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 18.949031829833984, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 16.835479736328125, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 3.3367068767547607, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 8.004900932312012, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 8.072371482849121, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 9.917716026306152, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 9.116827964782715, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 7.921419143676758, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 6.825031280517578, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 6.757511615753174, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 11.041048049926758, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 13.748991012573242, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 5.216953754425049, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 7.218094825744629, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 4.133030891418457, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 8.278654098510742, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 10.353484153747559, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 8.205766677856445, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 9.113909721374512, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 13.435678482055664, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 7.472805500030518, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 6.2927374839782715, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 12.961935997009277, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 13.134321212768555, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 3.311103582382202, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 20.138322830200195, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 15.088541030883789, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 7.937490463256836, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 24.575151443481445, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 1.3120315074920654, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 8.991385459899902, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 7.200927734375, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 9.841200828552246, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 8.015582084655762, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 8.205357551574707, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 13.542074203491211, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 11.515954971313477, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 16.647682189941406, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 15.563435554504395, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 2.6132571697235107, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 25.538162231445312, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 5.821999549865723, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 16.785518646240234, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 13.999275207519531, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 15.952714920043945, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 21.79082489013672, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 13.224407196044922, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 13.463597297668457, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 17.405467987060547, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 15.356319427490234, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 10.860158920288086, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 11.327224731445312, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 12.218438148498535, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 7.225792407989502, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 15.116665840148926, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 12.125268936157227, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 20.32888412475586, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 11.944461822509766, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 19.531972885131836, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 15.50171947479248, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 14.030842781066895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 8.110709190368652, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 11.908056259155273, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 6.210599422454834, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 11.965696334838867, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 8.917381286621094, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 7.367876052856445, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 20.438995361328125, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 8.617547035217285, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 12.958555221557617, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 14.83244514465332, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 18.258625030517578, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 8.951822280883789, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 11.939066886901855, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 15.721117973327637, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 16.21558952331543, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 15.323904991149902, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 17.336997985839844, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 11.583391189575195, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 11.544178009033203, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 7.748281002044678, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 9.992754936218262, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 4.86784029006958, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 4.973636627197266, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 21.17041015625, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 8.69924545288086, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.4944429397583, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 8.063563346862793, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 7.062926769256592, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 19.731889724731445, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 18.291259765625, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 8.747230529785156, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 18.810197830200195, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 15.205920219421387, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 11.039413452148438, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 12.377477645874023, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 11.87043285369873, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 14.266119956970215, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 4.876817226409912, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 4.9253435134887695, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 16.296428680419922, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 9.956404685974121, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 27.900943756103516, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 19.01661491394043, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 19.096683502197266, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 8.70776081085205, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 6.189742088317871, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 10.95691967010498, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 14.771323204040527, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 9.063048362731934, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 3.1430015563964844, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 18.078941345214844, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 23.35120964050293, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 25.607166290283203, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 4.532476425170898, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 8.57311725616455, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 9.384215354919434, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 18.20131492614746, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 16.084205627441406, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 12.738502502441406, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 11.328948020935059, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 10.262983322143555, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 4.377212047576904, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 17.15158462524414, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 17.101268768310547, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 10.145792007446289, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.732828140258789, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 11.779470443725586, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 16.50186538696289, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 10.43493938446045, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 11.151856422424316, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 16.47918701171875, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 12.971174240112305, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 13.91413688659668, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 15.176945686340332, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 7.0839128494262695, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 7.607177257537842, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 11.361753463745117, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 3.4405832290649414, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 11.53730583190918, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 12.28682804107666, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 10.009668350219727, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 8.554157257080078, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 21.14964485168457, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 12.436086654663086, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 11.749343872070312, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 21.76825523376465, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 22.942338943481445, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 9.235554695129395, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 6.003686904907227, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 9.031157493591309, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 8.527295112609863, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 14.437241554260254, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 19.985258102416992, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 13.9501953125, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 16.466049194335938, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.188323020935059, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 3.650052785873413, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": -0.5641259551048279, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 6.5888471603393555, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 11.593375205993652, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 12.203052520751953, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 8.825818061828613, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 3.8262438774108887, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 19.703861236572266, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 13.764286994934082, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 18.42430305480957, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 22.307876586914062, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 4.6359429359436035, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 20.210790634155273, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 8.959261894226074, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 11.98414421081543, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 7.425361633300781, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 9.654972076416016, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 9.502685546875, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 6.0089263916015625, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 0.37518641352653503, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 8.947497367858887, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 1.1788791418075562, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 13.108702659606934, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 15.722833633422852, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 17.616113662719727, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 18.214561462402344, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 18.49821662902832, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 15.843475341796875, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 12.071490287780762, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 7.961061954498291, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 7.763580322265625, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 8.794839859008789, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 8.805477142333984, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 15.065488815307617, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 19.071840286254883, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 15.21051025390625, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 17.50092315673828, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 10.562623023986816, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 12.626243591308594, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.377864837646484, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 3.399231433868408, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 19.375444412231445, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 6.916561603546143, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 11.265032768249512, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 7.75400972366333, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 8.189379692077637, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 14.990594863891602, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 11.744601249694824, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 15.621774673461914, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 14.313191413879395, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 13.430397033691406, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 13.630142211914062, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 3.9672305583953857, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 20.56456756591797, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 17.591711044311523, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 10.485973358154297, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 15.693488121032715, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 15.7683744430542, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 8.538536071777344, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 7.237646579742432, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 11.395334243774414, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 18.211868286132812, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": -3.2171363830566406, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 9.60183334350586, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 9.18093490600586, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 10.53969955444336, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 14.215615272521973, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 14.209391593933105, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 12.1614990234375, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 15.070243835449219, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.062638282775879, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 13.224609375, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 12.972430229187012, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 12.639427185058594, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 15.804996490478516, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 10.741495132446289, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 15.48204517364502, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 18.317256927490234, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 9.277792930603027, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 16.801820755004883, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 13.283445358276367, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 28.56692886352539, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 18.216144561767578, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 15.145745277404785, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 18.28443717956543, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 4.058918476104736, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 21.306411743164062, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 8.525124549865723, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 8.66665267944336, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 8.395552635192871, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 9.192790985107422, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 19.66211700439453, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 12.06894302368164, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 21.557912826538086, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 16.0334529876709, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 9.502646446228027, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": -7.473568439483643, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 27.26302146911621, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 5.679250717163086, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 3.9864566326141357, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 4.962776184082031, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 5.602456092834473, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 3.574613571166992, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 6.0953803062438965, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 4.117492198944092, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 4.3790388107299805, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 12.84201431274414, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 12.414887428283691, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 10.326018333435059, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 15.752734184265137, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 6.478569984436035, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 25.24509620666504, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 15.745749473571777, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 19.16963768005371, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 9.519261360168457, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 4.866501808166504, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 5.31254243850708, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 13.689255714416504, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 14.95084285736084, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 13.250029563903809, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 10.449140548706055, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 12.422623634338379, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 14.220320701599121, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 13.78234577178955, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 8.764466285705566, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 17.219280242919922, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 18.36520004272461, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 15.676915168762207, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 13.910944938659668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 14.644582748413086, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 11.859487533569336, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 12.685654640197754, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 5.6109538078308105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 5.270198345184326, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 14.604692459106445, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 13.351242065429688, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 14.131821632385254, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 11.933043479919434, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 9.581589698791504, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 11.551580429077148, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 13.48715877532959, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 17.530794143676758, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 23.088489532470703, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 10.952017784118652, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 7.797173023223877, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 7.918060779571533, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 3.837857961654663, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 14.90882682800293, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.232527732849121, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 11.916237831115723, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 11.307418823242188, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 10.764622688293457, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 12.162664413452148, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 11.911325454711914, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 6.723698616027832, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 18.798871994018555, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 20.45260238647461, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 12.415254592895508, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 11.33404541015625, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 16.511070251464844, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 22.255979537963867, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 7.811313629150391, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 9.574859619140625, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 16.238346099853516, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 16.363250732421875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 22.377403259277344, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 23.27312469482422, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 7.275153636932373, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 12.187787055969238, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 13.263769149780273, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 19.850170135498047, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 10.637458801269531, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 21.424161911010742, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 2.3877055644989014, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 17.00070571899414, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 16.119211196899414, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 4.714224338531494, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 9.48280143737793, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 11.932138442993164, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 11.462850570678711, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 4.972246170043945, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 11.98072624206543, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 17.432313919067383, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 24.201007843017578, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 1.2842515707015991, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 17.438961029052734, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.19468879699707, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 8.123538970947266, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 9.121965408325195, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 9.764420509338379, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 15.511746406555176, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 16.831241607666016, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 14.679157257080078, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 15.384532928466797, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 12.670796394348145, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 14.077652931213379, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 9.785552978515625, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 20.56226921081543, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 13.46574878692627, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 9.305739402770996, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 5.643798828125, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 10.33972454071045, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 14.556548118591309, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 24.412067413330078, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 8.456341743469238, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 17.468503952026367, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 12.381575584411621, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 18.401273727416992, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 20.803680419921875, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 16.706371307373047, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 7.785616874694824, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 5.340003490447998, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 5.669518947601318, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 11.059185981750488, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 16.556629180908203, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 16.046810150146484, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 21.35782814025879, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 12.369587898254395, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 15.511539459228516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 5.071626663208008, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 15.501636505126953, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 7.410902500152588, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 18.73247718811035, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 16.048852920532227, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 18.88574981689453, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 10.08126449584961, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 15.35366153717041, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 11.917501449584961, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 9.132963180541992, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 10.450651168823242, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 13.810266494750977, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 2.6890766620635986, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": -1.9913395643234253, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": -0.07536953687667847, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 10.385358810424805, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 13.682313919067383, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 8.612662315368652, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 21.080904006958008, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 2.9666049480438232, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 8.247576713562012, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 5.297784328460693, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 10.691640853881836, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 11.432547569274902, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 3.5715322494506836, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 8.139065742492676, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 7.719079971313477, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 10.299744606018066, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 10.130926132202148, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 11.452608108520508, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 10.793584823608398, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 8.838262557983398, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 7.482108116149902, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 11.77778148651123, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 5.817020893096924, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 13.539782524108887, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 2.742051601409912, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 2.0724174976348877, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": -3.768800735473633, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 21.81544303894043, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 4.7506608963012695, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 19.60413360595703, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 11.72191333770752, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 8.40286636352539, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 7.327067852020264, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 9.15285587310791, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 14.349908828735352, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 8.631303787231445, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 11.943130493164062, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 10.730412483215332, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 16.227359771728516, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 8.550874710083008, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 11.79819107055664, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 14.002288818359375, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 16.46881675720215, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 11.568902015686035, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 17.494281768798828, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 14.894147872924805, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 1.7984572649002075, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 12.85037899017334, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 8.293396949768066, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 18.77876853942871, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 6.6899333000183105, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 11.464505195617676, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 19.049238204956055, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 5.571662902832031, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 6.56072998046875, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 19.446683883666992, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 15.765954971313477, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 12.330999374389648, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 9.6436128616333, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 9.47997760772705, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 10.60527515411377, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.060279846191406, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 9.786256790161133, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 15.614481925964355, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 12.415962219238281, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 16.422975540161133, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 20.262948989868164, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 17.315725326538086, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 8.132803916931152, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 21.46075439453125, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 9.42358684539795, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 19.435306549072266, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 14.325714111328125, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 14.777213096618652, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 22.450634002685547, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 9.621647834777832, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 14.37435245513916, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 18.603113174438477, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 16.760051727294922, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 7.971218585968018, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 20.94237518310547, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 7.376929759979248, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 10.206183433532715, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 11.28425407409668, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 15.896408081054688, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 15.541982650756836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 8.340100288391113, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 17.229333877563477, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 17.312515258789062, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 9.402052879333496, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 8.678874969482422, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 9.498290061950684, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 11.953205108642578, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 10.073935508728027, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 16.469165802001953, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 15.24312686920166, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 17.935504913330078, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 9.6416015625, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 18.07929801940918, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 18.751453399658203, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 9.810301780700684, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 11.524846076965332, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.80354881286621, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 8.866294860839844, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 16.29786491394043, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 17.726667404174805, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 14.024088859558105, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 13.828648567199707, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 24.777212142944336, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 21.65932273864746, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 19.464895248413086, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 4.741896629333496, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 16.82868003845215, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.196017265319824, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 17.72896957397461, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 16.28904151916504, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 16.36051368713379, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 20.730735778808594, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 10.248053550720215, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 13.69138240814209, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 15.790809631347656, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 10.307531356811523, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 7.823513507843018, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 18.52081871032715, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 14.538589477539062, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 13.096989631652832, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 18.64503288269043, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 11.959044456481934, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 6.970203399658203, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 9.345170974731445, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 2.3109419345855713, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 3.450174331665039, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 1.402164101600647, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 19.996816635131836, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 5.368474006652832, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 8.667400360107422, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 8.736454963684082, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 640, \"mu_intercept_per_group\": 6.383976936340332, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 641, \"mu_intercept_per_group\": 17.02939796447754, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 642, \"mu_intercept_per_group\": 15.558263778686523, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 643, \"mu_intercept_per_group\": 11.166762351989746, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 644, \"mu_intercept_per_group\": 17.25875473022461, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 645, \"mu_intercept_per_group\": 10.982369422912598, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 646, \"mu_intercept_per_group\": 9.999495506286621, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 647, \"mu_intercept_per_group\": 6.820811748504639, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 648, \"mu_intercept_per_group\": 10.358931541442871, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 649, \"mu_intercept_per_group\": 23.390565872192383, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 650, \"mu_intercept_per_group\": 23.66953468322754, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 651, \"mu_intercept_per_group\": 24.429710388183594, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 652, \"mu_intercept_per_group\": 0.06105119735002518, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 653, \"mu_intercept_per_group\": 2.505930185317993, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 654, \"mu_intercept_per_group\": 11.448205947875977, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 655, \"mu_intercept_per_group\": 7.88395357131958, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 656, \"mu_intercept_per_group\": 14.944862365722656, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 657, \"mu_intercept_per_group\": 9.908576011657715, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 658, \"mu_intercept_per_group\": 8.306763648986816, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 659, \"mu_intercept_per_group\": 2.9190523624420166, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 660, \"mu_intercept_per_group\": 11.979454040527344, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 661, \"mu_intercept_per_group\": 8.05868911743164, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 662, \"mu_intercept_per_group\": 7.530640602111816, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 663, \"mu_intercept_per_group\": 9.62185001373291, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 664, \"mu_intercept_per_group\": 7.768664836883545, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 665, \"mu_intercept_per_group\": 7.691366672515869, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 666, \"mu_intercept_per_group\": 6.324993133544922, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 667, \"mu_intercept_per_group\": 15.22071361541748, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 668, \"mu_intercept_per_group\": 4.694248199462891, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 669, \"mu_intercept_per_group\": 5.925929069519043, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 670, \"mu_intercept_per_group\": 12.40772819519043, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 671, \"mu_intercept_per_group\": 6.877628326416016, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 672, \"mu_intercept_per_group\": 20.603790283203125, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 673, \"mu_intercept_per_group\": 20.2160587310791, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 674, \"mu_intercept_per_group\": 10.677534103393555, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 675, \"mu_intercept_per_group\": 9.891088485717773, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 676, \"mu_intercept_per_group\": 14.76111888885498, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 677, \"mu_intercept_per_group\": 5.17296028137207, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 678, \"mu_intercept_per_group\": 21.503398895263672, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 679, \"mu_intercept_per_group\": 13.5818452835083, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 680, \"mu_intercept_per_group\": 11.979031562805176, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 681, \"mu_intercept_per_group\": 13.752204895019531, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 682, \"mu_intercept_per_group\": 6.729361534118652, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 683, \"mu_intercept_per_group\": 14.156052589416504, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 684, \"mu_intercept_per_group\": 12.361424446105957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 685, \"mu_intercept_per_group\": 10.60273551940918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 686, \"mu_intercept_per_group\": 17.63189125061035, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 687, \"mu_intercept_per_group\": 17.9906005859375, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 688, \"mu_intercept_per_group\": 17.58872413635254, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 689, \"mu_intercept_per_group\": 10.29228687286377, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 690, \"mu_intercept_per_group\": 16.375364303588867, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 691, \"mu_intercept_per_group\": 11.047507286071777, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 692, \"mu_intercept_per_group\": 14.359484672546387, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 693, \"mu_intercept_per_group\": 13.661771774291992, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 694, \"mu_intercept_per_group\": 18.88800621032715, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 695, \"mu_intercept_per_group\": 17.933658599853516, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 696, \"mu_intercept_per_group\": 14.136847496032715, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 697, \"mu_intercept_per_group\": 14.391809463500977, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 698, \"mu_intercept_per_group\": 9.188444137573242, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 699, \"mu_intercept_per_group\": 2.5345370769500732, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 700, \"mu_intercept_per_group\": -1.8914897441864014, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 701, \"mu_intercept_per_group\": 11.63975715637207, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 702, \"mu_intercept_per_group\": 12.190738677978516, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 703, \"mu_intercept_per_group\": 13.46512222290039, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 704, \"mu_intercept_per_group\": 14.594451904296875, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 705, \"mu_intercept_per_group\": 26.660480499267578, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 706, \"mu_intercept_per_group\": -1.8297244310379028, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 707, \"mu_intercept_per_group\": 18.88283920288086, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 708, \"mu_intercept_per_group\": 13.798812866210938, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 709, \"mu_intercept_per_group\": 6.7603912353515625, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 710, \"mu_intercept_per_group\": 26.519031524658203, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 711, \"mu_intercept_per_group\": 9.139301300048828, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 712, \"mu_intercept_per_group\": 23.089824676513672, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 713, \"mu_intercept_per_group\": 17.76047134399414, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 714, \"mu_intercept_per_group\": 6.20468807220459, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 715, \"mu_intercept_per_group\": 10.100860595703125, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 716, \"mu_intercept_per_group\": 7.2865166664123535, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 717, \"mu_intercept_per_group\": 20.1359806060791, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 718, \"mu_intercept_per_group\": 10.927922248840332, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 719, \"mu_intercept_per_group\": 9.282352447509766, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 720, \"mu_intercept_per_group\": 10.734169006347656, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 721, \"mu_intercept_per_group\": 8.391326904296875, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 722, \"mu_intercept_per_group\": 12.880885124206543, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 723, \"mu_intercept_per_group\": 12.003371238708496, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 724, \"mu_intercept_per_group\": 14.61378002166748, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 725, \"mu_intercept_per_group\": 12.166694641113281, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 726, \"mu_intercept_per_group\": 15.044477462768555, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 727, \"mu_intercept_per_group\": 10.959748268127441, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 728, \"mu_intercept_per_group\": 14.52094554901123, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 729, \"mu_intercept_per_group\": 8.486616134643555, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 730, \"mu_intercept_per_group\": 15.75002384185791, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 731, \"mu_intercept_per_group\": 14.097485542297363, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 732, \"mu_intercept_per_group\": 2.0235254764556885, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 733, \"mu_intercept_per_group\": 3.8014142513275146, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 734, \"mu_intercept_per_group\": -0.5554197430610657, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 735, \"mu_intercept_per_group\": 17.080961227416992, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 736, \"mu_intercept_per_group\": 5.849990367889404, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 737, \"mu_intercept_per_group\": 19.19090461730957, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 738, \"mu_intercept_per_group\": 10.918693542480469, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 739, \"mu_intercept_per_group\": 13.553671836853027, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 740, \"mu_intercept_per_group\": 4.7978081703186035, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 741, \"mu_intercept_per_group\": 9.526103019714355, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 742, \"mu_intercept_per_group\": 6.554520130157471, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 743, \"mu_intercept_per_group\": 12.684871673583984, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 744, \"mu_intercept_per_group\": 9.742919921875, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 745, \"mu_intercept_per_group\": 19.76345443725586, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 746, \"mu_intercept_per_group\": 10.143475532531738, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 747, \"mu_intercept_per_group\": 17.446884155273438, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 748, \"mu_intercept_per_group\": 18.710128784179688, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 749, \"mu_intercept_per_group\": 14.642775535583496, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 750, \"mu_intercept_per_group\": 19.100881576538086, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 751, \"mu_intercept_per_group\": 8.402298927307129, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 752, \"mu_intercept_per_group\": 10.15411376953125, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 753, \"mu_intercept_per_group\": 6.538330554962158, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 754, \"mu_intercept_per_group\": 12.712666511535645, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 755, \"mu_intercept_per_group\": 7.455203533172607, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 756, \"mu_intercept_per_group\": 3.2716078758239746, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 757, \"mu_intercept_per_group\": 4.844691276550293, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 758, \"mu_intercept_per_group\": 17.15043067932129, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 759, \"mu_intercept_per_group\": 9.833940505981445, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 760, \"mu_intercept_per_group\": 8.629639625549316, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 7, \"draws\": 761, \"mu_intercept_per_group\": 8.8025541305542, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 7, \"draws\": 762, \"mu_intercept_per_group\": 13.855545043945312, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 7, \"draws\": 763, \"mu_intercept_per_group\": 17.514272689819336, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 7, \"draws\": 764, \"mu_intercept_per_group\": 14.950531959533691, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 7, \"draws\": 765, \"mu_intercept_per_group\": 15.36071491241455, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 7, \"draws\": 766, \"mu_intercept_per_group\": 17.131275177001953, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 7, \"draws\": 767, \"mu_intercept_per_group\": 6.334132671356201, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 7, \"draws\": 768, \"mu_intercept_per_group\": 4.500664234161377, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 7, \"draws\": 769, \"mu_intercept_per_group\": 31.4747314453125, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 7, \"draws\": 770, \"mu_intercept_per_group\": 5.083420753479004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 7, \"draws\": 771, \"mu_intercept_per_group\": 6.722559928894043, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 7, \"draws\": 772, \"mu_intercept_per_group\": 9.143126487731934, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 7, \"draws\": 773, \"mu_intercept_per_group\": 18.33839988708496, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 7, \"draws\": 774, \"mu_intercept_per_group\": 1.0376254320144653, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 7, \"draws\": 775, \"mu_intercept_per_group\": 24.4460391998291, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 7, \"draws\": 776, \"mu_intercept_per_group\": 3.071709394454956, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 7, \"draws\": 777, \"mu_intercept_per_group\": 11.179348945617676, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 7, \"draws\": 778, \"mu_intercept_per_group\": 11.647317886352539, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 7, \"draws\": 779, \"mu_intercept_per_group\": 11.261837005615234, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 7, \"draws\": 780, \"mu_intercept_per_group\": 14.204532623291016, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 7, \"draws\": 781, \"mu_intercept_per_group\": 10.796290397644043, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 7, \"draws\": 782, \"mu_intercept_per_group\": 12.963516235351562, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 7, \"draws\": 783, \"mu_intercept_per_group\": 6.624403953552246, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 7, \"draws\": 784, \"mu_intercept_per_group\": 20.135610580444336, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 7, \"draws\": 785, \"mu_intercept_per_group\": 11.501521110534668, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 7, \"draws\": 786, \"mu_intercept_per_group\": 9.679304122924805, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 7, \"draws\": 787, \"mu_intercept_per_group\": 9.904572486877441, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 7, \"draws\": 788, \"mu_intercept_per_group\": 11.821760177612305, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 7, \"draws\": 789, \"mu_intercept_per_group\": 10.323616027832031, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 7, \"draws\": 790, \"mu_intercept_per_group\": 15.954474449157715, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 7, \"draws\": 791, \"mu_intercept_per_group\": 17.040075302124023, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 7, \"draws\": 792, \"mu_intercept_per_group\": 13.847721099853516, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 7, \"draws\": 793, \"mu_intercept_per_group\": 16.707489013671875, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 7, \"draws\": 794, \"mu_intercept_per_group\": 11.388129234313965, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 7, \"draws\": 795, \"mu_intercept_per_group\": 10.363701820373535, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 7, \"draws\": 796, \"mu_intercept_per_group\": 16.580825805664062, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 7, \"draws\": 797, \"mu_intercept_per_group\": 7.494189739227295, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 7, \"draws\": 798, \"mu_intercept_per_group\": 26.840944290161133, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 7, \"draws\": 799, \"mu_intercept_per_group\": 16.009048461914062, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}], \"data-4b9cbfc1c4897c0672d6a06e25fe8ad5\": [{\"index\": \"C(stim, Treatment)[T.1]\", \"center interval\": 0.16, \"Std.Err.\": 0.027, \"z\": 5.863, \"p\": 0.0, \"higher interval\": 0.107, \"lower interval\": 0.214, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 18,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "chart_power_difference | chart_power_difference_lme"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Inspect Bayesian result further\n",
    "Let's take a look at the intercepts and compare them to levels of power in the original data:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "scrolled": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-51e89cfddc434448bea08b42dd9e2e1b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-51e89cfddc434448bea08b42dd9e2e1b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-51e89cfddc434448bea08b42dd9e2e1b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-55620c08ee0f2b51d1c658df744dfa2d\"}, \"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-55620c08ee0f2b51d1c658df744dfa2d\": [{\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.955295818792631, \"Firing rate\": 90.21854501261329, \"Power\": 90.21854501261329, \"i_spike\": 47.5, \"isi\": 0.0731915996436363, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6026484195029185, \"Firing rate\": 40.054232969747986, \"Power\": 40.054232969747986, \"i_spike\": 39.5, \"isi\": 0.08505458474637603, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1244493253919545, \"Firing rate\": 133.18316316728252, \"Power\": 133.18316316728252, \"i_spike\": 42.5, \"isi\": 0.08224071637572535, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8708094709723913, \"Firing rate\": 74.2693239984203, \"Power\": 74.2693239984203, \"i_spike\": 33.5, \"isi\": 0.10505328377444978, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9711426825012743, \"Firing rate\": 93.57130415068605, \"Power\": 93.57130415068605, \"i_spike\": 40.5, \"isi\": 0.08430258433195234, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8590874397971908, \"Firing rate\": 72.29153389710372, \"Power\": 72.29153389710372, \"i_spike\": 44.0, \"isi\": 0.0795434324837374, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0132461342812213, \"Firing rate\": 103.09702522654109, \"Power\": 103.09702522654109, \"i_spike\": 47.5, \"isi\": 0.07286723599674903, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0127266901312217, \"Firing rate\": 102.97378826377438, \"Power\": 102.97378826377438, \"i_spike\": 39.0, \"isi\": 0.08914566084967086, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503131681143027, \"Firing rate\": 56.27469736390204, \"Power\": 56.27469736390204, \"i_spike\": 40.0, \"isi\": 0.08700029609063652, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1169032082350827, \"Firing rate\": 130.88901764671587, \"Power\": 130.88901764671587, \"i_spike\": 62.0, \"isi\": 0.05659763212840744, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8770680415974088, \"Firing rate\": 75.34736023774802, \"Power\": 75.34736023774802, \"i_spike\": 39.0, \"isi\": 0.09009246539035318, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9310965336855828, \"Firing rate\": 85.32897596494497, \"Power\": 85.32897596494497, \"i_spike\": 34.0, \"isi\": 0.10149738234291991, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.5333013820605306, \"Firing rate\": 34.14297672922771, \"Power\": 34.14297672922771, \"i_spike\": 40.5, \"isi\": 0.08685116325741157, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.030855072834198, \"Firing rate\": 107.36310742084633, \"Power\": 107.36310742084633, \"i_spike\": 54.5, \"isi\": 0.059448248477706966, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.794551727002911, \"Firing rate\": 623.0913568201987, \"Power\": 623.0913568201987, \"i_spike\": 48.5, \"isi\": 0.0713719442616052, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7955427567112552, \"Firing rate\": 62.451483134242046, \"Power\": 62.451483134242046, \"i_spike\": 35.5, \"isi\": 0.09057886752422038, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9082000854510324, \"Firing rate\": 80.94687466873414, \"Power\": 80.94687466873414, \"i_spike\": 53.0, \"isi\": 0.06529444835938969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6555352624426098, \"Firing rate\": 45.24131944286433, \"Power\": 45.24131944286433, \"i_spike\": 43.5, \"isi\": 0.0768533496686384, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.177328557623848, \"Firing rate\": 150.42795711808552, \"Power\": 150.42795711808552, \"i_spike\": 34.5, \"isi\": 0.09830229180875018, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8645215585407622, \"Firing rate\": 73.20176599287585, \"Power\": 73.20176599287585, \"i_spike\": 55.5, \"isi\": 0.06179006984103724, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.535025958406892, \"Firing rate\": 34.27882748831966, \"Power\": 34.27882748831966, \"i_spike\": 34.5, \"isi\": 0.09915726015773765, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.32247920697616, \"Firing rate\": 210.125716326415, \"Power\": 210.125716326415, \"i_spike\": 33.0, \"isi\": 0.10502063399832753, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.43733847759269, \"Firing rate\": 273.74013531042965, \"Power\": 273.74013531042965, \"i_spike\": 56.0, \"isi\": 0.061967941571928455, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7969419629962189, \"Firing rate\": 62.653013263585784, \"Power\": 62.653013263585784, \"i_spike\": 37.0, \"isi\": 0.09259944757473725, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9846064873802938, \"Firing rate\": 96.51759403196418, \"Power\": 96.51759403196418, \"i_spike\": 41.5, \"isi\": 0.08460263304467304, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503293230777222, \"Firing rate\": 56.27679071904272, \"Power\": 56.27679071904272, \"i_spike\": 42.5, \"isi\": 0.07988986525214349, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.4286782943328151, \"Firing rate\": 26.83356000776027, \"Power\": 26.83356000776027, \"i_spike\": 35.5, \"isi\": 0.09874338503855341, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1383088558675207, \"Firing rate\": 137.50194957559475, \"Power\": 137.50194957559475, \"i_spike\": 48.5, \"isi\": 0.07210812725187593, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0035263866631934, \"Firing rate\": 100.81528603885884, \"Power\": 100.81528603885884, \"i_spike\": 49.5, \"isi\": 0.0672853207791876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6296351063659993, \"Firing rate\": 42.62212577953956, \"Power\": 42.62212577953956, \"i_spike\": 41.5, \"isi\": 0.0790188469593832, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.193262117122394, \"Firing rate\": 156.04940501335037, \"Power\": 156.04940501335037, \"i_spike\": 48.0, \"isi\": 0.07263392600048459, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9760548637782647, \"Firing rate\": 94.63567056548113, \"Power\": 94.63567056548113, \"i_spike\": 44.5, \"isi\": 0.0776680429623508, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6250730368645014, \"Firing rate\": 42.17674276093685, \"Power\": 42.17674276093685, \"i_spike\": 42.5, \"isi\": 0.08104853472101264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.491206995038427, \"Firing rate\": 309.8895954508339, \"Power\": 309.8895954508339, \"i_spike\": 51.5, \"isi\": 0.06708115735632907, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3589480963384455, \"Firing rate\": 228.53256618481504, \"Power\": 228.53256618481504, \"i_spike\": 47.5, \"isi\": 0.07348993800862964, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9281754169377023, \"Firing rate\": 84.75696889405249, \"Power\": 84.75696889405249, \"i_spike\": 53.0, \"isi\": 0.06509876660602372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9843209349691886, \"Firing rate\": 96.45415373032593, \"Power\": 96.45415373032593, \"i_spike\": 59.5, \"isi\": 0.05870376554536328, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7638817011892445, \"Firing rate\": 58.06062428577546, \"Power\": 58.06062428577546, \"i_spike\": 52.0, \"isi\": 0.06566204692122644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.650862407397869, \"Firing rate\": 44.75714827077759, \"Power\": 44.75714827077759, \"i_spike\": 49.0, \"isi\": 0.07040754805798212, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0583883119213846, \"Firing rate\": 114.39006635603113, \"Power\": 114.39006635603113, \"i_spike\": 51.0, \"isi\": 0.06837143070736648, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2173425763203, \"Firing rate\": 164.9462993258368, \"Power\": 164.9462993258368, \"i_spike\": 53.5, \"isi\": 0.06501277873096038, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2107084188475756, \"Firing rate\": 162.44577441851425, \"Power\": 162.44577441851425, \"i_spike\": 49.0, \"isi\": 0.06869119253150469, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5946141113333705, \"Firing rate\": 39.320054519388265, \"Power\": 39.320054519388265, \"i_spike\": 43.0, \"isi\": 0.08147481958019963, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.211944529140798, \"Firing rate\": 162.90879418557492, \"Power\": 162.90879418557492, \"i_spike\": 55.5, \"isi\": 0.06320352970416626, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5907555117125005, \"Firing rate\": 389.7225286301253, \"Power\": 389.7225286301253, \"i_spike\": 48.5, \"isi\": 0.07106759705283149, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.197050324722152, \"Firing rate\": 157.4165263375544, \"Power\": 157.4165263375544, \"i_spike\": 42.5, \"isi\": 0.08120962422114071, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.900738498847488, \"Firing rate\": 79.56801043564009, \"Power\": 79.56801043564009, \"i_spike\": 43.5, \"isi\": 0.07999246270715814, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7701446630135824, \"Firing rate\": 58.90398311997898, \"Power\": 58.90398311997898, \"i_spike\": 42.0, \"isi\": 0.08041029857361554, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5942453724234489, \"Firing rate\": 39.28668388897537, \"Power\": 39.28668388897537, \"i_spike\": 32.5, \"isi\": 0.1019318698052081, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6923353756705557, \"Firing rate\": 49.24196506231455, \"Power\": 49.24196506231455, \"i_spike\": 44.0, \"isi\": 0.07851300689834464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9096430648934821, \"Firing rate\": 81.21627467876483, \"Power\": 81.21627467876483, \"i_spike\": 42.0, \"isi\": 0.08279141280781681, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7227625327508387, \"Firing rate\": 52.815638294554915, \"Power\": 52.815638294554915, \"i_spike\": 47.0, \"isi\": 0.07465675585663739, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0772331102040815, \"Firing rate\": 119.4629156868915, \"Power\": 119.4629156868915, \"i_spike\": 45.0, \"isi\": 0.07778279269254963, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8962156003531803, \"Firing rate\": 78.7436606258303, \"Power\": 78.7436606258303, \"i_spike\": 45.0, \"isi\": 0.07723000353960975, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.539325164353972, \"Firing rate\": 34.61984860582479, \"Power\": 34.61984860582479, \"i_spike\": 43.5, \"isi\": 0.08038783649040848, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.795290559690197, \"Firing rate\": 62.41522776726645, \"Power\": 62.41522776726645, \"i_spike\": 51.0, \"isi\": 0.06863876971272939, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7829257189432979, \"Firing rate\": 60.6632563219068, \"Power\": 60.6632563219068, \"i_spike\": 51.5, \"isi\": 0.06724356364949484, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8506258960042894, \"Firing rate\": 70.89667964004052, \"Power\": 70.89667964004052, \"i_spike\": 53.0, \"isi\": 0.06603508775646316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9623740441999131, \"Firing rate\": 91.70099419760025, \"Power\": 91.70099419760025, \"i_spike\": 45.0, \"isi\": 0.0739363878905739, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0543726256433428, \"Firing rate\": 113.33723822345725, \"Power\": 113.33723822345725, \"i_spike\": 59.5, \"isi\": 0.05882184181366276, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0311570012276237, \"Firing rate\": 107.4377739030315, \"Power\": 107.4377739030315, \"i_spike\": 43.5, \"isi\": 0.08064172994284798, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.149704072470153, \"Firing rate\": 141.15753717632737, \"Power\": 141.15753717632737, \"i_spike\": 59.0, \"isi\": 0.059210435905617934, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0114163933193723, \"Firing rate\": 102.6635773453862, \"Power\": 102.6635773453862, \"i_spike\": 55.0, \"isi\": 0.06332773568755358, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9540841070386274, \"Firing rate\": 89.96717983510673, \"Power\": 89.96717983510673, \"i_spike\": 42.5, \"isi\": 0.08201299481958542, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8156677764444182, \"Firing rate\": 65.41355865573313, \"Power\": 65.41355865573313, \"i_spike\": 54.0, \"isi\": 0.06526466311001969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.893859348236818, \"Firing rate\": 78.31759602448699, \"Power\": 78.31759602448699, \"i_spike\": 56.5, \"isi\": 0.06184020841304989, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.773984421574805, \"Firing rate\": 59.427084135210976, \"Power\": 59.427084135210976, \"i_spike\": 60.0, \"isi\": 0.058270067505733734, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.210840290387196, \"Firing rate\": 162.49510782693136, \"Power\": 162.49510782693136, \"i_spike\": 56.5, \"isi\": 0.06020300273286523, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9713400241427212, \"Firing rate\": 93.61383223125311, \"Power\": 93.61383223125311, \"i_spike\": 61.0, \"isi\": 0.0543980735122145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8497634918355093, \"Firing rate\": 70.75603561035722, \"Power\": 70.75603561035722, \"i_spike\": 47.5, \"isi\": 0.07274197195399083, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9624750863491771, \"Firing rate\": 91.72233166302841, \"Power\": 91.72233166302841, \"i_spike\": 48.5, \"isi\": 0.07010114635983886, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.855302039054747, \"Firing rate\": 71.66416401500264, \"Power\": 71.66416401500264, \"i_spike\": 46.0, \"isi\": 0.0766119040381658, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.046426832369158, \"Firing rate\": 111.28248941720267, \"Power\": 111.28248941720267, \"i_spike\": 64.0, \"isi\": 0.05429137856724891, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7100483491678449, \"Firing rate\": 51.29184830393363, \"Power\": 51.29184830393363, \"i_spike\": 49.5, \"isi\": 0.0703751778152302, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3453546584516265, \"Firing rate\": 221.49027300778377, \"Power\": 221.49027300778377, \"i_spike\": 59.5, \"isi\": 0.058785042141719916, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.875277533612671, \"Firing rate\": 75.03735784498373, \"Power\": 75.03735784498373, \"i_spike\": 56.0, \"isi\": 0.06218241581461111, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6818911486395558, \"Firing rate\": 48.071884620822175, \"Power\": 48.071884620822175, \"i_spike\": 56.0, \"isi\": 0.06219590540248409, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7807624476641064, \"Firing rate\": 60.36183691888134, \"Power\": 60.36183691888134, \"i_spike\": 46.0, \"isi\": 0.07429803181700052, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7183011441323788, \"Firing rate\": 52.27585493529653, \"Power\": 52.27585493529653, \"i_spike\": 52.5, \"isi\": 0.06577263809678958, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.763346825231255, \"Firing rate\": 57.98916098746875, \"Power\": 57.98916098746875, \"i_spike\": 48.5, \"isi\": 0.07131264606340101, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.835065458404151, \"Firing rate\": 68.40147366385926, \"Power\": 68.40147366385926, \"i_spike\": 49.0, \"isi\": 0.07194196841840346, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.924715551322173, \"Firing rate\": 84.08442357857703, \"Power\": 84.08442357857703, \"i_spike\": 55.5, \"isi\": 0.06318891040674948, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.017073838923778, \"Firing rate\": 104.00969885083077, \"Power\": 104.00969885083077, \"i_spike\": 49.0, \"isi\": 0.07044066419783745, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7143174946332422, \"Firing rate\": 517.9853711282016, \"Power\": 517.9853711282016, \"i_spike\": 65.0, \"isi\": 0.052930696952406625, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.974181294239221, \"Firing rate\": 94.22828660927348, \"Power\": 94.22828660927348, \"i_spike\": 58.0, \"isi\": 0.060053602856178986, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9399526356112446, \"Firing rate\": 87.08686073800901, \"Power\": 87.08686073800901, \"i_spike\": 53.0, \"isi\": 0.06646977245711418, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6853656755730138, \"Firing rate\": 48.45802119713409, \"Power\": 48.45802119713409, \"i_spike\": 40.0, \"isi\": 0.08662078631540625, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9336719560475775, \"Firing rate\": 85.83649113967905, \"Power\": 85.83649113967905, \"i_spike\": 57.0, \"isi\": 0.060295111833858245, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0093234248133296, \"Firing rate\": 102.17000739461349, \"Power\": 102.17000739461349, \"i_spike\": 49.0, \"isi\": 0.06980898473808321, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6653323391451258, \"Firing rate\": 46.27349888819327, \"Power\": 46.27349888819327, \"i_spike\": 52.5, \"isi\": 0.06664468983496366, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.319563597750638, \"Firing rate\": 208.71977491726287, \"Power\": 208.71977491726287, \"i_spike\": 62.5, \"isi\": 0.054778780974004924, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9501238550989324, \"Firing rate\": 89.15051474767834, \"Power\": 89.15051474767834, \"i_spike\": 65.0, \"isi\": 0.052393936924168064, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.058384385790344, \"Firing rate\": 114.38903224581574, \"Power\": 114.38903224581574, \"i_spike\": 67.0, \"isi\": 0.051939822712101694, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.341203185363342, \"Firing rate\": 219.38310826468677, \"Power\": 219.38310826468677, \"i_spike\": 63.5, \"isi\": 0.054996827366133136, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9819991440519158, \"Firing rate\": 95.9398740641521, \"Power\": 95.9398740641521, \"i_spike\": 56.0, \"isi\": 0.06266914967033387, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.369563712635469, \"Firing rate\": 234.18750118502433, \"Power\": 234.18750118502433, \"i_spike\": 66.0, \"isi\": 0.05307466490753688, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8499974740031297, \"Firing rate\": 70.79416667549492, \"Power\": 70.79416667549492, \"i_spike\": 50.0, \"isi\": 0.06964434411828664, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4140871865689233, \"Firing rate\": 259.4700207563056, \"Power\": 259.4700207563056, \"i_spike\": 57.5, \"isi\": 0.05932812658617926, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2992730643707255, \"Firing rate\": 199.19253762816092, \"Power\": 199.19253762816092, \"i_spike\": 69.0, \"isi\": 0.0505200086604451, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1143279384255944, \"Firing rate\": 130.11517148140396, \"Power\": 130.11517148140396, \"i_spike\": 58.0, \"isi\": 0.06039580425018153, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1347425595996863, \"Firing rate\": 136.37744808427303, \"Power\": 136.37744808427303, \"i_spike\": 57.5, \"isi\": 0.06059068471302143, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9227227083724787, \"Firing rate\": 83.69947007723921, \"Power\": 83.69947007723921, \"i_spike\": 74.5, \"isi\": 0.04700841293964799, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9356641657046738, \"Firing rate\": 86.23114755907184, \"Power\": 86.23114755907184, \"i_spike\": 59.0, \"isi\": 0.05819722837595124, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1650029836128866, \"Firing rate\": 146.21872196813922, \"Power\": 146.21872196813922, \"i_spike\": 66.5, \"isi\": 0.05230105943774251, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.090242481076867, \"Firing rate\": 123.09558626462615, \"Power\": 123.09558626462615, \"i_spike\": 57.5, \"isi\": 0.059929836211731397, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9223690348846298, \"Firing rate\": 83.63133604719516, \"Power\": 83.63133604719516, \"i_spike\": 60.5, \"isi\": 0.05806760763773719, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1491227759212217, \"Firing rate\": 140.9687263512985, \"Power\": 140.9687263512985, \"i_spike\": 54.5, \"isi\": 0.06367419112012151, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3941117654392667, \"Firing rate\": 247.80597028438038, \"Power\": 247.80597028438038, \"i_spike\": 63.0, \"isi\": 0.05461154211696954, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9896786925487997, \"Firing rate\": 97.65144913558673, \"Power\": 97.65144913558673, \"i_spike\": 62.5, \"isi\": 0.05504185225729406, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.7731494316094232, \"Firing rate\": 59.31293728328963, \"Power\": 59.31293728328963, \"i_spike\": 55.0, \"isi\": 0.06267698786541855, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8554169772491347, \"Firing rate\": 71.68313280237724, \"Power\": 71.68313280237724, \"i_spike\": 60.5, \"isi\": 0.056999565632898194, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3716727528341055, \"Firing rate\": 235.32753886515357, \"Power\": 235.32753886515357, \"i_spike\": 52.0, \"isi\": 0.067154049479885, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2364092112497285, \"Firing rate\": 172.34917594410877, \"Power\": 172.34917594410877, \"i_spike\": 59.5, \"isi\": 0.05869502074828589, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2557126583819076, \"Firing rate\": 180.18252074391486, \"Power\": 180.18252074391486, \"i_spike\": 73.5, \"isi\": 0.04743594072717539, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.7433869258557073, \"Firing rate\": 553.8433249443033, \"Power\": 553.8433249443033, \"i_spike\": 55.0, \"isi\": 0.06360854706023654, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9410922920516542, \"Firing rate\": 87.31569035109068, \"Power\": 87.31569035109068, \"i_spike\": 65.5, \"isi\": 0.052877411734321145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.053756802379095, \"Firing rate\": 113.17664155543305, \"Power\": 113.17664155543305, \"i_spike\": 54.0, \"isi\": 0.06436186527784456, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.034873477705347, \"Firing rate\": 108.36111813754236, \"Power\": 108.36111813754236, \"i_spike\": 66.5, \"isi\": 0.050938903955247916, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9885417764206283, \"Firing rate\": 97.39614698417968, \"Power\": 97.39614698417968, \"i_spike\": 60.0, \"isi\": 0.05780359441402076, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4369749555623357, \"Firing rate\": 273.51109962529904, \"Power\": 273.51109962529904, \"i_spike\": 64.0, \"isi\": 0.053993497700095504, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1065489309483487, \"Firing rate\": 127.8053196733479, \"Power\": 127.8053196733479, \"i_spike\": 66.0, \"isi\": 0.05304312813996159, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9049237369041854, \"Firing rate\": 80.33850335646146, \"Power\": 80.33850335646146, \"i_spike\": 74.0, \"isi\": 0.046752172315214786, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.089842705284853, \"Firing rate\": 122.98232672563184, \"Power\": 122.98232672563184, \"i_spike\": 62.5, \"isi\": 0.055459566693195586, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0542996219949314, \"Firing rate\": 113.3181881621406, \"Power\": 113.3181881621406, \"i_spike\": 68.5, \"isi\": 0.04886679113481873, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5270188880084747, \"Firing rate\": 336.5262050014474, \"Power\": 336.5262050014474, \"i_spike\": 77.0, \"isi\": 0.045084314963419254, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8366391281202479, \"Firing rate\": 68.64977657243634, \"Power\": 68.64977657243634, \"i_spike\": 70.5, \"isi\": 0.04950827198418861, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9617130502576103, \"Firing rate\": 91.56153191880342, \"Power\": 91.56153191880342, \"i_spike\": 68.5, \"isi\": 0.05136728010783104, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.241494871870913, \"Firing rate\": 174.37927667202098, \"Power\": 174.37927667202098, \"i_spike\": 63.0, \"isi\": 0.05576348859764074, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 3.1251395921423315, \"Firing rate\": 1333.9501252294517, \"Power\": 1333.9501252294517, \"i_spike\": 64.5, \"isi\": 0.054262100729024564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8958624054342972, \"Firing rate\": 78.67964748291678, \"Power\": 78.67964748291678, \"i_spike\": 74.0, \"isi\": 0.046877125846140295, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5517732739731294, \"Firing rate\": 356.2650945497233, \"Power\": 356.2650945497233, \"i_spike\": 76.5, \"isi\": 0.04517211033649603, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0919634725229534, \"Firing rate\": 123.58434852138122, \"Power\": 123.58434852138122, \"i_spike\": 68.0, \"isi\": 0.05101734433625525, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3525110631387873, \"Firing rate\": 225.17027754817553, \"Power\": 225.17027754817553, \"i_spike\": 65.0, \"isi\": 0.05404540309717516, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.7819954120481858, \"Firing rate\": 60.53344798762198, \"Power\": 60.53344798762198, \"i_spike\": 53.0, \"isi\": 0.06467002728543748, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8422213318301035, \"Firing rate\": 69.5378616839905, \"Power\": 69.5378616839905, \"i_spike\": 69.0, \"isi\": 0.05037331163693314, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1868975598998643, \"Firing rate\": 153.77918677144316, \"Power\": 153.77918677144316, \"i_spike\": 70.0, \"isi\": 0.049775509977722336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9726367908939046, \"Firing rate\": 93.89377298287559, \"Power\": 93.89377298287559, \"i_spike\": 75.5, \"isi\": 0.04639225026242182, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.778101000828387, \"Firing rate\": 59.99305816899431, \"Power\": 59.99305816899431, \"i_spike\": 68.5, \"isi\": 0.05075104338195106, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9121660273135348, \"Firing rate\": 81.68946039587414, \"Power\": 81.68946039587414, \"i_spike\": 64.0, \"isi\": 0.05481280145440375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0478218930526535, \"Firing rate\": 111.64053089208255, \"Power\": 111.64053089208255, \"i_spike\": 70.0, \"isi\": 0.0489888087012864, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.117471278561992, \"Firing rate\": 131.0603364640247, \"Power\": 131.0603364640247, \"i_spike\": 65.5, \"isi\": 0.051671766893329675, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.931167591711936, \"Firing rate\": 853.4293839120918, \"Power\": 853.4293839120918, \"i_spike\": 63.0, \"isi\": 0.05525138390063168, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.277774705751867, \"Firing rate\": 189.57222427760698, \"Power\": 189.57222427760698, \"i_spike\": 78.0, \"isi\": 0.04456622398656536, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.845684289414062, \"Firing rate\": 70.09455604474384, \"Power\": 70.09455604474384, \"i_spike\": 63.5, \"isi\": 0.05469869440456847, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10431894281778, \"Firing rate\": 127.15075486242938, \"Power\": 127.15075486242938, \"i_spike\": 67.0, \"isi\": 0.05227215134911894, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.033552725921547, \"Firing rate\": 108.03207702586286, \"Power\": 108.03207702586286, \"i_spike\": 57.5, \"isi\": 0.060347774168580594, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1643005604050174, \"Firing rate\": 145.98242053251482, \"Power\": 145.98242053251482, \"i_spike\": 72.5, \"isi\": 0.04783783469680652, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0012121960819167, \"Firing rate\": 100.27950836105705, \"Power\": 100.27950836105705, \"i_spike\": 71.5, \"isi\": 0.048990832561469015, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9583920039283502, \"Firing rate\": 90.86403192498832, \"Power\": 90.86403192498832, \"i_spike\": 76.0, \"isi\": 0.04556701067411184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1124885757403176, \"Firing rate\": 129.56526144990931, \"Power\": 129.56526144990931, \"i_spike\": 75.0, \"isi\": 0.046659913362027156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7844790003053106, \"Firing rate\": 608.8061070924601, \"Power\": 608.8061070924601, \"i_spike\": 92.0, \"isi\": 0.03797865081756185, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1928313296970376, \"Firing rate\": 155.8946924977612, \"Power\": 155.8946924977612, \"i_spike\": 92.0, \"isi\": 0.038121755542223995, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077615601977832, \"Firing rate\": 119.56817539419721, \"Power\": 119.56817539419721, \"i_spike\": 74.5, \"isi\": 0.04660934195613513, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3240668465311076, \"Firing rate\": 210.895273459069, \"Power\": 210.895273459069, \"i_spike\": 75.5, \"isi\": 0.04641624316187993, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9441862764582671, \"Firing rate\": 87.93996257483187, \"Power\": 87.93996257483187, \"i_spike\": 73.0, \"isi\": 0.04692146801636959, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.0247285177119982, \"Firing rate\": 1058.591780864329, \"Power\": 1058.591780864329, \"i_spike\": 77.0, \"isi\": 0.045685464766526206, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.7391920768878777, \"Firing rate\": 54.85195068575797, \"Power\": 54.85195068575797, \"i_spike\": 64.5, \"isi\": 0.05399592200088135, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1934103426446043, \"Firing rate\": 156.10267405821313, \"Power\": 156.10267405821313, \"i_spike\": 74.5, \"isi\": 0.046628423844649644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.297774880328158, \"Firing rate\": 198.50656775360184, \"Power\": 198.50656775360184, \"i_spike\": 80.0, \"isi\": 0.04397457503735967, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1110133951114576, \"Firing rate\": 129.1259099799552, \"Power\": 129.1259099799552, \"i_spike\": 87.5, \"isi\": 0.03951101481601628, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9798834285720046, \"Firing rate\": 95.47362854816234, \"Power\": 95.47362854816234, \"i_spike\": 82.0, \"isi\": 0.04281447867823779, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9839401087688497, \"Firing rate\": 96.36961162784607, \"Power\": 96.36961162784607, \"i_spike\": 80.5, \"isi\": 0.0436343619819139, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9292502786690382, \"Firing rate\": 84.96699885333383, \"Power\": 84.96699885333383, \"i_spike\": 84.5, \"isi\": 0.040212763358464985, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.110242887829347, \"Firing rate\": 128.89702323935285, \"Power\": 128.89702323935285, \"i_spike\": 78.0, \"isi\": 0.044671705231796116, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9896296651016587, \"Firing rate\": 97.6404258985101, \"Power\": 97.6404258985101, \"i_spike\": 96.5, \"isi\": 0.03602341732975196, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.524514898794598, \"Firing rate\": 3345.9149606607, \"Power\": 3345.9149606607, \"i_spike\": 67.0, \"isi\": 0.05228146274267083, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1112668565940305, \"Firing rate\": 129.20129200352847, \"Power\": 129.20129200352847, \"i_spike\": 72.5, \"isi\": 0.04765721891987244, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9572989808412744, \"Firing rate\": 90.63563480094187, \"Power\": 90.63563480094187, \"i_spike\": 77.5, \"isi\": 0.04525372674699464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.543885879418327, \"Firing rate\": 349.85322319506616, \"Power\": 349.85322319506616, \"i_spike\": 71.5, \"isi\": 0.048639441668922465, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1757930037804383, \"Firing rate\": 149.89702164205846, \"Power\": 149.89702164205846, \"i_spike\": 82.0, \"isi\": 0.04242030307116036, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9882434867575853, \"Firing rate\": 97.32927464232434, \"Power\": 97.32927464232434, \"i_spike\": 73.0, \"isi\": 0.047906156958600565, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.123436432758141, \"Firing rate\": 132.8729058171096, \"Power\": 132.8729058171096, \"i_spike\": 74.0, \"isi\": 0.04678579996295997, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2883138118447697, \"Firing rate\": 194.22888267612504, \"Power\": 194.22888267612504, \"i_spike\": 76.0, \"isi\": 0.04579097873240445, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3338630531397206, \"Firing rate\": 215.70641109917793, \"Power\": 215.70641109917793, \"i_spike\": 82.0, \"isi\": 0.04253295769330548, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1368082310712584, \"Firing rate\": 137.02765673763616, \"Power\": 137.02765673763616, \"i_spike\": 87.0, \"isi\": 0.04009013967311376, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.304411865772515, \"Firing rate\": 201.5634883150203, \"Power\": 201.5634883150203, \"i_spike\": 84.5, \"isi\": 0.040969846937519115, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1578448451318133, \"Firing rate\": 143.82846487878152, \"Power\": 143.82846487878152, \"i_spike\": 93.0, \"isi\": 0.037192354679684805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.026210332863069, \"Firing rate\": 106.22098707802203, \"Power\": 106.22098707802203, \"i_spike\": 86.0, \"isi\": 0.039883894146009444, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0309948773666058, \"Firing rate\": 107.39767443894033, \"Power\": 107.39767443894033, \"i_spike\": 71.5, \"isi\": 0.04790202069793337, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1102417146873824, \"Firing rate\": 128.89667505555326, \"Power\": 128.89667505555326, \"i_spike\": 85.5, \"isi\": 0.040840328777172155, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3598760140799757, \"Firing rate\": 229.0213730590734, \"Power\": 229.0213730590734, \"i_spike\": 85.5, \"isi\": 0.041093869337129094, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4487993661694656, \"Firing rate\": 281.0602098401713, \"Power\": 281.0602098401713, \"i_spike\": 88.5, \"isi\": 0.03916681921061969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1541973100299687, \"Firing rate\": 142.6255427263312, \"Power\": 142.6255427263312, \"i_spike\": 87.5, \"isi\": 0.039474320407279974, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.234900540025064, \"Firing rate\": 171.7515005319624, \"Power\": 171.7515005319624, \"i_spike\": 94.5, \"isi\": 0.03655183866180524, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.7078341872007305, \"Firing rate\": 510.31012735003867, \"Power\": 510.31012735003867, \"i_spike\": 83.5, \"isi\": 0.041988842659945944, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1126963123799873, \"Firing rate\": 129.6272513932111, \"Power\": 129.6272513932111, \"i_spike\": 89.0, \"isi\": 0.03919921663226311, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1692211907420162, \"Firing rate\": 147.6458317545557, \"Power\": 147.6458317545557, \"i_spike\": 88.0, \"isi\": 0.03956930417423602, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1644556852991537, \"Firing rate\": 146.03457305415864, \"Power\": 146.03457305415864, \"i_spike\": 96.5, \"isi\": 0.03588734853002937, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.31196565210909, \"Firing rate\": 205.0999960994725, \"Power\": 205.0999960994725, \"i_spike\": 90.0, \"isi\": 0.03903067099230167, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.074577597091679, \"Firing rate\": 118.73468299886356, \"Power\": 118.73468299886356, \"i_spike\": 104.0, \"isi\": 0.03353750893302584, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2092160144315107, \"Firing rate\": 161.88850572662918, \"Power\": 161.88850572662918, \"i_spike\": 104.5, \"isi\": 0.03279156198398983, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.49914214982962, \"Firing rate\": 315.60374635173724, \"Power\": 315.60374635173724, \"i_spike\": 101.5, \"isi\": 0.034537567878371166, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1418864131165836, \"Firing rate\": 138.63931793743396, \"Power\": 138.63931793743396, \"i_spike\": 91.5, \"isi\": 0.03818102135269262, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8765227305978964, \"Firing rate\": 752.5281158141704, \"Power\": 752.5281158141704, \"i_spike\": 93.5, \"isi\": 0.03689839236734887, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.939461561874331, \"Firing rate\": 86.98844387480378, \"Power\": 86.98844387480378, \"i_spike\": 92.0, \"isi\": 0.03758519178898388, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2870436262828573, \"Firing rate\": 193.66164935551598, \"Power\": 193.66164935551598, \"i_spike\": 89.5, \"isi\": 0.03894744817039956, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1430297227592443, \"Firing rate\": 139.0047761690239, \"Power\": 139.0047761690239, \"i_spike\": 97.0, \"isi\": 0.03603976087193819, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.310726570280992, \"Firing rate\": 204.51566105247213, \"Power\": 204.51566105247213, \"i_spike\": 91.0, \"isi\": 0.03830441539373303, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3968118547257453, \"Firing rate\": 249.35142514175052, \"Power\": 249.35142514175052, \"i_spike\": 96.0, \"isi\": 0.03647169049835178, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 3.469141414513526, \"Firing rate\": 2945.3805493938794, \"Power\": 2945.3805493938794, \"i_spike\": 97.0, \"isi\": 0.03567197347869549, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189566775673024, \"Firing rate\": 262.39567812258474, \"Power\": 262.39567812258474, \"i_spike\": 109.0, \"isi\": 0.03178383198414856, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.404076689518491, \"Firing rate\": 253.55763335396162, \"Power\": 253.55763335396162, \"i_spike\": 100.0, \"isi\": 0.034975946689714515, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4991139433760545, \"Firing rate\": 315.58324926114744, \"Power\": 315.58324926114744, \"i_spike\": 83.5, \"isi\": 0.04187307899164901, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.379747962179488, \"Firing rate\": 239.7441187730139, \"Power\": 239.7441187730139, \"i_spike\": 100.0, \"isi\": 0.03471693037002835, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.8902246293874716, \"Firing rate\": 77.66487174396306, \"Power\": 77.66487174396306, \"i_spike\": 87.5, \"isi\": 0.03966381661521433, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.814843398948089, \"Firing rate\": 652.8950845550662, \"Power\": 652.8950845550662, \"i_spike\": 85.5, \"isi\": 0.040891388126968714, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.9487896110579808, \"Firing rate\": 888.7704589764036, \"Power\": 888.7704589764036, \"i_spike\": 89.5, \"isi\": 0.03915085074928612, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.0149402045520945, \"Firing rate\": 103.49996538656313, \"Power\": 103.49996538656313, \"i_spike\": 89.5, \"isi\": 0.03921140742804705, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.9542028872402641, \"Firing rate\": 89.9917893609065, \"Power\": 89.9917893609065, \"i_spike\": 85.5, \"isi\": 0.04054868314386225, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4881910216727383, \"Firing rate\": 307.74501140084084, \"Power\": 307.74501140084084, \"i_spike\": 88.0, \"isi\": 0.03904624656724844, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4115277428777, \"Firing rate\": 257.945373553756, \"Power\": 257.945373553756, \"i_spike\": 119.5, \"isi\": 0.02880924312756989, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4545567386868696, \"Firing rate\": 284.81098690467894, \"Power\": 284.81098690467894, \"i_spike\": 109.0, \"isi\": 0.03179620656212547, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3111719305423497, \"Firing rate\": 204.7254953238993, \"Power\": 204.7254953238993, \"i_spike\": 97.5, \"isi\": 0.03580379043600067, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.165545723182864, \"Firing rate\": 146.40156632304382, \"Power\": 146.40156632304382, \"i_spike\": 105.5, \"isi\": 0.03278382952607013, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2578646424397553, \"Firing rate\": 181.07756360533585, \"Power\": 181.07756360533585, \"i_spike\": 119.0, \"isi\": 0.029343681835626842, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.8107940843269335, \"Firing rate\": 646.835853340232, \"Power\": 646.835853340232, \"i_spike\": 116.0, \"isi\": 0.029999599974023163, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.39182087209241, \"Firing rate\": 246.50224111651946, \"Power\": 246.50224111651946, \"i_spike\": 117.5, \"isi\": 0.029502232467124783, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0658291633993806, \"Firing rate\": 116.36681920867568, \"Power\": 116.36681920867568, \"i_spike\": 101.0, \"isi\": 0.034668414565907774, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3285225511020813, \"Firing rate\": 213.07012031018914, \"Power\": 213.07012031018914, \"i_spike\": 113.5, \"isi\": 0.03083920593859388, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6729864873429214, \"Firing rate\": 470.9626726162531, \"Power\": 470.9626726162531, \"i_spike\": 122.0, \"isi\": 0.028568916959577716, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2018925265651847, \"Firing rate\": 159.18147571149987, \"Power\": 159.18147571149987, \"i_spike\": 112.0, \"isi\": 0.030867054694338973, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.374213868452394, \"Firing rate\": 236.70850822985395, \"Power\": 236.70850822985395, \"i_spike\": 105.0, \"isi\": 0.03330704053094981, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.311456530252207, \"Firing rate\": 204.85969899001685, \"Power\": 204.85969899001685, \"i_spike\": 104.0, \"isi\": 0.03379316964890372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.18089067422046, \"Firing rate\": 151.66685255353084, \"Power\": 151.66685255353084, \"i_spike\": 108.0, \"isi\": 0.03226254920952097, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1779833854348714, \"Firing rate\": 150.65494298513445, \"Power\": 150.65494298513445, \"i_spike\": 113.0, \"isi\": 0.030897373044620688, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3035855615368024, \"Firing rate\": 201.18035100403486, \"Power\": 201.18035100403486, \"i_spike\": 112.5, \"isi\": 0.031017803226141994, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4551657383947396, \"Firing rate\": 285.2106499995778, \"Power\": 285.2106499995778, \"i_spike\": 119.5, \"isi\": 0.02922791099470977, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 3.100538081982483, \"Firing rate\": 1260.486161305173, \"Power\": 1260.486161305173, \"i_spike\": 117.5, \"isi\": 0.029697418256461976, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1111083966350765, \"Firing rate\": 129.15415924516745, \"Power\": 129.15415924516745, \"i_spike\": 118.5, \"isi\": 0.02948619911662466, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.044552627498885, \"Firing rate\": 110.80328278754759, \"Power\": 110.80328278754759, \"i_spike\": 101.0, \"isi\": 0.03429723398050743, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.016091787828533, \"Firing rate\": 103.77477198816491, \"Power\": 103.77477198816491, \"i_spike\": 103.5, \"isi\": 0.03346541480440439, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2697421877977257, \"Firing rate\": 186.09820654703583, \"Power\": 186.09820654703583, \"i_spike\": 118.5, \"isi\": 0.029214269965179746, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.687691210640336, \"Firing rate\": 487.1819738340354, \"Power\": 487.1819738340354, \"i_spike\": 112.0, \"isi\": 0.031291789674142416, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.5700111791336004, \"Firing rate\": 371.5447928738117, \"Power\": 371.5447928738117, \"i_spike\": 119.5, \"isi\": 0.029125995163474167, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.324688636610815, \"Firing rate\": 211.19743365693657, \"Power\": 211.19743365693657, \"i_spike\": 128.5, \"isi\": 0.02689077169759444, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.197745717540907, \"Firing rate\": 157.668783762246, \"Power\": 157.668783762246, \"i_spike\": 116.5, \"isi\": 0.029739505746504635, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.232111730437686, \"Firing rate\": 170.65213673060103, \"Power\": 170.65213673060103, \"i_spike\": 119.5, \"isi\": 0.029278118430901116, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.226281785132872, \"Firing rate\": 168.3766191894407, \"Power\": 168.3766191894407, \"i_spike\": 100.5, \"isi\": 0.03487511849895156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4240095717708385, \"Firing rate\": 265.4664069640671, \"Power\": 265.4664069640671, \"i_spike\": 109.0, \"isi\": 0.032083977077943644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0765668363240124, \"Firing rate\": 119.27978189302107, \"Power\": 119.27978189302107, \"i_spike\": 118.0, \"isi\": 0.02924333618462232, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.710200388455537, \"Firing rate\": 513.0980787193608, \"Power\": 513.0980787193608, \"i_spike\": 58.0, \"isi\": 0.05755769778597422, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.086495554586632, \"Firing rate\": 122.03813289272098, \"Power\": 122.03813289272098, \"i_spike\": 58.0, \"isi\": 0.05954567433072462, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.4599942127543875, \"Firing rate\": 288.3993071858994, \"Power\": 288.3993071858994, \"i_spike\": 69.0, \"isi\": 0.050452157477652144, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8764248252258178, \"Firing rate\": 75.23584884202715, \"Power\": 75.23584884202715, \"i_spike\": 47.5, \"isi\": 0.0729232484181408, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.943371360287594, \"Firing rate\": 87.77510553153151, \"Power\": 87.77510553153151, \"i_spike\": 72.0, \"isi\": 0.04794968452690702, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0095288502408404, \"Firing rate\": 102.21834621295545, \"Power\": 102.21834621295545, \"i_spike\": 58.5, \"isi\": 0.05900199429876669, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.108813974324886, \"Firing rate\": 128.47362382167685, \"Power\": 128.47362382167685, \"i_spike\": 74.0, \"isi\": 0.04704885530644372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9546575480473676, \"Firing rate\": 90.08605066518454, \"Power\": 90.08605066518454, \"i_spike\": 66.0, \"isi\": 0.05192063434120186, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9556030665055126, \"Firing rate\": 90.28239396841717, \"Power\": 90.28239396841717, \"i_spike\": 63.0, \"isi\": 0.05547055572684698, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.116207536382213, \"Firing rate\": 130.6795217411474, \"Power\": 130.6795217411474, \"i_spike\": 60.5, \"isi\": 0.0574361231164934, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.125243880671493, \"Firing rate\": 133.4270489421996, \"Power\": 133.4270489421996, \"i_spike\": 68.0, \"isi\": 0.04981296493334266, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.067202187376957, \"Firing rate\": 116.73529559924685, \"Power\": 116.73529559924685, \"i_spike\": 61.5, \"isi\": 0.0564927141817096, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3223316454945286, \"Firing rate\": 210.0543334368294, \"Power\": 210.0543334368294, \"i_spike\": 59.5, \"isi\": 0.058641352393127184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0012989243549466, \"Firing rate\": 100.29953610121872, \"Power\": 100.29953610121872, \"i_spike\": 63.5, \"isi\": 0.053258724806304336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.740752379052743, \"Firing rate\": 55.049373283103336, \"Power\": 55.049373283103336, \"i_spike\": 68.5, \"isi\": 0.05025347412312059, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8372359506262905, \"Firing rate\": 68.74418232403539, \"Power\": 68.74418232403539, \"i_spike\": 58.5, \"isi\": 0.05883024786315191, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3872683261080843, \"Firing rate\": 243.9317469805847, \"Power\": 243.9317469805847, \"i_spike\": 52.0, \"isi\": 0.06463987437697509, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1699952647940046, \"Firing rate\": 147.90922612197502, \"Power\": 147.90922612197502, \"i_spike\": 58.0, \"isi\": 0.06041749419783433, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0727936321681573, \"Firing rate\": 118.24795321797994, \"Power\": 118.24795321797994, \"i_spike\": 74.0, \"isi\": 0.04733033921726912, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.44888166908114, \"Firing rate\": 281.11347845536557, \"Power\": 281.11347845536557, \"i_spike\": 64.0, \"isi\": 0.05283053800228937, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.268675264450081, \"Firing rate\": 185.64158358911618, \"Power\": 185.64158358911618, \"i_spike\": 65.5, \"isi\": 0.05201986674274169, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.428906190296464, \"Firing rate\": 268.4764460943622, \"Power\": 268.4764460943622, \"i_spike\": 58.5, \"isi\": 0.05911180928366123, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.049008675060004, \"Firing rate\": 111.94602445336766, \"Power\": 111.94602445336766, \"i_spike\": 84.0, \"isi\": 0.04125747764768612, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0516084499750704, \"Firing rate\": 112.61816585709414, \"Power\": 112.61816585709414, \"i_spike\": 66.0, \"isi\": 0.05216770534731938, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9822401781710393, \"Firing rate\": 95.99313562360203, \"Power\": 95.99313562360203, \"i_spike\": 68.5, \"isi\": 0.05091550082040577, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0413070869966092, \"Firing rate\": 109.97832146085658, \"Power\": 109.97832146085658, \"i_spike\": 69.5, \"isi\": 0.048261908955763336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9162564740110344, \"Firing rate\": 82.4624956181202, \"Power\": 82.4624956181202, \"i_spike\": 72.5, \"isi\": 0.04580300353406743, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.0251706690400266, \"Firing rate\": 1059.6700724955876, \"Power\": 1059.6700724955876, \"i_spike\": 71.0, \"isi\": 0.048977335140478306, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9185288956668356, \"Firing rate\": 82.89510684752574, \"Power\": 82.89510684752574, \"i_spike\": 65.0, \"isi\": 0.053468477919304494, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.7155492922987285, \"Firing rate\": 5194.566283391101, \"Power\": 5194.566283391101, \"i_spike\": 70.0, \"isi\": 0.047831889076879165, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2880559296273484, \"Firing rate\": 194.11358462627942, \"Power\": 194.11358462627942, \"i_spike\": 77.0, \"isi\": 0.04377704062250514, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2863930549701847, \"Firing rate\": 193.37176219598692, \"Power\": 193.37176219598692, \"i_spike\": 71.5, \"isi\": 0.04739471740371852, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 3.485362624668281, \"Firing rate\": 3057.4729586064655, \"Power\": 3057.4729586064655, \"i_spike\": 61.0, \"isi\": 0.05730472197648097, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2096939236101893, \"Firing rate\": 162.06675019105623, \"Power\": 162.06675019105623, \"i_spike\": 70.0, \"isi\": 0.04860233815068464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.837305629539864, \"Firing rate\": 687.5521263737877, \"Power\": 687.5521263737877, \"i_spike\": 76.0, \"isi\": 0.0462630290768705, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1604627571934727, \"Firing rate\": 144.6980762328094, \"Power\": 144.6980762328094, \"i_spike\": 71.5, \"isi\": 0.04871333606236235, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2330475254201847, \"Firing rate\": 171.0202454569647, \"Power\": 171.0202454569647, \"i_spike\": 71.5, \"isi\": 0.049080521297471015, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2588609326122553, \"Firing rate\": 181.4934401413059, \"Power\": 181.4934401413059, \"i_spike\": 66.5, \"isi\": 0.05057733095048499, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8829675842290474, \"Firing rate\": 76.37787729482577, \"Power\": 76.37787729482577, \"i_spike\": 81.0, \"isi\": 0.04283416965586292, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3279809733696553, \"Firing rate\": 212.80458133268078, \"Power\": 212.80458133268078, \"i_spike\": 74.5, \"isi\": 0.04442769500737385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8091068615972408, \"Firing rate\": 64.43277879673587, \"Power\": 64.43277879673587, \"i_spike\": 60.5, \"isi\": 0.056408495878117026, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0634103765045717, \"Firing rate\": 115.7205199960153, \"Power\": 115.7205199960153, \"i_spike\": 62.5, \"isi\": 0.05494193964992375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.057707201125165, \"Firing rate\": 114.21080723853781, \"Power\": 114.21080723853781, \"i_spike\": 66.5, \"isi\": 0.05118977826099244, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2746886859201556, \"Firing rate\": 188.2299322496126, \"Power\": 188.2299322496126, \"i_spike\": 76.5, \"isi\": 0.04519157254778185, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0019707623558363, \"Firing rate\": 100.45481596463469, \"Power\": 100.45481596463469, \"i_spike\": 76.0, \"isi\": 0.045327986132193195, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.295587633345161, \"Firing rate\": 197.50933799327007, \"Power\": 197.50933799327007, \"i_spike\": 74.0, \"isi\": 0.046483911938798965, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.945877973988118, \"Firing rate\": 88.28318116549227, \"Power\": 88.28318116549227, \"i_spike\": 66.5, \"isi\": 0.05264008421938133, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.471153315505243, \"Firing rate\": 295.90568943614835, \"Power\": 295.90568943614835, \"i_spike\": 87.0, \"isi\": 0.04015846530226762, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0265599217285164, \"Firing rate\": 106.30652494563125, \"Power\": 106.30652494563125, \"i_spike\": 78.5, \"isi\": 0.04422689053854093, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9009990463345725, \"Firing rate\": 79.61576021362671, \"Power\": 79.61576021362671, \"i_spike\": 60.0, \"isi\": 0.05558242287405482, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1371898250889654, \"Firing rate\": 137.14810936802255, \"Power\": 137.14810936802255, \"i_spike\": 78.0, \"isi\": 0.043423699441362415, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.18334195846327, \"Firing rate\": 152.5253247913568, \"Power\": 152.5253247913568, \"i_spike\": 79.5, \"isi\": 0.0439479607076074, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.018302892049905, \"Firing rate\": 104.30446313151317, \"Power\": 104.30446313151317, \"i_spike\": 69.5, \"isi\": 0.050417535373145216, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.520301793170094, \"Firing rate\": 331.36130594281525, \"Power\": 331.36130594281525, \"i_spike\": 63.0, \"isi\": 0.055194343234777954, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.140863371620742, \"Firing rate\": 138.3131179566823, \"Power\": 138.3131179566823, \"i_spike\": 67.0, \"isi\": 0.05011613503553582, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5790786138640915, \"Firing rate\": 379.38365293278486, \"Power\": 379.38365293278486, \"i_spike\": 70.0, \"isi\": 0.049862445465668585, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0046971363148742, \"Firing rate\": 101.08742556167319, \"Power\": 101.08742556167319, \"i_spike\": 77.0, \"isi\": 0.044773115940763754, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9299917883985747, \"Firing rate\": 85.11219451122186, \"Power\": 85.11219451122186, \"i_spike\": 63.5, \"isi\": 0.053279255805921924, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.507367640954118, \"Firing rate\": 321.63821330655077, \"Power\": 321.63821330655077, \"i_spike\": 83.0, \"isi\": 0.04180903485727737, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.043864219396577, \"Firing rate\": 110.62778561221664, \"Power\": 110.62778561221664, \"i_spike\": 60.5, \"isi\": 0.05613656256289283, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0343304902630406, \"Firing rate\": 108.2257216223445, \"Power\": 108.2257216223445, \"i_spike\": 76.5, \"isi\": 0.044990678072367146, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.265966193291141, \"Firing rate\": 184.48718035589718, \"Power\": 184.48718035589718, \"i_spike\": 82.5, \"isi\": 0.041218621498328945, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.184829164757981, \"Firing rate\": 153.0485307452557, \"Power\": 153.0485307452557, \"i_spike\": 79.5, \"isi\": 0.0438790508311261, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.482867251153031, \"Firing rate\": 303.99556740279854, \"Power\": 303.99556740279854, \"i_spike\": 72.0, \"isi\": 0.04732392940449676, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.679350887775424, \"Firing rate\": 477.91524884132025, \"Power\": 477.91524884132025, \"i_spike\": 75.0, \"isi\": 0.04487201851927047, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0102132106102126, \"Firing rate\": 102.37954865480673, \"Power\": 102.37954865480673, \"i_spike\": 71.5, \"isi\": 0.04878632929411457, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2925787627458876, \"Firing rate\": 196.14568689680337, \"Power\": 196.14568689680337, \"i_spike\": 71.5, \"isi\": 0.04751080235874853, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.408181131975511, \"Firing rate\": 255.96532234553712, \"Power\": 255.96532234553712, \"i_spike\": 78.5, \"isi\": 0.04224296754691385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3855583224969688, \"Firing rate\": 242.97317148876678, \"Power\": 242.97317148876678, \"i_spike\": 76.5, \"isi\": 0.045168110305337704, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9994034804402283, \"Firing rate\": 99.862740582426, \"Power\": 99.862740582426, \"i_spike\": 76.5, \"isi\": 0.04461518511387296, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.420657135162534, \"Firing rate\": 263.4250888241149, \"Power\": 263.4250888241149, \"i_spike\": 86.5, \"isi\": 0.039763315255390425, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0333948498686167, \"Firing rate\": 107.99281201345569, \"Power\": 107.99281201345569, \"i_spike\": 71.5, \"isi\": 0.04905015663749419, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1771834940956576, \"Firing rate\": 150.3777193944357, \"Power\": 150.3777193944357, \"i_spike\": 71.5, \"isi\": 0.048168145819388865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9004170909121822, \"Firing rate\": 79.50914639254572, \"Power\": 79.50914639254572, \"i_spike\": 72.0, \"isi\": 0.047053568472965865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2706500732886123, \"Firing rate\": 186.4876487147454, \"Power\": 186.4876487147454, \"i_spike\": 76.5, \"isi\": 0.04478958523955221, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3226879927203563, \"Firing rate\": 210.22675790778925, \"Power\": 210.22675790778925, \"i_spike\": 84.5, \"isi\": 0.041448783649683865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1236488593840726, \"Firing rate\": 132.93791388973483, \"Power\": 132.93791388973483, \"i_spike\": 73.5, \"isi\": 0.04771964422986316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9611984491654064, \"Firing rate\": 91.45310373895767, \"Power\": 91.45310373895767, \"i_spike\": 70.5, \"isi\": 0.04936860543367102, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0824773391122404, \"Firing rate\": 120.91420899286925, \"Power\": 120.91420899286925, \"i_spike\": 88.0, \"isi\": 0.03935522162784246, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9787501002284225, \"Firing rate\": 95.22480680598018, \"Power\": 95.22480680598018, \"i_spike\": 75.0, \"isi\": 0.045602480439414186, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1685898325916213, \"Firing rate\": 147.43134670286034, \"Power\": 147.43134670286034, \"i_spike\": 80.0, \"isi\": 0.0428366177384345, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.230731641001414, \"Firing rate\": 170.11070364760798, \"Power\": 170.11070364760798, \"i_spike\": 86.0, \"isi\": 0.04069000316608182, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7109408735479223, \"Firing rate\": 513.9736725480508, \"Power\": 513.9736725480508, \"i_spike\": 90.5, \"isi\": 0.03808087796581317, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.8904891156107295, \"Firing rate\": 777.121842141343, \"Power\": 777.121842141343, \"i_spike\": 67.5, \"isi\": 0.05050650450585472, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3884444205618465, \"Firing rate\": 244.59322344535366, \"Power\": 244.59322344535366, \"i_spike\": 75.5, \"isi\": 0.046160864179237364, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.215221869412756, \"Firing rate\": 164.14281206772014, \"Power\": 164.14281206772014, \"i_spike\": 76.0, \"isi\": 0.045973777674205345, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1044452923402397, \"Firing rate\": 127.18775228011826, \"Power\": 127.18775228011826, \"i_spike\": 74.5, \"isi\": 0.046825315835458, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.304794192932069, \"Firing rate\": 201.74101101002248, \"Power\": 201.74101101002248, \"i_spike\": 84.5, \"isi\": 0.0415838404784538, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9519897390823953, \"Firing rate\": 89.53436113421678, \"Power\": 89.53436113421678, \"i_spike\": 73.0, \"isi\": 0.04637231437529422, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.050715177785326, \"Firing rate\": 112.38676690257596, \"Power\": 112.38676690257596, \"i_spike\": 72.5, \"isi\": 0.047898939712791556, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.093906240936936, \"Firing rate\": 124.13842784179043, \"Power\": 124.13842784179043, \"i_spike\": 77.0, \"isi\": 0.04521406966614064, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.142532137492843, \"Firing rate\": 138.84560509200531, \"Power\": 138.84560509200531, \"i_spike\": 85.5, \"isi\": 0.04088215523965275, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1247106556001505, \"Firing rate\": 133.26332826018398, \"Power\": 133.26332826018398, \"i_spike\": 94.0, \"isi\": 0.03699718718109058, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0404961635875494, \"Firing rate\": 109.77315932365002, \"Power\": 109.77315932365002, \"i_spike\": 84.5, \"isi\": 0.040822879176668145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2076231068258, \"Firing rate\": 161.29581780251291, \"Power\": 161.29581780251291, \"i_spike\": 77.0, \"isi\": 0.04556164109048245, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0158640710626763, \"Firing rate\": 103.72037327450805, \"Power\": 103.72037327450805, \"i_spike\": 70.5, \"isi\": 0.04900422553915958, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1880248824801893, \"Firing rate\": 154.1788785708863, \"Power\": 154.1788785708863, \"i_spike\": 87.5, \"isi\": 0.039435886208280056, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9744105165726646, \"Firing rate\": 94.27803379629712, \"Power\": 94.27803379629712, \"i_spike\": 84.5, \"isi\": 0.04146392755918885, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 3.913843764110594, \"Firing rate\": 8200.564788680073, \"Power\": 8200.564788680073, \"i_spike\": 76.5, \"isi\": 0.04556363424648217, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1399954218244273, \"Firing rate\": 138.0369713167223, \"Power\": 138.0369713167223, \"i_spike\": 77.5, \"isi\": 0.0453981706218095, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9566148125838072, \"Firing rate\": 90.49296385155998, \"Power\": 90.49296385155998, \"i_spike\": 85.0, \"isi\": 0.03927323815030475, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2520245491348896, \"Firing rate\": 178.65885615461892, \"Power\": 178.65885615461892, \"i_spike\": 85.0, \"isi\": 0.040967992817435184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1754321193760866, \"Firing rate\": 149.77251389430003, \"Power\": 149.77251389430003, \"i_spike\": 91.5, \"isi\": 0.03836696480836998, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.635716855961742, \"Firing rate\": 432.2319398170039, \"Power\": 432.2319398170039, \"i_spike\": 96.5, \"isi\": 0.03578166736861596, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2160850620865733, \"Firing rate\": 164.46938258310612, \"Power\": 164.46938258310612, \"i_spike\": 80.0, \"isi\": 0.043473098367445215, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1205612291989038, \"Firing rate\": 131.9961393928132, \"Power\": 131.9961393928132, \"i_spike\": 75.5, \"isi\": 0.04626035487513255, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.024827292545692, \"Firing rate\": 105.88325716711356, \"Power\": 105.88325716711356, \"i_spike\": 80.5, \"isi\": 0.04253930743384717, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.074114281950763, \"Firing rate\": 118.60808170570037, \"Power\": 118.60808170570037, \"i_spike\": 67.0, \"isi\": 0.051334204579878646, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2811373940485504, \"Firing rate\": 191.04575581686126, \"Power\": 191.04575581686126, \"i_spike\": 74.5, \"isi\": 0.046987279420234215, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.014403068402744, \"Firing rate\": 103.37203558262294, \"Power\": 103.37203558262294, \"i_spike\": 82.5, \"isi\": 0.04146065949524595, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.108863671481811, \"Firing rate\": 128.4883261479434, \"Power\": 128.4883261479434, \"i_spike\": 87.5, \"isi\": 0.03907275494403815, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.658304695266665, \"Firing rate\": 455.30738576183563, \"Power\": 455.30738576183563, \"i_spike\": 93.5, \"isi\": 0.036909663672368385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2071328830952694, \"Firing rate\": 161.11385272898417, \"Power\": 161.11385272898417, \"i_spike\": 90.0, \"isi\": 0.03900063452819159, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.162120505142531, \"Firing rate\": 145.25145957605932, \"Power\": 145.25145957605932, \"i_spike\": 85.5, \"isi\": 0.0400904776550323, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9709911192109881, \"Firing rate\": 93.53865464453958, \"Power\": 93.53865464453958, \"i_spike\": 75.0, \"isi\": 0.045538771732070805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.134880880431313, \"Firing rate\": 136.42089060349338, \"Power\": 136.42089060349338, \"i_spike\": 88.5, \"isi\": 0.03943188805380755, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.066832430618179, \"Firing rate\": 116.63594988602028, \"Power\": 116.63594988602028, \"i_spike\": 70.5, \"isi\": 0.048970343212981035, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3793806836767333, \"Firing rate\": 239.5414552752351, \"Power\": 239.5414552752351, \"i_spike\": 82.5, \"isi\": 0.042043561438028454, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.399500106264406, \"Firing rate\": 250.89967933737773, \"Power\": 250.89967933737773, \"i_spike\": 75.5, \"isi\": 0.04561264334500348, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.220242199517701, \"Firing rate\": 166.0512692284522, \"Power\": 166.0512692284522, \"i_spike\": 77.5, \"isi\": 0.04518223580077409, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3997220560187014, \"Firing rate\": 251.02793644541697, \"Power\": 251.02793644541697, \"i_spike\": 92.0, \"isi\": 0.037630914484962856, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.166020646368421, \"Firing rate\": 146.56175147859375, \"Power\": 146.56175147859375, \"i_spike\": 91.0, \"isi\": 0.03827176241185468, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.185888096679604, \"Firing rate\": 153.4221613710901, \"Power\": 153.4221613710901, \"i_spike\": 92.0, \"isi\": 0.03761591240242529, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.4587317399206245, \"Firing rate\": 287.562161854551, \"Power\": 287.562161854551, \"i_spike\": 91.5, \"isi\": 0.03834390692603616, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.212868070184563, \"Firing rate\": 163.25559353268687, \"Power\": 163.25559353268687, \"i_spike\": 92.0, \"isi\": 0.03802455357122872, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2357931191352933, \"Firing rate\": 172.10485396344228, \"Power\": 172.10485396344228, \"i_spike\": 79.0, \"isi\": 0.04382598137502598, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3035618471296804, \"Firing rate\": 201.16936596348194, \"Power\": 201.16936596348194, \"i_spike\": 109.5, \"isi\": 0.03202543684399708, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.8017110410666857, \"Firing rate\": 633.4481047134145, \"Power\": 633.4481047134145, \"i_spike\": 98.0, \"isi\": 0.03550739167328109, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1697988740587917, \"Firing rate\": 147.8423557471093, \"Power\": 147.8423557471093, \"i_spike\": 88.5, \"isi\": 0.03925960981462805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.6760870929370943, \"Firing rate\": 474.3370987623261, \"Power\": 474.3370987623261, \"i_spike\": 87.5, \"isi\": 0.039431239454240596, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.433730632307909, \"Firing rate\": 271.47549414255656, \"Power\": 271.47549414255656, \"i_spike\": 96.5, \"isi\": 0.0363181558103682, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.063446911413506, \"Firing rate\": 115.73025536377592, \"Power\": 115.73025536377592, \"i_spike\": 79.0, \"isi\": 0.044476460189586564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.175425654268593, \"Firing rate\": 149.77028432833717, \"Power\": 149.77028432833717, \"i_spike\": 80.5, \"isi\": 0.04299945260731721, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3612576848505684, \"Firing rate\": 229.75114521901307, \"Power\": 229.75114521901307, \"i_spike\": 77.0, \"isi\": 0.04469056636440316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.147995753593227, \"Firing rate\": 140.60337762680615, \"Power\": 140.60337762680615, \"i_spike\": 87.5, \"isi\": 0.03976844291136797, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0929257700333896, \"Firing rate\": 123.85848685027362, \"Power\": 123.85848685027362, \"i_spike\": 94.0, \"isi\": 0.03657174288555396, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10475158728818, \"Firing rate\": 127.27748564862868, \"Power\": 127.27748564862868, \"i_spike\": 98.5, \"isi\": 0.03552973340735749, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2328647390747323, \"Firing rate\": 170.94828141071517, \"Power\": 170.94828141071517, \"i_spike\": 82.5, \"isi\": 0.04166360369234807, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1354623163537503, \"Firing rate\": 136.6036539827589, \"Power\": 136.6036539827589, \"i_spike\": 84.5, \"isi\": 0.040640693096263156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0464608797536576, \"Firing rate\": 111.29121397251097, \"Power\": 111.29121397251097, \"i_spike\": 89.5, \"isi\": 0.03879007896451536, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3355625956917723, \"Firing rate\": 216.5521977627491, \"Power\": 216.5521977627491, \"i_spike\": 98.0, \"isi\": 0.035422439393446775, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2161677848183947, \"Firing rate\": 164.50071305822243, \"Power\": 164.50071305822243, \"i_spike\": 85.0, \"isi\": 0.04048577743104151, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2837266052282277, \"Firing rate\": 192.18814953172904, \"Power\": 192.18814953172904, \"i_spike\": 99.5, \"isi\": 0.03520251098408982, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.161668219920541, \"Firing rate\": 145.10026978437168, \"Power\": 145.10026978437168, \"i_spike\": 90.0, \"isi\": 0.038734070453864254, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.282132072264165, \"Firing rate\": 191.4838153372827, \"Power\": 191.4838153372827, \"i_spike\": 78.0, \"isi\": 0.043996610728127564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0841752044242403, \"Firing rate\": 121.38784583039707, \"Power\": 121.38784583039707, \"i_spike\": 100.0, \"isi\": 0.03461991962811, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.447465040329036, \"Firing rate\": 280.1980059869962, \"Power\": 280.1980059869962, \"i_spike\": 79.0, \"isi\": 0.04452724337396078, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.081771364126096, \"Firing rate\": 120.71781445649961, \"Power\": 120.71781445649961, \"i_spike\": 91.0, \"isi\": 0.03856750376815478, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.9391326595223966, \"Firing rate\": 869.2259023424945, \"Power\": 869.2259023424945, \"i_spike\": 79.0, \"isi\": 0.04416616879896912, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8602028751437854, \"Firing rate\": 72.47744501747489, \"Power\": 72.47744501747489, \"i_spike\": 83.0, \"isi\": 0.04119329035591721, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1734123362153537, \"Firing rate\": 149.07758070284467, \"Power\": 149.07758070284467, \"i_spike\": 81.5, \"isi\": 0.0428418950531146, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.192601337300343, \"Firing rate\": 155.812156100815, \"Power\": 155.812156100815, \"i_spike\": 103.0, \"isi\": 0.03371726705897087, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.325538741593283, \"Firing rate\": 211.6112446357301, \"Power\": 211.6112446357301, \"i_spike\": 106.5, \"isi\": 0.03256875829829079, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0351612273023045, \"Firing rate\": 108.43293852986389, \"Power\": 108.43293852986389, \"i_spike\": 92.5, \"isi\": 0.03785767511850996, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3612887627039565, \"Firing rate\": 229.76758666182133, \"Power\": 229.76758666182133, \"i_spike\": 110.5, \"isi\": 0.0316478026663995, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.486602812028755, \"Firing rate\": 306.62164695003077, \"Power\": 306.62164695003077, \"i_spike\": 102.0, \"isi\": 0.03428746701402582, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.26907338816312, \"Firing rate\": 185.81184180415744, \"Power\": 185.81184180415744, \"i_spike\": 108.0, \"isi\": 0.03182822108027605, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2400289413579997, \"Firing rate\": 173.79166395502384, \"Power\": 173.79166395502384, \"i_spike\": 104.0, \"isi\": 0.03361245677188138, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.133061627118738, \"Firing rate\": 135.8506207230094, \"Power\": 135.8506207230094, \"i_spike\": 83.0, \"isi\": 0.04226663021993772, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.055873381143031, \"Firing rate\": 113.72956581458753, \"Power\": 113.72956581458753, \"i_spike\": 96.5, \"isi\": 0.03623434325043876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077393494053492, \"Firing rate\": 119.50704118553142, \"Power\": 119.50704118553142, \"i_spike\": 86.0, \"isi\": 0.03999884944106042, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7032986753124226, \"Firing rate\": 505.00848528812185, \"Power\": 505.00848528812185, \"i_spike\": 94.5, \"isi\": 0.03642922221630557, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2487291617775735, \"Firing rate\": 177.30833914875691, \"Power\": 177.30833914875691, \"i_spike\": 95.0, \"isi\": 0.035509978483580056, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.6190312582185733, \"Firing rate\": 415.9405466161257, \"Power\": 415.9405466161257, \"i_spike\": 92.5, \"isi\": 0.03739794009579709, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2214636345147007, \"Firing rate\": 166.51893879392634, \"Power\": 166.51893879392634, \"i_spike\": 104.5, \"isi\": 0.03334968571838423, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.050033014448482, \"Firing rate\": 1122.1037517902018, \"Power\": 1122.1037517902018, \"i_spike\": 109.0, \"isi\": 0.03174363047623115, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0201521306738686, \"Firing rate\": 104.7495414963806, \"Power\": 104.7495414963806, \"i_spike\": 84.0, \"isi\": 0.04150443974238124, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.394368017909442, \"Firing rate\": 247.95222963713232, \"Power\": 247.95222963713232, \"i_spike\": 97.5, \"isi\": 0.034832136270722715, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.329502121112529, \"Firing rate\": 213.551251595498, \"Power\": 213.551251595498, \"i_spike\": 119.5, \"isi\": 0.02914255148960452, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.296426000518237, \"Firing rate\": 197.89098058624842, \"Power\": 197.89098058624842, \"i_spike\": 100.5, \"isi\": 0.03453794209724264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9526063135638236, \"Firing rate\": 89.66156470356117, \"Power\": 89.66156470356117, \"i_spike\": 87.0, \"isi\": 0.0403252649629643, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1801699394018295, \"Firing rate\": 151.41536207419279, \"Power\": 151.41536207419279, \"i_spike\": 95.0, \"isi\": 0.0369374859002085, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9603011698286221, \"Firing rate\": 91.26435100880892, \"Power\": 91.26435100880892, \"i_spike\": 100.5, \"isi\": 0.03470962985025618, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1497807834136973, \"Firing rate\": 141.18247252479557, \"Power\": 141.18247252479557, \"i_spike\": 97.0, \"isi\": 0.03544340361561801, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.149622075943538, \"Firing rate\": 141.13088858728008, \"Power\": 141.13088858728008, \"i_spike\": 98.5, \"isi\": 0.03458549884764996, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.056159126623185, \"Firing rate\": 113.80441917809635, \"Power\": 113.80441917809635, \"i_spike\": 87.0, \"isi\": 0.03968042681843487, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3917479076029613, \"Firing rate\": 246.46083050660826, \"Power\": 246.46083050660826, \"i_spike\": 98.5, \"isi\": 0.035535360449709036, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0750924013179355, \"Firing rate\": 118.87551223280595, \"Power\": 118.87551223280595, \"i_spike\": 94.0, \"isi\": 0.03719199644955143, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.489337914838964, \"Firing rate\": 308.5587843479223, \"Power\": 308.5587843479223, \"i_spike\": 95.5, \"isi\": 0.03556131746210524, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.4520230739574873, \"Firing rate\": 283.154243094607, \"Power\": 283.154243094607, \"i_spike\": 107.0, \"isi\": 0.032710924682864184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.323245560174936, \"Firing rate\": 210.49683012562227, \"Power\": 210.49683012562227, \"i_spike\": 107.5, \"isi\": 0.03260971008319308, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4551248825615755, \"Firing rate\": 285.183820345654, \"Power\": 285.183820345654, \"i_spike\": 119.5, \"isi\": 0.029121401254440946, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2034473494582008, \"Firing rate\": 159.75238457442458, \"Power\": 159.75238457442458, \"i_spike\": 117.5, \"isi\": 0.02942985917936488, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.185090643987662, \"Firing rate\": 153.1407056710173, \"Power\": 153.1407056710173, \"i_spike\": 107.5, \"isi\": 0.03182653781887098, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3319515266612205, \"Firing rate\": 214.7590759585309, \"Power\": 214.7590759585309, \"i_spike\": 125.0, \"isi\": 0.028084978019438673, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6162367962967754, \"Firing rate\": 413.2727749153624, \"Power\": 413.2727749153624, \"i_spike\": 106.5, \"isi\": 0.032651038144998264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.251599839982757, \"Firing rate\": 178.48422588668325, \"Power\": 178.48422588668325, \"i_spike\": 112.0, \"isi\": 0.031077478691086027, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.700871783939369, \"Firing rate\": 502.194305618395, \"Power\": 502.194305618395, \"i_spike\": 94.0, \"isi\": 0.036901644723313094, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.314948450805621, \"Firing rate\": 206.5135017156736, \"Power\": 206.5135017156736, \"i_spike\": 93.5, \"isi\": 0.03744836002524842, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6205392303439177, \"Firing rate\": 417.3872998602738, \"Power\": 417.3872998602738, \"i_spike\": 112.5, \"isi\": 0.030901272636151618, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5103170415704716, \"Firing rate\": 323.82997146198255, \"Power\": 323.82997146198255, \"i_spike\": 118.5, \"isi\": 0.0292124077372491, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.267328656385887, \"Firing rate\": 185.06685998516417, \"Power\": 185.06685998516417, \"i_spike\": 112.0, \"isi\": 0.030900503373377113, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3735439867744246, \"Firing rate\": 236.34367636856805, \"Power\": 236.34367636856805, \"i_spike\": 111.5, \"isi\": 0.031086261056407043, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3925644433143702, \"Firing rate\": 246.9246479862117, \"Power\": 246.9246479862117, \"i_spike\": 116.5, \"isi\": 0.0291953589973033, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.561842054638256, \"Firing rate\": 364.6213163680733, \"Power\": 364.6213163680733, \"i_spike\": 111.5, \"isi\": 0.031029868021617713, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.171212511252901, \"Firing rate\": 148.32436961836746, \"Power\": 148.32436961836746, \"i_spike\": 98.0, \"isi\": 0.03548246558301557, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.305560627357594, \"Firing rate\": 202.09735394991617, \"Power\": 202.09735394991617, \"i_spike\": 116.5, \"isi\": 0.029539429675363767, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.230937526831537, \"Firing rate\": 170.19136708674088, \"Power\": 170.19136708674088, \"i_spike\": 109.5, \"isi\": 0.031509671304326574, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8998022408045885, \"Firing rate\": 793.9666138437617, \"Power\": 793.9666138437617, \"i_spike\": 117.0, \"isi\": 0.029395611103945375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.318691352753477, \"Firing rate\": 208.3009989753317, \"Power\": 208.3009989753317, \"i_spike\": 114.0, \"isi\": 0.03080051727849002, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5660625459247224, \"Firing rate\": 368.181994406344, \"Power\": 368.181994406344, \"i_spike\": 110.5, \"isi\": 0.03146794625834939, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.09200788071158, \"Firing rate\": 123.59698611612541, \"Power\": 123.59698611612541, \"i_spike\": 105.5, \"isi\": 0.03222740436284654, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3257979747918998, \"Firing rate\": 211.73759446862695, \"Power\": 211.73759446862695, \"i_spike\": 99.0, \"isi\": 0.035110212287434966, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6983799828455997, \"Firing rate\": 499.3211738782113, \"Power\": 499.3211738782113, \"i_spike\": 100.5, \"isi\": 0.03493647252317627, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.295038880371647, \"Firing rate\": 197.25993258831056, \"Power\": 197.25993258831056, \"i_spike\": 99.5, \"isi\": 0.034805791974127157, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189777301058197, \"Firing rate\": 262.40839812996177, \"Power\": 262.40839812996177, \"i_spike\": 114.0, \"isi\": 0.030289604306854862, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.108818343863044, \"Firing rate\": 128.47491643129774, \"Power\": 128.47491643129774, \"i_spike\": 105.0, \"isi\": 0.033402650086276076, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3301618907903223, \"Firing rate\": 213.8759200460872, \"Power\": 213.8759200460872, \"i_spike\": 102.0, \"isi\": 0.033515540373164496, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2662952548825976, \"Firing rate\": 184.62701784490469, \"Power\": 184.62701784490469, \"i_spike\": 99.5, \"isi\": 0.03522950669230892, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.431293700022412, \"Firing rate\": 269.9564447816099, \"Power\": 269.9564447816099, \"i_spike\": 112.5, \"isi\": 0.031214818356640563, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3379956540094025, \"Firing rate\": 217.76879800918366, \"Power\": 217.76879800918366, \"i_spike\": 128.0, \"isi\": 0.027142001158740867, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 4.268793452708704, \"Firing rate\": 18569.21106902568, \"Power\": 18569.21106902568, \"i_spike\": 112.5, \"isi\": 0.030884711280865364, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.470335706667271, \"Firing rate\": 295.3491373163173, \"Power\": 295.3491373163173, \"i_spike\": 118.5, \"isi\": 0.029429433800978892, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2298279031444963, \"Firing rate\": 169.7570826751943, \"Power\": 169.7570826751943, \"i_spike\": 115.5, \"isi\": 0.030066265039225337, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.079781857998895, \"Firing rate\": 120.16607002272158, \"Power\": 120.16607002272158, \"i_spike\": 112.5, \"isi\": 0.031040291113719316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3243380859972738, \"Firing rate\": 211.02702965366592, \"Power\": 211.02702965366592, \"i_spike\": 115.5, \"isi\": 0.03017297418481671, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.376992751237567, \"Firing rate\": 238.22797066527903, \"Power\": 238.22797066527903, \"i_spike\": 110.0, \"isi\": 0.03125175833885984, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.530486613796888, \"Firing rate\": 339.22403352142646, \"Power\": 339.22403352142646, \"i_spike\": 108.5, \"isi\": 0.03222598156798059, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4983008808245897, \"Firing rate\": 314.99298413824465, \"Power\": 314.99298413824465, \"i_spike\": 116.5, \"isi\": 0.029967692171019168, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.482166228126963, \"Firing rate\": 303.5052641678235, \"Power\": 303.5052641678235, \"i_spike\": 124.5, \"isi\": 0.02742142830301335, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6952270146103454, \"Firing rate\": 495.70924045465966, \"Power\": 495.70924045465966, \"i_spike\": 116.5, \"isi\": 0.029805997031659384, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 1.969829747877291, \"Firing rate\": 93.288851814792, \"Power\": 93.288851814792, \"i_spike\": 104.5, \"isi\": 0.033232072449794876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3040227572766634, \"Firing rate\": 201.3829772917563, \"Power\": 201.3829772917563, \"i_spike\": 118.5, \"isi\": 0.02930928089506225, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2482213585722888, \"Firing rate\": 177.10114074206854, \"Power\": 177.10114074206854, \"i_spike\": 118.5, \"isi\": 0.02923254019041047, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.302306969151288, \"Firing rate\": 200.58893343119396, \"Power\": 200.58893343119396, \"i_spike\": 114.0, \"isi\": 0.030554998388585986, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1470214089632194, \"Firing rate\": 140.28828593141267, \"Power\": 140.28828593141267, \"i_spike\": 123.0, \"isi\": 0.02824600472582251, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1317778042739737, \"Firing rate\": 135.44962414921912, \"Power\": 135.44962414921912, \"i_spike\": 107.5, \"isi\": 0.03260242125359381, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.861629232615016, \"Firing rate\": 727.1587469920275, \"Power\": 727.1587469920275, \"i_spike\": 121.5, \"isi\": 0.02876842284627423, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.309175796871508, \"Firing rate\": 203.7866813288123, \"Power\": 203.7866813288123, \"i_spike\": 127.0, \"isi\": 0.02726151253501496, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1426446687258776, \"Firing rate\": 138.88158641854218, \"Power\": 138.88158641854218, \"i_spike\": 120.0, \"isi\": 0.02911404261537866, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4489418426509477, \"Firing rate\": 281.15243076571574, \"Power\": 281.15243076571574, \"i_spike\": 128.5, \"isi\": 0.026789992139581283, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.412848701632391, \"Firing rate\": 258.73113973987586, \"Power\": 258.73113973987586, \"i_spike\": 124.0, \"isi\": 0.028201124990781163, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.710877629385823, \"Firing rate\": 513.8988305482127, \"Power\": 513.8988305482127, \"i_spike\": 119.0, \"isi\": 0.0293764992264836, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.991538408306236, \"Firing rate\": 980.7050424652082, \"Power\": 980.7050424652082, \"i_spike\": 135.0, \"isi\": 0.025953587990479317, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2762121037042795, \"Firing rate\": 188.89136444020025, \"Power\": 188.89136444020025, \"i_spike\": 122.0, \"isi\": 0.028669385615676706, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.7177018467167304, \"Firing rate\": 522.0376749188929, \"Power\": 522.0376749188929, \"i_spike\": 138.0, \"isi\": 0.02496409561586277, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3914116825786387, \"Firing rate\": 246.27009764338933, \"Power\": 246.27009764338933, \"i_spike\": 110.5, \"isi\": 0.0316618510656651, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6892037162497906, \"Firing rate\": 488.8816272272226, \"Power\": 488.8816272272226, \"i_spike\": 131.5, \"isi\": 0.02658745064897301, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4434824501248773, \"Firing rate\": 277.64026491830793, \"Power\": 277.64026491830793, \"i_spike\": 120.0, \"isi\": 0.0290789856927443, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.238506636309727, \"Firing rate\": 173.18354941508804, \"Power\": 173.18354941508804, \"i_spike\": 121.0, \"isi\": 0.028971993333475, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 19,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Initialize:\n",
    "window = BayesRegression(df=df, y='Power', treatment='stim', group='mouse', detail='i_trial')\n",
    "# Fit:\n",
    "window.fit(model=models.model_hierarchical, add_group_intercept=True,\n",
    "           add_group_slope=False, robust_slopes=False,\n",
    "           do_make_change='subtract', dist_y='gamma');\n",
    "\n",
    "chart_detail_and_intercepts = window.plot_intercepts(x='mouse')\n",
    "window.chart_posterior_intercept"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "pycharm": {
     "name": "#%%\n"
    },
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-78d9ed36657248638ea63193124e0462\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-78d9ed36657248638ea63193124e0462\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-78d9ed36657248638ea63193124e0462\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 4  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '4')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 5  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '5')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 6  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '6')\"}], \"width\": 80}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [58.861815178268806, 609.5203695788464], \"zero\": false}}}}]}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 7  \", \"transform\": [{\"filter\": \"(datum['mouse'] === '7')\"}], \"width\": 80}], \"data\": {\"name\": \"data-55620c08ee0f2b51d1c658df744dfa2d\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-55620c08ee0f2b51d1c658df744dfa2d\": [{\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.955295818792631, \"Firing rate\": 90.21854501261329, \"Power\": 90.21854501261329, \"i_spike\": 47.5, \"isi\": 0.0731915996436363, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6026484195029185, \"Firing rate\": 40.054232969747986, \"Power\": 40.054232969747986, \"i_spike\": 39.5, \"isi\": 0.08505458474637603, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1244493253919545, \"Firing rate\": 133.18316316728252, \"Power\": 133.18316316728252, \"i_spike\": 42.5, \"isi\": 0.08224071637572535, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8708094709723913, \"Firing rate\": 74.2693239984203, \"Power\": 74.2693239984203, \"i_spike\": 33.5, \"isi\": 0.10505328377444978, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9711426825012743, \"Firing rate\": 93.57130415068605, \"Power\": 93.57130415068605, \"i_spike\": 40.5, \"isi\": 0.08430258433195234, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8590874397971908, \"Firing rate\": 72.29153389710372, \"Power\": 72.29153389710372, \"i_spike\": 44.0, \"isi\": 0.0795434324837374, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0132461342812213, \"Firing rate\": 103.09702522654109, \"Power\": 103.09702522654109, \"i_spike\": 47.5, \"isi\": 0.07286723599674903, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0127266901312217, \"Firing rate\": 102.97378826377438, \"Power\": 102.97378826377438, \"i_spike\": 39.0, \"isi\": 0.08914566084967086, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503131681143027, \"Firing rate\": 56.27469736390204, \"Power\": 56.27469736390204, \"i_spike\": 40.0, \"isi\": 0.08700029609063652, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1169032082350827, \"Firing rate\": 130.88901764671587, \"Power\": 130.88901764671587, \"i_spike\": 62.0, \"isi\": 0.05659763212840744, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8770680415974088, \"Firing rate\": 75.34736023774802, \"Power\": 75.34736023774802, \"i_spike\": 39.0, \"isi\": 0.09009246539035318, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9310965336855828, \"Firing rate\": 85.32897596494497, \"Power\": 85.32897596494497, \"i_spike\": 34.0, \"isi\": 0.10149738234291991, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.5333013820605306, \"Firing rate\": 34.14297672922771, \"Power\": 34.14297672922771, \"i_spike\": 40.5, \"isi\": 0.08685116325741157, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.030855072834198, \"Firing rate\": 107.36310742084633, \"Power\": 107.36310742084633, \"i_spike\": 54.5, \"isi\": 0.059448248477706966, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.794551727002911, \"Firing rate\": 623.0913568201987, \"Power\": 623.0913568201987, \"i_spike\": 48.5, \"isi\": 0.0713719442616052, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7955427567112552, \"Firing rate\": 62.451483134242046, \"Power\": 62.451483134242046, \"i_spike\": 35.5, \"isi\": 0.09057886752422038, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9082000854510324, \"Firing rate\": 80.94687466873414, \"Power\": 80.94687466873414, \"i_spike\": 53.0, \"isi\": 0.06529444835938969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6555352624426098, \"Firing rate\": 45.24131944286433, \"Power\": 45.24131944286433, \"i_spike\": 43.5, \"isi\": 0.0768533496686384, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.177328557623848, \"Firing rate\": 150.42795711808552, \"Power\": 150.42795711808552, \"i_spike\": 34.5, \"isi\": 0.09830229180875018, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8645215585407622, \"Firing rate\": 73.20176599287585, \"Power\": 73.20176599287585, \"i_spike\": 55.5, \"isi\": 0.06179006984103724, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.535025958406892, \"Firing rate\": 34.27882748831966, \"Power\": 34.27882748831966, \"i_spike\": 34.5, \"isi\": 0.09915726015773765, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.32247920697616, \"Firing rate\": 210.125716326415, \"Power\": 210.125716326415, \"i_spike\": 33.0, \"isi\": 0.10502063399832753, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.43733847759269, \"Firing rate\": 273.74013531042965, \"Power\": 273.74013531042965, \"i_spike\": 56.0, \"isi\": 0.061967941571928455, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7969419629962189, \"Firing rate\": 62.653013263585784, \"Power\": 62.653013263585784, \"i_spike\": 37.0, \"isi\": 0.09259944757473725, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9846064873802938, \"Firing rate\": 96.51759403196418, \"Power\": 96.51759403196418, \"i_spike\": 41.5, \"isi\": 0.08460263304467304, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503293230777222, \"Firing rate\": 56.27679071904272, \"Power\": 56.27679071904272, \"i_spike\": 42.5, \"isi\": 0.07988986525214349, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.4286782943328151, \"Firing rate\": 26.83356000776027, \"Power\": 26.83356000776027, \"i_spike\": 35.5, \"isi\": 0.09874338503855341, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1383088558675207, \"Firing rate\": 137.50194957559475, \"Power\": 137.50194957559475, \"i_spike\": 48.5, \"isi\": 0.07210812725187593, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0035263866631934, \"Firing rate\": 100.81528603885884, \"Power\": 100.81528603885884, \"i_spike\": 49.5, \"isi\": 0.0672853207791876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6296351063659993, \"Firing rate\": 42.62212577953956, \"Power\": 42.62212577953956, \"i_spike\": 41.5, \"isi\": 0.0790188469593832, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.193262117122394, \"Firing rate\": 156.04940501335037, \"Power\": 156.04940501335037, \"i_spike\": 48.0, \"isi\": 0.07263392600048459, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9760548637782647, \"Firing rate\": 94.63567056548113, \"Power\": 94.63567056548113, \"i_spike\": 44.5, \"isi\": 0.0776680429623508, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6250730368645014, \"Firing rate\": 42.17674276093685, \"Power\": 42.17674276093685, \"i_spike\": 42.5, \"isi\": 0.08104853472101264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.491206995038427, \"Firing rate\": 309.8895954508339, \"Power\": 309.8895954508339, \"i_spike\": 51.5, \"isi\": 0.06708115735632907, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3589480963384455, \"Firing rate\": 228.53256618481504, \"Power\": 228.53256618481504, \"i_spike\": 47.5, \"isi\": 0.07348993800862964, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9281754169377023, \"Firing rate\": 84.75696889405249, \"Power\": 84.75696889405249, \"i_spike\": 53.0, \"isi\": 0.06509876660602372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9843209349691886, \"Firing rate\": 96.45415373032593, \"Power\": 96.45415373032593, \"i_spike\": 59.5, \"isi\": 0.05870376554536328, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7638817011892445, \"Firing rate\": 58.06062428577546, \"Power\": 58.06062428577546, \"i_spike\": 52.0, \"isi\": 0.06566204692122644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.650862407397869, \"Firing rate\": 44.75714827077759, \"Power\": 44.75714827077759, \"i_spike\": 49.0, \"isi\": 0.07040754805798212, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0583883119213846, \"Firing rate\": 114.39006635603113, \"Power\": 114.39006635603113, \"i_spike\": 51.0, \"isi\": 0.06837143070736648, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2173425763203, \"Firing rate\": 164.9462993258368, \"Power\": 164.9462993258368, \"i_spike\": 53.5, \"isi\": 0.06501277873096038, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2107084188475756, \"Firing rate\": 162.44577441851425, \"Power\": 162.44577441851425, \"i_spike\": 49.0, \"isi\": 0.06869119253150469, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5946141113333705, \"Firing rate\": 39.320054519388265, \"Power\": 39.320054519388265, \"i_spike\": 43.0, \"isi\": 0.08147481958019963, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.211944529140798, \"Firing rate\": 162.90879418557492, \"Power\": 162.90879418557492, \"i_spike\": 55.5, \"isi\": 0.06320352970416626, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5907555117125005, \"Firing rate\": 389.7225286301253, \"Power\": 389.7225286301253, \"i_spike\": 48.5, \"isi\": 0.07106759705283149, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.197050324722152, \"Firing rate\": 157.4165263375544, \"Power\": 157.4165263375544, \"i_spike\": 42.5, \"isi\": 0.08120962422114071, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.900738498847488, \"Firing rate\": 79.56801043564009, \"Power\": 79.56801043564009, \"i_spike\": 43.5, \"isi\": 0.07999246270715814, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7701446630135824, \"Firing rate\": 58.90398311997898, \"Power\": 58.90398311997898, \"i_spike\": 42.0, \"isi\": 0.08041029857361554, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5942453724234489, \"Firing rate\": 39.28668388897537, \"Power\": 39.28668388897537, \"i_spike\": 32.5, \"isi\": 0.1019318698052081, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6923353756705557, \"Firing rate\": 49.24196506231455, \"Power\": 49.24196506231455, \"i_spike\": 44.0, \"isi\": 0.07851300689834464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9096430648934821, \"Firing rate\": 81.21627467876483, \"Power\": 81.21627467876483, \"i_spike\": 42.0, \"isi\": 0.08279141280781681, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7227625327508387, \"Firing rate\": 52.815638294554915, \"Power\": 52.815638294554915, \"i_spike\": 47.0, \"isi\": 0.07465675585663739, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0772331102040815, \"Firing rate\": 119.4629156868915, \"Power\": 119.4629156868915, \"i_spike\": 45.0, \"isi\": 0.07778279269254963, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8962156003531803, \"Firing rate\": 78.7436606258303, \"Power\": 78.7436606258303, \"i_spike\": 45.0, \"isi\": 0.07723000353960975, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.539325164353972, \"Firing rate\": 34.61984860582479, \"Power\": 34.61984860582479, \"i_spike\": 43.5, \"isi\": 0.08038783649040848, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.795290559690197, \"Firing rate\": 62.41522776726645, \"Power\": 62.41522776726645, \"i_spike\": 51.0, \"isi\": 0.06863876971272939, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7829257189432979, \"Firing rate\": 60.6632563219068, \"Power\": 60.6632563219068, \"i_spike\": 51.5, \"isi\": 0.06724356364949484, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8506258960042894, \"Firing rate\": 70.89667964004052, \"Power\": 70.89667964004052, \"i_spike\": 53.0, \"isi\": 0.06603508775646316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9623740441999131, \"Firing rate\": 91.70099419760025, \"Power\": 91.70099419760025, \"i_spike\": 45.0, \"isi\": 0.0739363878905739, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0543726256433428, \"Firing rate\": 113.33723822345725, \"Power\": 113.33723822345725, \"i_spike\": 59.5, \"isi\": 0.05882184181366276, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0311570012276237, \"Firing rate\": 107.4377739030315, \"Power\": 107.4377739030315, \"i_spike\": 43.5, \"isi\": 0.08064172994284798, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.149704072470153, \"Firing rate\": 141.15753717632737, \"Power\": 141.15753717632737, \"i_spike\": 59.0, \"isi\": 0.059210435905617934, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0114163933193723, \"Firing rate\": 102.6635773453862, \"Power\": 102.6635773453862, \"i_spike\": 55.0, \"isi\": 0.06332773568755358, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9540841070386274, \"Firing rate\": 89.96717983510673, \"Power\": 89.96717983510673, \"i_spike\": 42.5, \"isi\": 0.08201299481958542, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8156677764444182, \"Firing rate\": 65.41355865573313, \"Power\": 65.41355865573313, \"i_spike\": 54.0, \"isi\": 0.06526466311001969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.893859348236818, \"Firing rate\": 78.31759602448699, \"Power\": 78.31759602448699, \"i_spike\": 56.5, \"isi\": 0.06184020841304989, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.773984421574805, \"Firing rate\": 59.427084135210976, \"Power\": 59.427084135210976, \"i_spike\": 60.0, \"isi\": 0.058270067505733734, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.210840290387196, \"Firing rate\": 162.49510782693136, \"Power\": 162.49510782693136, \"i_spike\": 56.5, \"isi\": 0.06020300273286523, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9713400241427212, \"Firing rate\": 93.61383223125311, \"Power\": 93.61383223125311, \"i_spike\": 61.0, \"isi\": 0.0543980735122145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8497634918355093, \"Firing rate\": 70.75603561035722, \"Power\": 70.75603561035722, \"i_spike\": 47.5, \"isi\": 0.07274197195399083, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9624750863491771, \"Firing rate\": 91.72233166302841, \"Power\": 91.72233166302841, \"i_spike\": 48.5, \"isi\": 0.07010114635983886, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.855302039054747, \"Firing rate\": 71.66416401500264, \"Power\": 71.66416401500264, \"i_spike\": 46.0, \"isi\": 0.0766119040381658, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.046426832369158, \"Firing rate\": 111.28248941720267, \"Power\": 111.28248941720267, \"i_spike\": 64.0, \"isi\": 0.05429137856724891, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7100483491678449, \"Firing rate\": 51.29184830393363, \"Power\": 51.29184830393363, \"i_spike\": 49.5, \"isi\": 0.0703751778152302, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3453546584516265, \"Firing rate\": 221.49027300778377, \"Power\": 221.49027300778377, \"i_spike\": 59.5, \"isi\": 0.058785042141719916, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.875277533612671, \"Firing rate\": 75.03735784498373, \"Power\": 75.03735784498373, \"i_spike\": 56.0, \"isi\": 0.06218241581461111, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6818911486395558, \"Firing rate\": 48.071884620822175, \"Power\": 48.071884620822175, \"i_spike\": 56.0, \"isi\": 0.06219590540248409, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7807624476641064, \"Firing rate\": 60.36183691888134, \"Power\": 60.36183691888134, \"i_spike\": 46.0, \"isi\": 0.07429803181700052, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7183011441323788, \"Firing rate\": 52.27585493529653, \"Power\": 52.27585493529653, \"i_spike\": 52.5, \"isi\": 0.06577263809678958, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.763346825231255, \"Firing rate\": 57.98916098746875, \"Power\": 57.98916098746875, \"i_spike\": 48.5, \"isi\": 0.07131264606340101, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.835065458404151, \"Firing rate\": 68.40147366385926, \"Power\": 68.40147366385926, \"i_spike\": 49.0, \"isi\": 0.07194196841840346, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.924715551322173, \"Firing rate\": 84.08442357857703, \"Power\": 84.08442357857703, \"i_spike\": 55.5, \"isi\": 0.06318891040674948, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.017073838923778, \"Firing rate\": 104.00969885083077, \"Power\": 104.00969885083077, \"i_spike\": 49.0, \"isi\": 0.07044066419783745, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7143174946332422, \"Firing rate\": 517.9853711282016, \"Power\": 517.9853711282016, \"i_spike\": 65.0, \"isi\": 0.052930696952406625, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.974181294239221, \"Firing rate\": 94.22828660927348, \"Power\": 94.22828660927348, \"i_spike\": 58.0, \"isi\": 0.060053602856178986, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9399526356112446, \"Firing rate\": 87.08686073800901, \"Power\": 87.08686073800901, \"i_spike\": 53.0, \"isi\": 0.06646977245711418, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6853656755730138, \"Firing rate\": 48.45802119713409, \"Power\": 48.45802119713409, \"i_spike\": 40.0, \"isi\": 0.08662078631540625, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9336719560475775, \"Firing rate\": 85.83649113967905, \"Power\": 85.83649113967905, \"i_spike\": 57.0, \"isi\": 0.060295111833858245, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0093234248133296, \"Firing rate\": 102.17000739461349, \"Power\": 102.17000739461349, \"i_spike\": 49.0, \"isi\": 0.06980898473808321, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6653323391451258, \"Firing rate\": 46.27349888819327, \"Power\": 46.27349888819327, \"i_spike\": 52.5, \"isi\": 0.06664468983496366, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.319563597750638, \"Firing rate\": 208.71977491726287, \"Power\": 208.71977491726287, \"i_spike\": 62.5, \"isi\": 0.054778780974004924, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9501238550989324, \"Firing rate\": 89.15051474767834, \"Power\": 89.15051474767834, \"i_spike\": 65.0, \"isi\": 0.052393936924168064, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.058384385790344, \"Firing rate\": 114.38903224581574, \"Power\": 114.38903224581574, \"i_spike\": 67.0, \"isi\": 0.051939822712101694, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.341203185363342, \"Firing rate\": 219.38310826468677, \"Power\": 219.38310826468677, \"i_spike\": 63.5, \"isi\": 0.054996827366133136, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9819991440519158, \"Firing rate\": 95.9398740641521, \"Power\": 95.9398740641521, \"i_spike\": 56.0, \"isi\": 0.06266914967033387, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.369563712635469, \"Firing rate\": 234.18750118502433, \"Power\": 234.18750118502433, \"i_spike\": 66.0, \"isi\": 0.05307466490753688, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8499974740031297, \"Firing rate\": 70.79416667549492, \"Power\": 70.79416667549492, \"i_spike\": 50.0, \"isi\": 0.06964434411828664, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4140871865689233, \"Firing rate\": 259.4700207563056, \"Power\": 259.4700207563056, \"i_spike\": 57.5, \"isi\": 0.05932812658617926, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2992730643707255, \"Firing rate\": 199.19253762816092, \"Power\": 199.19253762816092, \"i_spike\": 69.0, \"isi\": 0.0505200086604451, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1143279384255944, \"Firing rate\": 130.11517148140396, \"Power\": 130.11517148140396, \"i_spike\": 58.0, \"isi\": 0.06039580425018153, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1347425595996863, \"Firing rate\": 136.37744808427303, \"Power\": 136.37744808427303, \"i_spike\": 57.5, \"isi\": 0.06059068471302143, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9227227083724787, \"Firing rate\": 83.69947007723921, \"Power\": 83.69947007723921, \"i_spike\": 74.5, \"isi\": 0.04700841293964799, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9356641657046738, \"Firing rate\": 86.23114755907184, \"Power\": 86.23114755907184, \"i_spike\": 59.0, \"isi\": 0.05819722837595124, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1650029836128866, \"Firing rate\": 146.21872196813922, \"Power\": 146.21872196813922, \"i_spike\": 66.5, \"isi\": 0.05230105943774251, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.090242481076867, \"Firing rate\": 123.09558626462615, \"Power\": 123.09558626462615, \"i_spike\": 57.5, \"isi\": 0.059929836211731397, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9223690348846298, \"Firing rate\": 83.63133604719516, \"Power\": 83.63133604719516, \"i_spike\": 60.5, \"isi\": 0.05806760763773719, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1491227759212217, \"Firing rate\": 140.9687263512985, \"Power\": 140.9687263512985, \"i_spike\": 54.5, \"isi\": 0.06367419112012151, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3941117654392667, \"Firing rate\": 247.80597028438038, \"Power\": 247.80597028438038, \"i_spike\": 63.0, \"isi\": 0.05461154211696954, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9896786925487997, \"Firing rate\": 97.65144913558673, \"Power\": 97.65144913558673, \"i_spike\": 62.5, \"isi\": 0.05504185225729406, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.7731494316094232, \"Firing rate\": 59.31293728328963, \"Power\": 59.31293728328963, \"i_spike\": 55.0, \"isi\": 0.06267698786541855, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8554169772491347, \"Firing rate\": 71.68313280237724, \"Power\": 71.68313280237724, \"i_spike\": 60.5, \"isi\": 0.056999565632898194, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3716727528341055, \"Firing rate\": 235.32753886515357, \"Power\": 235.32753886515357, \"i_spike\": 52.0, \"isi\": 0.067154049479885, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2364092112497285, \"Firing rate\": 172.34917594410877, \"Power\": 172.34917594410877, \"i_spike\": 59.5, \"isi\": 0.05869502074828589, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2557126583819076, \"Firing rate\": 180.18252074391486, \"Power\": 180.18252074391486, \"i_spike\": 73.5, \"isi\": 0.04743594072717539, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.7433869258557073, \"Firing rate\": 553.8433249443033, \"Power\": 553.8433249443033, \"i_spike\": 55.0, \"isi\": 0.06360854706023654, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9410922920516542, \"Firing rate\": 87.31569035109068, \"Power\": 87.31569035109068, \"i_spike\": 65.5, \"isi\": 0.052877411734321145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.053756802379095, \"Firing rate\": 113.17664155543305, \"Power\": 113.17664155543305, \"i_spike\": 54.0, \"isi\": 0.06436186527784456, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.034873477705347, \"Firing rate\": 108.36111813754236, \"Power\": 108.36111813754236, \"i_spike\": 66.5, \"isi\": 0.050938903955247916, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9885417764206283, \"Firing rate\": 97.39614698417968, \"Power\": 97.39614698417968, \"i_spike\": 60.0, \"isi\": 0.05780359441402076, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4369749555623357, \"Firing rate\": 273.51109962529904, \"Power\": 273.51109962529904, \"i_spike\": 64.0, \"isi\": 0.053993497700095504, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1065489309483487, \"Firing rate\": 127.8053196733479, \"Power\": 127.8053196733479, \"i_spike\": 66.0, \"isi\": 0.05304312813996159, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9049237369041854, \"Firing rate\": 80.33850335646146, \"Power\": 80.33850335646146, \"i_spike\": 74.0, \"isi\": 0.046752172315214786, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.089842705284853, \"Firing rate\": 122.98232672563184, \"Power\": 122.98232672563184, \"i_spike\": 62.5, \"isi\": 0.055459566693195586, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0542996219949314, \"Firing rate\": 113.3181881621406, \"Power\": 113.3181881621406, \"i_spike\": 68.5, \"isi\": 0.04886679113481873, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5270188880084747, \"Firing rate\": 336.5262050014474, \"Power\": 336.5262050014474, \"i_spike\": 77.0, \"isi\": 0.045084314963419254, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8366391281202479, \"Firing rate\": 68.64977657243634, \"Power\": 68.64977657243634, \"i_spike\": 70.5, \"isi\": 0.04950827198418861, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9617130502576103, \"Firing rate\": 91.56153191880342, \"Power\": 91.56153191880342, \"i_spike\": 68.5, \"isi\": 0.05136728010783104, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.241494871870913, \"Firing rate\": 174.37927667202098, \"Power\": 174.37927667202098, \"i_spike\": 63.0, \"isi\": 0.05576348859764074, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 3.1251395921423315, \"Firing rate\": 1333.9501252294517, \"Power\": 1333.9501252294517, \"i_spike\": 64.5, \"isi\": 0.054262100729024564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8958624054342972, \"Firing rate\": 78.67964748291678, \"Power\": 78.67964748291678, \"i_spike\": 74.0, \"isi\": 0.046877125846140295, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5517732739731294, \"Firing rate\": 356.2650945497233, \"Power\": 356.2650945497233, \"i_spike\": 76.5, \"isi\": 0.04517211033649603, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0919634725229534, \"Firing rate\": 123.58434852138122, \"Power\": 123.58434852138122, \"i_spike\": 68.0, \"isi\": 0.05101734433625525, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3525110631387873, \"Firing rate\": 225.17027754817553, \"Power\": 225.17027754817553, \"i_spike\": 65.0, \"isi\": 0.05404540309717516, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.7819954120481858, \"Firing rate\": 60.53344798762198, \"Power\": 60.53344798762198, \"i_spike\": 53.0, \"isi\": 0.06467002728543748, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8422213318301035, \"Firing rate\": 69.5378616839905, \"Power\": 69.5378616839905, \"i_spike\": 69.0, \"isi\": 0.05037331163693314, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1868975598998643, \"Firing rate\": 153.77918677144316, \"Power\": 153.77918677144316, \"i_spike\": 70.0, \"isi\": 0.049775509977722336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9726367908939046, \"Firing rate\": 93.89377298287559, \"Power\": 93.89377298287559, \"i_spike\": 75.5, \"isi\": 0.04639225026242182, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.778101000828387, \"Firing rate\": 59.99305816899431, \"Power\": 59.99305816899431, \"i_spike\": 68.5, \"isi\": 0.05075104338195106, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9121660273135348, \"Firing rate\": 81.68946039587414, \"Power\": 81.68946039587414, \"i_spike\": 64.0, \"isi\": 0.05481280145440375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0478218930526535, \"Firing rate\": 111.64053089208255, \"Power\": 111.64053089208255, \"i_spike\": 70.0, \"isi\": 0.0489888087012864, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.117471278561992, \"Firing rate\": 131.0603364640247, \"Power\": 131.0603364640247, \"i_spike\": 65.5, \"isi\": 0.051671766893329675, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.931167591711936, \"Firing rate\": 853.4293839120918, \"Power\": 853.4293839120918, \"i_spike\": 63.0, \"isi\": 0.05525138390063168, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.277774705751867, \"Firing rate\": 189.57222427760698, \"Power\": 189.57222427760698, \"i_spike\": 78.0, \"isi\": 0.04456622398656536, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.845684289414062, \"Firing rate\": 70.09455604474384, \"Power\": 70.09455604474384, \"i_spike\": 63.5, \"isi\": 0.05469869440456847, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10431894281778, \"Firing rate\": 127.15075486242938, \"Power\": 127.15075486242938, \"i_spike\": 67.0, \"isi\": 0.05227215134911894, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.033552725921547, \"Firing rate\": 108.03207702586286, \"Power\": 108.03207702586286, \"i_spike\": 57.5, \"isi\": 0.060347774168580594, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1643005604050174, \"Firing rate\": 145.98242053251482, \"Power\": 145.98242053251482, \"i_spike\": 72.5, \"isi\": 0.04783783469680652, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0012121960819167, \"Firing rate\": 100.27950836105705, \"Power\": 100.27950836105705, \"i_spike\": 71.5, \"isi\": 0.048990832561469015, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9583920039283502, \"Firing rate\": 90.86403192498832, \"Power\": 90.86403192498832, \"i_spike\": 76.0, \"isi\": 0.04556701067411184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1124885757403176, \"Firing rate\": 129.56526144990931, \"Power\": 129.56526144990931, \"i_spike\": 75.0, \"isi\": 0.046659913362027156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7844790003053106, \"Firing rate\": 608.8061070924601, \"Power\": 608.8061070924601, \"i_spike\": 92.0, \"isi\": 0.03797865081756185, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1928313296970376, \"Firing rate\": 155.8946924977612, \"Power\": 155.8946924977612, \"i_spike\": 92.0, \"isi\": 0.038121755542223995, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077615601977832, \"Firing rate\": 119.56817539419721, \"Power\": 119.56817539419721, \"i_spike\": 74.5, \"isi\": 0.04660934195613513, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3240668465311076, \"Firing rate\": 210.895273459069, \"Power\": 210.895273459069, \"i_spike\": 75.5, \"isi\": 0.04641624316187993, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9441862764582671, \"Firing rate\": 87.93996257483187, \"Power\": 87.93996257483187, \"i_spike\": 73.0, \"isi\": 0.04692146801636959, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.0247285177119982, \"Firing rate\": 1058.591780864329, \"Power\": 1058.591780864329, \"i_spike\": 77.0, \"isi\": 0.045685464766526206, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.7391920768878777, \"Firing rate\": 54.85195068575797, \"Power\": 54.85195068575797, \"i_spike\": 64.5, \"isi\": 0.05399592200088135, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1934103426446043, \"Firing rate\": 156.10267405821313, \"Power\": 156.10267405821313, \"i_spike\": 74.5, \"isi\": 0.046628423844649644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.297774880328158, \"Firing rate\": 198.50656775360184, \"Power\": 198.50656775360184, \"i_spike\": 80.0, \"isi\": 0.04397457503735967, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1110133951114576, \"Firing rate\": 129.1259099799552, \"Power\": 129.1259099799552, \"i_spike\": 87.5, \"isi\": 0.03951101481601628, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9798834285720046, \"Firing rate\": 95.47362854816234, \"Power\": 95.47362854816234, \"i_spike\": 82.0, \"isi\": 0.04281447867823779, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9839401087688497, \"Firing rate\": 96.36961162784607, \"Power\": 96.36961162784607, \"i_spike\": 80.5, \"isi\": 0.0436343619819139, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9292502786690382, \"Firing rate\": 84.96699885333383, \"Power\": 84.96699885333383, \"i_spike\": 84.5, \"isi\": 0.040212763358464985, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.110242887829347, \"Firing rate\": 128.89702323935285, \"Power\": 128.89702323935285, \"i_spike\": 78.0, \"isi\": 0.044671705231796116, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9896296651016587, \"Firing rate\": 97.6404258985101, \"Power\": 97.6404258985101, \"i_spike\": 96.5, \"isi\": 0.03602341732975196, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.524514898794598, \"Firing rate\": 3345.9149606607, \"Power\": 3345.9149606607, \"i_spike\": 67.0, \"isi\": 0.05228146274267083, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1112668565940305, \"Firing rate\": 129.20129200352847, \"Power\": 129.20129200352847, \"i_spike\": 72.5, \"isi\": 0.04765721891987244, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9572989808412744, \"Firing rate\": 90.63563480094187, \"Power\": 90.63563480094187, \"i_spike\": 77.5, \"isi\": 0.04525372674699464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.543885879418327, \"Firing rate\": 349.85322319506616, \"Power\": 349.85322319506616, \"i_spike\": 71.5, \"isi\": 0.048639441668922465, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1757930037804383, \"Firing rate\": 149.89702164205846, \"Power\": 149.89702164205846, \"i_spike\": 82.0, \"isi\": 0.04242030307116036, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9882434867575853, \"Firing rate\": 97.32927464232434, \"Power\": 97.32927464232434, \"i_spike\": 73.0, \"isi\": 0.047906156958600565, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.123436432758141, \"Firing rate\": 132.8729058171096, \"Power\": 132.8729058171096, \"i_spike\": 74.0, \"isi\": 0.04678579996295997, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2883138118447697, \"Firing rate\": 194.22888267612504, \"Power\": 194.22888267612504, \"i_spike\": 76.0, \"isi\": 0.04579097873240445, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3338630531397206, \"Firing rate\": 215.70641109917793, \"Power\": 215.70641109917793, \"i_spike\": 82.0, \"isi\": 0.04253295769330548, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1368082310712584, \"Firing rate\": 137.02765673763616, \"Power\": 137.02765673763616, \"i_spike\": 87.0, \"isi\": 0.04009013967311376, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.304411865772515, \"Firing rate\": 201.5634883150203, \"Power\": 201.5634883150203, \"i_spike\": 84.5, \"isi\": 0.040969846937519115, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1578448451318133, \"Firing rate\": 143.82846487878152, \"Power\": 143.82846487878152, \"i_spike\": 93.0, \"isi\": 0.037192354679684805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.026210332863069, \"Firing rate\": 106.22098707802203, \"Power\": 106.22098707802203, \"i_spike\": 86.0, \"isi\": 0.039883894146009444, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0309948773666058, \"Firing rate\": 107.39767443894033, \"Power\": 107.39767443894033, \"i_spike\": 71.5, \"isi\": 0.04790202069793337, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1102417146873824, \"Firing rate\": 128.89667505555326, \"Power\": 128.89667505555326, \"i_spike\": 85.5, \"isi\": 0.040840328777172155, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3598760140799757, \"Firing rate\": 229.0213730590734, \"Power\": 229.0213730590734, \"i_spike\": 85.5, \"isi\": 0.041093869337129094, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4487993661694656, \"Firing rate\": 281.0602098401713, \"Power\": 281.0602098401713, \"i_spike\": 88.5, \"isi\": 0.03916681921061969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1541973100299687, \"Firing rate\": 142.6255427263312, \"Power\": 142.6255427263312, \"i_spike\": 87.5, \"isi\": 0.039474320407279974, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.234900540025064, \"Firing rate\": 171.7515005319624, \"Power\": 171.7515005319624, \"i_spike\": 94.5, \"isi\": 0.03655183866180524, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.7078341872007305, \"Firing rate\": 510.31012735003867, \"Power\": 510.31012735003867, \"i_spike\": 83.5, \"isi\": 0.041988842659945944, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1126963123799873, \"Firing rate\": 129.6272513932111, \"Power\": 129.6272513932111, \"i_spike\": 89.0, \"isi\": 0.03919921663226311, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1692211907420162, \"Firing rate\": 147.6458317545557, \"Power\": 147.6458317545557, \"i_spike\": 88.0, \"isi\": 0.03956930417423602, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1644556852991537, \"Firing rate\": 146.03457305415864, \"Power\": 146.03457305415864, \"i_spike\": 96.5, \"isi\": 0.03588734853002937, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.31196565210909, \"Firing rate\": 205.0999960994725, \"Power\": 205.0999960994725, \"i_spike\": 90.0, \"isi\": 0.03903067099230167, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.074577597091679, \"Firing rate\": 118.73468299886356, \"Power\": 118.73468299886356, \"i_spike\": 104.0, \"isi\": 0.03353750893302584, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2092160144315107, \"Firing rate\": 161.88850572662918, \"Power\": 161.88850572662918, \"i_spike\": 104.5, \"isi\": 0.03279156198398983, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.49914214982962, \"Firing rate\": 315.60374635173724, \"Power\": 315.60374635173724, \"i_spike\": 101.5, \"isi\": 0.034537567878371166, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1418864131165836, \"Firing rate\": 138.63931793743396, \"Power\": 138.63931793743396, \"i_spike\": 91.5, \"isi\": 0.03818102135269262, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8765227305978964, \"Firing rate\": 752.5281158141704, \"Power\": 752.5281158141704, \"i_spike\": 93.5, \"isi\": 0.03689839236734887, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.939461561874331, \"Firing rate\": 86.98844387480378, \"Power\": 86.98844387480378, \"i_spike\": 92.0, \"isi\": 0.03758519178898388, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2870436262828573, \"Firing rate\": 193.66164935551598, \"Power\": 193.66164935551598, \"i_spike\": 89.5, \"isi\": 0.03894744817039956, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1430297227592443, \"Firing rate\": 139.0047761690239, \"Power\": 139.0047761690239, \"i_spike\": 97.0, \"isi\": 0.03603976087193819, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.310726570280992, \"Firing rate\": 204.51566105247213, \"Power\": 204.51566105247213, \"i_spike\": 91.0, \"isi\": 0.03830441539373303, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3968118547257453, \"Firing rate\": 249.35142514175052, \"Power\": 249.35142514175052, \"i_spike\": 96.0, \"isi\": 0.03647169049835178, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 3.469141414513526, \"Firing rate\": 2945.3805493938794, \"Power\": 2945.3805493938794, \"i_spike\": 97.0, \"isi\": 0.03567197347869549, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189566775673024, \"Firing rate\": 262.39567812258474, \"Power\": 262.39567812258474, \"i_spike\": 109.0, \"isi\": 0.03178383198414856, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.404076689518491, \"Firing rate\": 253.55763335396162, \"Power\": 253.55763335396162, \"i_spike\": 100.0, \"isi\": 0.034975946689714515, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4991139433760545, \"Firing rate\": 315.58324926114744, \"Power\": 315.58324926114744, \"i_spike\": 83.5, \"isi\": 0.04187307899164901, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.379747962179488, \"Firing rate\": 239.7441187730139, \"Power\": 239.7441187730139, \"i_spike\": 100.0, \"isi\": 0.03471693037002835, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.8902246293874716, \"Firing rate\": 77.66487174396306, \"Power\": 77.66487174396306, \"i_spike\": 87.5, \"isi\": 0.03966381661521433, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.814843398948089, \"Firing rate\": 652.8950845550662, \"Power\": 652.8950845550662, \"i_spike\": 85.5, \"isi\": 0.040891388126968714, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.9487896110579808, \"Firing rate\": 888.7704589764036, \"Power\": 888.7704589764036, \"i_spike\": 89.5, \"isi\": 0.03915085074928612, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.0149402045520945, \"Firing rate\": 103.49996538656313, \"Power\": 103.49996538656313, \"i_spike\": 89.5, \"isi\": 0.03921140742804705, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.9542028872402641, \"Firing rate\": 89.9917893609065, \"Power\": 89.9917893609065, \"i_spike\": 85.5, \"isi\": 0.04054868314386225, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4881910216727383, \"Firing rate\": 307.74501140084084, \"Power\": 307.74501140084084, \"i_spike\": 88.0, \"isi\": 0.03904624656724844, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4115277428777, \"Firing rate\": 257.945373553756, \"Power\": 257.945373553756, \"i_spike\": 119.5, \"isi\": 0.02880924312756989, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4545567386868696, \"Firing rate\": 284.81098690467894, \"Power\": 284.81098690467894, \"i_spike\": 109.0, \"isi\": 0.03179620656212547, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3111719305423497, \"Firing rate\": 204.7254953238993, \"Power\": 204.7254953238993, \"i_spike\": 97.5, \"isi\": 0.03580379043600067, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.165545723182864, \"Firing rate\": 146.40156632304382, \"Power\": 146.40156632304382, \"i_spike\": 105.5, \"isi\": 0.03278382952607013, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2578646424397553, \"Firing rate\": 181.07756360533585, \"Power\": 181.07756360533585, \"i_spike\": 119.0, \"isi\": 0.029343681835626842, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.8107940843269335, \"Firing rate\": 646.835853340232, \"Power\": 646.835853340232, \"i_spike\": 116.0, \"isi\": 0.029999599974023163, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.39182087209241, \"Firing rate\": 246.50224111651946, \"Power\": 246.50224111651946, \"i_spike\": 117.5, \"isi\": 0.029502232467124783, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0658291633993806, \"Firing rate\": 116.36681920867568, \"Power\": 116.36681920867568, \"i_spike\": 101.0, \"isi\": 0.034668414565907774, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3285225511020813, \"Firing rate\": 213.07012031018914, \"Power\": 213.07012031018914, \"i_spike\": 113.5, \"isi\": 0.03083920593859388, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6729864873429214, \"Firing rate\": 470.9626726162531, \"Power\": 470.9626726162531, \"i_spike\": 122.0, \"isi\": 0.028568916959577716, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2018925265651847, \"Firing rate\": 159.18147571149987, \"Power\": 159.18147571149987, \"i_spike\": 112.0, \"isi\": 0.030867054694338973, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.374213868452394, \"Firing rate\": 236.70850822985395, \"Power\": 236.70850822985395, \"i_spike\": 105.0, \"isi\": 0.03330704053094981, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.311456530252207, \"Firing rate\": 204.85969899001685, \"Power\": 204.85969899001685, \"i_spike\": 104.0, \"isi\": 0.03379316964890372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.18089067422046, \"Firing rate\": 151.66685255353084, \"Power\": 151.66685255353084, \"i_spike\": 108.0, \"isi\": 0.03226254920952097, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1779833854348714, \"Firing rate\": 150.65494298513445, \"Power\": 150.65494298513445, \"i_spike\": 113.0, \"isi\": 0.030897373044620688, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3035855615368024, \"Firing rate\": 201.18035100403486, \"Power\": 201.18035100403486, \"i_spike\": 112.5, \"isi\": 0.031017803226141994, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4551657383947396, \"Firing rate\": 285.2106499995778, \"Power\": 285.2106499995778, \"i_spike\": 119.5, \"isi\": 0.02922791099470977, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 3.100538081982483, \"Firing rate\": 1260.486161305173, \"Power\": 1260.486161305173, \"i_spike\": 117.5, \"isi\": 0.029697418256461976, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1111083966350765, \"Firing rate\": 129.15415924516745, \"Power\": 129.15415924516745, \"i_spike\": 118.5, \"isi\": 0.02948619911662466, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.044552627498885, \"Firing rate\": 110.80328278754759, \"Power\": 110.80328278754759, \"i_spike\": 101.0, \"isi\": 0.03429723398050743, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.016091787828533, \"Firing rate\": 103.77477198816491, \"Power\": 103.77477198816491, \"i_spike\": 103.5, \"isi\": 0.03346541480440439, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2697421877977257, \"Firing rate\": 186.09820654703583, \"Power\": 186.09820654703583, \"i_spike\": 118.5, \"isi\": 0.029214269965179746, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.687691210640336, \"Firing rate\": 487.1819738340354, \"Power\": 487.1819738340354, \"i_spike\": 112.0, \"isi\": 0.031291789674142416, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.5700111791336004, \"Firing rate\": 371.5447928738117, \"Power\": 371.5447928738117, \"i_spike\": 119.5, \"isi\": 0.029125995163474167, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.324688636610815, \"Firing rate\": 211.19743365693657, \"Power\": 211.19743365693657, \"i_spike\": 128.5, \"isi\": 0.02689077169759444, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.197745717540907, \"Firing rate\": 157.668783762246, \"Power\": 157.668783762246, \"i_spike\": 116.5, \"isi\": 0.029739505746504635, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.232111730437686, \"Firing rate\": 170.65213673060103, \"Power\": 170.65213673060103, \"i_spike\": 119.5, \"isi\": 0.029278118430901116, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.226281785132872, \"Firing rate\": 168.3766191894407, \"Power\": 168.3766191894407, \"i_spike\": 100.5, \"isi\": 0.03487511849895156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4240095717708385, \"Firing rate\": 265.4664069640671, \"Power\": 265.4664069640671, \"i_spike\": 109.0, \"isi\": 0.032083977077943644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0765668363240124, \"Firing rate\": 119.27978189302107, \"Power\": 119.27978189302107, \"i_spike\": 118.0, \"isi\": 0.02924333618462232, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.710200388455537, \"Firing rate\": 513.0980787193608, \"Power\": 513.0980787193608, \"i_spike\": 58.0, \"isi\": 0.05755769778597422, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.086495554586632, \"Firing rate\": 122.03813289272098, \"Power\": 122.03813289272098, \"i_spike\": 58.0, \"isi\": 0.05954567433072462, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.4599942127543875, \"Firing rate\": 288.3993071858994, \"Power\": 288.3993071858994, \"i_spike\": 69.0, \"isi\": 0.050452157477652144, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8764248252258178, \"Firing rate\": 75.23584884202715, \"Power\": 75.23584884202715, \"i_spike\": 47.5, \"isi\": 0.0729232484181408, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.943371360287594, \"Firing rate\": 87.77510553153151, \"Power\": 87.77510553153151, \"i_spike\": 72.0, \"isi\": 0.04794968452690702, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0095288502408404, \"Firing rate\": 102.21834621295545, \"Power\": 102.21834621295545, \"i_spike\": 58.5, \"isi\": 0.05900199429876669, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.108813974324886, \"Firing rate\": 128.47362382167685, \"Power\": 128.47362382167685, \"i_spike\": 74.0, \"isi\": 0.04704885530644372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9546575480473676, \"Firing rate\": 90.08605066518454, \"Power\": 90.08605066518454, \"i_spike\": 66.0, \"isi\": 0.05192063434120186, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9556030665055126, \"Firing rate\": 90.28239396841717, \"Power\": 90.28239396841717, \"i_spike\": 63.0, \"isi\": 0.05547055572684698, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.116207536382213, \"Firing rate\": 130.6795217411474, \"Power\": 130.6795217411474, \"i_spike\": 60.5, \"isi\": 0.0574361231164934, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.125243880671493, \"Firing rate\": 133.4270489421996, \"Power\": 133.4270489421996, \"i_spike\": 68.0, \"isi\": 0.04981296493334266, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.067202187376957, \"Firing rate\": 116.73529559924685, \"Power\": 116.73529559924685, \"i_spike\": 61.5, \"isi\": 0.0564927141817096, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3223316454945286, \"Firing rate\": 210.0543334368294, \"Power\": 210.0543334368294, \"i_spike\": 59.5, \"isi\": 0.058641352393127184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0012989243549466, \"Firing rate\": 100.29953610121872, \"Power\": 100.29953610121872, \"i_spike\": 63.5, \"isi\": 0.053258724806304336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.740752379052743, \"Firing rate\": 55.049373283103336, \"Power\": 55.049373283103336, \"i_spike\": 68.5, \"isi\": 0.05025347412312059, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8372359506262905, \"Firing rate\": 68.74418232403539, \"Power\": 68.74418232403539, \"i_spike\": 58.5, \"isi\": 0.05883024786315191, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3872683261080843, \"Firing rate\": 243.9317469805847, \"Power\": 243.9317469805847, \"i_spike\": 52.0, \"isi\": 0.06463987437697509, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1699952647940046, \"Firing rate\": 147.90922612197502, \"Power\": 147.90922612197502, \"i_spike\": 58.0, \"isi\": 0.06041749419783433, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0727936321681573, \"Firing rate\": 118.24795321797994, \"Power\": 118.24795321797994, \"i_spike\": 74.0, \"isi\": 0.04733033921726912, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.44888166908114, \"Firing rate\": 281.11347845536557, \"Power\": 281.11347845536557, \"i_spike\": 64.0, \"isi\": 0.05283053800228937, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.268675264450081, \"Firing rate\": 185.64158358911618, \"Power\": 185.64158358911618, \"i_spike\": 65.5, \"isi\": 0.05201986674274169, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.428906190296464, \"Firing rate\": 268.4764460943622, \"Power\": 268.4764460943622, \"i_spike\": 58.5, \"isi\": 0.05911180928366123, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.049008675060004, \"Firing rate\": 111.94602445336766, \"Power\": 111.94602445336766, \"i_spike\": 84.0, \"isi\": 0.04125747764768612, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0516084499750704, \"Firing rate\": 112.61816585709414, \"Power\": 112.61816585709414, \"i_spike\": 66.0, \"isi\": 0.05216770534731938, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9822401781710393, \"Firing rate\": 95.99313562360203, \"Power\": 95.99313562360203, \"i_spike\": 68.5, \"isi\": 0.05091550082040577, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0413070869966092, \"Firing rate\": 109.97832146085658, \"Power\": 109.97832146085658, \"i_spike\": 69.5, \"isi\": 0.048261908955763336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9162564740110344, \"Firing rate\": 82.4624956181202, \"Power\": 82.4624956181202, \"i_spike\": 72.5, \"isi\": 0.04580300353406743, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.0251706690400266, \"Firing rate\": 1059.6700724955876, \"Power\": 1059.6700724955876, \"i_spike\": 71.0, \"isi\": 0.048977335140478306, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9185288956668356, \"Firing rate\": 82.89510684752574, \"Power\": 82.89510684752574, \"i_spike\": 65.0, \"isi\": 0.053468477919304494, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.7155492922987285, \"Firing rate\": 5194.566283391101, \"Power\": 5194.566283391101, \"i_spike\": 70.0, \"isi\": 0.047831889076879165, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2880559296273484, \"Firing rate\": 194.11358462627942, \"Power\": 194.11358462627942, \"i_spike\": 77.0, \"isi\": 0.04377704062250514, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2863930549701847, \"Firing rate\": 193.37176219598692, \"Power\": 193.37176219598692, \"i_spike\": 71.5, \"isi\": 0.04739471740371852, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 3.485362624668281, \"Firing rate\": 3057.4729586064655, \"Power\": 3057.4729586064655, \"i_spike\": 61.0, \"isi\": 0.05730472197648097, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2096939236101893, \"Firing rate\": 162.06675019105623, \"Power\": 162.06675019105623, \"i_spike\": 70.0, \"isi\": 0.04860233815068464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.837305629539864, \"Firing rate\": 687.5521263737877, \"Power\": 687.5521263737877, \"i_spike\": 76.0, \"isi\": 0.0462630290768705, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1604627571934727, \"Firing rate\": 144.6980762328094, \"Power\": 144.6980762328094, \"i_spike\": 71.5, \"isi\": 0.04871333606236235, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2330475254201847, \"Firing rate\": 171.0202454569647, \"Power\": 171.0202454569647, \"i_spike\": 71.5, \"isi\": 0.049080521297471015, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2588609326122553, \"Firing rate\": 181.4934401413059, \"Power\": 181.4934401413059, \"i_spike\": 66.5, \"isi\": 0.05057733095048499, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8829675842290474, \"Firing rate\": 76.37787729482577, \"Power\": 76.37787729482577, \"i_spike\": 81.0, \"isi\": 0.04283416965586292, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3279809733696553, \"Firing rate\": 212.80458133268078, \"Power\": 212.80458133268078, \"i_spike\": 74.5, \"isi\": 0.04442769500737385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8091068615972408, \"Firing rate\": 64.43277879673587, \"Power\": 64.43277879673587, \"i_spike\": 60.5, \"isi\": 0.056408495878117026, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0634103765045717, \"Firing rate\": 115.7205199960153, \"Power\": 115.7205199960153, \"i_spike\": 62.5, \"isi\": 0.05494193964992375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.057707201125165, \"Firing rate\": 114.21080723853781, \"Power\": 114.21080723853781, \"i_spike\": 66.5, \"isi\": 0.05118977826099244, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2746886859201556, \"Firing rate\": 188.2299322496126, \"Power\": 188.2299322496126, \"i_spike\": 76.5, \"isi\": 0.04519157254778185, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0019707623558363, \"Firing rate\": 100.45481596463469, \"Power\": 100.45481596463469, \"i_spike\": 76.0, \"isi\": 0.045327986132193195, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.295587633345161, \"Firing rate\": 197.50933799327007, \"Power\": 197.50933799327007, \"i_spike\": 74.0, \"isi\": 0.046483911938798965, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.945877973988118, \"Firing rate\": 88.28318116549227, \"Power\": 88.28318116549227, \"i_spike\": 66.5, \"isi\": 0.05264008421938133, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.471153315505243, \"Firing rate\": 295.90568943614835, \"Power\": 295.90568943614835, \"i_spike\": 87.0, \"isi\": 0.04015846530226762, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0265599217285164, \"Firing rate\": 106.30652494563125, \"Power\": 106.30652494563125, \"i_spike\": 78.5, \"isi\": 0.04422689053854093, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9009990463345725, \"Firing rate\": 79.61576021362671, \"Power\": 79.61576021362671, \"i_spike\": 60.0, \"isi\": 0.05558242287405482, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1371898250889654, \"Firing rate\": 137.14810936802255, \"Power\": 137.14810936802255, \"i_spike\": 78.0, \"isi\": 0.043423699441362415, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.18334195846327, \"Firing rate\": 152.5253247913568, \"Power\": 152.5253247913568, \"i_spike\": 79.5, \"isi\": 0.0439479607076074, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.018302892049905, \"Firing rate\": 104.30446313151317, \"Power\": 104.30446313151317, \"i_spike\": 69.5, \"isi\": 0.050417535373145216, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.520301793170094, \"Firing rate\": 331.36130594281525, \"Power\": 331.36130594281525, \"i_spike\": 63.0, \"isi\": 0.055194343234777954, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.140863371620742, \"Firing rate\": 138.3131179566823, \"Power\": 138.3131179566823, \"i_spike\": 67.0, \"isi\": 0.05011613503553582, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5790786138640915, \"Firing rate\": 379.38365293278486, \"Power\": 379.38365293278486, \"i_spike\": 70.0, \"isi\": 0.049862445465668585, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0046971363148742, \"Firing rate\": 101.08742556167319, \"Power\": 101.08742556167319, \"i_spike\": 77.0, \"isi\": 0.044773115940763754, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9299917883985747, \"Firing rate\": 85.11219451122186, \"Power\": 85.11219451122186, \"i_spike\": 63.5, \"isi\": 0.053279255805921924, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.507367640954118, \"Firing rate\": 321.63821330655077, \"Power\": 321.63821330655077, \"i_spike\": 83.0, \"isi\": 0.04180903485727737, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.043864219396577, \"Firing rate\": 110.62778561221664, \"Power\": 110.62778561221664, \"i_spike\": 60.5, \"isi\": 0.05613656256289283, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0343304902630406, \"Firing rate\": 108.2257216223445, \"Power\": 108.2257216223445, \"i_spike\": 76.5, \"isi\": 0.044990678072367146, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.265966193291141, \"Firing rate\": 184.48718035589718, \"Power\": 184.48718035589718, \"i_spike\": 82.5, \"isi\": 0.041218621498328945, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.184829164757981, \"Firing rate\": 153.0485307452557, \"Power\": 153.0485307452557, \"i_spike\": 79.5, \"isi\": 0.0438790508311261, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.482867251153031, \"Firing rate\": 303.99556740279854, \"Power\": 303.99556740279854, \"i_spike\": 72.0, \"isi\": 0.04732392940449676, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.679350887775424, \"Firing rate\": 477.91524884132025, \"Power\": 477.91524884132025, \"i_spike\": 75.0, \"isi\": 0.04487201851927047, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0102132106102126, \"Firing rate\": 102.37954865480673, \"Power\": 102.37954865480673, \"i_spike\": 71.5, \"isi\": 0.04878632929411457, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2925787627458876, \"Firing rate\": 196.14568689680337, \"Power\": 196.14568689680337, \"i_spike\": 71.5, \"isi\": 0.04751080235874853, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.408181131975511, \"Firing rate\": 255.96532234553712, \"Power\": 255.96532234553712, \"i_spike\": 78.5, \"isi\": 0.04224296754691385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3855583224969688, \"Firing rate\": 242.97317148876678, \"Power\": 242.97317148876678, \"i_spike\": 76.5, \"isi\": 0.045168110305337704, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9994034804402283, \"Firing rate\": 99.862740582426, \"Power\": 99.862740582426, \"i_spike\": 76.5, \"isi\": 0.04461518511387296, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.420657135162534, \"Firing rate\": 263.4250888241149, \"Power\": 263.4250888241149, \"i_spike\": 86.5, \"isi\": 0.039763315255390425, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0333948498686167, \"Firing rate\": 107.99281201345569, \"Power\": 107.99281201345569, \"i_spike\": 71.5, \"isi\": 0.04905015663749419, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1771834940956576, \"Firing rate\": 150.3777193944357, \"Power\": 150.3777193944357, \"i_spike\": 71.5, \"isi\": 0.048168145819388865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9004170909121822, \"Firing rate\": 79.50914639254572, \"Power\": 79.50914639254572, \"i_spike\": 72.0, \"isi\": 0.047053568472965865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2706500732886123, \"Firing rate\": 186.4876487147454, \"Power\": 186.4876487147454, \"i_spike\": 76.5, \"isi\": 0.04478958523955221, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3226879927203563, \"Firing rate\": 210.22675790778925, \"Power\": 210.22675790778925, \"i_spike\": 84.5, \"isi\": 0.041448783649683865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1236488593840726, \"Firing rate\": 132.93791388973483, \"Power\": 132.93791388973483, \"i_spike\": 73.5, \"isi\": 0.04771964422986316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9611984491654064, \"Firing rate\": 91.45310373895767, \"Power\": 91.45310373895767, \"i_spike\": 70.5, \"isi\": 0.04936860543367102, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0824773391122404, \"Firing rate\": 120.91420899286925, \"Power\": 120.91420899286925, \"i_spike\": 88.0, \"isi\": 0.03935522162784246, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9787501002284225, \"Firing rate\": 95.22480680598018, \"Power\": 95.22480680598018, \"i_spike\": 75.0, \"isi\": 0.045602480439414186, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1685898325916213, \"Firing rate\": 147.43134670286034, \"Power\": 147.43134670286034, \"i_spike\": 80.0, \"isi\": 0.0428366177384345, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.230731641001414, \"Firing rate\": 170.11070364760798, \"Power\": 170.11070364760798, \"i_spike\": 86.0, \"isi\": 0.04069000316608182, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7109408735479223, \"Firing rate\": 513.9736725480508, \"Power\": 513.9736725480508, \"i_spike\": 90.5, \"isi\": 0.03808087796581317, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.8904891156107295, \"Firing rate\": 777.121842141343, \"Power\": 777.121842141343, \"i_spike\": 67.5, \"isi\": 0.05050650450585472, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3884444205618465, \"Firing rate\": 244.59322344535366, \"Power\": 244.59322344535366, \"i_spike\": 75.5, \"isi\": 0.046160864179237364, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.215221869412756, \"Firing rate\": 164.14281206772014, \"Power\": 164.14281206772014, \"i_spike\": 76.0, \"isi\": 0.045973777674205345, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1044452923402397, \"Firing rate\": 127.18775228011826, \"Power\": 127.18775228011826, \"i_spike\": 74.5, \"isi\": 0.046825315835458, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.304794192932069, \"Firing rate\": 201.74101101002248, \"Power\": 201.74101101002248, \"i_spike\": 84.5, \"isi\": 0.0415838404784538, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9519897390823953, \"Firing rate\": 89.53436113421678, \"Power\": 89.53436113421678, \"i_spike\": 73.0, \"isi\": 0.04637231437529422, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.050715177785326, \"Firing rate\": 112.38676690257596, \"Power\": 112.38676690257596, \"i_spike\": 72.5, \"isi\": 0.047898939712791556, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.093906240936936, \"Firing rate\": 124.13842784179043, \"Power\": 124.13842784179043, \"i_spike\": 77.0, \"isi\": 0.04521406966614064, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.142532137492843, \"Firing rate\": 138.84560509200531, \"Power\": 138.84560509200531, \"i_spike\": 85.5, \"isi\": 0.04088215523965275, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1247106556001505, \"Firing rate\": 133.26332826018398, \"Power\": 133.26332826018398, \"i_spike\": 94.0, \"isi\": 0.03699718718109058, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0404961635875494, \"Firing rate\": 109.77315932365002, \"Power\": 109.77315932365002, \"i_spike\": 84.5, \"isi\": 0.040822879176668145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2076231068258, \"Firing rate\": 161.29581780251291, \"Power\": 161.29581780251291, \"i_spike\": 77.0, \"isi\": 0.04556164109048245, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0158640710626763, \"Firing rate\": 103.72037327450805, \"Power\": 103.72037327450805, \"i_spike\": 70.5, \"isi\": 0.04900422553915958, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1880248824801893, \"Firing rate\": 154.1788785708863, \"Power\": 154.1788785708863, \"i_spike\": 87.5, \"isi\": 0.039435886208280056, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9744105165726646, \"Firing rate\": 94.27803379629712, \"Power\": 94.27803379629712, \"i_spike\": 84.5, \"isi\": 0.04146392755918885, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 3.913843764110594, \"Firing rate\": 8200.564788680073, \"Power\": 8200.564788680073, \"i_spike\": 76.5, \"isi\": 0.04556363424648217, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1399954218244273, \"Firing rate\": 138.0369713167223, \"Power\": 138.0369713167223, \"i_spike\": 77.5, \"isi\": 0.0453981706218095, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9566148125838072, \"Firing rate\": 90.49296385155998, \"Power\": 90.49296385155998, \"i_spike\": 85.0, \"isi\": 0.03927323815030475, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2520245491348896, \"Firing rate\": 178.65885615461892, \"Power\": 178.65885615461892, \"i_spike\": 85.0, \"isi\": 0.040967992817435184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1754321193760866, \"Firing rate\": 149.77251389430003, \"Power\": 149.77251389430003, \"i_spike\": 91.5, \"isi\": 0.03836696480836998, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.635716855961742, \"Firing rate\": 432.2319398170039, \"Power\": 432.2319398170039, \"i_spike\": 96.5, \"isi\": 0.03578166736861596, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2160850620865733, \"Firing rate\": 164.46938258310612, \"Power\": 164.46938258310612, \"i_spike\": 80.0, \"isi\": 0.043473098367445215, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1205612291989038, \"Firing rate\": 131.9961393928132, \"Power\": 131.9961393928132, \"i_spike\": 75.5, \"isi\": 0.04626035487513255, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.024827292545692, \"Firing rate\": 105.88325716711356, \"Power\": 105.88325716711356, \"i_spike\": 80.5, \"isi\": 0.04253930743384717, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.074114281950763, \"Firing rate\": 118.60808170570037, \"Power\": 118.60808170570037, \"i_spike\": 67.0, \"isi\": 0.051334204579878646, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2811373940485504, \"Firing rate\": 191.04575581686126, \"Power\": 191.04575581686126, \"i_spike\": 74.5, \"isi\": 0.046987279420234215, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.014403068402744, \"Firing rate\": 103.37203558262294, \"Power\": 103.37203558262294, \"i_spike\": 82.5, \"isi\": 0.04146065949524595, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.108863671481811, \"Firing rate\": 128.4883261479434, \"Power\": 128.4883261479434, \"i_spike\": 87.5, \"isi\": 0.03907275494403815, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.658304695266665, \"Firing rate\": 455.30738576183563, \"Power\": 455.30738576183563, \"i_spike\": 93.5, \"isi\": 0.036909663672368385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2071328830952694, \"Firing rate\": 161.11385272898417, \"Power\": 161.11385272898417, \"i_spike\": 90.0, \"isi\": 0.03900063452819159, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.162120505142531, \"Firing rate\": 145.25145957605932, \"Power\": 145.25145957605932, \"i_spike\": 85.5, \"isi\": 0.0400904776550323, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9709911192109881, \"Firing rate\": 93.53865464453958, \"Power\": 93.53865464453958, \"i_spike\": 75.0, \"isi\": 0.045538771732070805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.134880880431313, \"Firing rate\": 136.42089060349338, \"Power\": 136.42089060349338, \"i_spike\": 88.5, \"isi\": 0.03943188805380755, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.066832430618179, \"Firing rate\": 116.63594988602028, \"Power\": 116.63594988602028, \"i_spike\": 70.5, \"isi\": 0.048970343212981035, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3793806836767333, \"Firing rate\": 239.5414552752351, \"Power\": 239.5414552752351, \"i_spike\": 82.5, \"isi\": 0.042043561438028454, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.399500106264406, \"Firing rate\": 250.89967933737773, \"Power\": 250.89967933737773, \"i_spike\": 75.5, \"isi\": 0.04561264334500348, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.220242199517701, \"Firing rate\": 166.0512692284522, \"Power\": 166.0512692284522, \"i_spike\": 77.5, \"isi\": 0.04518223580077409, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3997220560187014, \"Firing rate\": 251.02793644541697, \"Power\": 251.02793644541697, \"i_spike\": 92.0, \"isi\": 0.037630914484962856, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.166020646368421, \"Firing rate\": 146.56175147859375, \"Power\": 146.56175147859375, \"i_spike\": 91.0, \"isi\": 0.03827176241185468, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.185888096679604, \"Firing rate\": 153.4221613710901, \"Power\": 153.4221613710901, \"i_spike\": 92.0, \"isi\": 0.03761591240242529, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.4587317399206245, \"Firing rate\": 287.562161854551, \"Power\": 287.562161854551, \"i_spike\": 91.5, \"isi\": 0.03834390692603616, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.212868070184563, \"Firing rate\": 163.25559353268687, \"Power\": 163.25559353268687, \"i_spike\": 92.0, \"isi\": 0.03802455357122872, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2357931191352933, \"Firing rate\": 172.10485396344228, \"Power\": 172.10485396344228, \"i_spike\": 79.0, \"isi\": 0.04382598137502598, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3035618471296804, \"Firing rate\": 201.16936596348194, \"Power\": 201.16936596348194, \"i_spike\": 109.5, \"isi\": 0.03202543684399708, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.8017110410666857, \"Firing rate\": 633.4481047134145, \"Power\": 633.4481047134145, \"i_spike\": 98.0, \"isi\": 0.03550739167328109, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1697988740587917, \"Firing rate\": 147.8423557471093, \"Power\": 147.8423557471093, \"i_spike\": 88.5, \"isi\": 0.03925960981462805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.6760870929370943, \"Firing rate\": 474.3370987623261, \"Power\": 474.3370987623261, \"i_spike\": 87.5, \"isi\": 0.039431239454240596, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.433730632307909, \"Firing rate\": 271.47549414255656, \"Power\": 271.47549414255656, \"i_spike\": 96.5, \"isi\": 0.0363181558103682, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.063446911413506, \"Firing rate\": 115.73025536377592, \"Power\": 115.73025536377592, \"i_spike\": 79.0, \"isi\": 0.044476460189586564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.175425654268593, \"Firing rate\": 149.77028432833717, \"Power\": 149.77028432833717, \"i_spike\": 80.5, \"isi\": 0.04299945260731721, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3612576848505684, \"Firing rate\": 229.75114521901307, \"Power\": 229.75114521901307, \"i_spike\": 77.0, \"isi\": 0.04469056636440316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.147995753593227, \"Firing rate\": 140.60337762680615, \"Power\": 140.60337762680615, \"i_spike\": 87.5, \"isi\": 0.03976844291136797, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0929257700333896, \"Firing rate\": 123.85848685027362, \"Power\": 123.85848685027362, \"i_spike\": 94.0, \"isi\": 0.03657174288555396, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10475158728818, \"Firing rate\": 127.27748564862868, \"Power\": 127.27748564862868, \"i_spike\": 98.5, \"isi\": 0.03552973340735749, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2328647390747323, \"Firing rate\": 170.94828141071517, \"Power\": 170.94828141071517, \"i_spike\": 82.5, \"isi\": 0.04166360369234807, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1354623163537503, \"Firing rate\": 136.6036539827589, \"Power\": 136.6036539827589, \"i_spike\": 84.5, \"isi\": 0.040640693096263156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0464608797536576, \"Firing rate\": 111.29121397251097, \"Power\": 111.29121397251097, \"i_spike\": 89.5, \"isi\": 0.03879007896451536, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3355625956917723, \"Firing rate\": 216.5521977627491, \"Power\": 216.5521977627491, \"i_spike\": 98.0, \"isi\": 0.035422439393446775, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2161677848183947, \"Firing rate\": 164.50071305822243, \"Power\": 164.50071305822243, \"i_spike\": 85.0, \"isi\": 0.04048577743104151, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2837266052282277, \"Firing rate\": 192.18814953172904, \"Power\": 192.18814953172904, \"i_spike\": 99.5, \"isi\": 0.03520251098408982, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.161668219920541, \"Firing rate\": 145.10026978437168, \"Power\": 145.10026978437168, \"i_spike\": 90.0, \"isi\": 0.038734070453864254, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.282132072264165, \"Firing rate\": 191.4838153372827, \"Power\": 191.4838153372827, \"i_spike\": 78.0, \"isi\": 0.043996610728127564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0841752044242403, \"Firing rate\": 121.38784583039707, \"Power\": 121.38784583039707, \"i_spike\": 100.0, \"isi\": 0.03461991962811, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.447465040329036, \"Firing rate\": 280.1980059869962, \"Power\": 280.1980059869962, \"i_spike\": 79.0, \"isi\": 0.04452724337396078, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.081771364126096, \"Firing rate\": 120.71781445649961, \"Power\": 120.71781445649961, \"i_spike\": 91.0, \"isi\": 0.03856750376815478, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.9391326595223966, \"Firing rate\": 869.2259023424945, \"Power\": 869.2259023424945, \"i_spike\": 79.0, \"isi\": 0.04416616879896912, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8602028751437854, \"Firing rate\": 72.47744501747489, \"Power\": 72.47744501747489, \"i_spike\": 83.0, \"isi\": 0.04119329035591721, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1734123362153537, \"Firing rate\": 149.07758070284467, \"Power\": 149.07758070284467, \"i_spike\": 81.5, \"isi\": 0.0428418950531146, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.192601337300343, \"Firing rate\": 155.812156100815, \"Power\": 155.812156100815, \"i_spike\": 103.0, \"isi\": 0.03371726705897087, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.325538741593283, \"Firing rate\": 211.6112446357301, \"Power\": 211.6112446357301, \"i_spike\": 106.5, \"isi\": 0.03256875829829079, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0351612273023045, \"Firing rate\": 108.43293852986389, \"Power\": 108.43293852986389, \"i_spike\": 92.5, \"isi\": 0.03785767511850996, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3612887627039565, \"Firing rate\": 229.76758666182133, \"Power\": 229.76758666182133, \"i_spike\": 110.5, \"isi\": 0.0316478026663995, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.486602812028755, \"Firing rate\": 306.62164695003077, \"Power\": 306.62164695003077, \"i_spike\": 102.0, \"isi\": 0.03428746701402582, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.26907338816312, \"Firing rate\": 185.81184180415744, \"Power\": 185.81184180415744, \"i_spike\": 108.0, \"isi\": 0.03182822108027605, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2400289413579997, \"Firing rate\": 173.79166395502384, \"Power\": 173.79166395502384, \"i_spike\": 104.0, \"isi\": 0.03361245677188138, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.133061627118738, \"Firing rate\": 135.8506207230094, \"Power\": 135.8506207230094, \"i_spike\": 83.0, \"isi\": 0.04226663021993772, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.055873381143031, \"Firing rate\": 113.72956581458753, \"Power\": 113.72956581458753, \"i_spike\": 96.5, \"isi\": 0.03623434325043876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077393494053492, \"Firing rate\": 119.50704118553142, \"Power\": 119.50704118553142, \"i_spike\": 86.0, \"isi\": 0.03999884944106042, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7032986753124226, \"Firing rate\": 505.00848528812185, \"Power\": 505.00848528812185, \"i_spike\": 94.5, \"isi\": 0.03642922221630557, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2487291617775735, \"Firing rate\": 177.30833914875691, \"Power\": 177.30833914875691, \"i_spike\": 95.0, \"isi\": 0.035509978483580056, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.6190312582185733, \"Firing rate\": 415.9405466161257, \"Power\": 415.9405466161257, \"i_spike\": 92.5, \"isi\": 0.03739794009579709, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2214636345147007, \"Firing rate\": 166.51893879392634, \"Power\": 166.51893879392634, \"i_spike\": 104.5, \"isi\": 0.03334968571838423, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.050033014448482, \"Firing rate\": 1122.1037517902018, \"Power\": 1122.1037517902018, \"i_spike\": 109.0, \"isi\": 0.03174363047623115, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0201521306738686, \"Firing rate\": 104.7495414963806, \"Power\": 104.7495414963806, \"i_spike\": 84.0, \"isi\": 0.04150443974238124, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.394368017909442, \"Firing rate\": 247.95222963713232, \"Power\": 247.95222963713232, \"i_spike\": 97.5, \"isi\": 0.034832136270722715, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.329502121112529, \"Firing rate\": 213.551251595498, \"Power\": 213.551251595498, \"i_spike\": 119.5, \"isi\": 0.02914255148960452, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.296426000518237, \"Firing rate\": 197.89098058624842, \"Power\": 197.89098058624842, \"i_spike\": 100.5, \"isi\": 0.03453794209724264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9526063135638236, \"Firing rate\": 89.66156470356117, \"Power\": 89.66156470356117, \"i_spike\": 87.0, \"isi\": 0.0403252649629643, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1801699394018295, \"Firing rate\": 151.41536207419279, \"Power\": 151.41536207419279, \"i_spike\": 95.0, \"isi\": 0.0369374859002085, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9603011698286221, \"Firing rate\": 91.26435100880892, \"Power\": 91.26435100880892, \"i_spike\": 100.5, \"isi\": 0.03470962985025618, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1497807834136973, \"Firing rate\": 141.18247252479557, \"Power\": 141.18247252479557, \"i_spike\": 97.0, \"isi\": 0.03544340361561801, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.149622075943538, \"Firing rate\": 141.13088858728008, \"Power\": 141.13088858728008, \"i_spike\": 98.5, \"isi\": 0.03458549884764996, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.056159126623185, \"Firing rate\": 113.80441917809635, \"Power\": 113.80441917809635, \"i_spike\": 87.0, \"isi\": 0.03968042681843487, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3917479076029613, \"Firing rate\": 246.46083050660826, \"Power\": 246.46083050660826, \"i_spike\": 98.5, \"isi\": 0.035535360449709036, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0750924013179355, \"Firing rate\": 118.87551223280595, \"Power\": 118.87551223280595, \"i_spike\": 94.0, \"isi\": 0.03719199644955143, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.489337914838964, \"Firing rate\": 308.5587843479223, \"Power\": 308.5587843479223, \"i_spike\": 95.5, \"isi\": 0.03556131746210524, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.4520230739574873, \"Firing rate\": 283.154243094607, \"Power\": 283.154243094607, \"i_spike\": 107.0, \"isi\": 0.032710924682864184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.323245560174936, \"Firing rate\": 210.49683012562227, \"Power\": 210.49683012562227, \"i_spike\": 107.5, \"isi\": 0.03260971008319308, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4551248825615755, \"Firing rate\": 285.183820345654, \"Power\": 285.183820345654, \"i_spike\": 119.5, \"isi\": 0.029121401254440946, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2034473494582008, \"Firing rate\": 159.75238457442458, \"Power\": 159.75238457442458, \"i_spike\": 117.5, \"isi\": 0.02942985917936488, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.185090643987662, \"Firing rate\": 153.1407056710173, \"Power\": 153.1407056710173, \"i_spike\": 107.5, \"isi\": 0.03182653781887098, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3319515266612205, \"Firing rate\": 214.7590759585309, \"Power\": 214.7590759585309, \"i_spike\": 125.0, \"isi\": 0.028084978019438673, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6162367962967754, \"Firing rate\": 413.2727749153624, \"Power\": 413.2727749153624, \"i_spike\": 106.5, \"isi\": 0.032651038144998264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.251599839982757, \"Firing rate\": 178.48422588668325, \"Power\": 178.48422588668325, \"i_spike\": 112.0, \"isi\": 0.031077478691086027, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.700871783939369, \"Firing rate\": 502.194305618395, \"Power\": 502.194305618395, \"i_spike\": 94.0, \"isi\": 0.036901644723313094, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.314948450805621, \"Firing rate\": 206.5135017156736, \"Power\": 206.5135017156736, \"i_spike\": 93.5, \"isi\": 0.03744836002524842, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6205392303439177, \"Firing rate\": 417.3872998602738, \"Power\": 417.3872998602738, \"i_spike\": 112.5, \"isi\": 0.030901272636151618, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5103170415704716, \"Firing rate\": 323.82997146198255, \"Power\": 323.82997146198255, \"i_spike\": 118.5, \"isi\": 0.0292124077372491, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.267328656385887, \"Firing rate\": 185.06685998516417, \"Power\": 185.06685998516417, \"i_spike\": 112.0, \"isi\": 0.030900503373377113, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3735439867744246, \"Firing rate\": 236.34367636856805, \"Power\": 236.34367636856805, \"i_spike\": 111.5, \"isi\": 0.031086261056407043, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3925644433143702, \"Firing rate\": 246.9246479862117, \"Power\": 246.9246479862117, \"i_spike\": 116.5, \"isi\": 0.0291953589973033, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.561842054638256, \"Firing rate\": 364.6213163680733, \"Power\": 364.6213163680733, \"i_spike\": 111.5, \"isi\": 0.031029868021617713, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.171212511252901, \"Firing rate\": 148.32436961836746, \"Power\": 148.32436961836746, \"i_spike\": 98.0, \"isi\": 0.03548246558301557, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.305560627357594, \"Firing rate\": 202.09735394991617, \"Power\": 202.09735394991617, \"i_spike\": 116.5, \"isi\": 0.029539429675363767, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.230937526831537, \"Firing rate\": 170.19136708674088, \"Power\": 170.19136708674088, \"i_spike\": 109.5, \"isi\": 0.031509671304326574, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8998022408045885, \"Firing rate\": 793.9666138437617, \"Power\": 793.9666138437617, \"i_spike\": 117.0, \"isi\": 0.029395611103945375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.318691352753477, \"Firing rate\": 208.3009989753317, \"Power\": 208.3009989753317, \"i_spike\": 114.0, \"isi\": 0.03080051727849002, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5660625459247224, \"Firing rate\": 368.181994406344, \"Power\": 368.181994406344, \"i_spike\": 110.5, \"isi\": 0.03146794625834939, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.09200788071158, \"Firing rate\": 123.59698611612541, \"Power\": 123.59698611612541, \"i_spike\": 105.5, \"isi\": 0.03222740436284654, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3257979747918998, \"Firing rate\": 211.73759446862695, \"Power\": 211.73759446862695, \"i_spike\": 99.0, \"isi\": 0.035110212287434966, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6983799828455997, \"Firing rate\": 499.3211738782113, \"Power\": 499.3211738782113, \"i_spike\": 100.5, \"isi\": 0.03493647252317627, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.295038880371647, \"Firing rate\": 197.25993258831056, \"Power\": 197.25993258831056, \"i_spike\": 99.5, \"isi\": 0.034805791974127157, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189777301058197, \"Firing rate\": 262.40839812996177, \"Power\": 262.40839812996177, \"i_spike\": 114.0, \"isi\": 0.030289604306854862, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.108818343863044, \"Firing rate\": 128.47491643129774, \"Power\": 128.47491643129774, \"i_spike\": 105.0, \"isi\": 0.033402650086276076, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3301618907903223, \"Firing rate\": 213.8759200460872, \"Power\": 213.8759200460872, \"i_spike\": 102.0, \"isi\": 0.033515540373164496, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2662952548825976, \"Firing rate\": 184.62701784490469, \"Power\": 184.62701784490469, \"i_spike\": 99.5, \"isi\": 0.03522950669230892, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.431293700022412, \"Firing rate\": 269.9564447816099, \"Power\": 269.9564447816099, \"i_spike\": 112.5, \"isi\": 0.031214818356640563, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3379956540094025, \"Firing rate\": 217.76879800918366, \"Power\": 217.76879800918366, \"i_spike\": 128.0, \"isi\": 0.027142001158740867, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 4.268793452708704, \"Firing rate\": 18569.21106902568, \"Power\": 18569.21106902568, \"i_spike\": 112.5, \"isi\": 0.030884711280865364, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.470335706667271, \"Firing rate\": 295.3491373163173, \"Power\": 295.3491373163173, \"i_spike\": 118.5, \"isi\": 0.029429433800978892, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2298279031444963, \"Firing rate\": 169.7570826751943, \"Power\": 169.7570826751943, \"i_spike\": 115.5, \"isi\": 0.030066265039225337, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.079781857998895, \"Firing rate\": 120.16607002272158, \"Power\": 120.16607002272158, \"i_spike\": 112.5, \"isi\": 0.031040291113719316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3243380859972738, \"Firing rate\": 211.02702965366592, \"Power\": 211.02702965366592, \"i_spike\": 115.5, \"isi\": 0.03017297418481671, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.376992751237567, \"Firing rate\": 238.22797066527903, \"Power\": 238.22797066527903, \"i_spike\": 110.0, \"isi\": 0.03125175833885984, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.530486613796888, \"Firing rate\": 339.22403352142646, \"Power\": 339.22403352142646, \"i_spike\": 108.5, \"isi\": 0.03222598156798059, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4983008808245897, \"Firing rate\": 314.99298413824465, \"Power\": 314.99298413824465, \"i_spike\": 116.5, \"isi\": 0.029967692171019168, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.482166228126963, \"Firing rate\": 303.5052641678235, \"Power\": 303.5052641678235, \"i_spike\": 124.5, \"isi\": 0.02742142830301335, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6952270146103454, \"Firing rate\": 495.70924045465966, \"Power\": 495.70924045465966, \"i_spike\": 116.5, \"isi\": 0.029805997031659384, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 1.969829747877291, \"Firing rate\": 93.288851814792, \"Power\": 93.288851814792, \"i_spike\": 104.5, \"isi\": 0.033232072449794876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3040227572766634, \"Firing rate\": 201.3829772917563, \"Power\": 201.3829772917563, \"i_spike\": 118.5, \"isi\": 0.02930928089506225, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2482213585722888, \"Firing rate\": 177.10114074206854, \"Power\": 177.10114074206854, \"i_spike\": 118.5, \"isi\": 0.02923254019041047, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.302306969151288, \"Firing rate\": 200.58893343119396, \"Power\": 200.58893343119396, \"i_spike\": 114.0, \"isi\": 0.030554998388585986, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1470214089632194, \"Firing rate\": 140.28828593141267, \"Power\": 140.28828593141267, \"i_spike\": 123.0, \"isi\": 0.02824600472582251, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1317778042739737, \"Firing rate\": 135.44962414921912, \"Power\": 135.44962414921912, \"i_spike\": 107.5, \"isi\": 0.03260242125359381, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.861629232615016, \"Firing rate\": 727.1587469920275, \"Power\": 727.1587469920275, \"i_spike\": 121.5, \"isi\": 0.02876842284627423, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.309175796871508, \"Firing rate\": 203.7866813288123, \"Power\": 203.7866813288123, \"i_spike\": 127.0, \"isi\": 0.02726151253501496, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1426446687258776, \"Firing rate\": 138.88158641854218, \"Power\": 138.88158641854218, \"i_spike\": 120.0, \"isi\": 0.02911404261537866, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4489418426509477, \"Firing rate\": 281.15243076571574, \"Power\": 281.15243076571574, \"i_spike\": 128.5, \"isi\": 0.026789992139581283, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.412848701632391, \"Firing rate\": 258.73113973987586, \"Power\": 258.73113973987586, \"i_spike\": 124.0, \"isi\": 0.028201124990781163, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.710877629385823, \"Firing rate\": 513.8988305482127, \"Power\": 513.8988305482127, \"i_spike\": 119.0, \"isi\": 0.0293764992264836, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.991538408306236, \"Firing rate\": 980.7050424652082, \"Power\": 980.7050424652082, \"i_spike\": 135.0, \"isi\": 0.025953587990479317, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2762121037042795, \"Firing rate\": 188.89136444020025, \"Power\": 188.89136444020025, \"i_spike\": 122.0, \"isi\": 0.028669385615676706, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.7177018467167304, \"Firing rate\": 522.0376749188929, \"Power\": 522.0376749188929, \"i_spike\": 138.0, \"isi\": 0.02496409561586277, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3914116825786387, \"Firing rate\": 246.27009764338933, \"Power\": 246.27009764338933, \"i_spike\": 110.5, \"isi\": 0.0316618510656651, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6892037162497906, \"Firing rate\": 488.8816272272226, \"Power\": 488.8816272272226, \"i_spike\": 131.5, \"isi\": 0.02658745064897301, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4434824501248773, \"Firing rate\": 277.64026491830793, \"Power\": 277.64026491830793, \"i_spike\": 120.0, \"isi\": 0.0290789856927443, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.238506636309727, \"Firing rate\": 173.18354941508804, \"Power\": 173.18354941508804, \"i_spike\": 121.0, \"isi\": 0.028971993333475, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 20,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "chart_detail_and_intercepts"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "Our plotting backend's flexibility allows us to easily concatenate multiple charts in the same figures with the | operator:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-1ea58492362d4f08971168d841633d05\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-1ea58492362d4f08971168d841633d05\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-1ea58492362d4f08971168d841633d05\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"hconcat\": [{\"data\": {\"name\": \"data-55620c08ee0f2b51d1c658df744dfa2d\"}, \"mark\": {\"type\": \"tick\", \"color\": \"red\"}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"x\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"mu_intercept_per_group center interval\", \"scale\": {\"domain\": [-7.657114028930664, 10.212915420532227]}, \"title\": \"Intercept estimate\"}}}, {\"layer\": [{\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-7b75ead138b5701714ef21e640a42f5e\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-75.9449754787322, 514.3435240860015], \"zero\": false}}}}, {\"data\": {\"name\": \"data-335274e0c5848c5eb146b4572e80f925\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.3416309952735901], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.06997033208608627, 0.3416309952735901], \"as\": [\"slope\", \"density\"]}], \"width\": 30}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\"}, {\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}, \"title\": \"\\u0394 Log_power\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.214], \"zero\": true}}}}], \"data\": {\"name\": \"data-4b9cbfc1c4897c0672d6a06e25fe8ad5\"}, \"title\": \"LME\"}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-55620c08ee0f2b51d1c658df744dfa2d\": [{\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.955295818792631, \"Firing rate\": 90.21854501261329, \"Power\": 90.21854501261329, \"i_spike\": 47.5, \"isi\": 0.0731915996436363, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6026484195029185, \"Firing rate\": 40.054232969747986, \"Power\": 40.054232969747986, \"i_spike\": 39.5, \"isi\": 0.08505458474637603, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1244493253919545, \"Firing rate\": 133.18316316728252, \"Power\": 133.18316316728252, \"i_spike\": 42.5, \"isi\": 0.08224071637572535, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8708094709723913, \"Firing rate\": 74.2693239984203, \"Power\": 74.2693239984203, \"i_spike\": 33.5, \"isi\": 0.10505328377444978, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9711426825012743, \"Firing rate\": 93.57130415068605, \"Power\": 93.57130415068605, \"i_spike\": 40.5, \"isi\": 0.08430258433195234, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8590874397971908, \"Firing rate\": 72.29153389710372, \"Power\": 72.29153389710372, \"i_spike\": 44.0, \"isi\": 0.0795434324837374, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0132461342812213, \"Firing rate\": 103.09702522654109, \"Power\": 103.09702522654109, \"i_spike\": 47.5, \"isi\": 0.07286723599674903, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0127266901312217, \"Firing rate\": 102.97378826377438, \"Power\": 102.97378826377438, \"i_spike\": 39.0, \"isi\": 0.08914566084967086, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503131681143027, \"Firing rate\": 56.27469736390204, \"Power\": 56.27469736390204, \"i_spike\": 40.0, \"isi\": 0.08700029609063652, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1169032082350827, \"Firing rate\": 130.88901764671587, \"Power\": 130.88901764671587, \"i_spike\": 62.0, \"isi\": 0.05659763212840744, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8770680415974088, \"Firing rate\": 75.34736023774802, \"Power\": 75.34736023774802, \"i_spike\": 39.0, \"isi\": 0.09009246539035318, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9310965336855828, \"Firing rate\": 85.32897596494497, \"Power\": 85.32897596494497, \"i_spike\": 34.0, \"isi\": 0.10149738234291991, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.5333013820605306, \"Firing rate\": 34.14297672922771, \"Power\": 34.14297672922771, \"i_spike\": 40.5, \"isi\": 0.08685116325741157, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.030855072834198, \"Firing rate\": 107.36310742084633, \"Power\": 107.36310742084633, \"i_spike\": 54.5, \"isi\": 0.059448248477706966, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.794551727002911, \"Firing rate\": 623.0913568201987, \"Power\": 623.0913568201987, \"i_spike\": 48.5, \"isi\": 0.0713719442616052, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7955427567112552, \"Firing rate\": 62.451483134242046, \"Power\": 62.451483134242046, \"i_spike\": 35.5, \"isi\": 0.09057886752422038, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9082000854510324, \"Firing rate\": 80.94687466873414, \"Power\": 80.94687466873414, \"i_spike\": 53.0, \"isi\": 0.06529444835938969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6555352624426098, \"Firing rate\": 45.24131944286433, \"Power\": 45.24131944286433, \"i_spike\": 43.5, \"isi\": 0.0768533496686384, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.177328557623848, \"Firing rate\": 150.42795711808552, \"Power\": 150.42795711808552, \"i_spike\": 34.5, \"isi\": 0.09830229180875018, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8645215585407622, \"Firing rate\": 73.20176599287585, \"Power\": 73.20176599287585, \"i_spike\": 55.5, \"isi\": 0.06179006984103724, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.535025958406892, \"Firing rate\": 34.27882748831966, \"Power\": 34.27882748831966, \"i_spike\": 34.5, \"isi\": 0.09915726015773765, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.32247920697616, \"Firing rate\": 210.125716326415, \"Power\": 210.125716326415, \"i_spike\": 33.0, \"isi\": 0.10502063399832753, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.43733847759269, \"Firing rate\": 273.74013531042965, \"Power\": 273.74013531042965, \"i_spike\": 56.0, \"isi\": 0.061967941571928455, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7969419629962189, \"Firing rate\": 62.653013263585784, \"Power\": 62.653013263585784, \"i_spike\": 37.0, \"isi\": 0.09259944757473725, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9846064873802938, \"Firing rate\": 96.51759403196418, \"Power\": 96.51759403196418, \"i_spike\": 41.5, \"isi\": 0.08460263304467304, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.7503293230777222, \"Firing rate\": 56.27679071904272, \"Power\": 56.27679071904272, \"i_spike\": 42.5, \"isi\": 0.07988986525214349, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.4286782943328151, \"Firing rate\": 26.83356000776027, \"Power\": 26.83356000776027, \"i_spike\": 35.5, \"isi\": 0.09874338503855341, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1383088558675207, \"Firing rate\": 137.50194957559475, \"Power\": 137.50194957559475, \"i_spike\": 48.5, \"isi\": 0.07210812725187593, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0035263866631934, \"Firing rate\": 100.81528603885884, \"Power\": 100.81528603885884, \"i_spike\": 49.5, \"isi\": 0.0672853207791876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"0\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.6296351063659993, \"Firing rate\": 42.62212577953956, \"Power\": 42.62212577953956, \"i_spike\": 41.5, \"isi\": 0.0790188469593832, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.193262117122394, \"Firing rate\": 156.04940501335037, \"Power\": 156.04940501335037, \"i_spike\": 48.0, \"isi\": 0.07263392600048459, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9760548637782647, \"Firing rate\": 94.63567056548113, \"Power\": 94.63567056548113, \"i_spike\": 44.5, \"isi\": 0.0776680429623508, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6250730368645014, \"Firing rate\": 42.17674276093685, \"Power\": 42.17674276093685, \"i_spike\": 42.5, \"isi\": 0.08104853472101264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.491206995038427, \"Firing rate\": 309.8895954508339, \"Power\": 309.8895954508339, \"i_spike\": 51.5, \"isi\": 0.06708115735632907, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3589480963384455, \"Firing rate\": 228.53256618481504, \"Power\": 228.53256618481504, \"i_spike\": 47.5, \"isi\": 0.07348993800862964, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9281754169377023, \"Firing rate\": 84.75696889405249, \"Power\": 84.75696889405249, \"i_spike\": 53.0, \"isi\": 0.06509876660602372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9843209349691886, \"Firing rate\": 96.45415373032593, \"Power\": 96.45415373032593, \"i_spike\": 59.5, \"isi\": 0.05870376554536328, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7638817011892445, \"Firing rate\": 58.06062428577546, \"Power\": 58.06062428577546, \"i_spike\": 52.0, \"isi\": 0.06566204692122644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.650862407397869, \"Firing rate\": 44.75714827077759, \"Power\": 44.75714827077759, \"i_spike\": 49.0, \"isi\": 0.07040754805798212, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0583883119213846, \"Firing rate\": 114.39006635603113, \"Power\": 114.39006635603113, \"i_spike\": 51.0, \"isi\": 0.06837143070736648, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2173425763203, \"Firing rate\": 164.9462993258368, \"Power\": 164.9462993258368, \"i_spike\": 53.5, \"isi\": 0.06501277873096038, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2107084188475756, \"Firing rate\": 162.44577441851425, \"Power\": 162.44577441851425, \"i_spike\": 49.0, \"isi\": 0.06869119253150469, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5946141113333705, \"Firing rate\": 39.320054519388265, \"Power\": 39.320054519388265, \"i_spike\": 43.0, \"isi\": 0.08147481958019963, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.211944529140798, \"Firing rate\": 162.90879418557492, \"Power\": 162.90879418557492, \"i_spike\": 55.5, \"isi\": 0.06320352970416626, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5907555117125005, \"Firing rate\": 389.7225286301253, \"Power\": 389.7225286301253, \"i_spike\": 48.5, \"isi\": 0.07106759705283149, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.197050324722152, \"Firing rate\": 157.4165263375544, \"Power\": 157.4165263375544, \"i_spike\": 42.5, \"isi\": 0.08120962422114071, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.900738498847488, \"Firing rate\": 79.56801043564009, \"Power\": 79.56801043564009, \"i_spike\": 43.5, \"isi\": 0.07999246270715814, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7701446630135824, \"Firing rate\": 58.90398311997898, \"Power\": 58.90398311997898, \"i_spike\": 42.0, \"isi\": 0.08041029857361554, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.5942453724234489, \"Firing rate\": 39.28668388897537, \"Power\": 39.28668388897537, \"i_spike\": 32.5, \"isi\": 0.1019318698052081, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.6923353756705557, \"Firing rate\": 49.24196506231455, \"Power\": 49.24196506231455, \"i_spike\": 44.0, \"isi\": 0.07851300689834464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9096430648934821, \"Firing rate\": 81.21627467876483, \"Power\": 81.21627467876483, \"i_spike\": 42.0, \"isi\": 0.08279141280781681, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7227625327508387, \"Firing rate\": 52.815638294554915, \"Power\": 52.815638294554915, \"i_spike\": 47.0, \"isi\": 0.07465675585663739, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0772331102040815, \"Firing rate\": 119.4629156868915, \"Power\": 119.4629156868915, \"i_spike\": 45.0, \"isi\": 0.07778279269254963, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8962156003531803, \"Firing rate\": 78.7436606258303, \"Power\": 78.7436606258303, \"i_spike\": 45.0, \"isi\": 0.07723000353960975, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.539325164353972, \"Firing rate\": 34.61984860582479, \"Power\": 34.61984860582479, \"i_spike\": 43.5, \"isi\": 0.08038783649040848, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.795290559690197, \"Firing rate\": 62.41522776726645, \"Power\": 62.41522776726645, \"i_spike\": 51.0, \"isi\": 0.06863876971272939, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.7829257189432979, \"Firing rate\": 60.6632563219068, \"Power\": 60.6632563219068, \"i_spike\": 51.5, \"isi\": 0.06724356364949484, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8506258960042894, \"Firing rate\": 70.89667964004052, \"Power\": 70.89667964004052, \"i_spike\": 53.0, \"isi\": 0.06603508775646316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9623740441999131, \"Firing rate\": 91.70099419760025, \"Power\": 91.70099419760025, \"i_spike\": 45.0, \"isi\": 0.0739363878905739, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"1\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0543726256433428, \"Firing rate\": 113.33723822345725, \"Power\": 113.33723822345725, \"i_spike\": 59.5, \"isi\": 0.05882184181366276, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0311570012276237, \"Firing rate\": 107.4377739030315, \"Power\": 107.4377739030315, \"i_spike\": 43.5, \"isi\": 0.08064172994284798, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.149704072470153, \"Firing rate\": 141.15753717632737, \"Power\": 141.15753717632737, \"i_spike\": 59.0, \"isi\": 0.059210435905617934, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0114163933193723, \"Firing rate\": 102.6635773453862, \"Power\": 102.6635773453862, \"i_spike\": 55.0, \"isi\": 0.06332773568755358, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9540841070386274, \"Firing rate\": 89.96717983510673, \"Power\": 89.96717983510673, \"i_spike\": 42.5, \"isi\": 0.08201299481958542, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8156677764444182, \"Firing rate\": 65.41355865573313, \"Power\": 65.41355865573313, \"i_spike\": 54.0, \"isi\": 0.06526466311001969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.893859348236818, \"Firing rate\": 78.31759602448699, \"Power\": 78.31759602448699, \"i_spike\": 56.5, \"isi\": 0.06184020841304989, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.773984421574805, \"Firing rate\": 59.427084135210976, \"Power\": 59.427084135210976, \"i_spike\": 60.0, \"isi\": 0.058270067505733734, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.210840290387196, \"Firing rate\": 162.49510782693136, \"Power\": 162.49510782693136, \"i_spike\": 56.5, \"isi\": 0.06020300273286523, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9713400241427212, \"Firing rate\": 93.61383223125311, \"Power\": 93.61383223125311, \"i_spike\": 61.0, \"isi\": 0.0543980735122145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.8497634918355093, \"Firing rate\": 70.75603561035722, \"Power\": 70.75603561035722, \"i_spike\": 47.5, \"isi\": 0.07274197195399083, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9624750863491771, \"Firing rate\": 91.72233166302841, \"Power\": 91.72233166302841, \"i_spike\": 48.5, \"isi\": 0.07010114635983886, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.855302039054747, \"Firing rate\": 71.66416401500264, \"Power\": 71.66416401500264, \"i_spike\": 46.0, \"isi\": 0.0766119040381658, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.046426832369158, \"Firing rate\": 111.28248941720267, \"Power\": 111.28248941720267, \"i_spike\": 64.0, \"isi\": 0.05429137856724891, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7100483491678449, \"Firing rate\": 51.29184830393363, \"Power\": 51.29184830393363, \"i_spike\": 49.5, \"isi\": 0.0703751778152302, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3453546584516265, \"Firing rate\": 221.49027300778377, \"Power\": 221.49027300778377, \"i_spike\": 59.5, \"isi\": 0.058785042141719916, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.875277533612671, \"Firing rate\": 75.03735784498373, \"Power\": 75.03735784498373, \"i_spike\": 56.0, \"isi\": 0.06218241581461111, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6818911486395558, \"Firing rate\": 48.071884620822175, \"Power\": 48.071884620822175, \"i_spike\": 56.0, \"isi\": 0.06219590540248409, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7807624476641064, \"Firing rate\": 60.36183691888134, \"Power\": 60.36183691888134, \"i_spike\": 46.0, \"isi\": 0.07429803181700052, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.7183011441323788, \"Firing rate\": 52.27585493529653, \"Power\": 52.27585493529653, \"i_spike\": 52.5, \"isi\": 0.06577263809678958, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.763346825231255, \"Firing rate\": 57.98916098746875, \"Power\": 57.98916098746875, \"i_spike\": 48.5, \"isi\": 0.07131264606340101, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.835065458404151, \"Firing rate\": 68.40147366385926, \"Power\": 68.40147366385926, \"i_spike\": 49.0, \"isi\": 0.07194196841840346, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.924715551322173, \"Firing rate\": 84.08442357857703, \"Power\": 84.08442357857703, \"i_spike\": 55.5, \"isi\": 0.06318891040674948, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.017073838923778, \"Firing rate\": 104.00969885083077, \"Power\": 104.00969885083077, \"i_spike\": 49.0, \"isi\": 0.07044066419783745, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7143174946332422, \"Firing rate\": 517.9853711282016, \"Power\": 517.9853711282016, \"i_spike\": 65.0, \"isi\": 0.052930696952406625, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.974181294239221, \"Firing rate\": 94.22828660927348, \"Power\": 94.22828660927348, \"i_spike\": 58.0, \"isi\": 0.060053602856178986, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9399526356112446, \"Firing rate\": 87.08686073800901, \"Power\": 87.08686073800901, \"i_spike\": 53.0, \"isi\": 0.06646977245711418, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6853656755730138, \"Firing rate\": 48.45802119713409, \"Power\": 48.45802119713409, \"i_spike\": 40.0, \"isi\": 0.08662078631540625, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9336719560475775, \"Firing rate\": 85.83649113967905, \"Power\": 85.83649113967905, \"i_spike\": 57.0, \"isi\": 0.060295111833858245, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0093234248133296, \"Firing rate\": 102.17000739461349, \"Power\": 102.17000739461349, \"i_spike\": 49.0, \"isi\": 0.06980898473808321, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"2\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.6653323391451258, \"Firing rate\": 46.27349888819327, \"Power\": 46.27349888819327, \"i_spike\": 52.5, \"isi\": 0.06664468983496366, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.319563597750638, \"Firing rate\": 208.71977491726287, \"Power\": 208.71977491726287, \"i_spike\": 62.5, \"isi\": 0.054778780974004924, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9501238550989324, \"Firing rate\": 89.15051474767834, \"Power\": 89.15051474767834, \"i_spike\": 65.0, \"isi\": 0.052393936924168064, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.058384385790344, \"Firing rate\": 114.38903224581574, \"Power\": 114.38903224581574, \"i_spike\": 67.0, \"isi\": 0.051939822712101694, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.341203185363342, \"Firing rate\": 219.38310826468677, \"Power\": 219.38310826468677, \"i_spike\": 63.5, \"isi\": 0.054996827366133136, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9819991440519158, \"Firing rate\": 95.9398740641521, \"Power\": 95.9398740641521, \"i_spike\": 56.0, \"isi\": 0.06266914967033387, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.369563712635469, \"Firing rate\": 234.18750118502433, \"Power\": 234.18750118502433, \"i_spike\": 66.0, \"isi\": 0.05307466490753688, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8499974740031297, \"Firing rate\": 70.79416667549492, \"Power\": 70.79416667549492, \"i_spike\": 50.0, \"isi\": 0.06964434411828664, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4140871865689233, \"Firing rate\": 259.4700207563056, \"Power\": 259.4700207563056, \"i_spike\": 57.5, \"isi\": 0.05932812658617926, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2992730643707255, \"Firing rate\": 199.19253762816092, \"Power\": 199.19253762816092, \"i_spike\": 69.0, \"isi\": 0.0505200086604451, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1143279384255944, \"Firing rate\": 130.11517148140396, \"Power\": 130.11517148140396, \"i_spike\": 58.0, \"isi\": 0.06039580425018153, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1347425595996863, \"Firing rate\": 136.37744808427303, \"Power\": 136.37744808427303, \"i_spike\": 57.5, \"isi\": 0.06059068471302143, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9227227083724787, \"Firing rate\": 83.69947007723921, \"Power\": 83.69947007723921, \"i_spike\": 74.5, \"isi\": 0.04700841293964799, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9356641657046738, \"Firing rate\": 86.23114755907184, \"Power\": 86.23114755907184, \"i_spike\": 59.0, \"isi\": 0.05819722837595124, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1650029836128866, \"Firing rate\": 146.21872196813922, \"Power\": 146.21872196813922, \"i_spike\": 66.5, \"isi\": 0.05230105943774251, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.090242481076867, \"Firing rate\": 123.09558626462615, \"Power\": 123.09558626462615, \"i_spike\": 57.5, \"isi\": 0.059929836211731397, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9223690348846298, \"Firing rate\": 83.63133604719516, \"Power\": 83.63133604719516, \"i_spike\": 60.5, \"isi\": 0.05806760763773719, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1491227759212217, \"Firing rate\": 140.9687263512985, \"Power\": 140.9687263512985, \"i_spike\": 54.5, \"isi\": 0.06367419112012151, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3941117654392667, \"Firing rate\": 247.80597028438038, \"Power\": 247.80597028438038, \"i_spike\": 63.0, \"isi\": 0.05461154211696954, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9896786925487997, \"Firing rate\": 97.65144913558673, \"Power\": 97.65144913558673, \"i_spike\": 62.5, \"isi\": 0.05504185225729406, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.7731494316094232, \"Firing rate\": 59.31293728328963, \"Power\": 59.31293728328963, \"i_spike\": 55.0, \"isi\": 0.06267698786541855, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.8554169772491347, \"Firing rate\": 71.68313280237724, \"Power\": 71.68313280237724, \"i_spike\": 60.5, \"isi\": 0.056999565632898194, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3716727528341055, \"Firing rate\": 235.32753886515357, \"Power\": 235.32753886515357, \"i_spike\": 52.0, \"isi\": 0.067154049479885, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2364092112497285, \"Firing rate\": 172.34917594410877, \"Power\": 172.34917594410877, \"i_spike\": 59.5, \"isi\": 0.05869502074828589, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2557126583819076, \"Firing rate\": 180.18252074391486, \"Power\": 180.18252074391486, \"i_spike\": 73.5, \"isi\": 0.04743594072717539, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.7433869258557073, \"Firing rate\": 553.8433249443033, \"Power\": 553.8433249443033, \"i_spike\": 55.0, \"isi\": 0.06360854706023654, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9410922920516542, \"Firing rate\": 87.31569035109068, \"Power\": 87.31569035109068, \"i_spike\": 65.5, \"isi\": 0.052877411734321145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.053756802379095, \"Firing rate\": 113.17664155543305, \"Power\": 113.17664155543305, \"i_spike\": 54.0, \"isi\": 0.06436186527784456, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.034873477705347, \"Firing rate\": 108.36111813754236, \"Power\": 108.36111813754236, \"i_spike\": 66.5, \"isi\": 0.050938903955247916, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9885417764206283, \"Firing rate\": 97.39614698417968, \"Power\": 97.39614698417968, \"i_spike\": 60.0, \"isi\": 0.05780359441402076, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"3\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.4369749555623357, \"Firing rate\": 273.51109962529904, \"Power\": 273.51109962529904, \"i_spike\": 64.0, \"isi\": 0.053993497700095504, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1065489309483487, \"Firing rate\": 127.8053196733479, \"Power\": 127.8053196733479, \"i_spike\": 66.0, \"isi\": 0.05304312813996159, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9049237369041854, \"Firing rate\": 80.33850335646146, \"Power\": 80.33850335646146, \"i_spike\": 74.0, \"isi\": 0.046752172315214786, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.089842705284853, \"Firing rate\": 122.98232672563184, \"Power\": 122.98232672563184, \"i_spike\": 62.5, \"isi\": 0.055459566693195586, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0542996219949314, \"Firing rate\": 113.3181881621406, \"Power\": 113.3181881621406, \"i_spike\": 68.5, \"isi\": 0.04886679113481873, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5270188880084747, \"Firing rate\": 336.5262050014474, \"Power\": 336.5262050014474, \"i_spike\": 77.0, \"isi\": 0.045084314963419254, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8366391281202479, \"Firing rate\": 68.64977657243634, \"Power\": 68.64977657243634, \"i_spike\": 70.5, \"isi\": 0.04950827198418861, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9617130502576103, \"Firing rate\": 91.56153191880342, \"Power\": 91.56153191880342, \"i_spike\": 68.5, \"isi\": 0.05136728010783104, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.241494871870913, \"Firing rate\": 174.37927667202098, \"Power\": 174.37927667202098, \"i_spike\": 63.0, \"isi\": 0.05576348859764074, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 3.1251395921423315, \"Firing rate\": 1333.9501252294517, \"Power\": 1333.9501252294517, \"i_spike\": 64.5, \"isi\": 0.054262100729024564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8958624054342972, \"Firing rate\": 78.67964748291678, \"Power\": 78.67964748291678, \"i_spike\": 74.0, \"isi\": 0.046877125846140295, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.5517732739731294, \"Firing rate\": 356.2650945497233, \"Power\": 356.2650945497233, \"i_spike\": 76.5, \"isi\": 0.04517211033649603, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0919634725229534, \"Firing rate\": 123.58434852138122, \"Power\": 123.58434852138122, \"i_spike\": 68.0, \"isi\": 0.05101734433625525, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3525110631387873, \"Firing rate\": 225.17027754817553, \"Power\": 225.17027754817553, \"i_spike\": 65.0, \"isi\": 0.05404540309717516, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.7819954120481858, \"Firing rate\": 60.53344798762198, \"Power\": 60.53344798762198, \"i_spike\": 53.0, \"isi\": 0.06467002728543748, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8422213318301035, \"Firing rate\": 69.5378616839905, \"Power\": 69.5378616839905, \"i_spike\": 69.0, \"isi\": 0.05037331163693314, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1868975598998643, \"Firing rate\": 153.77918677144316, \"Power\": 153.77918677144316, \"i_spike\": 70.0, \"isi\": 0.049775509977722336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9726367908939046, \"Firing rate\": 93.89377298287559, \"Power\": 93.89377298287559, \"i_spike\": 75.5, \"isi\": 0.04639225026242182, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.778101000828387, \"Firing rate\": 59.99305816899431, \"Power\": 59.99305816899431, \"i_spike\": 68.5, \"isi\": 0.05075104338195106, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9121660273135348, \"Firing rate\": 81.68946039587414, \"Power\": 81.68946039587414, \"i_spike\": 64.0, \"isi\": 0.05481280145440375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0478218930526535, \"Firing rate\": 111.64053089208255, \"Power\": 111.64053089208255, \"i_spike\": 70.0, \"isi\": 0.0489888087012864, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.117471278561992, \"Firing rate\": 131.0603364640247, \"Power\": 131.0603364640247, \"i_spike\": 65.5, \"isi\": 0.051671766893329675, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.931167591711936, \"Firing rate\": 853.4293839120918, \"Power\": 853.4293839120918, \"i_spike\": 63.0, \"isi\": 0.05525138390063168, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.277774705751867, \"Firing rate\": 189.57222427760698, \"Power\": 189.57222427760698, \"i_spike\": 78.0, \"isi\": 0.04456622398656536, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.845684289414062, \"Firing rate\": 70.09455604474384, \"Power\": 70.09455604474384, \"i_spike\": 63.5, \"isi\": 0.05469869440456847, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10431894281778, \"Firing rate\": 127.15075486242938, \"Power\": 127.15075486242938, \"i_spike\": 67.0, \"isi\": 0.05227215134911894, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.033552725921547, \"Firing rate\": 108.03207702586286, \"Power\": 108.03207702586286, \"i_spike\": 57.5, \"isi\": 0.060347774168580594, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1643005604050174, \"Firing rate\": 145.98242053251482, \"Power\": 145.98242053251482, \"i_spike\": 72.5, \"isi\": 0.04783783469680652, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0012121960819167, \"Firing rate\": 100.27950836105705, \"Power\": 100.27950836105705, \"i_spike\": 71.5, \"isi\": 0.048990832561469015, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.9583920039283502, \"Firing rate\": 90.86403192498832, \"Power\": 90.86403192498832, \"i_spike\": 76.0, \"isi\": 0.04556701067411184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"4\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1124885757403176, \"Firing rate\": 129.56526144990931, \"Power\": 129.56526144990931, \"i_spike\": 75.0, \"isi\": 0.046659913362027156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7844790003053106, \"Firing rate\": 608.8061070924601, \"Power\": 608.8061070924601, \"i_spike\": 92.0, \"isi\": 0.03797865081756185, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1928313296970376, \"Firing rate\": 155.8946924977612, \"Power\": 155.8946924977612, \"i_spike\": 92.0, \"isi\": 0.038121755542223995, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077615601977832, \"Firing rate\": 119.56817539419721, \"Power\": 119.56817539419721, \"i_spike\": 74.5, \"isi\": 0.04660934195613513, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3240668465311076, \"Firing rate\": 210.895273459069, \"Power\": 210.895273459069, \"i_spike\": 75.5, \"isi\": 0.04641624316187993, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9441862764582671, \"Firing rate\": 87.93996257483187, \"Power\": 87.93996257483187, \"i_spike\": 73.0, \"isi\": 0.04692146801636959, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.0247285177119982, \"Firing rate\": 1058.591780864329, \"Power\": 1058.591780864329, \"i_spike\": 77.0, \"isi\": 0.045685464766526206, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.7391920768878777, \"Firing rate\": 54.85195068575797, \"Power\": 54.85195068575797, \"i_spike\": 64.5, \"isi\": 0.05399592200088135, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1934103426446043, \"Firing rate\": 156.10267405821313, \"Power\": 156.10267405821313, \"i_spike\": 74.5, \"isi\": 0.046628423844649644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.297774880328158, \"Firing rate\": 198.50656775360184, \"Power\": 198.50656775360184, \"i_spike\": 80.0, \"isi\": 0.04397457503735967, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1110133951114576, \"Firing rate\": 129.1259099799552, \"Power\": 129.1259099799552, \"i_spike\": 87.5, \"isi\": 0.03951101481601628, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9798834285720046, \"Firing rate\": 95.47362854816234, \"Power\": 95.47362854816234, \"i_spike\": 82.0, \"isi\": 0.04281447867823779, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9839401087688497, \"Firing rate\": 96.36961162784607, \"Power\": 96.36961162784607, \"i_spike\": 80.5, \"isi\": 0.0436343619819139, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9292502786690382, \"Firing rate\": 84.96699885333383, \"Power\": 84.96699885333383, \"i_spike\": 84.5, \"isi\": 0.040212763358464985, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.110242887829347, \"Firing rate\": 128.89702323935285, \"Power\": 128.89702323935285, \"i_spike\": 78.0, \"isi\": 0.044671705231796116, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9896296651016587, \"Firing rate\": 97.6404258985101, \"Power\": 97.6404258985101, \"i_spike\": 96.5, \"isi\": 0.03602341732975196, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.524514898794598, \"Firing rate\": 3345.9149606607, \"Power\": 3345.9149606607, \"i_spike\": 67.0, \"isi\": 0.05228146274267083, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1112668565940305, \"Firing rate\": 129.20129200352847, \"Power\": 129.20129200352847, \"i_spike\": 72.5, \"isi\": 0.04765721891987244, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9572989808412744, \"Firing rate\": 90.63563480094187, \"Power\": 90.63563480094187, \"i_spike\": 77.5, \"isi\": 0.04525372674699464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.543885879418327, \"Firing rate\": 349.85322319506616, \"Power\": 349.85322319506616, \"i_spike\": 71.5, \"isi\": 0.048639441668922465, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1757930037804383, \"Firing rate\": 149.89702164205846, \"Power\": 149.89702164205846, \"i_spike\": 82.0, \"isi\": 0.04242030307116036, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9882434867575853, \"Firing rate\": 97.32927464232434, \"Power\": 97.32927464232434, \"i_spike\": 73.0, \"isi\": 0.047906156958600565, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.123436432758141, \"Firing rate\": 132.8729058171096, \"Power\": 132.8729058171096, \"i_spike\": 74.0, \"isi\": 0.04678579996295997, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2883138118447697, \"Firing rate\": 194.22888267612504, \"Power\": 194.22888267612504, \"i_spike\": 76.0, \"isi\": 0.04579097873240445, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3338630531397206, \"Firing rate\": 215.70641109917793, \"Power\": 215.70641109917793, \"i_spike\": 82.0, \"isi\": 0.04253295769330548, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1368082310712584, \"Firing rate\": 137.02765673763616, \"Power\": 137.02765673763616, \"i_spike\": 87.0, \"isi\": 0.04009013967311376, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.304411865772515, \"Firing rate\": 201.5634883150203, \"Power\": 201.5634883150203, \"i_spike\": 84.5, \"isi\": 0.040969846937519115, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1578448451318133, \"Firing rate\": 143.82846487878152, \"Power\": 143.82846487878152, \"i_spike\": 93.0, \"isi\": 0.037192354679684805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.026210332863069, \"Firing rate\": 106.22098707802203, \"Power\": 106.22098707802203, \"i_spike\": 86.0, \"isi\": 0.039883894146009444, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0309948773666058, \"Firing rate\": 107.39767443894033, \"Power\": 107.39767443894033, \"i_spike\": 71.5, \"isi\": 0.04790202069793337, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"5\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1102417146873824, \"Firing rate\": 128.89667505555326, \"Power\": 128.89667505555326, \"i_spike\": 85.5, \"isi\": 0.040840328777172155, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3598760140799757, \"Firing rate\": 229.0213730590734, \"Power\": 229.0213730590734, \"i_spike\": 85.5, \"isi\": 0.041093869337129094, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4487993661694656, \"Firing rate\": 281.0602098401713, \"Power\": 281.0602098401713, \"i_spike\": 88.5, \"isi\": 0.03916681921061969, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1541973100299687, \"Firing rate\": 142.6255427263312, \"Power\": 142.6255427263312, \"i_spike\": 87.5, \"isi\": 0.039474320407279974, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.234900540025064, \"Firing rate\": 171.7515005319624, \"Power\": 171.7515005319624, \"i_spike\": 94.5, \"isi\": 0.03655183866180524, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.7078341872007305, \"Firing rate\": 510.31012735003867, \"Power\": 510.31012735003867, \"i_spike\": 83.5, \"isi\": 0.041988842659945944, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1126963123799873, \"Firing rate\": 129.6272513932111, \"Power\": 129.6272513932111, \"i_spike\": 89.0, \"isi\": 0.03919921663226311, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1692211907420162, \"Firing rate\": 147.6458317545557, \"Power\": 147.6458317545557, \"i_spike\": 88.0, \"isi\": 0.03956930417423602, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1644556852991537, \"Firing rate\": 146.03457305415864, \"Power\": 146.03457305415864, \"i_spike\": 96.5, \"isi\": 0.03588734853002937, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.31196565210909, \"Firing rate\": 205.0999960994725, \"Power\": 205.0999960994725, \"i_spike\": 90.0, \"isi\": 0.03903067099230167, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.074577597091679, \"Firing rate\": 118.73468299886356, \"Power\": 118.73468299886356, \"i_spike\": 104.0, \"isi\": 0.03353750893302584, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2092160144315107, \"Firing rate\": 161.88850572662918, \"Power\": 161.88850572662918, \"i_spike\": 104.5, \"isi\": 0.03279156198398983, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.49914214982962, \"Firing rate\": 315.60374635173724, \"Power\": 315.60374635173724, \"i_spike\": 101.5, \"isi\": 0.034537567878371166, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1418864131165836, \"Firing rate\": 138.63931793743396, \"Power\": 138.63931793743396, \"i_spike\": 91.5, \"isi\": 0.03818102135269262, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8765227305978964, \"Firing rate\": 752.5281158141704, \"Power\": 752.5281158141704, \"i_spike\": 93.5, \"isi\": 0.03689839236734887, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.939461561874331, \"Firing rate\": 86.98844387480378, \"Power\": 86.98844387480378, \"i_spike\": 92.0, \"isi\": 0.03758519178898388, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2870436262828573, \"Firing rate\": 193.66164935551598, \"Power\": 193.66164935551598, \"i_spike\": 89.5, \"isi\": 0.03894744817039956, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.1430297227592443, \"Firing rate\": 139.0047761690239, \"Power\": 139.0047761690239, \"i_spike\": 97.0, \"isi\": 0.03603976087193819, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.310726570280992, \"Firing rate\": 204.51566105247213, \"Power\": 204.51566105247213, \"i_spike\": 91.0, \"isi\": 0.03830441539373303, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3968118547257453, \"Firing rate\": 249.35142514175052, \"Power\": 249.35142514175052, \"i_spike\": 96.0, \"isi\": 0.03647169049835178, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 3.469141414513526, \"Firing rate\": 2945.3805493938794, \"Power\": 2945.3805493938794, \"i_spike\": 97.0, \"isi\": 0.03567197347869549, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189566775673024, \"Firing rate\": 262.39567812258474, \"Power\": 262.39567812258474, \"i_spike\": 109.0, \"isi\": 0.03178383198414856, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.404076689518491, \"Firing rate\": 253.55763335396162, \"Power\": 253.55763335396162, \"i_spike\": 100.0, \"isi\": 0.034975946689714515, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4991139433760545, \"Firing rate\": 315.58324926114744, \"Power\": 315.58324926114744, \"i_spike\": 83.5, \"isi\": 0.04187307899164901, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.379747962179488, \"Firing rate\": 239.7441187730139, \"Power\": 239.7441187730139, \"i_spike\": 100.0, \"isi\": 0.03471693037002835, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.8902246293874716, \"Firing rate\": 77.66487174396306, \"Power\": 77.66487174396306, \"i_spike\": 87.5, \"isi\": 0.03966381661521433, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.814843398948089, \"Firing rate\": 652.8950845550662, \"Power\": 652.8950845550662, \"i_spike\": 85.5, \"isi\": 0.040891388126968714, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.9487896110579808, \"Firing rate\": 888.7704589764036, \"Power\": 888.7704589764036, \"i_spike\": 89.5, \"isi\": 0.03915085074928612, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.0149402045520945, \"Firing rate\": 103.49996538656313, \"Power\": 103.49996538656313, \"i_spike\": 89.5, \"isi\": 0.03921140742804705, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 1.9542028872402641, \"Firing rate\": 89.9917893609065, \"Power\": 89.9917893609065, \"i_spike\": 85.5, \"isi\": 0.04054868314386225, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"6\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4881910216727383, \"Firing rate\": 307.74501140084084, \"Power\": 307.74501140084084, \"i_spike\": 88.0, \"isi\": 0.03904624656724844, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4115277428777, \"Firing rate\": 257.945373553756, \"Power\": 257.945373553756, \"i_spike\": 119.5, \"isi\": 0.02880924312756989, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4545567386868696, \"Firing rate\": 284.81098690467894, \"Power\": 284.81098690467894, \"i_spike\": 109.0, \"isi\": 0.03179620656212547, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3111719305423497, \"Firing rate\": 204.7254953238993, \"Power\": 204.7254953238993, \"i_spike\": 97.5, \"isi\": 0.03580379043600067, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.165545723182864, \"Firing rate\": 146.40156632304382, \"Power\": 146.40156632304382, \"i_spike\": 105.5, \"isi\": 0.03278382952607013, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2578646424397553, \"Firing rate\": 181.07756360533585, \"Power\": 181.07756360533585, \"i_spike\": 119.0, \"isi\": 0.029343681835626842, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.8107940843269335, \"Firing rate\": 646.835853340232, \"Power\": 646.835853340232, \"i_spike\": 116.0, \"isi\": 0.029999599974023163, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.39182087209241, \"Firing rate\": 246.50224111651946, \"Power\": 246.50224111651946, \"i_spike\": 117.5, \"isi\": 0.029502232467124783, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0658291633993806, \"Firing rate\": 116.36681920867568, \"Power\": 116.36681920867568, \"i_spike\": 101.0, \"isi\": 0.034668414565907774, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3285225511020813, \"Firing rate\": 213.07012031018914, \"Power\": 213.07012031018914, \"i_spike\": 113.5, \"isi\": 0.03083920593859388, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6729864873429214, \"Firing rate\": 470.9626726162531, \"Power\": 470.9626726162531, \"i_spike\": 122.0, \"isi\": 0.028568916959577716, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2018925265651847, \"Firing rate\": 159.18147571149987, \"Power\": 159.18147571149987, \"i_spike\": 112.0, \"isi\": 0.030867054694338973, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.374213868452394, \"Firing rate\": 236.70850822985395, \"Power\": 236.70850822985395, \"i_spike\": 105.0, \"isi\": 0.03330704053094981, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.311456530252207, \"Firing rate\": 204.85969899001685, \"Power\": 204.85969899001685, \"i_spike\": 104.0, \"isi\": 0.03379316964890372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.18089067422046, \"Firing rate\": 151.66685255353084, \"Power\": 151.66685255353084, \"i_spike\": 108.0, \"isi\": 0.03226254920952097, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1779833854348714, \"Firing rate\": 150.65494298513445, \"Power\": 150.65494298513445, \"i_spike\": 113.0, \"isi\": 0.030897373044620688, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3035855615368024, \"Firing rate\": 201.18035100403486, \"Power\": 201.18035100403486, \"i_spike\": 112.5, \"isi\": 0.031017803226141994, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4551657383947396, \"Firing rate\": 285.2106499995778, \"Power\": 285.2106499995778, \"i_spike\": 119.5, \"isi\": 0.02922791099470977, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 3.100538081982483, \"Firing rate\": 1260.486161305173, \"Power\": 1260.486161305173, \"i_spike\": 117.5, \"isi\": 0.029697418256461976, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1111083966350765, \"Firing rate\": 129.15415924516745, \"Power\": 129.15415924516745, \"i_spike\": 118.5, \"isi\": 0.02948619911662466, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.044552627498885, \"Firing rate\": 110.80328278754759, \"Power\": 110.80328278754759, \"i_spike\": 101.0, \"isi\": 0.03429723398050743, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.016091787828533, \"Firing rate\": 103.77477198816491, \"Power\": 103.77477198816491, \"i_spike\": 103.5, \"isi\": 0.03346541480440439, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2697421877977257, \"Firing rate\": 186.09820654703583, \"Power\": 186.09820654703583, \"i_spike\": 118.5, \"isi\": 0.029214269965179746, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.687691210640336, \"Firing rate\": 487.1819738340354, \"Power\": 487.1819738340354, \"i_spike\": 112.0, \"isi\": 0.031291789674142416, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.5700111791336004, \"Firing rate\": 371.5447928738117, \"Power\": 371.5447928738117, \"i_spike\": 119.5, \"isi\": 0.029125995163474167, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.324688636610815, \"Firing rate\": 211.19743365693657, \"Power\": 211.19743365693657, \"i_spike\": 128.5, \"isi\": 0.02689077169759444, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.197745717540907, \"Firing rate\": 157.668783762246, \"Power\": 157.668783762246, \"i_spike\": 116.5, \"isi\": 0.029739505746504635, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.232111730437686, \"Firing rate\": 170.65213673060103, \"Power\": 170.65213673060103, \"i_spike\": 119.5, \"isi\": 0.029278118430901116, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.226281785132872, \"Firing rate\": 168.3766191894407, \"Power\": 168.3766191894407, \"i_spike\": 100.5, \"isi\": 0.03487511849895156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4240095717708385, \"Firing rate\": 265.4664069640671, \"Power\": 265.4664069640671, \"i_spike\": 109.0, \"isi\": 0.032083977077943644, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 0, \"mouse\": \"7\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.0765668363240124, \"Firing rate\": 119.27978189302107, \"Power\": 119.27978189302107, \"i_spike\": 118.0, \"isi\": 0.02924333618462232, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.710200388455537, \"Firing rate\": 513.0980787193608, \"Power\": 513.0980787193608, \"i_spike\": 58.0, \"isi\": 0.05755769778597422, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.086495554586632, \"Firing rate\": 122.03813289272098, \"Power\": 122.03813289272098, \"i_spike\": 58.0, \"isi\": 0.05954567433072462, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.4599942127543875, \"Firing rate\": 288.3993071858994, \"Power\": 288.3993071858994, \"i_spike\": 69.0, \"isi\": 0.050452157477652144, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8764248252258178, \"Firing rate\": 75.23584884202715, \"Power\": 75.23584884202715, \"i_spike\": 47.5, \"isi\": 0.0729232484181408, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.943371360287594, \"Firing rate\": 87.77510553153151, \"Power\": 87.77510553153151, \"i_spike\": 72.0, \"isi\": 0.04794968452690702, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0095288502408404, \"Firing rate\": 102.21834621295545, \"Power\": 102.21834621295545, \"i_spike\": 58.5, \"isi\": 0.05900199429876669, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.108813974324886, \"Firing rate\": 128.47362382167685, \"Power\": 128.47362382167685, \"i_spike\": 74.0, \"isi\": 0.04704885530644372, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9546575480473676, \"Firing rate\": 90.08605066518454, \"Power\": 90.08605066518454, \"i_spike\": 66.0, \"isi\": 0.05192063434120186, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9556030665055126, \"Firing rate\": 90.28239396841717, \"Power\": 90.28239396841717, \"i_spike\": 63.0, \"isi\": 0.05547055572684698, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.116207536382213, \"Firing rate\": 130.6795217411474, \"Power\": 130.6795217411474, \"i_spike\": 60.5, \"isi\": 0.0574361231164934, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.125243880671493, \"Firing rate\": 133.4270489421996, \"Power\": 133.4270489421996, \"i_spike\": 68.0, \"isi\": 0.04981296493334266, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.067202187376957, \"Firing rate\": 116.73529559924685, \"Power\": 116.73529559924685, \"i_spike\": 61.5, \"isi\": 0.0564927141817096, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3223316454945286, \"Firing rate\": 210.0543334368294, \"Power\": 210.0543334368294, \"i_spike\": 59.5, \"isi\": 0.058641352393127184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0012989243549466, \"Firing rate\": 100.29953610121872, \"Power\": 100.29953610121872, \"i_spike\": 63.5, \"isi\": 0.053258724806304336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.740752379052743, \"Firing rate\": 55.049373283103336, \"Power\": 55.049373283103336, \"i_spike\": 68.5, \"isi\": 0.05025347412312059, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.8372359506262905, \"Firing rate\": 68.74418232403539, \"Power\": 68.74418232403539, \"i_spike\": 58.5, \"isi\": 0.05883024786315191, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.3872683261080843, \"Firing rate\": 243.9317469805847, \"Power\": 243.9317469805847, \"i_spike\": 52.0, \"isi\": 0.06463987437697509, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.1699952647940046, \"Firing rate\": 147.90922612197502, \"Power\": 147.90922612197502, \"i_spike\": 58.0, \"isi\": 0.06041749419783433, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0727936321681573, \"Firing rate\": 118.24795321797994, \"Power\": 118.24795321797994, \"i_spike\": 74.0, \"isi\": 0.04733033921726912, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.44888166908114, \"Firing rate\": 281.11347845536557, \"Power\": 281.11347845536557, \"i_spike\": 64.0, \"isi\": 0.05283053800228937, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.268675264450081, \"Firing rate\": 185.64158358911618, \"Power\": 185.64158358911618, \"i_spike\": 65.5, \"isi\": 0.05201986674274169, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.428906190296464, \"Firing rate\": 268.4764460943622, \"Power\": 268.4764460943622, \"i_spike\": 58.5, \"isi\": 0.05911180928366123, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.049008675060004, \"Firing rate\": 111.94602445336766, \"Power\": 111.94602445336766, \"i_spike\": 84.0, \"isi\": 0.04125747764768612, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0516084499750704, \"Firing rate\": 112.61816585709414, \"Power\": 112.61816585709414, \"i_spike\": 66.0, \"isi\": 0.05216770534731938, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9822401781710393, \"Firing rate\": 95.99313562360203, \"Power\": 95.99313562360203, \"i_spike\": 68.5, \"isi\": 0.05091550082040577, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 2.0413070869966092, \"Firing rate\": 109.97832146085658, \"Power\": 109.97832146085658, \"i_spike\": 69.5, \"isi\": 0.048261908955763336, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9162564740110344, \"Firing rate\": 82.4624956181202, \"Power\": 82.4624956181202, \"i_spike\": 72.5, \"isi\": 0.04580300353406743, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.0251706690400266, \"Firing rate\": 1059.6700724955876, \"Power\": 1059.6700724955876, \"i_spike\": 71.0, \"isi\": 0.048977335140478306, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 1.9185288956668356, \"Firing rate\": 82.89510684752574, \"Power\": 82.89510684752574, \"i_spike\": 65.0, \"isi\": 0.053468477919304494, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"0\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes0\", \"Log power\": 3.7155492922987285, \"Firing rate\": 5194.566283391101, \"Power\": 5194.566283391101, \"i_spike\": 70.0, \"isi\": 0.047831889076879165, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2880559296273484, \"Firing rate\": 194.11358462627942, \"Power\": 194.11358462627942, \"i_spike\": 77.0, \"isi\": 0.04377704062250514, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2863930549701847, \"Firing rate\": 193.37176219598692, \"Power\": 193.37176219598692, \"i_spike\": 71.5, \"isi\": 0.04739471740371852, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 3.485362624668281, \"Firing rate\": 3057.4729586064655, \"Power\": 3057.4729586064655, \"i_spike\": 61.0, \"isi\": 0.05730472197648097, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2096939236101893, \"Firing rate\": 162.06675019105623, \"Power\": 162.06675019105623, \"i_spike\": 70.0, \"isi\": 0.04860233815068464, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.837305629539864, \"Firing rate\": 687.5521263737877, \"Power\": 687.5521263737877, \"i_spike\": 76.0, \"isi\": 0.0462630290768705, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1604627571934727, \"Firing rate\": 144.6980762328094, \"Power\": 144.6980762328094, \"i_spike\": 71.5, \"isi\": 0.04871333606236235, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2330475254201847, \"Firing rate\": 171.0202454569647, \"Power\": 171.0202454569647, \"i_spike\": 71.5, \"isi\": 0.049080521297471015, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2588609326122553, \"Firing rate\": 181.4934401413059, \"Power\": 181.4934401413059, \"i_spike\": 66.5, \"isi\": 0.05057733095048499, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8829675842290474, \"Firing rate\": 76.37787729482577, \"Power\": 76.37787729482577, \"i_spike\": 81.0, \"isi\": 0.04283416965586292, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.3279809733696553, \"Firing rate\": 212.80458133268078, \"Power\": 212.80458133268078, \"i_spike\": 74.5, \"isi\": 0.04442769500737385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.8091068615972408, \"Firing rate\": 64.43277879673587, \"Power\": 64.43277879673587, \"i_spike\": 60.5, \"isi\": 0.056408495878117026, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0634103765045717, \"Firing rate\": 115.7205199960153, \"Power\": 115.7205199960153, \"i_spike\": 62.5, \"isi\": 0.05494193964992375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.057707201125165, \"Firing rate\": 114.21080723853781, \"Power\": 114.21080723853781, \"i_spike\": 66.5, \"isi\": 0.05118977826099244, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.2746886859201556, \"Firing rate\": 188.2299322496126, \"Power\": 188.2299322496126, \"i_spike\": 76.5, \"isi\": 0.04519157254778185, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0019707623558363, \"Firing rate\": 100.45481596463469, \"Power\": 100.45481596463469, \"i_spike\": 76.0, \"isi\": 0.045327986132193195, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.295587633345161, \"Firing rate\": 197.50933799327007, \"Power\": 197.50933799327007, \"i_spike\": 74.0, \"isi\": 0.046483911938798965, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.945877973988118, \"Firing rate\": 88.28318116549227, \"Power\": 88.28318116549227, \"i_spike\": 66.5, \"isi\": 0.05264008421938133, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.471153315505243, \"Firing rate\": 295.90568943614835, \"Power\": 295.90568943614835, \"i_spike\": 87.0, \"isi\": 0.04015846530226762, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0265599217285164, \"Firing rate\": 106.30652494563125, \"Power\": 106.30652494563125, \"i_spike\": 78.5, \"isi\": 0.04422689053854093, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9009990463345725, \"Firing rate\": 79.61576021362671, \"Power\": 79.61576021362671, \"i_spike\": 60.0, \"isi\": 0.05558242287405482, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.1371898250889654, \"Firing rate\": 137.14810936802255, \"Power\": 137.14810936802255, \"i_spike\": 78.0, \"isi\": 0.043423699441362415, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.18334195846327, \"Firing rate\": 152.5253247913568, \"Power\": 152.5253247913568, \"i_spike\": 79.5, \"isi\": 0.0439479607076074, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.018302892049905, \"Firing rate\": 104.30446313151317, \"Power\": 104.30446313151317, \"i_spike\": 69.5, \"isi\": 0.050417535373145216, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.520301793170094, \"Firing rate\": 331.36130594281525, \"Power\": 331.36130594281525, \"i_spike\": 63.0, \"isi\": 0.055194343234777954, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.140863371620742, \"Firing rate\": 138.3131179566823, \"Power\": 138.3131179566823, \"i_spike\": 67.0, \"isi\": 0.05011613503553582, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.5790786138640915, \"Firing rate\": 379.38365293278486, \"Power\": 379.38365293278486, \"i_spike\": 70.0, \"isi\": 0.049862445465668585, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.0046971363148742, \"Firing rate\": 101.08742556167319, \"Power\": 101.08742556167319, \"i_spike\": 77.0, \"isi\": 0.044773115940763754, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 1.9299917883985747, \"Firing rate\": 85.11219451122186, \"Power\": 85.11219451122186, \"i_spike\": 63.5, \"isi\": 0.053279255805921924, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.507367640954118, \"Firing rate\": 321.63821330655077, \"Power\": 321.63821330655077, \"i_spike\": 83.0, \"isi\": 0.04180903485727737, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"1\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes1\", \"Log power\": 2.043864219396577, \"Firing rate\": 110.62778561221664, \"Power\": 110.62778561221664, \"i_spike\": 60.5, \"isi\": 0.05613656256289283, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0343304902630406, \"Firing rate\": 108.2257216223445, \"Power\": 108.2257216223445, \"i_spike\": 76.5, \"isi\": 0.044990678072367146, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.265966193291141, \"Firing rate\": 184.48718035589718, \"Power\": 184.48718035589718, \"i_spike\": 82.5, \"isi\": 0.041218621498328945, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.184829164757981, \"Firing rate\": 153.0485307452557, \"Power\": 153.0485307452557, \"i_spike\": 79.5, \"isi\": 0.0438790508311261, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.482867251153031, \"Firing rate\": 303.99556740279854, \"Power\": 303.99556740279854, \"i_spike\": 72.0, \"isi\": 0.04732392940449676, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.679350887775424, \"Firing rate\": 477.91524884132025, \"Power\": 477.91524884132025, \"i_spike\": 75.0, \"isi\": 0.04487201851927047, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0102132106102126, \"Firing rate\": 102.37954865480673, \"Power\": 102.37954865480673, \"i_spike\": 71.5, \"isi\": 0.04878632929411457, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2925787627458876, \"Firing rate\": 196.14568689680337, \"Power\": 196.14568689680337, \"i_spike\": 71.5, \"isi\": 0.04751080235874853, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.408181131975511, \"Firing rate\": 255.96532234553712, \"Power\": 255.96532234553712, \"i_spike\": 78.5, \"isi\": 0.04224296754691385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3855583224969688, \"Firing rate\": 242.97317148876678, \"Power\": 242.97317148876678, \"i_spike\": 76.5, \"isi\": 0.045168110305337704, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9994034804402283, \"Firing rate\": 99.862740582426, \"Power\": 99.862740582426, \"i_spike\": 76.5, \"isi\": 0.04461518511387296, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.420657135162534, \"Firing rate\": 263.4250888241149, \"Power\": 263.4250888241149, \"i_spike\": 86.5, \"isi\": 0.039763315255390425, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0333948498686167, \"Firing rate\": 107.99281201345569, \"Power\": 107.99281201345569, \"i_spike\": 71.5, \"isi\": 0.04905015663749419, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1771834940956576, \"Firing rate\": 150.3777193944357, \"Power\": 150.3777193944357, \"i_spike\": 71.5, \"isi\": 0.048168145819388865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9004170909121822, \"Firing rate\": 79.50914639254572, \"Power\": 79.50914639254572, \"i_spike\": 72.0, \"isi\": 0.047053568472965865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.2706500732886123, \"Firing rate\": 186.4876487147454, \"Power\": 186.4876487147454, \"i_spike\": 76.5, \"isi\": 0.04478958523955221, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3226879927203563, \"Firing rate\": 210.22675790778925, \"Power\": 210.22675790778925, \"i_spike\": 84.5, \"isi\": 0.041448783649683865, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1236488593840726, \"Firing rate\": 132.93791388973483, \"Power\": 132.93791388973483, \"i_spike\": 73.5, \"isi\": 0.04771964422986316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9611984491654064, \"Firing rate\": 91.45310373895767, \"Power\": 91.45310373895767, \"i_spike\": 70.5, \"isi\": 0.04936860543367102, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.0824773391122404, \"Firing rate\": 120.91420899286925, \"Power\": 120.91420899286925, \"i_spike\": 88.0, \"isi\": 0.03935522162784246, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9787501002284225, \"Firing rate\": 95.22480680598018, \"Power\": 95.22480680598018, \"i_spike\": 75.0, \"isi\": 0.045602480439414186, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1685898325916213, \"Firing rate\": 147.43134670286034, \"Power\": 147.43134670286034, \"i_spike\": 80.0, \"isi\": 0.0428366177384345, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.230731641001414, \"Firing rate\": 170.11070364760798, \"Power\": 170.11070364760798, \"i_spike\": 86.0, \"isi\": 0.04069000316608182, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.7109408735479223, \"Firing rate\": 513.9736725480508, \"Power\": 513.9736725480508, \"i_spike\": 90.5, \"isi\": 0.03808087796581317, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.8904891156107295, \"Firing rate\": 777.121842141343, \"Power\": 777.121842141343, \"i_spike\": 67.5, \"isi\": 0.05050650450585472, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.3884444205618465, \"Firing rate\": 244.59322344535366, \"Power\": 244.59322344535366, \"i_spike\": 75.5, \"isi\": 0.046160864179237364, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.215221869412756, \"Firing rate\": 164.14281206772014, \"Power\": 164.14281206772014, \"i_spike\": 76.0, \"isi\": 0.045973777674205345, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.1044452923402397, \"Firing rate\": 127.18775228011826, \"Power\": 127.18775228011826, \"i_spike\": 74.5, \"isi\": 0.046825315835458, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.304794192932069, \"Firing rate\": 201.74101101002248, \"Power\": 201.74101101002248, \"i_spike\": 84.5, \"isi\": 0.0415838404784538, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 1.9519897390823953, \"Firing rate\": 89.53436113421678, \"Power\": 89.53436113421678, \"i_spike\": 73.0, \"isi\": 0.04637231437529422, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"2\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes2\", \"Log power\": 2.050715177785326, \"Firing rate\": 112.38676690257596, \"Power\": 112.38676690257596, \"i_spike\": 72.5, \"isi\": 0.047898939712791556, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.093906240936936, \"Firing rate\": 124.13842784179043, \"Power\": 124.13842784179043, \"i_spike\": 77.0, \"isi\": 0.04521406966614064, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.142532137492843, \"Firing rate\": 138.84560509200531, \"Power\": 138.84560509200531, \"i_spike\": 85.5, \"isi\": 0.04088215523965275, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1247106556001505, \"Firing rate\": 133.26332826018398, \"Power\": 133.26332826018398, \"i_spike\": 94.0, \"isi\": 0.03699718718109058, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0404961635875494, \"Firing rate\": 109.77315932365002, \"Power\": 109.77315932365002, \"i_spike\": 84.5, \"isi\": 0.040822879176668145, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2076231068258, \"Firing rate\": 161.29581780251291, \"Power\": 161.29581780251291, \"i_spike\": 77.0, \"isi\": 0.04556164109048245, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.0158640710626763, \"Firing rate\": 103.72037327450805, \"Power\": 103.72037327450805, \"i_spike\": 70.5, \"isi\": 0.04900422553915958, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1880248824801893, \"Firing rate\": 154.1788785708863, \"Power\": 154.1788785708863, \"i_spike\": 87.5, \"isi\": 0.039435886208280056, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9744105165726646, \"Firing rate\": 94.27803379629712, \"Power\": 94.27803379629712, \"i_spike\": 84.5, \"isi\": 0.04146392755918885, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 3.913843764110594, \"Firing rate\": 8200.564788680073, \"Power\": 8200.564788680073, \"i_spike\": 76.5, \"isi\": 0.04556363424648217, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1399954218244273, \"Firing rate\": 138.0369713167223, \"Power\": 138.0369713167223, \"i_spike\": 77.5, \"isi\": 0.0453981706218095, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9566148125838072, \"Firing rate\": 90.49296385155998, \"Power\": 90.49296385155998, \"i_spike\": 85.0, \"isi\": 0.03927323815030475, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2520245491348896, \"Firing rate\": 178.65885615461892, \"Power\": 178.65885615461892, \"i_spike\": 85.0, \"isi\": 0.040967992817435184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1754321193760866, \"Firing rate\": 149.77251389430003, \"Power\": 149.77251389430003, \"i_spike\": 91.5, \"isi\": 0.03836696480836998, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.635716855961742, \"Firing rate\": 432.2319398170039, \"Power\": 432.2319398170039, \"i_spike\": 96.5, \"isi\": 0.03578166736861596, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2160850620865733, \"Firing rate\": 164.46938258310612, \"Power\": 164.46938258310612, \"i_spike\": 80.0, \"isi\": 0.043473098367445215, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.1205612291989038, \"Firing rate\": 131.9961393928132, \"Power\": 131.9961393928132, \"i_spike\": 75.5, \"isi\": 0.04626035487513255, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.024827292545692, \"Firing rate\": 105.88325716711356, \"Power\": 105.88325716711356, \"i_spike\": 80.5, \"isi\": 0.04253930743384717, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.074114281950763, \"Firing rate\": 118.60808170570037, \"Power\": 118.60808170570037, \"i_spike\": 67.0, \"isi\": 0.051334204579878646, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2811373940485504, \"Firing rate\": 191.04575581686126, \"Power\": 191.04575581686126, \"i_spike\": 74.5, \"isi\": 0.046987279420234215, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.014403068402744, \"Firing rate\": 103.37203558262294, \"Power\": 103.37203558262294, \"i_spike\": 82.5, \"isi\": 0.04146065949524595, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.108863671481811, \"Firing rate\": 128.4883261479434, \"Power\": 128.4883261479434, \"i_spike\": 87.5, \"isi\": 0.03907275494403815, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.658304695266665, \"Firing rate\": 455.30738576183563, \"Power\": 455.30738576183563, \"i_spike\": 93.5, \"isi\": 0.036909663672368385, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.2071328830952694, \"Firing rate\": 161.11385272898417, \"Power\": 161.11385272898417, \"i_spike\": 90.0, \"isi\": 0.03900063452819159, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.162120505142531, \"Firing rate\": 145.25145957605932, \"Power\": 145.25145957605932, \"i_spike\": 85.5, \"isi\": 0.0400904776550323, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 1.9709911192109881, \"Firing rate\": 93.53865464453958, \"Power\": 93.53865464453958, \"i_spike\": 75.0, \"isi\": 0.045538771732070805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.134880880431313, \"Firing rate\": 136.42089060349338, \"Power\": 136.42089060349338, \"i_spike\": 88.5, \"isi\": 0.03943188805380755, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.066832430618179, \"Firing rate\": 116.63594988602028, \"Power\": 116.63594988602028, \"i_spike\": 70.5, \"isi\": 0.048970343212981035, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.3793806836767333, \"Firing rate\": 239.5414552752351, \"Power\": 239.5414552752351, \"i_spike\": 82.5, \"isi\": 0.042043561438028454, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.399500106264406, \"Firing rate\": 250.89967933737773, \"Power\": 250.89967933737773, \"i_spike\": 75.5, \"isi\": 0.04561264334500348, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"3\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes3\", \"Log power\": 2.220242199517701, \"Firing rate\": 166.0512692284522, \"Power\": 166.0512692284522, \"i_spike\": 77.5, \"isi\": 0.04518223580077409, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3997220560187014, \"Firing rate\": 251.02793644541697, \"Power\": 251.02793644541697, \"i_spike\": 92.0, \"isi\": 0.037630914484962856, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.166020646368421, \"Firing rate\": 146.56175147859375, \"Power\": 146.56175147859375, \"i_spike\": 91.0, \"isi\": 0.03827176241185468, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.185888096679604, \"Firing rate\": 153.4221613710901, \"Power\": 153.4221613710901, \"i_spike\": 92.0, \"isi\": 0.03761591240242529, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.4587317399206245, \"Firing rate\": 287.562161854551, \"Power\": 287.562161854551, \"i_spike\": 91.5, \"isi\": 0.03834390692603616, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.212868070184563, \"Firing rate\": 163.25559353268687, \"Power\": 163.25559353268687, \"i_spike\": 92.0, \"isi\": 0.03802455357122872, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2357931191352933, \"Firing rate\": 172.10485396344228, \"Power\": 172.10485396344228, \"i_spike\": 79.0, \"isi\": 0.04382598137502598, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3035618471296804, \"Firing rate\": 201.16936596348194, \"Power\": 201.16936596348194, \"i_spike\": 109.5, \"isi\": 0.03202543684399708, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.8017110410666857, \"Firing rate\": 633.4481047134145, \"Power\": 633.4481047134145, \"i_spike\": 98.0, \"isi\": 0.03550739167328109, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1697988740587917, \"Firing rate\": 147.8423557471093, \"Power\": 147.8423557471093, \"i_spike\": 88.5, \"isi\": 0.03925960981462805, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.6760870929370943, \"Firing rate\": 474.3370987623261, \"Power\": 474.3370987623261, \"i_spike\": 87.5, \"isi\": 0.039431239454240596, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.433730632307909, \"Firing rate\": 271.47549414255656, \"Power\": 271.47549414255656, \"i_spike\": 96.5, \"isi\": 0.0363181558103682, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.063446911413506, \"Firing rate\": 115.73025536377592, \"Power\": 115.73025536377592, \"i_spike\": 79.0, \"isi\": 0.044476460189586564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.175425654268593, \"Firing rate\": 149.77028432833717, \"Power\": 149.77028432833717, \"i_spike\": 80.5, \"isi\": 0.04299945260731721, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3612576848505684, \"Firing rate\": 229.75114521901307, \"Power\": 229.75114521901307, \"i_spike\": 77.0, \"isi\": 0.04469056636440316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.147995753593227, \"Firing rate\": 140.60337762680615, \"Power\": 140.60337762680615, \"i_spike\": 87.5, \"isi\": 0.03976844291136797, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0929257700333896, \"Firing rate\": 123.85848685027362, \"Power\": 123.85848685027362, \"i_spike\": 94.0, \"isi\": 0.03657174288555396, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.10475158728818, \"Firing rate\": 127.27748564862868, \"Power\": 127.27748564862868, \"i_spike\": 98.5, \"isi\": 0.03552973340735749, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2328647390747323, \"Firing rate\": 170.94828141071517, \"Power\": 170.94828141071517, \"i_spike\": 82.5, \"isi\": 0.04166360369234807, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.1354623163537503, \"Firing rate\": 136.6036539827589, \"Power\": 136.6036539827589, \"i_spike\": 84.5, \"isi\": 0.040640693096263156, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0464608797536576, \"Firing rate\": 111.29121397251097, \"Power\": 111.29121397251097, \"i_spike\": 89.5, \"isi\": 0.03879007896451536, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.3355625956917723, \"Firing rate\": 216.5521977627491, \"Power\": 216.5521977627491, \"i_spike\": 98.0, \"isi\": 0.035422439393446775, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2161677848183947, \"Firing rate\": 164.50071305822243, \"Power\": 164.50071305822243, \"i_spike\": 85.0, \"isi\": 0.04048577743104151, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.2837266052282277, \"Firing rate\": 192.18814953172904, \"Power\": 192.18814953172904, \"i_spike\": 99.5, \"isi\": 0.03520251098408982, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.161668219920541, \"Firing rate\": 145.10026978437168, \"Power\": 145.10026978437168, \"i_spike\": 90.0, \"isi\": 0.038734070453864254, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.282132072264165, \"Firing rate\": 191.4838153372827, \"Power\": 191.4838153372827, \"i_spike\": 78.0, \"isi\": 0.043996610728127564, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.0841752044242403, \"Firing rate\": 121.38784583039707, \"Power\": 121.38784583039707, \"i_spike\": 100.0, \"isi\": 0.03461991962811, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.447465040329036, \"Firing rate\": 280.1980059869962, \"Power\": 280.1980059869962, \"i_spike\": 79.0, \"isi\": 0.04452724337396078, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.081771364126096, \"Firing rate\": 120.71781445649961, \"Power\": 120.71781445649961, \"i_spike\": 91.0, \"isi\": 0.03856750376815478, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 2.9391326595223966, \"Firing rate\": 869.2259023424945, \"Power\": 869.2259023424945, \"i_spike\": 79.0, \"isi\": 0.04416616879896912, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"4\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes4\", \"Log power\": 1.8602028751437854, \"Firing rate\": 72.47744501747489, \"Power\": 72.47744501747489, \"i_spike\": 83.0, \"isi\": 0.04119329035591721, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1734123362153537, \"Firing rate\": 149.07758070284467, \"Power\": 149.07758070284467, \"i_spike\": 81.5, \"isi\": 0.0428418950531146, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.192601337300343, \"Firing rate\": 155.812156100815, \"Power\": 155.812156100815, \"i_spike\": 103.0, \"isi\": 0.03371726705897087, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.325538741593283, \"Firing rate\": 211.6112446357301, \"Power\": 211.6112446357301, \"i_spike\": 106.5, \"isi\": 0.03256875829829079, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0351612273023045, \"Firing rate\": 108.43293852986389, \"Power\": 108.43293852986389, \"i_spike\": 92.5, \"isi\": 0.03785767511850996, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3612887627039565, \"Firing rate\": 229.76758666182133, \"Power\": 229.76758666182133, \"i_spike\": 110.5, \"isi\": 0.0316478026663995, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.486602812028755, \"Firing rate\": 306.62164695003077, \"Power\": 306.62164695003077, \"i_spike\": 102.0, \"isi\": 0.03428746701402582, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.26907338816312, \"Firing rate\": 185.81184180415744, \"Power\": 185.81184180415744, \"i_spike\": 108.0, \"isi\": 0.03182822108027605, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2400289413579997, \"Firing rate\": 173.79166395502384, \"Power\": 173.79166395502384, \"i_spike\": 104.0, \"isi\": 0.03361245677188138, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.133061627118738, \"Firing rate\": 135.8506207230094, \"Power\": 135.8506207230094, \"i_spike\": 83.0, \"isi\": 0.04226663021993772, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.055873381143031, \"Firing rate\": 113.72956581458753, \"Power\": 113.72956581458753, \"i_spike\": 96.5, \"isi\": 0.03623434325043876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.077393494053492, \"Firing rate\": 119.50704118553142, \"Power\": 119.50704118553142, \"i_spike\": 86.0, \"isi\": 0.03999884944106042, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.7032986753124226, \"Firing rate\": 505.00848528812185, \"Power\": 505.00848528812185, \"i_spike\": 94.5, \"isi\": 0.03642922221630557, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2487291617775735, \"Firing rate\": 177.30833914875691, \"Power\": 177.30833914875691, \"i_spike\": 95.0, \"isi\": 0.035509978483580056, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.6190312582185733, \"Firing rate\": 415.9405466161257, \"Power\": 415.9405466161257, \"i_spike\": 92.5, \"isi\": 0.03739794009579709, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.2214636345147007, \"Firing rate\": 166.51893879392634, \"Power\": 166.51893879392634, \"i_spike\": 104.5, \"isi\": 0.03334968571838423, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 3.050033014448482, \"Firing rate\": 1122.1037517902018, \"Power\": 1122.1037517902018, \"i_spike\": 109.0, \"isi\": 0.03174363047623115, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0201521306738686, \"Firing rate\": 104.7495414963806, \"Power\": 104.7495414963806, \"i_spike\": 84.0, \"isi\": 0.04150443974238124, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.394368017909442, \"Firing rate\": 247.95222963713232, \"Power\": 247.95222963713232, \"i_spike\": 97.5, \"isi\": 0.034832136270722715, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.329502121112529, \"Firing rate\": 213.551251595498, \"Power\": 213.551251595498, \"i_spike\": 119.5, \"isi\": 0.02914255148960452, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.296426000518237, \"Firing rate\": 197.89098058624842, \"Power\": 197.89098058624842, \"i_spike\": 100.5, \"isi\": 0.03453794209724264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9526063135638236, \"Firing rate\": 89.66156470356117, \"Power\": 89.66156470356117, \"i_spike\": 87.0, \"isi\": 0.0403252649629643, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1801699394018295, \"Firing rate\": 151.41536207419279, \"Power\": 151.41536207419279, \"i_spike\": 95.0, \"isi\": 0.0369374859002085, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 1.9603011698286221, \"Firing rate\": 91.26435100880892, \"Power\": 91.26435100880892, \"i_spike\": 100.5, \"isi\": 0.03470962985025618, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.1497807834136973, \"Firing rate\": 141.18247252479557, \"Power\": 141.18247252479557, \"i_spike\": 97.0, \"isi\": 0.03544340361561801, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.149622075943538, \"Firing rate\": 141.13088858728008, \"Power\": 141.13088858728008, \"i_spike\": 98.5, \"isi\": 0.03458549884764996, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.056159126623185, \"Firing rate\": 113.80441917809635, \"Power\": 113.80441917809635, \"i_spike\": 87.0, \"isi\": 0.03968042681843487, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.3917479076029613, \"Firing rate\": 246.46083050660826, \"Power\": 246.46083050660826, \"i_spike\": 98.5, \"isi\": 0.035535360449709036, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.0750924013179355, \"Firing rate\": 118.87551223280595, \"Power\": 118.87551223280595, \"i_spike\": 94.0, \"isi\": 0.03719199644955143, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.489337914838964, \"Firing rate\": 308.5587843479223, \"Power\": 308.5587843479223, \"i_spike\": 95.5, \"isi\": 0.03556131746210524, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"5\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes5\", \"Log power\": 2.4520230739574873, \"Firing rate\": 283.154243094607, \"Power\": 283.154243094607, \"i_spike\": 107.0, \"isi\": 0.032710924682864184, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.323245560174936, \"Firing rate\": 210.49683012562227, \"Power\": 210.49683012562227, \"i_spike\": 107.5, \"isi\": 0.03260971008319308, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4551248825615755, \"Firing rate\": 285.183820345654, \"Power\": 285.183820345654, \"i_spike\": 119.5, \"isi\": 0.029121401254440946, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2034473494582008, \"Firing rate\": 159.75238457442458, \"Power\": 159.75238457442458, \"i_spike\": 117.5, \"isi\": 0.02942985917936488, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.185090643987662, \"Firing rate\": 153.1407056710173, \"Power\": 153.1407056710173, \"i_spike\": 107.5, \"isi\": 0.03182653781887098, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3319515266612205, \"Firing rate\": 214.7590759585309, \"Power\": 214.7590759585309, \"i_spike\": 125.0, \"isi\": 0.028084978019438673, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6162367962967754, \"Firing rate\": 413.2727749153624, \"Power\": 413.2727749153624, \"i_spike\": 106.5, \"isi\": 0.032651038144998264, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.251599839982757, \"Firing rate\": 178.48422588668325, \"Power\": 178.48422588668325, \"i_spike\": 112.0, \"isi\": 0.031077478691086027, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.700871783939369, \"Firing rate\": 502.194305618395, \"Power\": 502.194305618395, \"i_spike\": 94.0, \"isi\": 0.036901644723313094, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.314948450805621, \"Firing rate\": 206.5135017156736, \"Power\": 206.5135017156736, \"i_spike\": 93.5, \"isi\": 0.03744836002524842, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6205392303439177, \"Firing rate\": 417.3872998602738, \"Power\": 417.3872998602738, \"i_spike\": 112.5, \"isi\": 0.030901272636151618, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5103170415704716, \"Firing rate\": 323.82997146198255, \"Power\": 323.82997146198255, \"i_spike\": 118.5, \"isi\": 0.0292124077372491, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.267328656385887, \"Firing rate\": 185.06685998516417, \"Power\": 185.06685998516417, \"i_spike\": 112.0, \"isi\": 0.030900503373377113, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3735439867744246, \"Firing rate\": 236.34367636856805, \"Power\": 236.34367636856805, \"i_spike\": 111.5, \"isi\": 0.031086261056407043, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3925644433143702, \"Firing rate\": 246.9246479862117, \"Power\": 246.9246479862117, \"i_spike\": 116.5, \"isi\": 0.0291953589973033, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.561842054638256, \"Firing rate\": 364.6213163680733, \"Power\": 364.6213163680733, \"i_spike\": 111.5, \"isi\": 0.031029868021617713, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.171212511252901, \"Firing rate\": 148.32436961836746, \"Power\": 148.32436961836746, \"i_spike\": 98.0, \"isi\": 0.03548246558301557, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.305560627357594, \"Firing rate\": 202.09735394991617, \"Power\": 202.09735394991617, \"i_spike\": 116.5, \"isi\": 0.029539429675363767, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.230937526831537, \"Firing rate\": 170.19136708674088, \"Power\": 170.19136708674088, \"i_spike\": 109.5, \"isi\": 0.031509671304326574, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.8998022408045885, \"Firing rate\": 793.9666138437617, \"Power\": 793.9666138437617, \"i_spike\": 117.0, \"isi\": 0.029395611103945375, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.318691352753477, \"Firing rate\": 208.3009989753317, \"Power\": 208.3009989753317, \"i_spike\": 114.0, \"isi\": 0.03080051727849002, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.5660625459247224, \"Firing rate\": 368.181994406344, \"Power\": 368.181994406344, \"i_spike\": 110.5, \"isi\": 0.03146794625834939, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.09200788071158, \"Firing rate\": 123.59698611612541, \"Power\": 123.59698611612541, \"i_spike\": 105.5, \"isi\": 0.03222740436284654, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3257979747918998, \"Firing rate\": 211.73759446862695, \"Power\": 211.73759446862695, \"i_spike\": 99.0, \"isi\": 0.035110212287434966, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.6983799828455997, \"Firing rate\": 499.3211738782113, \"Power\": 499.3211738782113, \"i_spike\": 100.5, \"isi\": 0.03493647252317627, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.295038880371647, \"Firing rate\": 197.25993258831056, \"Power\": 197.25993258831056, \"i_spike\": 99.5, \"isi\": 0.034805791974127157, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.4189777301058197, \"Firing rate\": 262.40839812996177, \"Power\": 262.40839812996177, \"i_spike\": 114.0, \"isi\": 0.030289604306854862, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.108818343863044, \"Firing rate\": 128.47491643129774, \"Power\": 128.47491643129774, \"i_spike\": 105.0, \"isi\": 0.033402650086276076, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.3301618907903223, \"Firing rate\": 213.8759200460872, \"Power\": 213.8759200460872, \"i_spike\": 102.0, \"isi\": 0.033515540373164496, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.2662952548825976, \"Firing rate\": 184.62701784490469, \"Power\": 184.62701784490469, \"i_spike\": 99.5, \"isi\": 0.03522950669230892, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"6\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes6\", \"Log power\": 2.431293700022412, \"Firing rate\": 269.9564447816099, \"Power\": 269.9564447816099, \"i_spike\": 112.5, \"isi\": 0.031214818356640563, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 0, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3379956540094025, \"Firing rate\": 217.76879800918366, \"Power\": 217.76879800918366, \"i_spike\": 128.0, \"isi\": 0.027142001158740867, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 1, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 4.268793452708704, \"Firing rate\": 18569.21106902568, \"Power\": 18569.21106902568, \"i_spike\": 112.5, \"isi\": 0.030884711280865364, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 2, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.470335706667271, \"Firing rate\": 295.3491373163173, \"Power\": 295.3491373163173, \"i_spike\": 118.5, \"isi\": 0.029429433800978892, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 3, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2298279031444963, \"Firing rate\": 169.7570826751943, \"Power\": 169.7570826751943, \"i_spike\": 115.5, \"isi\": 0.030066265039225337, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 4, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.079781857998895, \"Firing rate\": 120.16607002272158, \"Power\": 120.16607002272158, \"i_spike\": 112.5, \"isi\": 0.031040291113719316, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 5, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3243380859972738, \"Firing rate\": 211.02702965366592, \"Power\": 211.02702965366592, \"i_spike\": 115.5, \"isi\": 0.03017297418481671, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 6, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.376992751237567, \"Firing rate\": 238.22797066527903, \"Power\": 238.22797066527903, \"i_spike\": 110.0, \"isi\": 0.03125175833885984, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.530486613796888, \"Firing rate\": 339.22403352142646, \"Power\": 339.22403352142646, \"i_spike\": 108.5, \"isi\": 0.03222598156798059, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 8, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4983008808245897, \"Firing rate\": 314.99298413824465, \"Power\": 314.99298413824465, \"i_spike\": 116.5, \"isi\": 0.029967692171019168, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 9, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.482166228126963, \"Firing rate\": 303.5052641678235, \"Power\": 303.5052641678235, \"i_spike\": 124.5, \"isi\": 0.02742142830301335, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 10, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6952270146103454, \"Firing rate\": 495.70924045465966, \"Power\": 495.70924045465966, \"i_spike\": 116.5, \"isi\": 0.029805997031659384, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 11, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 1.969829747877291, \"Firing rate\": 93.288851814792, \"Power\": 93.288851814792, \"i_spike\": 104.5, \"isi\": 0.033232072449794876, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 12, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3040227572766634, \"Firing rate\": 201.3829772917563, \"Power\": 201.3829772917563, \"i_spike\": 118.5, \"isi\": 0.02930928089506225, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 13, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2482213585722888, \"Firing rate\": 177.10114074206854, \"Power\": 177.10114074206854, \"i_spike\": 118.5, \"isi\": 0.02923254019041047, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 14, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.302306969151288, \"Firing rate\": 200.58893343119396, \"Power\": 200.58893343119396, \"i_spike\": 114.0, \"isi\": 0.030554998388585986, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 15, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1470214089632194, \"Firing rate\": 140.28828593141267, \"Power\": 140.28828593141267, \"i_spike\": 123.0, \"isi\": 0.02824600472582251, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 16, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1317778042739737, \"Firing rate\": 135.44962414921912, \"Power\": 135.44962414921912, \"i_spike\": 107.5, \"isi\": 0.03260242125359381, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 17, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.861629232615016, \"Firing rate\": 727.1587469920275, \"Power\": 727.1587469920275, \"i_spike\": 121.5, \"isi\": 0.02876842284627423, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 18, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.309175796871508, \"Firing rate\": 203.7866813288123, \"Power\": 203.7866813288123, \"i_spike\": 127.0, \"isi\": 0.02726151253501496, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 19, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.1426446687258776, \"Firing rate\": 138.88158641854218, \"Power\": 138.88158641854218, \"i_spike\": 120.0, \"isi\": 0.02911404261537866, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 20, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4489418426509477, \"Firing rate\": 281.15243076571574, \"Power\": 281.15243076571574, \"i_spike\": 128.5, \"isi\": 0.026789992139581283, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 21, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.412848701632391, \"Firing rate\": 258.73113973987586, \"Power\": 258.73113973987586, \"i_spike\": 124.0, \"isi\": 0.028201124990781163, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 22, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.710877629385823, \"Firing rate\": 513.8988305482127, \"Power\": 513.8988305482127, \"i_spike\": 119.0, \"isi\": 0.0293764992264836, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 23, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.991538408306236, \"Firing rate\": 980.7050424652082, \"Power\": 980.7050424652082, \"i_spike\": 135.0, \"isi\": 0.025953587990479317, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 24, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.2762121037042795, \"Firing rate\": 188.89136444020025, \"Power\": 188.89136444020025, \"i_spike\": 122.0, \"isi\": 0.028669385615676706, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 25, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.7177018467167304, \"Firing rate\": 522.0376749188929, \"Power\": 522.0376749188929, \"i_spike\": 138.0, \"isi\": 0.02496409561586277, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 26, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.3914116825786387, \"Firing rate\": 246.27009764338933, \"Power\": 246.27009764338933, \"i_spike\": 110.5, \"isi\": 0.0316618510656651, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 27, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.6892037162497906, \"Firing rate\": 488.8816272272226, \"Power\": 488.8816272272226, \"i_spike\": 131.5, \"isi\": 0.02658745064897301, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 28, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.4434824501248773, \"Firing rate\": 277.64026491830793, \"Power\": 277.64026491830793, \"i_spike\": 120.0, \"isi\": 0.0290789856927443, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}, {\"stim\": 1, \"mouse\": \"7\", \"i_trial\": 29, \"neuron_x_mouse\": \"m1bayes7\", \"Log power\": 2.238506636309727, \"Firing rate\": 173.18354941508804, \"Power\": 173.18354941508804, \"i_spike\": 121.0, \"isi\": 0.028971993333475, \"combined_condition\": 1.0, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null}], \"data-7b75ead138b5701714ef21e640a42f5e\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 237.74384705687086, \"mu_intercept_per_group higher interval\": 1.0736088752746582, \"mu_intercept_per_group lower interval\": -19.911861419677734, \"mu_intercept_per_group center interval\": -7.5485639572143555, \"mu_intercept_per_group higher interval75\": -2.3359830379486084, \"mu_intercept_per_group lower interval75\": -15.0798978805542, \"sigma_intercept_per_group higher interval\": 0.031264778226614, \"sigma_intercept_per_group lower interval\": 0.004640578757971525, \"sigma_intercept_per_group center interval\": 0.017955578863620758, \"sigma_obs higher interval\": 0.004585281014442444, \"sigma_obs lower interval\": 0.0035526063293218613, \"sigma_obs center interval\": 0.00401670066639781, \"higher interval\": 0.3416309952735901, \"lower interval\": 0.06997033208608627, \"center interval\": 0.20574018359184265, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 166.46023493627612, \"mu_intercept_per_group higher interval\": 4.521572113037109, \"mu_intercept_per_group lower interval\": -16.98981285095215, \"mu_intercept_per_group center interval\": -5.73008918762207, \"mu_intercept_per_group higher interval75\": -1.303446888923645, \"mu_intercept_per_group lower interval75\": -12.848074913024902, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": 102.02669332812849, \"mu_intercept_per_group higher interval\": 2.897442579269409, \"mu_intercept_per_group lower interval\": -18.406869888305664, \"mu_intercept_per_group center interval\": -7.657114028930664, \"mu_intercept_per_group higher interval75\": -1.417212963104248, \"mu_intercept_per_group lower interval75\": -12.833268165588379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": 273.27981160465947, \"mu_intercept_per_group higher interval\": 10.665518760681152, \"mu_intercept_per_group lower interval\": -13.32564640045166, \"mu_intercept_per_group center interval\": -1.9964020252227783, \"mu_intercept_per_group higher interval75\": 3.5060598850250244, \"mu_intercept_per_group lower interval75\": -8.762786865234375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 25.7188242111219, \"mu_intercept_per_group higher interval\": 9.48569107055664, \"mu_intercept_per_group lower interval\": -12.494241714477539, \"mu_intercept_per_group center interval\": -1.488588571548462, \"mu_intercept_per_group higher interval75\": 5.5281548500061035, \"mu_intercept_per_group lower interval75\": -7.519647598266602, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -69.5886318431294, \"mu_intercept_per_group higher interval\": 12.668036460876465, \"mu_intercept_per_group lower interval\": -10.468371391296387, \"mu_intercept_per_group center interval\": 1.7557737827301025, \"mu_intercept_per_group higher interval75\": 8.505128860473633, \"mu_intercept_per_group lower interval75\": -4.7760329246521, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -79.3676220517491, \"mu_intercept_per_group higher interval\": 21.381479263305664, \"mu_intercept_per_group lower interval\": -1.037280559539795, \"mu_intercept_per_group center interval\": 9.134395599365234, \"mu_intercept_per_group higher interval75\": 16.458255767822266, \"mu_intercept_per_group lower interval75\": 3.5455243587493896, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": 644.1470615759551, \"mu_intercept_per_group higher interval\": 23.390565872192383, \"mu_intercept_per_group lower interval\": 0.8245984315872192, \"mu_intercept_per_group center interval\": 10.212915420532227, \"mu_intercept_per_group higher interval75\": 18.52081871032715, \"mu_intercept_per_group lower interval75\": 5.602456092834473, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-335274e0c5848c5eb146b4572e80f925\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -5.040781497955322, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -3.2319483757019043, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -14.338045120239258, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -9.673306465148926, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -4.925235748291016, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -12.546177864074707, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -11.706274032592773, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -14.756869316101074, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -12.631892204284668, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -16.163843154907227, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -4.770541191101074, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -6.212677478790283, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -9.943546295166016, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -8.178187370300293, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -8.886363983154297, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.480189323425293, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -10.987234115600586, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -10.944351196289062, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -11.506084442138672, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -1.8251782655715942, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -12.498072624206543, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -12.514010429382324, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -17.6185245513916, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -5.716065406799316, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -12.775249481201172, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -3.373499870300293, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -10.66567611694336, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -3.174480676651001, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -6.656539440155029, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -5.057694435119629, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -6.132038593292236, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -6.260168075561523, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -6.267385959625244, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -18.276689529418945, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -14.591009140014648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -6.426440715789795, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -14.020872116088867, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -8.92737102508545, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -8.799839973449707, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -10.442145347595215, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -11.592804908752441, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -1.3473926782608032, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -4.051822662353516, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -5.211493015289307, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -4.1107282638549805, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -2.415545701980591, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -16.093782424926758, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -17.072484970092773, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -20.167388916015625, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -23.8348388671875, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": -7.981138229370117, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -0.04728800058364868, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -8.871659278869629, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -9.35479736328125, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -3.8808343410491943, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -6.361900329589844, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -7.999002456665039, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -5.894481658935547, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -13.972681045532227, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -13.822797775268555, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -3.046886682510376, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -16.953060150146484, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -3.695838451385498, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -14.566791534423828, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -13.50625991821289, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -18.355134963989258, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -2.4528801441192627, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -7.53265905380249, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -6.505617618560791, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -12.704715728759766, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -1.9597692489624023, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -12.978065490722656, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -8.506797790527344, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -5.759369850158691, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": -25.789400100708008, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -22.311338424682617, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -8.781279563903809, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -13.314993858337402, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -1.3805243968963623, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -1.0229171514511108, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -7.584434986114502, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -7.566932678222656, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -7.094293117523193, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -11.389894485473633, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -8.709399223327637, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -10.357560157775879, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -16.34046173095703, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": 0.6019138693809509, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -1.9741706848144531, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -7.676919937133789, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -11.231236457824707, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -1.5288472175598145, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -16.779338836669922, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -4.3895158767700195, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -18.84963035583496, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -17.951358795166016, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -5.909987926483154, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -12.995099067687988, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -14.546140670776367, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -12.310595512390137, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -12.568388938903809, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -11.030439376831055, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -11.577783584594727, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -19.112316131591797, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -12.155937194824219, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -13.99992561340332, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -7.133065223693848, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -11.40817642211914, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -7.663388252258301, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -7.15134859085083, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -11.182429313659668, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -6.685650825500488, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -13.261324882507324, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -8.376654624938965, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -8.474446296691895, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -11.404654502868652, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -15.137195587158203, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -2.7283873558044434, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -5.247433662414551, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -9.17174243927002, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -3.0005855560302734, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -4.599752902984619, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -9.993454933166504, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -8.326324462890625, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -6.7738237380981445, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -18.34370994567871, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -16.528854370117188, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -6.6535491943359375, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -11.81106185913086, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -16.69459342956543, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -14.064314842224121, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -9.772653579711914, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -11.23830509185791, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -4.780694961547852, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -14.838922500610352, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -5.256370544433594, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -9.29879093170166, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -13.37845230102539, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -10.741788864135742, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -7.814037799835205, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -8.544958114624023, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -5.639056205749512, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -2.9378082752227783, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -8.153556823730469, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -14.391047477722168, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -4.369668960571289, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -2.46347713470459, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -3.629565954208374, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -10.348349571228027, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -4.948489665985107, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -12.884615898132324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -5.245946407318115, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -6.670903205871582, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -8.891148567199707, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -9.279622077941895, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -8.383540153503418, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -4.247647762298584, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -12.485112190246582, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -5.546526908874512, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -10.073062896728516, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -10.178902626037598, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -13.806653022766113, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -13.627968788146973, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -15.624517440795898, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -17.04638671875, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -8.39765453338623, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -9.610179901123047, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -12.103351593017578, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -19.356971740722656, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -2.4488518238067627, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -17.13677215576172, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -5.408355236053467, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -7.60662317276001, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": 0.21036642789840698, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -4.18886661529541, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -1.2615326642990112, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -6.848775863647461, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -9.153616905212402, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -2.357057571411133, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -7.682571887969971, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -3.3885879516601562, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -11.814712524414062, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -6.619076251983643, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -12.91315746307373, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -8.867708206176758, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -14.581746101379395, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -19.71653175354004, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -19.991769790649414, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -21.214252471923828, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -6.644197940826416, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -10.407630920410156, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -11.46703052520752, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -8.729238510131836, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -7.291738510131836, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -8.144486427307129, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.621789932250977, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -9.452020645141602, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -2.7215309143066406, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -3.036237955093384, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -19.85153579711914, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -12.849891662597656, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -6.997928142547607, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -10.627803802490234, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -5.472050189971924, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -16.494998931884766, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -16.4442138671875, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -5.7470502853393555, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -8.932648658752441, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -8.577373504638672, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -8.965713500976562, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -11.161826133728027, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -7.89268684387207, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -7.564478397369385, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -13.452535629272461, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -14.08469295501709, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -2.954566717147827, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -11.441118240356445, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -6.81473970413208, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -2.3359830379486084, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -3.075653553009033, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -11.325859069824219, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -4.258692264556885, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -4.423980712890625, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -13.428261756896973, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -11.3971586227417, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -13.256096839904785, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.62111234664917, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -4.03687047958374, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -11.875662803649902, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -7.4272379875183105, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -7.029792308807373, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -9.917837142944336, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -6.4340691566467285, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -8.416629791259766, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -9.764811515808105, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -13.684724807739258, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -9.332736015319824, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -5.513200759887695, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -5.412356853485107, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -10.102581977844238, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -9.726181030273438, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -8.257014274597168, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -3.624953508377075, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -2.589315891265869, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -8.779748916625977, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -6.400252342224121, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -8.629778861999512, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -16.5101318359375, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -17.6689453125, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": -4.915207386016846, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -6.15136194229126, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -6.802655220031738, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -7.658843517303467, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -9.336639404296875, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -6.3743815422058105, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -3.255826711654663, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -12.883275985717773, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -16.258590698242188, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -16.643815994262695, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -5.674232482910156, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -10.518762588500977, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -11.083512306213379, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -5.980678081512451, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -2.541947364807129, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -20.78319549560547, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -3.921635150909424, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": 0.5861846804618835, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -11.339868545532227, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -0.389615923166275, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -12.612652778625488, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -10.362377166748047, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -1.3020634651184082, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -14.657515525817871, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.195693016052246, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -13.869643211364746, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -14.57094669342041, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -13.50912857055664, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -8.952861785888672, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -8.80617904663086, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -3.6185855865478516, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -10.87226390838623, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -12.242692947387695, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -15.20461368560791, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -9.234443664550781, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -7.426700592041016, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -13.220755577087402, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -5.277491569519043, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -8.162809371948242, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -7.106990337371826, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -8.721697807312012, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -10.575236320495605, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -9.488320350646973, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -6.3274407386779785, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -8.079594612121582, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -8.850040435791016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -4.494203090667725, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -8.342353820800781, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -7.779570579528809, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -5.749445915222168, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -3.8445205688476562, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -9.672994613647461, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -2.8184850215911865, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -5.3096466064453125, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -9.379035949707031, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -8.699469566345215, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -6.1675639152526855, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.189728736877441, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -5.6182026863098145, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -2.484952211380005, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -4.12829065322876, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -11.519996643066406, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -7.22760009765625, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -4.460574626922607, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -14.75634479522705, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -1.8370130062103271, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -4.823190212249756, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -17.70157814025879, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -17.373361587524414, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -18.10245132446289, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -3.457681655883789, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -8.75065803527832, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -16.165645599365234, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -22.6804141998291, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -19.911861419677734, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -22.61591148376465, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -11.622304916381836, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": 0.998124361038208, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -6.8948655128479, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -4.078651428222656, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -7.3026604652404785, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -11.44503116607666, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -17.5340576171875, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -16.409536361694336, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -5.208342552185059, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -10.778684616088867, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -17.12391471862793, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -15.53206729888916, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -24.478370666503906, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -3.444739818572998, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -8.01969051361084, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -6.329585552215576, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -4.347865581512451, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -12.938542366027832, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -9.006197929382324, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -5.012093544006348, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -4.965196132659912, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -15.606342315673828, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -5.539521217346191, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -5.314929962158203, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -1.2871633768081665, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -14.534015655517578, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -4.73247766494751, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -11.297335624694824, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": 0.9405475854873657, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.757895469665527, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -10.374063491821289, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -16.98774528503418, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -8.18375015258789, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -4.701827526092529, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -11.026098251342773, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -10.939376831054688, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -2.6122803688049316, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -12.174870491027832, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -6.430441856384277, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -10.59070873260498, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -3.260490655899048, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -3.310577154159546, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -11.701184272766113, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -16.167146682739258, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -6.8973283767700195, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -19.691875457763672, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -11.031414985656738, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -5.411973476409912, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -3.844919443130493, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -5.477871417999268, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -9.450149536132812, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -7.657480239868164, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -13.941293716430664, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -9.572578430175781, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -8.065054893493652, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -4.444667339324951, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -6.401512145996094, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -7.924699306488037, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": 0.7744003534317017, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -24.4804630279541, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -39.773441314697266, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -31.81466293334961, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -20.902446746826172, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -17.315820693969727, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": 5.48476505279541, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -1.5803248882293701, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -18.618637084960938, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -8.642467498779297, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -11.297926902770996, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -15.921405792236328, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -6.936874866485596, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -0.2094547003507614, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -18.638042449951172, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -14.544658660888672, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -12.04907512664795, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -5.024633407592773, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -3.489513635635376, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -9.497099876403809, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -8.240531921386719, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -6.346133232116699, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -14.385534286499023, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -12.13107681274414, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -10.018568992614746, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -5.1738667488098145, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -10.29282283782959, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -9.026412963867188, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -4.315159320831299, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -6.5509257316589355, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -19.04126739501953, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -16.34767723083496, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -2.5898938179016113, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -3.3687591552734375, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -7.322995662689209, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -2.7231345176696777, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -10.025606155395508, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -3.8277714252471924, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -14.222061157226562, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -7.5450663566589355, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -9.19723892211914, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -9.410855293273926, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -1.858840823173523, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -9.601522445678711, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -23.54803466796875, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -23.492151260375977, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -2.0137908458709717, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -7.213013648986816, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -5.775428295135498, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -5.777145862579346, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -17.992870330810547, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -19.222583770751953, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -3.606680393218994, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -7.077849388122559, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -7.946872234344482, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -7.342119216918945, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -7.215571880340576, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -9.698287010192871, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -11.335079193115234, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -5.650229454040527, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -6.336968898773193, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -3.8731679916381836, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -11.074392318725586, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -3.630917549133301, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -6.614351749420166, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -8.51510238647461, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -2.4186511039733887, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -1.1323734521865845, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -18.85658073425293, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -3.8716964721679688, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -9.455548286437988, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -13.154111862182617, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -2.69400691986084, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -16.04335594177246, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -15.140952110290527, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -16.074392318725586, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -10.598502159118652, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -4.471084117889404, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -9.135819435119629, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -6.191133499145508, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -0.926066517829895, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -12.166131973266602, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -12.361000061035156, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -16.498821258544922, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -17.714357376098633, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -15.189769744873047, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -18.966697692871094, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -10.010828018188477, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -9.98740291595459, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -5.75197172164917, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -15.284516334533691, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -5.489589214324951, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -12.943856239318848, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -0.22668716311454773, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -15.675498008728027, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -6.588681221008301, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -7.812132835388184, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -6.533406734466553, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -8.366008758544922, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -6.541745662689209, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -7.343019485473633, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -2.4424896240234375, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -23.04140281677246, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -0.7497562766075134, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -4.742270469665527, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": 1.0736088752746582, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": 0.024408448487520218, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -2.8643569946289062, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -8.307125091552734, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -8.772392272949219, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -0.5112401843070984, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -6.886197090148926, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -6.327877998352051, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -12.50365924835205, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -11.757549285888672, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -1.3050986528396606, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -13.721922874450684, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -12.205488204956055, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -15.0798978805542, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -3.8415820598602295, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -9.192111015319824, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -7.257448673248291, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -6.073168754577637, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -6.093765735626221, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -9.180815696716309, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -14.790719032287598, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -8.083637237548828, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -16.844039916992188, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -15.44870376586914, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -7.9280314445495605, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -15.37336254119873, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": 0.20836150646209717, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -9.434063911437988, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -10.677699089050293, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -13.1483154296875, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -8.331754684448242, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -11.413102149963379, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -10.736640930175781, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -20.958683013916016, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -3.8055968284606934, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -5.030653953552246, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -13.732660293579102, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -12.01431655883789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -14.626978874206543, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -14.44836711883545, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -11.47911548614502, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -15.735791206359863, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -13.227349281311035, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -3.8430216312408447, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -10.357236862182617, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -8.008966445922852, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -6.926792144775391, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -7.791112899780273, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -6.468642711639404, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -9.571223258972168, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -3.7362332344055176, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -10.967222213745117, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -18.106294631958008, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -16.127092361450195, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -10.687830924987793, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -8.566162109375, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -4.050730228424072, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": 1.3152552843093872, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -2.0139448642730713, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -4.341344833374023, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -8.37908935546875, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -22.976163864135742, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -10.430059432983398, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -14.850079536437988, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -20.197887420654297, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -6.68999719619751, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -2.815863847732544, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -17.887845993041992, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -3.541370153427124, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -3.542423963546753, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -6.5178399085998535, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -6.637992858886719, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": -1.2293953895568848, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -17.230424880981445, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -11.51131534576416, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -8.765068054199219, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -6.458959102630615, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -5.430912017822266, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -3.6724812984466553, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -3.493516206741333, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -11.444568634033203, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -9.342259407043457, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -9.024116516113281, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -7.584840297698975, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -19.061552047729492, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -10.222793579101562, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -14.651355743408203, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -14.484232902526855, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -0.38055333495140076, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": 2.191359043121338, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -16.867826461791992, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -5.231989860534668, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -4.299243927001953, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -1.6465952396392822, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -18.220346450805664, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -6.526581287384033, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -9.6726713180542, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -9.635215759277344, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -13.181056022644043, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -5.687668323516846, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -16.44668197631836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -3.8459317684173584, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -10.190849304199219, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -11.476523399353027, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -5.591184616088867, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -5.949356555938721, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -5.420851230621338, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -14.403029441833496, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -10.093840599060059, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -18.961095809936523, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -11.777244567871094, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -13.17252254486084, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -12.879655838012695, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": 0.7822245359420776, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -10.36086654663086, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -28.181034088134766, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": 0.6640376448631287, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -17.449878692626953, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -13.05380916595459, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": 0.5147354602813721, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -0.6536664962768555, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": 2.406078338623047, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": 6.2492570877075195, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -16.29853057861328, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -14.67895221710205, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -14.72924518585205, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -7.888645172119141, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -13.071282386779785, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -5.036900043487549, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -16.05565071105957, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -7.945497035980225, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -12.781723022460938, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -11.250772476196289, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -5.3124680519104, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -11.05871868133545, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -13.738811492919922, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -5.289099216461182, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -2.5719308853149414, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": 4.691713809967041, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": 1.5101555585861206, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -16.513256072998047, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": 4.7369537353515625, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -16.79252052307129, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -17.795873641967773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -17.840864181518555, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -11.204030990600586, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -11.924735069274902, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -19.330913543701172, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -21.98118782043457, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -3.0958797931671143, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -2.735022783279419, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -10.548039436340332, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 640, \"mu_intercept_per_group\": -1.3955962657928467, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 641, \"mu_intercept_per_group\": -17.113033294677734, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 642, \"mu_intercept_per_group\": -11.39327621459961, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 643, \"mu_intercept_per_group\": -12.532562255859375, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 644, \"mu_intercept_per_group\": -8.902205467224121, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 645, \"mu_intercept_per_group\": -16.35418128967285, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 646, \"mu_intercept_per_group\": -18.42349624633789, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 647, \"mu_intercept_per_group\": -20.9619083404541, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 648, \"mu_intercept_per_group\": -18.798307418823242, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 649, \"mu_intercept_per_group\": 4.921034812927246, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 650, \"mu_intercept_per_group\": 2.829319953918457, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 651, \"mu_intercept_per_group\": -19.05095672607422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 652, \"mu_intercept_per_group\": -5.474806785583496, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 653, \"mu_intercept_per_group\": -4.922374725341797, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 654, \"mu_intercept_per_group\": -10.816702842712402, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 655, \"mu_intercept_per_group\": 0.6563606858253479, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 656, \"mu_intercept_per_group\": -11.115660667419434, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 657, \"mu_intercept_per_group\": -9.447301864624023, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 658, \"mu_intercept_per_group\": -13.556966781616211, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 659, \"mu_intercept_per_group\": -11.097416877746582, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 660, \"mu_intercept_per_group\": -5.995758533477783, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 661, \"mu_intercept_per_group\": -2.3554229736328125, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 662, \"mu_intercept_per_group\": -3.1295342445373535, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 663, \"mu_intercept_per_group\": -4.682866096496582, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 664, \"mu_intercept_per_group\": -3.5213005542755127, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 665, \"mu_intercept_per_group\": -4.978518486022949, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 666, \"mu_intercept_per_group\": -3.724959135055542, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 667, \"mu_intercept_per_group\": -6.1379313468933105, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 668, \"mu_intercept_per_group\": -4.124699115753174, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 669, \"mu_intercept_per_group\": -8.214367866516113, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 670, \"mu_intercept_per_group\": 1.0553821325302124, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 671, \"mu_intercept_per_group\": -11.239164352416992, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 672, \"mu_intercept_per_group\": -6.925349235534668, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 673, \"mu_intercept_per_group\": -6.511587619781494, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 674, \"mu_intercept_per_group\": -11.621158599853516, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 675, \"mu_intercept_per_group\": -10.887262344360352, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 676, \"mu_intercept_per_group\": -7.85366678237915, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 677, \"mu_intercept_per_group\": -9.883703231811523, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 678, \"mu_intercept_per_group\": -5.222884654998779, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 679, \"mu_intercept_per_group\": -7.691766262054443, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 680, \"mu_intercept_per_group\": -3.4161531925201416, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 681, \"mu_intercept_per_group\": -23.19988250732422, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 682, \"mu_intercept_per_group\": 0.4955381453037262, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 683, \"mu_intercept_per_group\": -19.23976707458496, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 684, \"mu_intercept_per_group\": -15.268034934997559, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 685, \"mu_intercept_per_group\": -15.744549751281738, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 686, \"mu_intercept_per_group\": -13.575891494750977, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 687, \"mu_intercept_per_group\": -12.361751556396484, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 688, \"mu_intercept_per_group\": -15.737735748291016, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 689, \"mu_intercept_per_group\": -3.832686424255371, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 690, \"mu_intercept_per_group\": -6.5279645919799805, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 691, \"mu_intercept_per_group\": -4.437520980834961, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 692, \"mu_intercept_per_group\": -3.609692096710205, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 693, \"mu_intercept_per_group\": 5.752180576324463, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 694, \"mu_intercept_per_group\": -6.594266414642334, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 695, \"mu_intercept_per_group\": -8.382157325744629, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 696, \"mu_intercept_per_group\": -5.280394077301025, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 697, \"mu_intercept_per_group\": -3.3657338619232178, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 698, \"mu_intercept_per_group\": -13.693631172180176, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 699, \"mu_intercept_per_group\": -15.320185661315918, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 700, \"mu_intercept_per_group\": -16.62302589416504, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 701, \"mu_intercept_per_group\": -14.20588207244873, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 702, \"mu_intercept_per_group\": -14.253565788269043, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 703, \"mu_intercept_per_group\": -1.8492915630340576, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 704, \"mu_intercept_per_group\": -9.212831497192383, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 705, \"mu_intercept_per_group\": -7.338194847106934, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 706, \"mu_intercept_per_group\": -14.641120910644531, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 707, \"mu_intercept_per_group\": -16.60073471069336, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 708, \"mu_intercept_per_group\": -1.3629611730575562, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 709, \"mu_intercept_per_group\": -7.777461051940918, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 710, \"mu_intercept_per_group\": -1.8500031232833862, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 711, \"mu_intercept_per_group\": -22.09663200378418, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 712, \"mu_intercept_per_group\": 0.018531644716858864, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 713, \"mu_intercept_per_group\": 3.0248255729675293, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 714, \"mu_intercept_per_group\": -7.417457580566406, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 715, \"mu_intercept_per_group\": -6.956211090087891, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 716, \"mu_intercept_per_group\": -8.928647994995117, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 717, \"mu_intercept_per_group\": -0.22857104241847992, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 718, \"mu_intercept_per_group\": -6.185298442840576, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 719, \"mu_intercept_per_group\": -16.681169509887695, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 720, \"mu_intercept_per_group\": -5.962151050567627, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 721, \"mu_intercept_per_group\": -6.805093288421631, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 722, \"mu_intercept_per_group\": -11.011396408081055, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 723, \"mu_intercept_per_group\": -9.850343704223633, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 724, \"mu_intercept_per_group\": -10.407118797302246, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 725, \"mu_intercept_per_group\": -10.117226600646973, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 726, \"mu_intercept_per_group\": -5.316917419433594, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 727, \"mu_intercept_per_group\": -6.945923328399658, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 728, \"mu_intercept_per_group\": -9.492375373840332, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 729, \"mu_intercept_per_group\": -8.86750602722168, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 730, \"mu_intercept_per_group\": -7.798107624053955, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 731, \"mu_intercept_per_group\": -12.682540893554688, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 732, \"mu_intercept_per_group\": -12.547581672668457, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 733, \"mu_intercept_per_group\": -18.491785049438477, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 734, \"mu_intercept_per_group\": -8.545707702636719, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 735, \"mu_intercept_per_group\": -17.687284469604492, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 736, \"mu_intercept_per_group\": -5.70229434967041, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 737, \"mu_intercept_per_group\": -13.548932075500488, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 738, \"mu_intercept_per_group\": -9.389627456665039, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 739, \"mu_intercept_per_group\": -15.26278305053711, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 740, \"mu_intercept_per_group\": -1.2251851558685303, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 741, \"mu_intercept_per_group\": -11.610944747924805, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 742, \"mu_intercept_per_group\": -1.3939104080200195, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 743, \"mu_intercept_per_group\": -1.9360616207122803, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 744, \"mu_intercept_per_group\": -10.431615829467773, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 745, \"mu_intercept_per_group\": -8.211955070495605, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 746, \"mu_intercept_per_group\": -13.654766082763672, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 747, \"mu_intercept_per_group\": -2.444514513015747, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 748, \"mu_intercept_per_group\": -9.148351669311523, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 749, \"mu_intercept_per_group\": -1.5807955265045166, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 750, \"mu_intercept_per_group\": -15.372639656066895, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 751, \"mu_intercept_per_group\": -5.23089075088501, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 752, \"mu_intercept_per_group\": -14.592620849609375, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 753, \"mu_intercept_per_group\": -9.639511108398438, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 754, \"mu_intercept_per_group\": -9.418307304382324, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 755, \"mu_intercept_per_group\": -3.8247220516204834, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 756, \"mu_intercept_per_group\": -5.8500590324401855, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 757, \"mu_intercept_per_group\": -5.908278465270996, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 758, \"mu_intercept_per_group\": -14.808974266052246, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 759, \"mu_intercept_per_group\": -9.69106388092041, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 0, \"draws\": 760, \"mu_intercept_per_group\": -8.039718627929688, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 0, \"draws\": 761, \"mu_intercept_per_group\": -6.686943531036377, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 0, \"draws\": 762, \"mu_intercept_per_group\": -6.237182140350342, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 0, \"draws\": 763, \"mu_intercept_per_group\": -15.060968399047852, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 0, \"draws\": 764, \"mu_intercept_per_group\": -0.531229555606842, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 0, \"draws\": 765, \"mu_intercept_per_group\": -4.671209812164307, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 0, \"draws\": 766, \"mu_intercept_per_group\": -15.774847030639648, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 0, \"draws\": 767, \"mu_intercept_per_group\": -16.489418029785156, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 0, \"draws\": 768, \"mu_intercept_per_group\": -13.781782150268555, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 0, \"draws\": 769, \"mu_intercept_per_group\": -13.473760604858398, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 0, \"draws\": 770, \"mu_intercept_per_group\": -0.21044935286045074, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 0, \"draws\": 771, \"mu_intercept_per_group\": -15.083337783813477, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 0, \"draws\": 772, \"mu_intercept_per_group\": -4.676630973815918, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 0, \"draws\": 773, \"mu_intercept_per_group\": -12.31003189086914, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 0, \"draws\": 774, \"mu_intercept_per_group\": -6.071263790130615, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 0, \"draws\": 775, \"mu_intercept_per_group\": -12.3790864944458, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 0, \"draws\": 776, \"mu_intercept_per_group\": -10.242154121398926, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 0, \"draws\": 777, \"mu_intercept_per_group\": -14.512199401855469, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 0, \"draws\": 778, \"mu_intercept_per_group\": -6.676771640777588, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 0, \"draws\": 779, \"mu_intercept_per_group\": -9.669127464294434, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 0, \"draws\": 780, \"mu_intercept_per_group\": -11.874094009399414, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 0, \"draws\": 781, \"mu_intercept_per_group\": 0.7495285272598267, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 0, \"draws\": 782, \"mu_intercept_per_group\": -11.307819366455078, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 0, \"draws\": 783, \"mu_intercept_per_group\": -11.859552383422852, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 0, \"draws\": 784, \"mu_intercept_per_group\": -6.786609649658203, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 0, \"draws\": 785, \"mu_intercept_per_group\": -4.8037872314453125, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 0, \"draws\": 786, \"mu_intercept_per_group\": -1.0827637910842896, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 0, \"draws\": 787, \"mu_intercept_per_group\": -9.0177583694458, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 0, \"draws\": 788, \"mu_intercept_per_group\": -2.8852615356445312, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 0, \"draws\": 789, \"mu_intercept_per_group\": -2.3375611305236816, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 0, \"draws\": 790, \"mu_intercept_per_group\": -5.916977882385254, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 0, \"draws\": 791, \"mu_intercept_per_group\": -5.5406341552734375, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 0, \"draws\": 792, \"mu_intercept_per_group\": -5.125442028045654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 0, \"draws\": 793, \"mu_intercept_per_group\": -9.392108917236328, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 0, \"draws\": 794, \"mu_intercept_per_group\": 5.721161365509033, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 0, \"draws\": 795, \"mu_intercept_per_group\": -3.4059906005859375, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 0, \"draws\": 796, \"mu_intercept_per_group\": -5.1101531982421875, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 0, \"draws\": 797, \"mu_intercept_per_group\": -15.806418418884277, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 0, \"draws\": 798, \"mu_intercept_per_group\": 4.5742669105529785, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 0, \"draws\": 799, \"mu_intercept_per_group\": -16.5518798828125, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -8.463964462280273, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -5.522490978240967, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -8.630327224731445, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -7.021143913269043, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -2.774968385696411, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -10.757180213928223, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -8.160569190979004, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -10.12001895904541, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -4.824865341186523, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -8.315885543823242, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -5.182793140411377, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -10.113337516784668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -7.616043567657471, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -7.081296443939209, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -8.140750885009766, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -11.904815673828125, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -11.351101875305176, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -4.601489067077637, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -5.248831748962402, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -6.81367301940918, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -2.246152639389038, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -5.514193058013916, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -11.95570182800293, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -3.89855694770813, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": 4.90255069732666, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": 13.422053337097168, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": 6.911807537078857, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -5.5922770500183105, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -6.857975482940674, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -2.1050865650177, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -6.132362365722656, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -2.787949323654175, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -7.256302833557129, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -15.257880210876465, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -5.019294738769531, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -16.966064453125, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -8.912954330444336, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -14.777284622192383, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -5.526966571807861, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -4.6448774337768555, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": 2.525085687637329, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -15.121261596679688, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -3.2543210983276367, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -4.027781963348389, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -3.056781053543091, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -4.625176906585693, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": 2.2165396213531494, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": 1.1302454471588135, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -8.88571548461914, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -12.499415397644043, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -5.258360385894775, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -1.1019741296768188, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -2.7254743576049805, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -4.00599479675293, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -7.0142059326171875, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -4.741383075714111, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -2.4022116661071777, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -7.611382961273193, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -7.375605583190918, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -13.864294052124023, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": 1.5573049783706665, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -18.688922882080078, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -3.8896350860595703, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -2.6664626598358154, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -5.915189266204834, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -11.641724586486816, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -24.968902587890625, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": 3.673384428024292, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": 3.2681491374969482, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -5.521426200866699, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -9.135942459106445, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -9.367850303649902, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -8.582090377807617, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -12.789557456970215, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -7.178985595703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -3.3624579906463623, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -3.7026774883270264, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -20.197704315185547, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -2.000335216522217, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": 0.3444068729877472, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -6.717190742492676, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -5.477149486541748, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -11.214262008666992, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -16.399005889892578, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -1.7473465204238892, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -1.0917484760284424, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -3.080193519592285, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": 0.8146815299987793, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": 4.521572113037109, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.99426555633545, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -9.336772918701172, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -5.096127033233643, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -18.555667877197266, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": 8.260923385620117, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -19.096702575683594, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -19.96316146850586, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -1.9338761568069458, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -7.733426570892334, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -11.19599723815918, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -3.0945422649383545, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -4.423023700714111, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -14.207892417907715, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -10.578598976135254, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -6.583150863647461, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -18.78107452392578, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -5.156072616577148, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -13.016656875610352, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -3.282268524169922, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -1.4693411588668823, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -1.5940797328948975, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -8.228626251220703, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -7.249871253967285, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -5.003849029541016, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -6.709216117858887, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -5.370258808135986, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -6.2389020919799805, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -4.802653789520264, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -3.672044515609741, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -2.5114827156066895, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -6.614682197570801, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -1.314194679260254, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -7.518023490905762, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -5.575322151184082, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -4.340911865234375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -6.025227069854736, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -11.910261154174805, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -13.2202730178833, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -10.20504379272461, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -10.171121597290039, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -7.420294761657715, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -8.76205062866211, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -8.214826583862305, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -1.5067857503890991, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -2.995762348175049, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -10.4031982421875, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -5.307545185089111, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -6.915334701538086, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -6.712177276611328, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -11.415205001831055, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -15.197175979614258, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -5.711830139160156, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -1.4785627126693726, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -3.285017490386963, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -5.481128215789795, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -11.936737060546875, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": 0.36717545986175537, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -4.167700290679932, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": 0.07449424266815186, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -7.763571262359619, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -5.035675048828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -9.300844192504883, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": 3.1366419792175293, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -12.75354290008545, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -12.582444190979004, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -2.3910295963287354, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -12.289669036865234, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -2.905604362487793, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -7.637528896331787, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -5.888548851013184, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -9.943721771240234, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -7.501426696777344, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -5.770092487335205, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -1.948828935623169, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -15.492814064025879, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": 4.272012233734131, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -7.3533501625061035, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -7.2175164222717285, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -14.558330535888672, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -16.98981285095215, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": 4.297924995422363, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -19.546592712402344, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -8.8070650100708, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -4.942563056945801, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": 0.48789316415786743, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -2.812572479248047, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -1.250403881072998, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": 0.201321542263031, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -5.401147842407227, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -8.158730506896973, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -4.766443729400635, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -10.177217483520508, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -1.0570824146270752, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -17.689987182617188, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -9.77273941040039, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -7.371433734893799, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": 2.80295991897583, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": 3.2416961193084717, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": 0.44132789969444275, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -2.6126503944396973, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -9.670760154724121, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -8.313094139099121, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -10.328643798828125, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -9.322820663452148, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -12.268668174743652, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -10.417738914489746, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -11.325778007507324, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -11.268610000610352, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -2.5182535648345947, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -2.6109728813171387, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -11.761697769165039, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -1.9480599164962769, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -15.995800971984863, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -7.968087196350098, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -12.817194938659668, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -7.802563190460205, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -2.0851564407348633, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -9.967320442199707, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -2.524480104446411, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -1.9567384719848633, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -6.825958728790283, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -3.56683611869812, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -10.835593223571777, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -8.808893203735352, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -6.46396017074585, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -10.878059387207031, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -2.6873679161071777, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -6.742923259735107, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -9.391840934753418, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": 1.4834914207458496, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -0.8790526390075684, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -16.255952835083008, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -14.247909545898438, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -5.371616363525391, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -5.0700883865356445, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -7.676242828369141, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -9.607836723327637, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -22.520721435546875, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -9.707636833190918, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -18.860963821411133, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": 2.2030763626098633, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": 2.202141523361206, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -0.7342286109924316, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -7.996046543121338, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -8.649276733398438, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -6.344440460205078, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -4.691237926483154, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -7.299112796783447, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -5.575038433074951, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -3.972187042236328, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -9.599820137023926, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -8.358413696289062, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -5.024391174316406, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -5.716562747955322, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -3.77807879447937, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -5.500432014465332, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -7.615743160247803, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -4.611034393310547, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -10.824134826660156, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -9.529510498046875, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -6.8019843101501465, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -7.914368152618408, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -6.4699482917785645, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -5.027370929718018, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -3.10154128074646, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": 0.27238428592681885, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -11.068960189819336, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -1.8688381910324097, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -1.5642330646514893, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": 2.16567063331604, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -4.079339027404785, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -0.5596898794174194, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -13.810405731201172, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -2.4614691734313965, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -4.566840171813965, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -9.446951866149902, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -6.827064037322998, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": 2.2277393341064453, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -5.073843479156494, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -0.4736955165863037, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -9.838051795959473, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -5.923642158508301, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -7.2732462882995605, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -2.9811365604400635, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -5.687343597412109, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -7.497012138366699, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -6.166018962860107, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": 1.1129947900772095, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -2.388124942779541, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -4.539252758026123, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -17.606914520263672, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -6.165983200073242, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -3.742136001586914, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -3.639493703842163, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -5.823246955871582, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -12.123866081237793, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -7.763772010803223, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -6.970352649688721, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -0.6010066866874695, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -2.378098249435425, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -5.7572832107543945, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -11.822481155395508, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -4.5131025314331055, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -7.647518634796143, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -5.036931037902832, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -8.063419342041016, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -8.231720924377441, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -10.115706443786621, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": 11.774689674377441, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": 1.6975617408752441, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -0.44665879011154175, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -5.412267208099365, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -4.182696342468262, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -1.9100764989852905, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -8.234150886535645, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -8.763331413269043, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -5.511397361755371, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -9.85831356048584, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -12.8724946975708, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": 7.688490867614746, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -12.401480674743652, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": 4.287363529205322, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -11.154162406921387, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -9.18152141571045, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -5.775693416595459, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -6.747610569000244, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -7.762335300445557, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -8.072798728942871, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -7.486238479614258, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -12.458937644958496, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -3.4186317920684814, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -5.2962493896484375, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -4.723546981811523, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -2.6898562908172607, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -3.6324923038482666, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -13.080504417419434, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -6.417844772338867, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -1.665814995765686, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -4.46502161026001, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -14.899575233459473, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -10.645574569702148, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -3.14841628074646, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -13.237945556640625, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -12.312538146972656, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -7.097439765930176, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -14.861870765686035, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -11.7489652633667, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -11.972259521484375, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -10.411721229553223, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -11.556038856506348, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -1.303446888923645, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -8.312260627746582, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -11.57768726348877, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -13.761001586914062, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -6.086140155792236, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -5.489706039428711, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -2.0879509449005127, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -13.66417407989502, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -10.065771102905273, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -5.447312355041504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -9.46387004852295, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -5.7930755615234375, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.894649505615234, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -4.028882026672363, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -1.6248077154159546, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -13.211878776550293, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -12.292472839355469, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -6.505354404449463, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -9.881367683410645, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -0.13978375494480133, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -10.650283813476562, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -9.862833023071289, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -5.99295711517334, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -3.788276433944702, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -4.967767715454102, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -10.58394718170166, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": 1.6004167795181274, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -0.0031337225809693336, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -12.571540832519531, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -11.773927688598633, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -6.5745062828063965, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -6.903250694274902, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -4.94040060043335, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -11.601109504699707, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -12.11928653717041, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -3.1288840770721436, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -9.122939109802246, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -11.455864906311035, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -7.932468891143799, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -5.82853889465332, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -5.114236831665039, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -2.7878990173339844, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -4.554833889007568, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -13.072132110595703, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": 5.590129375457764, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -20.363454818725586, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -34.7641716003418, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -15.950664520263672, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -10.630252838134766, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -13.557367324829102, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": 2.0046355724334717, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -12.566685676574707, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -7.294683933258057, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -12.405985832214355, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -8.00912094116211, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -8.846941947937012, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.363330841064453, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -3.7095868587493896, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -4.117101669311523, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -6.945756435394287, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -8.627290725708008, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -1.4066123962402344, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -14.80611801147461, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -5.313531875610352, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -7.835374355316162, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -4.99541711807251, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -4.97422981262207, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -5.330106735229492, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -8.303894996643066, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": 2.135199546813965, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -16.06319808959961, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": 0.7605302333831787, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -13.170872688293457, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -15.687202453613281, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -1.7165426015853882, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -5.136164665222168, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -4.370528697967529, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -4.880247592926025, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -1.911839246749878, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -9.556730270385742, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -0.8126273155212402, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -6.101413726806641, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.357921600341797, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -13.671849250793457, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -3.5299882888793945, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -4.885555267333984, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -8.022061347961426, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -2.0411484241485596, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -9.610355377197266, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -1.847278118133545, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -11.80907154083252, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -8.462021827697754, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -4.326870441436768, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -5.468924522399902, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -6.299935817718506, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -13.798683166503906, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -3.594536304473877, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -8.656484603881836, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -6.9296417236328125, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -7.686049938201904, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -12.964165687561035, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -7.580221176147461, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -7.629336833953857, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -7.874495029449463, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -3.870492458343506, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -15.039116859436035, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -3.3166422843933105, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -10.479406356811523, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -10.407120704650879, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -3.1247706413269043, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -9.59276294708252, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -8.741473197937012, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -2.6316232681274414, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -10.259936332702637, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -16.08149528503418, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -22.595226287841797, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -13.521262168884277, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -15.243318557739258, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -8.26047420501709, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -5.657673358917236, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -3.0963892936706543, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -10.927461624145508, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -1.3937886953353882, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -12.800820350646973, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -2.9563820362091064, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": 3.0324513912200928, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -1.3185973167419434, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -10.170413970947266, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -8.437788009643555, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -29.883220672607422, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -2.5528335571289062, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -5.943991184234619, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.220870971679688, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -10.247591972351074, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -11.83267593383789, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -1.1434195041656494, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -3.710218906402588, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -4.687295913696289, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -6.169580936431885, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -12.876049041748047, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -7.897989749908447, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -7.6432037353515625, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -3.8371458053588867, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -7.476674556732178, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -6.591335773468018, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -2.628870964050293, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -19.54383087158203, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": 3.079812526702881, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": 3.0599868297576904, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -4.361057758331299, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -13.445945739746094, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -8.224185943603516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -5.457669258117676, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -7.8514838218688965, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -14.69129467010498, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -4.073327541351318, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -10.719621658325195, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -3.484194040298462, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -21.873950958251953, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -12.562688827514648, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -14.433303833007812, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -11.538043022155762, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -5.583098411560059, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -6.319106101989746, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -4.117209434509277, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -4.087664604187012, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -5.711300373077393, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -6.448568344116211, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -9.299012184143066, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -1.6976025104522705, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -10.521522521972656, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -9.352278709411621, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -14.279708862304688, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -11.237142562866211, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -3.7602996826171875, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -14.102614402770996, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": 1.834031581878662, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -6.776103496551514, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -7.349850654602051, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -11.03607177734375, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -10.871505737304688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -10.033157348632812, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -10.515748977661133, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -10.465447425842285, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -11.220648765563965, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -9.48349380493164, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -19.80289077758789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -18.929874420166016, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -15.037124633789062, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -15.797110557556152, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -11.973806381225586, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -11.365989685058594, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -14.679963111877441, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -11.842629432678223, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -2.3008553981781006, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -5.299274444580078, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -9.47567081451416, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -8.240625381469727, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -6.985145568847656, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -1.8116092681884766, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -14.579553604125977, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -0.15882565081119537, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -11.052987098693848, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -10.534075736999512, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -12.461343765258789, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -3.4963104724884033, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -3.2063283920288086, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -4.655256271362305, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": 3.90130352973938, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -9.238557815551758, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -12.395340919494629, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -10.23513412475586, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -10.9961576461792, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -9.297804832458496, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -8.414896965026855, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -11.95994758605957, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -2.9788801670074463, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -11.210237503051758, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -9.273188591003418, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -6.25204610824585, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -9.3336181640625, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -7.024564266204834, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -4.346048831939697, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -4.706249237060547, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -7.968608379364014, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -1.565627932548523, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -6.640815258026123, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -5.302150249481201, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -6.941023349761963, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -1.2704907655715942, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -7.112493515014648, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -8.465219497680664, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -5.155795097351074, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -6.536206245422363, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -9.535880088806152, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -10.2841157913208, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -8.211404800415039, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -8.24379825592041, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -8.449947357177734, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -10.331687927246094, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -16.199155807495117, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -13.972550392150879, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -18.041168212890625, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -3.4920613765716553, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -7.985953330993652, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -7.014187335968018, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -1.605649471282959, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -8.235715866088867, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -5.29293155670166, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -9.228889465332031, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -4.049346446990967, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -10.81877613067627, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -14.659221649169922, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -4.774314880371094, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -8.7986478805542, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -4.895114898681641, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -10.780174255371094, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -8.298257827758789, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -13.849451065063477, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -2.4056859016418457, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -3.175271987915039, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": 0.10836401581764221, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -14.298521041870117, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -9.087770462036133, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -10.402381896972656, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -9.93741512298584, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -10.765823364257812, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -6.67334508895874, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -4.509544372558594, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -9.220878601074219, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -4.86932897567749, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": 4.452273368835449, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -3.046302080154419, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -9.8165922164917, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -12.620911598205566, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -5.204877853393555, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -11.999639511108398, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -2.291882038116455, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -10.168539047241211, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -16.272212982177734, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -15.966462135314941, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -8.96129322052002, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -8.631392478942871, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": 3.074772834777832, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": 0.14587892591953278, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -12.751314163208008, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -13.256711959838867, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -10.27218246459961, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -7.958676815032959, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -5.983311176300049, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -4.754218578338623, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -7.612178325653076, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -10.645689010620117, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -0.6197846531867981, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -20.461259841918945, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -20.499818801879883, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -20.013587951660156, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -14.218558311462402, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": 2.9418017864227295, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": 0.09507820010185242, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": 0.4870001971721649, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 640, \"mu_intercept_per_group\": -6.998203754425049, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 641, \"mu_intercept_per_group\": -12.70267105102539, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 642, \"mu_intercept_per_group\": -12.564757347106934, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 643, \"mu_intercept_per_group\": -13.075398445129395, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 644, \"mu_intercept_per_group\": -14.863747596740723, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 645, \"mu_intercept_per_group\": -2.4183244705200195, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 646, \"mu_intercept_per_group\": -0.7938307523727417, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 647, \"mu_intercept_per_group\": -7.049498558044434, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 648, \"mu_intercept_per_group\": -5.135613918304443, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 649, \"mu_intercept_per_group\": -3.4538235664367676, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 650, \"mu_intercept_per_group\": -3.8301169872283936, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 651, \"mu_intercept_per_group\": -8.055845260620117, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 652, \"mu_intercept_per_group\": -10.992918014526367, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 653, \"mu_intercept_per_group\": -3.1368653774261475, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 654, \"mu_intercept_per_group\": -2.5501515865325928, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 655, \"mu_intercept_per_group\": -7.712600231170654, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 656, \"mu_intercept_per_group\": -8.44206714630127, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 657, \"mu_intercept_per_group\": -14.379984855651855, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 658, \"mu_intercept_per_group\": -11.493062973022461, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 659, \"mu_intercept_per_group\": -3.9389209747314453, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 660, \"mu_intercept_per_group\": -6.9828081130981445, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 661, \"mu_intercept_per_group\": -9.729299545288086, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 662, \"mu_intercept_per_group\": -9.274621963500977, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 663, \"mu_intercept_per_group\": -8.24915599822998, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 664, \"mu_intercept_per_group\": 1.9177732467651367, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 665, \"mu_intercept_per_group\": 0.6679157614707947, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 666, \"mu_intercept_per_group\": -6.791961193084717, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 667, \"mu_intercept_per_group\": -9.511539459228516, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 668, \"mu_intercept_per_group\": -8.007267951965332, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 669, \"mu_intercept_per_group\": -3.350052833557129, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 670, \"mu_intercept_per_group\": -3.5129752159118652, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 671, \"mu_intercept_per_group\": -6.794730186462402, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 672, \"mu_intercept_per_group\": 3.360326051712036, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 673, \"mu_intercept_per_group\": -1.6963112354278564, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 674, \"mu_intercept_per_group\": -11.35863208770752, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 675, \"mu_intercept_per_group\": -9.890142440795898, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 676, \"mu_intercept_per_group\": -6.259748458862305, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 677, \"mu_intercept_per_group\": -4.0634942054748535, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 678, \"mu_intercept_per_group\": -3.5187900066375732, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 679, \"mu_intercept_per_group\": -8.828516006469727, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 680, \"mu_intercept_per_group\": -5.272643566131592, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 681, \"mu_intercept_per_group\": -5.677806854248047, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 682, \"mu_intercept_per_group\": -11.633842468261719, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 683, \"mu_intercept_per_group\": -6.39860725402832, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 684, \"mu_intercept_per_group\": -15.06329345703125, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 685, \"mu_intercept_per_group\": -13.745234489440918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 686, \"mu_intercept_per_group\": -13.775030136108398, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 687, \"mu_intercept_per_group\": -10.523633003234863, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 688, \"mu_intercept_per_group\": -13.00391674041748, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 689, \"mu_intercept_per_group\": -0.534116268157959, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 690, \"mu_intercept_per_group\": -9.273967742919922, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 691, \"mu_intercept_per_group\": -1.7329838275909424, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 692, \"mu_intercept_per_group\": -0.6396942734718323, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 693, \"mu_intercept_per_group\": -7.303791046142578, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 694, \"mu_intercept_per_group\": -12.832805633544922, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 695, \"mu_intercept_per_group\": -12.848074913024902, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 696, \"mu_intercept_per_group\": 0.7132947444915771, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 697, \"mu_intercept_per_group\": -0.01631096377968788, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 698, \"mu_intercept_per_group\": -15.826177597045898, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 699, \"mu_intercept_per_group\": -14.799540519714355, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 700, \"mu_intercept_per_group\": -15.701089859008789, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 701, \"mu_intercept_per_group\": -25.847299575805664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 702, \"mu_intercept_per_group\": -15.596050262451172, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 703, \"mu_intercept_per_group\": -3.0136518478393555, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 704, \"mu_intercept_per_group\": -10.249879837036133, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 705, \"mu_intercept_per_group\": -3.0909831523895264, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 706, \"mu_intercept_per_group\": -11.727210998535156, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 707, \"mu_intercept_per_group\": -2.4828298091888428, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 708, \"mu_intercept_per_group\": -9.143221855163574, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 709, \"mu_intercept_per_group\": -8.30216121673584, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 710, \"mu_intercept_per_group\": -15.986251831054688, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 711, \"mu_intercept_per_group\": 3.363057851791382, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 712, \"mu_intercept_per_group\": -14.843551635742188, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 713, \"mu_intercept_per_group\": -9.049310684204102, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 714, \"mu_intercept_per_group\": -11.122550964355469, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 715, \"mu_intercept_per_group\": -10.008472442626953, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 716, \"mu_intercept_per_group\": -4.341726779937744, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 717, \"mu_intercept_per_group\": -6.1400651931762695, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 718, \"mu_intercept_per_group\": -10.843049049377441, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 719, \"mu_intercept_per_group\": -16.954082489013672, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 720, \"mu_intercept_per_group\": -1.3038560152053833, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 721, \"mu_intercept_per_group\": -3.9746432304382324, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 722, \"mu_intercept_per_group\": -15.726155281066895, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 723, \"mu_intercept_per_group\": -18.059703826904297, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 724, \"mu_intercept_per_group\": -15.85275936126709, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 725, \"mu_intercept_per_group\": -15.225875854492188, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 726, \"mu_intercept_per_group\": -0.8269123435020447, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 727, \"mu_intercept_per_group\": -8.880156517028809, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 728, \"mu_intercept_per_group\": -4.952438831329346, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 729, \"mu_intercept_per_group\": 2.1097402572631836, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 730, \"mu_intercept_per_group\": -19.530475616455078, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 731, \"mu_intercept_per_group\": -12.512855529785156, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 732, \"mu_intercept_per_group\": -11.262587547302246, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 733, \"mu_intercept_per_group\": -5.691250801086426, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 734, \"mu_intercept_per_group\": -5.709987163543701, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 735, \"mu_intercept_per_group\": -13.027153015136719, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 736, \"mu_intercept_per_group\": -4.580695152282715, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 737, \"mu_intercept_per_group\": -5.58447790145874, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 738, \"mu_intercept_per_group\": -7.456693649291992, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 739, \"mu_intercept_per_group\": -4.1011481285095215, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 740, \"mu_intercept_per_group\": -7.866563320159912, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 741, \"mu_intercept_per_group\": -2.8816299438476562, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 742, \"mu_intercept_per_group\": -3.1140661239624023, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 743, \"mu_intercept_per_group\": -7.392512798309326, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 744, \"mu_intercept_per_group\": -0.40461915731430054, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 745, \"mu_intercept_per_group\": -13.69776439666748, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 746, \"mu_intercept_per_group\": -2.8043599128723145, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 747, \"mu_intercept_per_group\": -5.48544454574585, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 748, \"mu_intercept_per_group\": -6.651001930236816, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 749, \"mu_intercept_per_group\": -0.7668727040290833, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 750, \"mu_intercept_per_group\": -13.935588836669922, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 751, \"mu_intercept_per_group\": -18.877792358398438, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 752, \"mu_intercept_per_group\": -13.951913833618164, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 753, \"mu_intercept_per_group\": 1.7729135751724243, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 754, \"mu_intercept_per_group\": -10.468303680419922, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 755, \"mu_intercept_per_group\": -5.0220441818237305, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 756, \"mu_intercept_per_group\": 1.5663807392120361, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 757, \"mu_intercept_per_group\": 4.801385402679443, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 758, \"mu_intercept_per_group\": -19.007904052734375, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 759, \"mu_intercept_per_group\": -4.879411220550537, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 760, \"mu_intercept_per_group\": -4.549781799316406, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 1, \"draws\": 761, \"mu_intercept_per_group\": -2.94614577293396, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 1, \"draws\": 762, \"mu_intercept_per_group\": -4.423861980438232, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 1, \"draws\": 763, \"mu_intercept_per_group\": -7.034924507141113, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 1, \"draws\": 764, \"mu_intercept_per_group\": 1.8200410604476929, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 1, \"draws\": 765, \"mu_intercept_per_group\": -8.238364219665527, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 1, \"draws\": 766, \"mu_intercept_per_group\": -7.395601749420166, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 1, \"draws\": 767, \"mu_intercept_per_group\": -20.068384170532227, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 1, \"draws\": 768, \"mu_intercept_per_group\": -17.523784637451172, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 1, \"draws\": 769, \"mu_intercept_per_group\": -11.089550018310547, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 1, \"draws\": 770, \"mu_intercept_per_group\": -2.1942050457000732, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 1, \"draws\": 771, \"mu_intercept_per_group\": -9.11524486541748, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 1, \"draws\": 772, \"mu_intercept_per_group\": -7.53018856048584, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 1, \"draws\": 773, \"mu_intercept_per_group\": -16.917530059814453, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 1, \"draws\": 774, \"mu_intercept_per_group\": -7.4532928466796875, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 1, \"draws\": 775, \"mu_intercept_per_group\": -8.408575057983398, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 1, \"draws\": 776, \"mu_intercept_per_group\": -10.65970230102539, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 1, \"draws\": 777, \"mu_intercept_per_group\": -11.440478324890137, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 1, \"draws\": 778, \"mu_intercept_per_group\": -3.9567081928253174, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 1, \"draws\": 779, \"mu_intercept_per_group\": -3.3428282737731934, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 1, \"draws\": 780, \"mu_intercept_per_group\": -3.787095546722412, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 1, \"draws\": 781, \"mu_intercept_per_group\": -5.192613124847412, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 1, \"draws\": 782, \"mu_intercept_per_group\": -1.9134330749511719, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 1, \"draws\": 783, \"mu_intercept_per_group\": -15.909469604492188, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 1, \"draws\": 784, \"mu_intercept_per_group\": -4.824670791625977, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 1, \"draws\": 785, \"mu_intercept_per_group\": -3.8470840454101562, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 1, \"draws\": 786, \"mu_intercept_per_group\": -10.330160140991211, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 1, \"draws\": 787, \"mu_intercept_per_group\": -2.9051589965820312, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 1, \"draws\": 788, \"mu_intercept_per_group\": -1.402732014656067, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 1, \"draws\": 789, \"mu_intercept_per_group\": -1.9129210710525513, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 1, \"draws\": 790, \"mu_intercept_per_group\": -2.001810312271118, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 1, \"draws\": 791, \"mu_intercept_per_group\": -1.3983904123306274, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 1, \"draws\": 792, \"mu_intercept_per_group\": -2.998652219772339, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 1, \"draws\": 793, \"mu_intercept_per_group\": -5.212745666503906, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 1, \"draws\": 794, \"mu_intercept_per_group\": -5.740200042724609, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 1, \"draws\": 795, \"mu_intercept_per_group\": -13.511787414550781, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 1, \"draws\": 796, \"mu_intercept_per_group\": -11.45315933227539, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 1, \"draws\": 797, \"mu_intercept_per_group\": 0.3158457577228546, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 1, \"draws\": 798, \"mu_intercept_per_group\": -7.817399978637695, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 1, \"draws\": 799, \"mu_intercept_per_group\": -5.6703596115112305, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": 3.732858419418335, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -14.74763298034668, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -0.7920447587966919, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -9.022059440612793, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": 0.6570751070976257, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -15.827178001403809, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": 1.0846809148788452, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -9.276813507080078, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -8.951321601867676, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -6.864566326141357, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -1.9341707229614258, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -2.0510671138763428, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -10.089612007141113, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -10.680008888244629, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -8.804644584655762, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -6.305605888366699, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": 0.3000829219818115, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -1.7551122903823853, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -2.3900818824768066, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -7.888637065887451, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -2.895343542098999, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": 1.3380863666534424, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -23.78074073791504, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -11.098406791687012, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -3.1819076538085938, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -4.800429344177246, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": 3.4133005142211914, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -4.96135139465332, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -2.690692663192749, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -2.0235795974731445, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -4.189643383026123, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -8.388700485229492, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -8.43273639678955, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -7.213374614715576, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -15.214789390563965, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -9.292546272277832, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": -2.4623196125030518, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -4.815928936004639, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -10.999615669250488, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -2.146559476852417, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": -0.2502283751964569, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -11.01223373413086, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": 0.8173249959945679, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": 1.2063239812850952, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -7.440464973449707, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": -2.0382120609283447, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -8.468244552612305, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": -10.96498966217041, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": -3.679169178009033, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": -1.5366096496582031, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -15.801124572753906, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -13.245361328125, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -1.2482539415359497, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -1.9702545404434204, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -10.261996269226074, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -6.809752464294434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -4.980435371398926, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -1.1392760276794434, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -14.793569564819336, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -9.13333797454834, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -12.414731979370117, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -6.6255903244018555, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -7.025851726531982, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -5.728945732116699, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -33.51395034790039, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -25.522985458374023, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -9.523961067199707, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -4.857399940490723, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -5.243505001068115, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -8.11296272277832, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -4.921431064605713, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -7.549405574798584, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -10.010002136230469, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -12.585983276367188, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -12.470001220703125, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -13.422882080078125, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -7.613100528717041, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -13.645598411560059, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": 1.5563081502914429, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -0.2708023190498352, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -3.8437490463256836, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -10.29825496673584, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -2.2668702602386475, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -18.09571075439453, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -2.0356709957122803, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -8.436660766601562, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -11.393402099609375, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -0.09373881667852402, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -7.675854682922363, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -10.161646842956543, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -5.003331184387207, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -5.881323337554932, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -15.590445518493652, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.46782112121582, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -6.074382305145264, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -9.703702926635742, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -11.3945894241333, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -22.94749641418457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -9.107547760009766, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -5.638185501098633, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -7.5632805824279785, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -5.779253005981445, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -12.833268165588379, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -24.00741195678711, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": -17.91518783569336, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -6.520063877105713, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -17.20440673828125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -0.8397051692008972, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -6.851493835449219, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -6.914797306060791, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -3.951817035675049, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -9.044754028320312, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -3.339143991470337, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -11.259417533874512, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -1.629762053489685, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -10.254329681396484, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -8.390010833740234, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -4.76670503616333, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -4.235963821411133, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -3.3014323711395264, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -3.503049373626709, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -1.417212963104248, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -12.009513854980469, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -2.5017096996307373, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -1.5731955766677856, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -15.161019325256348, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -11.574864387512207, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -5.0208420753479, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -11.90736198425293, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -10.829822540283203, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -3.8257577419281006, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -14.482948303222656, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -1.8139958381652832, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": 2.497969388961792, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": -16.498340606689453, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -0.2805044651031494, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -11.179259300231934, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -2.3191945552825928, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -16.078134536743164, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -8.03470230102539, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -7.668808937072754, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -6.628554821014404, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -9.30042839050293, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -4.862789630889893, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -13.12014102935791, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -4.942154407501221, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -1.706308364868164, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.927155017852783, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -5.129053592681885, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -5.170759677886963, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -9.57567024230957, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": 0.7154896855354309, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -10.724403381347656, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -6.5022735595703125, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -11.366816520690918, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -2.3977396488189697, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -2.8498568534851074, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -11.582931518554688, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -6.644885540008545, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -9.830425262451172, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -7.095962047576904, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -5.265265464782715, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -0.462955117225647, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -7.801544189453125, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -5.688144683837891, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -7.555182933807373, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -11.031906127929688, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -12.016904830932617, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -12.225738525390625, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -6.396834850311279, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -8.859726905822754, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -12.181182861328125, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -1.3500686883926392, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -0.9643192291259766, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": 5.729019641876221, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -7.027344226837158, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -8.903620719909668, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -11.632333755493164, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -7.708724021911621, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -4.908493995666504, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -2.233981132507324, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -11.19131851196289, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -3.624091863632202, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -8.907787322998047, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -10.99387264251709, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -13.788372039794922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -8.753623962402344, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -4.643501281738281, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -3.7619428634643555, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -13.322681427001953, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -13.632486343383789, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -13.1654691696167, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -21.33490753173828, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -20.72462272644043, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -8.248591423034668, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -11.590217590332031, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -0.4311475455760956, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -6.358354091644287, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -5.212062835693359, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -11.44992733001709, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -8.220882415771484, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -9.12226676940918, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -19.992965698242188, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.073141574859619, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -8.739863395690918, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -6.4528117179870605, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -1.6325939893722534, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -10.420852661132812, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -7.879732608795166, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -5.497306823730469, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -9.596871376037598, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -5.04962158203125, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -5.920009613037109, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -14.4966402053833, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -12.751287460327148, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -2.2573904991149902, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -7.686809539794922, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -4.8248610496521, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -1.765623927116394, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -3.668644428253174, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -11.203539848327637, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -5.001384258270264, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -5.6280837059021, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -8.435948371887207, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -16.05109405517578, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -11.728601455688477, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -10.938681602478027, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -12.06391716003418, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -9.29641342163086, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -8.03704833984375, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": -9.065410614013672, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -4.80192232131958, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": -1.2938531637191772, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": -9.983661651611328, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -8.687374114990234, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -8.76640796661377, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -13.491843223571777, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -14.784497261047363, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -7.058042049407959, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -8.410482406616211, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": -7.969771862030029, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": -5.700320720672607, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -8.23973274230957, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -6.37434720993042, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -4.339025974273682, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -12.471747398376465, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": 2.5074687004089355, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -7.676962375640869, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -9.073676109313965, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -3.8976588249206543, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -9.184854507446289, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -8.97800350189209, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": 0.567714512348175, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -9.884993553161621, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -2.6615822315216064, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -4.578339099884033, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -4.606342792510986, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -3.4974441528320312, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -7.455306529998779, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -8.015759468078613, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -6.008310794830322, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -9.581665992736816, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -18.30813217163086, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -5.676492691040039, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -5.461687088012695, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -10.037436485290527, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -5.408499240875244, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -3.463329315185547, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -8.462669372558594, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -0.7396417856216431, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": 0.3627697825431824, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -8.535021781921387, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -14.763421058654785, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -12.69399356842041, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -5.960251808166504, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -15.310663223266602, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -11.386277198791504, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": -0.6379175186157227, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": 2.479771614074707, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -27.945741653442383, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -25.226280212402344, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -25.83666229248047, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -25.84488868713379, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": -3.639381170272827, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -3.4970641136169434, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -8.06601619720459, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -1.5408661365509033, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -8.879176139831543, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -5.490477085113525, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": 0.7783665657043457, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": -5.810604572296143, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -6.816895008087158, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": -5.717819690704346, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": -3.2649192810058594, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -7.394350051879883, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -5.316237449645996, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -4.33823823928833, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -3.374006748199463, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -3.690908670425415, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -3.286393642425537, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -6.020491600036621, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -3.8602819442749023, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -3.8057656288146973, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -11.836518287658691, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -11.771985054016113, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -2.775174379348755, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -8.22934627532959, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -5.914505481719971, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": 0.35630086064338684, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -8.621039390563965, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": 0.03868190944194794, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -7.187379360198975, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -2.533694267272949, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -13.379923820495605, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -2.356395721435547, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -8.24489974975586, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -9.023186683654785, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -10.784841537475586, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -13.656123161315918, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -3.4743764400482178, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -7.933475971221924, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -11.61305046081543, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -12.829791069030762, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -13.294774055480957, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -0.8171144723892212, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -8.221381187438965, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -6.305694580078125, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -1.9388025999069214, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -8.794182777404785, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -14.92114543914795, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": 1.2037016153335571, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -0.29571962356567383, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -2.143641233444214, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": 0.28064489364624023, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -11.181112289428711, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -17.93585777282715, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -16.54886245727539, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -14.920042037963867, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -4.039874076843262, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -2.210084915161133, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -6.806283473968506, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -8.500036239624023, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -10.403523445129395, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -12.121692657470703, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -1.4248536825180054, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -6.124846935272217, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -9.547216415405273, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -7.770440101623535, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": -1.1363286972045898, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -5.304030895233154, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -16.298486709594727, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": 0.6669440269470215, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -12.736757278442383, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -0.40219584107398987, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -11.14700698852539, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -10.505026817321777, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -13.417987823486328, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -4.444047927856445, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -5.558975696563721, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -6.314434051513672, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -5.409777641296387, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -12.233269691467285, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": 2.4941351413726807, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -8.505087852478027, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -11.589695930480957, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": 2.68093204498291, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -2.3584933280944824, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -10.62534236907959, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -11.387564659118652, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -6.608433246612549, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -11.981107711791992, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -8.635040283203125, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -5.843832015991211, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.792159557342529, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -9.92165756225586, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -0.5195949077606201, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -0.48983699083328247, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -8.744340896606445, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -4.345973968505859, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -7.0246405601501465, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -8.06035041809082, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -3.0483062267303467, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -7.415585041046143, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -4.294566631317139, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -7.638671875, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -5.52531099319458, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": -22.398527145385742, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -26.254108428955078, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -22.66168212890625, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": 11.287065505981445, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -18.271297454833984, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": 5.90974760055542, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -20.47370147705078, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": -21.0311222076416, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -24.008012771606445, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": 3.4749786853790283, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -5.57877254486084, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": 7.922347545623779, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": 3.74188494682312, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -1.6988954544067383, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -5.097616672515869, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -8.846117973327637, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": 0.1722397655248642, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -11.248380661010742, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -5.576571464538574, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -11.188019752502441, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -7.977139472961426, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -7.824069499969482, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -6.561493873596191, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -4.329862117767334, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -9.109274864196777, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -2.5585813522338867, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -3.9632863998413086, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -8.33236312866211, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": -12.320808410644531, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -5.167570114135742, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -0.7097181081771851, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -6.286855697631836, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -3.0909993648529053, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -9.099831581115723, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -9.916319847106934, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -3.4401278495788574, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -10.867147445678711, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -3.1852986812591553, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -2.7473909854888916, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -8.0872163772583, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -6.562880992889404, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": -4.1757941246032715, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -7.16696834564209, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -10.26915168762207, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -9.438253402709961, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -9.75649356842041, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -10.471683502197266, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -6.7206597328186035, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -7.505468368530273, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -12.156686782836914, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -8.14764404296875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -12.892260551452637, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -7.857025146484375, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -5.481618404388428, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -7.646692752838135, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -8.294184684753418, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -6.671442031860352, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -5.029989719390869, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -6.067749977111816, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -8.702014923095703, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -1.9200150966644287, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": 2.897442579269409, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -6.439794540405273, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -9.116233825683594, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -8.189045906066895, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -7.817679405212402, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -8.17243480682373, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -7.344018936157227, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -9.187037467956543, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -11.351550102233887, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -6.207816123962402, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -12.242033004760742, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -8.850366592407227, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -7.808396339416504, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -6.700761795043945, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -4.922554969787598, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -7.77886962890625, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -8.31988525390625, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -12.699518203735352, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": 0.7110630869865417, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -5.795843124389648, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -9.777260780334473, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -12.110445976257324, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -0.4430992007255554, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -6.092288970947266, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -14.46850872039795, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": -13.915558815002441, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -11.345191955566406, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -9.869769096374512, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -14.827057838439941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": 2.4836864471435547, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -17.392253875732422, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -1.5566017627716064, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -4.168797969818115, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -6.886236190795898, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -2.3287723064422607, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": -9.082579612731934, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -8.306184768676758, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -10.162294387817383, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -6.873996257781982, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -10.086308479309082, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -8.069391250610352, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -10.074687004089355, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -17.203676223754883, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -15.812134742736816, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -10.763212203979492, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -3.6097567081451416, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -7.371165752410889, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -10.116365432739258, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": 2.3381083011627197, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -15.05810832977295, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -3.4082698822021484, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -8.308154106140137, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -9.934334754943848, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -4.966827869415283, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -13.838757514953613, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -8.109692573547363, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -2.6857166290283203, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -12.619490623474121, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -12.56435489654541, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -10.434200286865234, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -6.927921295166016, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -6.527944564819336, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -6.607351779937744, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -12.63137435913086, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": -12.4427490234375, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -3.7763655185699463, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -9.528964042663574, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -4.6869120597839355, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -10.90855598449707, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -6.655173301696777, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -3.270554304122925, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -16.982526779174805, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -15.353683471679688, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -8.847289085388184, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -10.179303169250488, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -6.731151103973389, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -7.674241542816162, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -9.233016967773438, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -11.5830717086792, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -14.37897777557373, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -4.1582865715026855, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": 0.197475865483284, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -18.406869888305664, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -6.320181369781494, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -24.789236068725586, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -8.58946704864502, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -6.373545169830322, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -16.464635848999023, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -9.792702674865723, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -8.00907039642334, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": 6.568103790283203, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -1.1935948133468628, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -4.287923336029053, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -13.90717601776123, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -13.259078979492188, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -4.4597859382629395, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": 3.266550064086914, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -17.591632843017578, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -6.757795333862305, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -3.6606576442718506, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -0.4319865107536316, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -8.018631935119629, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -9.239262580871582, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": -5.867883682250977, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -16.606130599975586, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -11.81203842163086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -7.561521530151367, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": 3.4671599864959717, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -21.93998908996582, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -4.782626628875732, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -4.104213714599609, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -6.890751838684082, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -9.23733901977539, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -4.768161773681641, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -6.677367210388184, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -9.043994903564453, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -4.714869022369385, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -3.2620174884796143, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -5.250110149383545, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -6.488597393035889, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -3.883333683013916, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -5.378838062286377, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -8.393364906311035, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -4.350249767303467, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -10.24892520904541, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -5.905289649963379, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -13.357450485229492, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -16.178735733032227, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -15.908679008483887, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -7.344059944152832, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -7.44371223449707, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -9.754671096801758, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -14.778365135192871, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": -13.482151985168457, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -7.292673587799072, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -9.378966331481934, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -9.126514434814453, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": -4.56641960144043, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -4.477183818817139, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -6.549602031707764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -6.186005592346191, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -9.142590522766113, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -6.239355564117432, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": -2.2536373138427734, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": -1.894028902053833, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -8.125317573547363, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -6.698769569396973, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -9.687060356140137, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -5.876283168792725, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -15.55165958404541, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -11.94643783569336, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -9.460631370544434, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -11.773155212402344, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -11.088447570800781, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -3.3102426528930664, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -1.4685629606246948, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -7.10137414932251, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -17.07517433166504, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -9.918875694274902, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -2.0156307220458984, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -9.946962356567383, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -7.392494201660156, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -9.749910354614258, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -7.147546291351318, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -11.540006637573242, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -9.33851432800293, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -9.769523620605469, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -12.711801528930664, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -6.6422953605651855, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -7.653461456298828, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": 0.8141601085662842, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -0.6052043437957764, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -4.644975185394287, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": 5.55590295791626, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -19.888980865478516, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": 1.2527320384979248, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -4.81308650970459, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -9.619791030883789, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -12.583415985107422, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -1.2959754467010498, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -6.864170551300049, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -8.394363403320312, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -1.894271731376648, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -8.552262306213379, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -7.477956771850586, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -12.555445671081543, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -17.114042282104492, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -17.859159469604492, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -19.37428092956543, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -4.23969841003418, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -6.650465965270996, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -7.718262672424316, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -6.551194667816162, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 640, \"mu_intercept_per_group\": -7.141420841217041, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 641, \"mu_intercept_per_group\": -12.319287300109863, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 642, \"mu_intercept_per_group\": -1.9240094423294067, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 643, \"mu_intercept_per_group\": -12.14867877960205, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 644, \"mu_intercept_per_group\": -8.549842834472656, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 645, \"mu_intercept_per_group\": -4.7822747230529785, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 646, \"mu_intercept_per_group\": -7.511908054351807, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 647, \"mu_intercept_per_group\": -8.554618835449219, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 648, \"mu_intercept_per_group\": -6.192224025726318, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 649, \"mu_intercept_per_group\": -2.184715986251831, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 650, \"mu_intercept_per_group\": 0.327439546585083, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 651, \"mu_intercept_per_group\": -8.841228485107422, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 652, \"mu_intercept_per_group\": -10.685248374938965, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 653, \"mu_intercept_per_group\": -11.242206573486328, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 654, \"mu_intercept_per_group\": -10.382344245910645, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 655, \"mu_intercept_per_group\": -5.185843467712402, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 656, \"mu_intercept_per_group\": -4.3155622482299805, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 657, \"mu_intercept_per_group\": -11.385210037231445, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 658, \"mu_intercept_per_group\": -15.944779396057129, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 659, \"mu_intercept_per_group\": -9.161582946777344, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 660, \"mu_intercept_per_group\": -7.693521976470947, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 661, \"mu_intercept_per_group\": -6.487646579742432, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 662, \"mu_intercept_per_group\": -6.708395004272461, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 663, \"mu_intercept_per_group\": -3.748321771621704, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 664, \"mu_intercept_per_group\": -3.1187522411346436, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 665, \"mu_intercept_per_group\": -5.392289161682129, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 666, \"mu_intercept_per_group\": -2.2252864837646484, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 667, \"mu_intercept_per_group\": -0.012133646756410599, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 668, \"mu_intercept_per_group\": -6.209344863891602, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 669, \"mu_intercept_per_group\": -4.447170257568359, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 670, \"mu_intercept_per_group\": 0.12659278512001038, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 671, \"mu_intercept_per_group\": -4.577426433563232, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 672, \"mu_intercept_per_group\": -8.053205490112305, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 673, \"mu_intercept_per_group\": -7.424107551574707, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 674, \"mu_intercept_per_group\": -7.840348243713379, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 675, \"mu_intercept_per_group\": -12.95202350616455, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 676, \"mu_intercept_per_group\": -2.3764352798461914, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 677, \"mu_intercept_per_group\": -7.701026916503906, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 678, \"mu_intercept_per_group\": 1.1807005405426025, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 679, \"mu_intercept_per_group\": -9.633260726928711, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 680, \"mu_intercept_per_group\": -8.008782386779785, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 681, \"mu_intercept_per_group\": -2.400926351547241, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 682, \"mu_intercept_per_group\": -16.178964614868164, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 683, \"mu_intercept_per_group\": -13.101844787597656, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 684, \"mu_intercept_per_group\": -8.684494972229004, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 685, \"mu_intercept_per_group\": -6.833575248718262, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 686, \"mu_intercept_per_group\": -3.6441476345062256, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 687, \"mu_intercept_per_group\": -3.5922977924346924, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 688, \"mu_intercept_per_group\": -18.850242614746094, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 689, \"mu_intercept_per_group\": 1.0820876359939575, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 690, \"mu_intercept_per_group\": -6.514820575714111, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 691, \"mu_intercept_per_group\": -1.3514366149902344, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 692, \"mu_intercept_per_group\": -1.5759904384613037, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 693, \"mu_intercept_per_group\": 2.053717613220215, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 694, \"mu_intercept_per_group\": -4.6263651847839355, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 695, \"mu_intercept_per_group\": -6.750999450683594, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 696, \"mu_intercept_per_group\": -4.758124351501465, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 697, \"mu_intercept_per_group\": -1.9505478143692017, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 698, \"mu_intercept_per_group\": -16.749841690063477, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 699, \"mu_intercept_per_group\": -13.986458778381348, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 700, \"mu_intercept_per_group\": -17.15596580505371, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 701, \"mu_intercept_per_group\": -17.973060607910156, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 702, \"mu_intercept_per_group\": -11.176142692565918, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 703, \"mu_intercept_per_group\": -0.8515474200248718, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 704, \"mu_intercept_per_group\": -16.14752769470215, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 705, \"mu_intercept_per_group\": -17.337581634521484, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 706, \"mu_intercept_per_group\": -5.1819167137146, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 707, \"mu_intercept_per_group\": -12.231256484985352, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 708, \"mu_intercept_per_group\": 1.0472511053085327, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 709, \"mu_intercept_per_group\": -26.541973114013672, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 710, \"mu_intercept_per_group\": -4.820431232452393, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 711, \"mu_intercept_per_group\": -17.555593490600586, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 712, \"mu_intercept_per_group\": -4.313548564910889, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 713, \"mu_intercept_per_group\": -12.815875053405762, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 714, \"mu_intercept_per_group\": -7.939393997192383, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 715, \"mu_intercept_per_group\": -9.014795303344727, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 716, \"mu_intercept_per_group\": -7.826602935791016, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 717, \"mu_intercept_per_group\": -1.84090256690979, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 718, \"mu_intercept_per_group\": -8.720623016357422, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 719, \"mu_intercept_per_group\": -13.187346458435059, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 720, \"mu_intercept_per_group\": -8.846368789672852, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 721, \"mu_intercept_per_group\": -6.637916564941406, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 722, \"mu_intercept_per_group\": -3.355745315551758, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 723, \"mu_intercept_per_group\": -2.7655088901519775, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 724, \"mu_intercept_per_group\": -4.8449811935424805, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 725, \"mu_intercept_per_group\": -3.848680257797241, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 726, \"mu_intercept_per_group\": -10.032918930053711, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 727, \"mu_intercept_per_group\": -3.0833189487457275, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 728, \"mu_intercept_per_group\": -9.624643325805664, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 729, \"mu_intercept_per_group\": -5.940707683563232, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 730, \"mu_intercept_per_group\": -7.710272789001465, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 731, \"mu_intercept_per_group\": -23.57373809814453, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 732, \"mu_intercept_per_group\": -15.726632118225098, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 733, \"mu_intercept_per_group\": -7.308401584625244, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 734, \"mu_intercept_per_group\": -9.822031021118164, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 735, \"mu_intercept_per_group\": -8.193119049072266, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 736, \"mu_intercept_per_group\": -1.6803587675094604, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 737, \"mu_intercept_per_group\": -14.743664741516113, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 738, \"mu_intercept_per_group\": -11.672747611999512, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 739, \"mu_intercept_per_group\": -8.721245765686035, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 740, \"mu_intercept_per_group\": -9.85912036895752, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 741, \"mu_intercept_per_group\": -1.3250946998596191, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 742, \"mu_intercept_per_group\": -6.714052677154541, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 743, \"mu_intercept_per_group\": -4.2093281745910645, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 744, \"mu_intercept_per_group\": -6.668892860412598, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 745, \"mu_intercept_per_group\": -3.4528956413269043, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 746, \"mu_intercept_per_group\": -6.977998733520508, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 747, \"mu_intercept_per_group\": -5.103305339813232, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 748, \"mu_intercept_per_group\": 0.21640686690807343, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 749, \"mu_intercept_per_group\": -2.2673940658569336, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 750, \"mu_intercept_per_group\": -1.6518634557724, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 751, \"mu_intercept_per_group\": -5.230224609375, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 752, \"mu_intercept_per_group\": -0.9623963832855225, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 753, \"mu_intercept_per_group\": -11.71789264678955, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 754, \"mu_intercept_per_group\": -3.776665210723877, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 755, \"mu_intercept_per_group\": -11.82597541809082, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 756, \"mu_intercept_per_group\": -12.082707405090332, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 757, \"mu_intercept_per_group\": -12.341635704040527, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 758, \"mu_intercept_per_group\": -14.834488868713379, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 759, \"mu_intercept_per_group\": -9.986968994140625, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 760, \"mu_intercept_per_group\": -10.320402145385742, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 2, \"draws\": 761, \"mu_intercept_per_group\": -13.905303955078125, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 2, \"draws\": 762, \"mu_intercept_per_group\": -16.491025924682617, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 2, \"draws\": 763, \"mu_intercept_per_group\": -5.7081732749938965, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 2, \"draws\": 764, \"mu_intercept_per_group\": -14.90152645111084, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 2, \"draws\": 765, \"mu_intercept_per_group\": -0.3089122772216797, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 2, \"draws\": 766, \"mu_intercept_per_group\": -15.320383071899414, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 2, \"draws\": 767, \"mu_intercept_per_group\": -4.846121788024902, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 2, \"draws\": 768, \"mu_intercept_per_group\": -6.406315326690674, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 2, \"draws\": 769, \"mu_intercept_per_group\": -10.758137702941895, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 2, \"draws\": 770, \"mu_intercept_per_group\": -7.8329854011535645, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 2, \"draws\": 771, \"mu_intercept_per_group\": 0.8221447467803955, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 2, \"draws\": 772, \"mu_intercept_per_group\": -21.661827087402344, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 2, \"draws\": 773, \"mu_intercept_per_group\": -12.66462230682373, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 2, \"draws\": 774, \"mu_intercept_per_group\": -14.172645568847656, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 2, \"draws\": 775, \"mu_intercept_per_group\": -8.050253868103027, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 2, \"draws\": 776, \"mu_intercept_per_group\": -11.800787925720215, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 2, \"draws\": 777, \"mu_intercept_per_group\": -21.02047348022461, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 2, \"draws\": 778, \"mu_intercept_per_group\": -7.51196813583374, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 2, \"draws\": 779, \"mu_intercept_per_group\": -8.911922454833984, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 2, \"draws\": 780, \"mu_intercept_per_group\": -10.23464298248291, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 2, \"draws\": 781, \"mu_intercept_per_group\": -2.848794460296631, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 2, \"draws\": 782, \"mu_intercept_per_group\": -3.9888498783111572, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 2, \"draws\": 783, \"mu_intercept_per_group\": -12.056135177612305, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 2, \"draws\": 784, \"mu_intercept_per_group\": -7.282134056091309, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 2, \"draws\": 785, \"mu_intercept_per_group\": -5.6719231605529785, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 2, \"draws\": 786, \"mu_intercept_per_group\": 0.6745861172676086, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 2, \"draws\": 787, \"mu_intercept_per_group\": -1.0155054330825806, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 2, \"draws\": 788, \"mu_intercept_per_group\": -8.687138557434082, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 2, \"draws\": 789, \"mu_intercept_per_group\": -7.499844074249268, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 2, \"draws\": 790, \"mu_intercept_per_group\": -2.866102933883667, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 2, \"draws\": 791, \"mu_intercept_per_group\": -3.8333287239074707, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 2, \"draws\": 792, \"mu_intercept_per_group\": -6.34598970413208, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 2, \"draws\": 793, \"mu_intercept_per_group\": -14.285922050476074, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 2, \"draws\": 794, \"mu_intercept_per_group\": -17.319591522216797, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 2, \"draws\": 795, \"mu_intercept_per_group\": -12.132493019104004, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 2, \"draws\": 796, \"mu_intercept_per_group\": -7.3018975257873535, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 2, \"draws\": 797, \"mu_intercept_per_group\": -10.934429168701172, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 2, \"draws\": 798, \"mu_intercept_per_group\": 1.3345128297805786, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 2, \"draws\": 799, \"mu_intercept_per_group\": -7.95594596862793, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": 1.1422832012176514, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": 3.4451889991760254, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -13.309249877929688, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -2.334221363067627, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -2.6834938526153564, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -1.050855040550232, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": -11.638349533081055, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -3.4021027088165283, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": -4.454543590545654, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -4.641628742218018, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": 1.0176398754119873, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": 1.382218837738037, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -4.815413475036621, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": 5.528326988220215, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": 8.008136749267578, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": 11.768983840942383, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -5.568403720855713, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -6.959604740142822, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -6.039422512054443, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": 2.300753116607666, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -5.080330848693848, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": -4.960811614990234, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -0.6755471229553223, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": 2.055466651916504, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": 15.956356048583984, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": 4.9173808097839355, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -14.728536605834961, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": -13.294828414916992, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -5.873209476470947, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": 2.3663792610168457, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -1.0872663259506226, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": 1.0575892925262451, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -0.23079244792461395, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -6.030643463134766, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -7.986595630645752, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -3.6445791721343994, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -1.7929785251617432, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -10.452860832214355, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -6.082972049713135, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -1.2904764413833618, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -0.5038827657699585, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -1.9818707704544067, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": -2.4391608238220215, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -3.6116600036621094, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": 1.880308985710144, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -1.596183180809021, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": 10.43369197845459, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": 10.978118896484375, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": 11.816225051879883, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": 7.06320858001709, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": 5.699960708618164, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.811556339263916, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": 7.416693687438965, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": 5.239987373352051, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -6.371124744415283, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -6.321715354919434, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -0.8365016579627991, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -1.100523829460144, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -9.814924240112305, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -2.12493634223938, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.7239115238189697, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -6.467557430267334, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -9.944820404052734, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -9.137910842895508, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": 4.786907196044922, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": 7.342767715454102, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": 21.530065536499023, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -3.220067024230957, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -2.410952568054199, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -0.7614163756370544, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -3.118800163269043, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -7.121359348297119, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": 0.9711492657661438, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -9.067095756530762, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.610410690307617, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -1.9965918064117432, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -5.7381486892700195, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -5.407534599304199, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -3.1097052097320557, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -0.051551930606365204, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": 1.6425068378448486, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": 2.8682215213775635, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": -5.482365131378174, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.255630016326904, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -1.8998559713363647, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -4.396988391876221, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": 0.8396350145339966, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": 1.5524109601974487, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": 4.776217460632324, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": 11.44230842590332, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": 9.291142463684082, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": -5.650680065155029, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": 0.710728645324707, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -5.860079765319824, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": 3.1312332153320312, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": 1.5535598993301392, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -2.915241003036499, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": 0.9959485530853271, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": 8.354219436645508, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.838305950164795, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": -5.439314842224121, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": 4.786798477172852, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -1.9363937377929688, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -7.338453769683838, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": 0.36386746168136597, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": -10.497365951538086, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -8.698169708251953, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": 0.6599807143211365, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -4.565549373626709, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -4.984137535095215, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -3.4180290699005127, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -2.035233736038208, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": -2.8604378700256348, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": -3.704653263092041, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": 1.111017107963562, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -0.39979448914527893, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -6.098702430725098, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -1.463597059249878, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -0.000967649684753269, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": -2.249558448791504, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": -2.216856002807617, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": -4.691045761108398, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -0.8590145707130432, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -4.1990814208984375, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -3.9876046180725098, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -0.9444401264190674, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -3.738778591156006, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": -9.33457088470459, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -1.212861180305481, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -9.126809120178223, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -16.431392669677734, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": 1.9312454462051392, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -6.761323928833008, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -2.729433536529541, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": 0.7777804732322693, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -6.178104877471924, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": 0.9076302647590637, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -6.937652587890625, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -2.5492546558380127, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -4.945709705352783, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -1.7667300701141357, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": 0.7200169563293457, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": 3.5294952392578125, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -4.999780178070068, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -2.732987642288208, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": 1.1399319171905518, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -0.09409604221582413, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -2.603269338607788, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": 2.263167381286621, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -2.1555821895599365, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": -4.189473628997803, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -1.4529013633728027, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": -2.817486524581909, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -0.8714385628700256, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -8.482097625732422, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": 4.959986686706543, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -6.086630344390869, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": 2.741875410079956, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -7.743535995483398, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": 11.827567100524902, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": 14.373174667358398, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -11.803725242614746, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": -17.219268798828125, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": 10.779607772827148, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": -7.521295070648193, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": 2.204723834991455, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": -0.06757959723472595, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -7.076362133026123, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -19.321819305419922, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": 10.665518760681152, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -15.639404296875, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": 7.635056018829346, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -0.4615268409252167, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": 8.905537605285645, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": 5.470874786376953, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -0.41181477904319763, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -3.8645167350769043, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": 2.6198697090148926, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -0.5493851900100708, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -2.6867988109588623, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -2.045103073120117, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -2.85786771774292, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -1.5691494941711426, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -6.313195705413818, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -5.157509803771973, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -1.6202298402786255, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": 0.9412631392478943, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -9.106287002563477, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -11.040139198303223, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": 5.320924758911133, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -1.043454885482788, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": 2.8296430110931396, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -3.5491135120391846, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -3.0336110591888428, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": 4.867432594299316, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -0.9833825826644897, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -0.5252104997634888, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": -5.145560264587402, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -4.320082187652588, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": 1.111548662185669, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -2.541640520095825, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -6.575405120849609, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -11.184614181518555, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -5.859685897827148, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -4.4939703941345215, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -6.390528202056885, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": 8.489559173583984, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -10.59765338897705, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -9.754304885864258, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -2.605734348297119, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": 3.5903382301330566, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -7.091739177703857, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -7.92171573638916, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": 0.17396149039268494, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -9.727476119995117, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": 3.487213373184204, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -2.6936447620391846, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": 12.155808448791504, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -3.0443296432495117, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -0.5025920271873474, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": 2.8304405212402344, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -10.801639556884766, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -0.5220856070518494, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -3.85499906539917, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -1.3167321681976318, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -6.445994853973389, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -6.1198835372924805, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": 4.902685165405273, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": 5.7540106773376465, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -5.082253456115723, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -3.7886149883270264, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -4.4853291511535645, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": 7.6265788078308105, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -1.692143201828003, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -4.007877349853516, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -3.221977710723877, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -1.347394585609436, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": 3.4872400760650635, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -6.5580620765686035, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": -5.686244010925293, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -1.484086275100708, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -6.134275436401367, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -3.998112201690674, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": 3.097943067550659, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -3.10587477684021, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -1.2060569524765015, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": 2.667961835861206, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -1.136277675628662, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": 0.020718803629279137, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": 2.6314878463745117, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -1.9009311199188232, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": -1.2595146894454956, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -1.4188594818115234, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": 0.3701774477958679, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -4.469882488250732, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -4.703858852386475, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": 2.9320223331451416, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": 3.490630865097046, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": -1.2078993320465088, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -4.197757244110107, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -6.318816661834717, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": 2.92828631401062, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -1.5768591165542603, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": 7.342698574066162, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -6.412532329559326, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": 3.4590110778808594, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": 5.967440605163574, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": 0.5187315940856934, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": 4.232466697692871, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -2.6163413524627686, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": 1.1103160381317139, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": -6.491605758666992, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -3.8196685314178467, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -2.652308702468872, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": 7.153045654296875, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -12.401137351989746, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -1.4257242679595947, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -3.7779064178466797, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": 5.371438026428223, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -10.941880226135254, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -11.144450187683105, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -3.7005515098571777, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -4.426377773284912, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -5.206786155700684, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": 8.41220474243164, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -3.45896053314209, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -2.978003740310669, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -1.7527974843978882, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -3.5697708129882812, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -7.499160289764404, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -2.673635244369507, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": -4.929272651672363, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -1.617139458656311, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -1.8594846725463867, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": -2.0745227336883545, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": 0.6467105746269226, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": 4.440384387969971, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": 1.7059365510940552, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -0.42386800050735474, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": -2.8983304500579834, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -3.9906091690063477, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -1.4967854022979736, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -2.459275960922241, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -0.5270119309425354, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -0.7536998391151428, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -4.541114807128906, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": 6.655881881713867, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -0.4428862929344177, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": 4.027284622192383, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -0.18719589710235596, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -5.053924560546875, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": -0.9571754336357117, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -4.632637977600098, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": 1.230791449546814, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -4.023431777954102, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -10.133399963378906, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -0.15544360876083374, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -5.1925859451293945, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": 10.034708976745605, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -11.376166343688965, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": -5.671952724456787, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -4.728982448577881, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -0.477090060710907, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -1.1253021955490112, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": 2.1307523250579834, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -4.218825817108154, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": 0.7177229523658752, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": 5.307969570159912, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -6.659838676452637, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": 0.8339402675628662, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -7.1644511222839355, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": 9.08468246459961, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": 8.221074104309082, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": 3.2874090671539307, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -10.034884452819824, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -7.14697790145874, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -5.812159061431885, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -9.020214080810547, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -0.0592881515622139, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -2.267007827758789, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": -2.3067283630371094, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": 2.1847925186157227, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": -8.609108924865723, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -7.968606472015381, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": 5.869666576385498, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -4.742668151855469, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": 2.67676043510437, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": -4.7433671951293945, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -5.591422080993652, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -4.894288539886475, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": 1.1010111570358276, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -10.362127304077148, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": 7.756590366363525, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": 10.190167427062988, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -2.9594478607177734, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -1.6523555517196655, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -8.56190299987793, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -2.955606460571289, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": 1.5201140642166138, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": 0.5285970568656921, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -0.9237287640571594, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -1.2570079565048218, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": -5.493432998657227, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -3.5231142044067383, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": 1.628109097480774, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": 0.5275156497955322, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": 5.90330696105957, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -7.689522743225098, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": 0.6258456707000732, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -8.762786865234375, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -5.9061994552612305, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -6.406050205230713, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -2.177804708480835, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -3.175398349761963, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.53462815284729, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.8630146980285645, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -3.1630401611328125, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -4.196714878082275, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -2.6307883262634277, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": 0.23636986315250397, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": 1.7251968383789062, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": -8.066803932189941, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -9.934847831726074, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": 10.237847328186035, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -16.784555435180664, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -14.604349136352539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -12.49198055267334, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -18.91082191467285, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -12.75493335723877, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": 8.327741622924805, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": -5.912790775299072, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -5.286569595336914, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -5.302486896514893, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -4.904359340667725, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -3.9771060943603516, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -2.971621513366699, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.789281845092773, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": 0.550115704536438, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -1.1442714929580688, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": 0.5929803252220154, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": -4.128983020782471, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": 0.654107928276062, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": 1.1824840307235718, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -4.839790344238281, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -3.5365540981292725, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.722402572631836, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": 3.623861074447632, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -1.5331995487213135, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -0.9055638909339905, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": -4.37939977645874, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -0.09710405766963959, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -4.23989725112915, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -5.184539318084717, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -1.9728769063949585, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": -5.851361274719238, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": 2.593122720718384, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": 3.2033915519714355, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -3.1738393306732178, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": 0.07471458613872528, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -5.293779373168945, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -0.15786832571029663, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": 7.1509528160095215, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -3.041566848754883, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -8.282413482666016, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": -8.749505043029785, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": 12.567148208618164, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -7.595125198364258, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -4.985073089599609, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -2.9983041286468506, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": 2.977707862854004, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -0.13216590881347656, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": 0.08115331083536148, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": 1.0226789712905884, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -6.061187744140625, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -12.322136878967285, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": 5.065090179443359, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": 7.918672561645508, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": 5.867305755615234, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": 2.042487621307373, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -0.6973666548728943, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -1.4755373001098633, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -0.40214118361473083, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": 1.972685694694519, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -5.049294948577881, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": 3.5060598850250244, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -3.3422980308532715, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": -2.1599979400634766, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -0.16590610146522522, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -0.675101637840271, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -1.7655251026153564, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": -3.0615193843841553, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": 0.9273499846458435, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -6.301034927368164, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -5.81266975402832, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -12.09800910949707, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -16.9748477935791, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -0.8389238119125366, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": 13.40527629852295, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": 4.561748027801514, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": 0.8433964848518372, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -6.979583263397217, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -0.5884028673171997, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -4.402454853057861, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -4.225096702575684, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -6.455096244812012, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -5.126056671142578, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -9.202210426330566, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -13.092423439025879, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": 2.330103874206543, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -3.111171245574951, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -1.5748965740203857, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": 6.025733470916748, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": -20.092267990112305, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -11.896636962890625, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": 0.13928580284118652, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": 8.409333229064941, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -5.502542018890381, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -4.66280460357666, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -1.5036921501159668, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": 2.001307964324951, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": 5.179535865783691, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": 0.6891594529151917, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -3.987020254135132, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -3.130981683731079, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -8.0926513671875, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": 3.002039670944214, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -10.398992538452148, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -0.7789192795753479, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": 16.261219024658203, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -15.879326820373535, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -14.116984367370605, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -5.021420001983643, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": 0.48141056299209595, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": 3.443138360977173, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": -4.203012943267822, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": 1.2212390899658203, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": 2.878952741622925, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -4.4430155754089355, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -1.9320683479309082, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": 3.059864044189453, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": -1.5174566507339478, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -7.900796890258789, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -7.854007720947266, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": 5.19315242767334, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": 2.12386155128479, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": 2.578529119491577, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -1.7175145149230957, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -3.82033371925354, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": 0.0025268117897212505, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -5.460965156555176, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -0.6229301691055298, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -0.009420330636203289, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": 5.668510913848877, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -5.805806636810303, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -5.268351078033447, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": 3.3501031398773193, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": 2.2356791496276855, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -2.5880022048950195, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -6.686184883117676, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -7.809329509735107, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -5.405384540557861, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": 1.952531337738037, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -11.692564010620117, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -6.440998554229736, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -10.477301597595215, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": 7.941324234008789, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": 9.543127059936523, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": 5.6837639808654785, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": 1.7521110773086548, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -5.787217140197754, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -7.043797969818115, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -8.691217422485352, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -3.84586238861084, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": 1.4004701375961304, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -1.488426685333252, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -6.012677192687988, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -1.4134918451309204, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.400400400161743, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": 0.3176666498184204, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -7.941269874572754, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -0.4374779462814331, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -5.062107563018799, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": 2.9750351905822754, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": 0.8638477325439453, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -1.4666558504104614, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": 5.508360862731934, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": 3.3465919494628906, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": 6.344620704650879, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": -2.2002763748168945, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -14.220636367797852, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": 6.004452705383301, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -19.313186645507812, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": 3.035220146179199, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -7.511860370635986, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": -1.2900664806365967, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -2.8503220081329346, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -6.260819435119629, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": -2.5331246852874756, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -8.642271995544434, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": 4.178277492523193, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": 2.3975954055786133, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -5.3959641456604, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -0.10079754143953323, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -4.879522323608398, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": 3.477522134780884, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -6.130655288696289, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": 1.7411397695541382, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": 9.138921737670898, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -10.642536163330078, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": 8.479148864746094, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": 6.1939873695373535, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": -11.953067779541016, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -9.57574462890625, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -12.450737953186035, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -1.5178221464157104, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": 0.982293963432312, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -4.705238342285156, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -1.3431538343429565, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -4.971939563751221, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -0.4891444742679596, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": 0.38888153433799744, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": 1.532944679260254, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -7.4955596923828125, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -10.090048789978027, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": 8.15038013458252, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": 7.267123699188232, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -2.7479090690612793, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": -9.160313606262207, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": -2.9178810119628906, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -1.0811572074890137, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -1.5299677848815918, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -3.080362558364868, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -6.4926676750183105, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -0.15025557577610016, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -5.4212188720703125, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": 0.12190693616867065, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -8.257290840148926, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -6.4581708908081055, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -1.8280775547027588, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -4.033593654632568, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": -2.4062139987945557, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -14.466475486755371, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": 3.689469575881958, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": 3.022028684616089, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -4.515467166900635, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -4.477755069732666, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -2.8041117191314697, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": 2.587585210800171, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": 6.183584213256836, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": 7.167823791503906, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": 9.330349922180176, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -0.7203639149665833, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -12.502355575561523, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": -10.53499984741211, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": 1.4793434143066406, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -9.836216926574707, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": 5.254878997802734, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -0.6041688323020935, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": 3.4832756519317627, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -3.310424327850342, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -6.958009719848633, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": 1.9582477807998657, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": 0.9501878023147583, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": 0.5971997380256653, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": 1.221201777458191, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -2.0772831439971924, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -5.599991321563721, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": 1.1452524662017822, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -3.9608592987060547, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": 2.485051155090332, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -6.193269729614258, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -5.742509841918945, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": 0.0498674251139164, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -13.879101753234863, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -14.36821460723877, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -18.042510986328125, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -3.22035813331604, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -1.0437861680984497, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": 0.015396964736282825, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -1.583577275276184, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 640, \"mu_intercept_per_group\": -2.0819149017333984, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 641, \"mu_intercept_per_group\": -0.7863612771034241, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 642, \"mu_intercept_per_group\": 7.002364635467529, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 643, \"mu_intercept_per_group\": 4.588798999786377, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 644, \"mu_intercept_per_group\": -10.203553199768066, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 645, \"mu_intercept_per_group\": 12.023187637329102, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 646, \"mu_intercept_per_group\": 6.173324108123779, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 647, \"mu_intercept_per_group\": 3.815366744995117, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 648, \"mu_intercept_per_group\": 1.77543306350708, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 649, \"mu_intercept_per_group\": 0.8806454539299011, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 650, \"mu_intercept_per_group\": 0.8425295352935791, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 651, \"mu_intercept_per_group\": -5.0908989906311035, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 652, \"mu_intercept_per_group\": -6.294406890869141, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 653, \"mu_intercept_per_group\": -4.240575790405273, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 654, \"mu_intercept_per_group\": 1.1153373718261719, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 655, \"mu_intercept_per_group\": -8.701765060424805, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 656, \"mu_intercept_per_group\": -8.359423637390137, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 657, \"mu_intercept_per_group\": -9.169832229614258, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 658, \"mu_intercept_per_group\": -4.485829830169678, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 659, \"mu_intercept_per_group\": -1.2002664804458618, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 660, \"mu_intercept_per_group\": -1.283840298652649, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 661, \"mu_intercept_per_group\": 0.8676854968070984, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 662, \"mu_intercept_per_group\": 1.0672951936721802, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 663, \"mu_intercept_per_group\": 4.966071605682373, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 664, \"mu_intercept_per_group\": -5.618011474609375, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 665, \"mu_intercept_per_group\": -3.85263729095459, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 666, \"mu_intercept_per_group\": 1.6280697584152222, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 667, \"mu_intercept_per_group\": 6.69218635559082, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 668, \"mu_intercept_per_group\": -1.8946659564971924, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 669, \"mu_intercept_per_group\": -3.206312417984009, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 670, \"mu_intercept_per_group\": -7.758072853088379, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 671, \"mu_intercept_per_group\": -8.816082000732422, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 672, \"mu_intercept_per_group\": -2.9414925575256348, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 673, \"mu_intercept_per_group\": 0.16837017238140106, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 674, \"mu_intercept_per_group\": -3.6111299991607666, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 675, \"mu_intercept_per_group\": -4.992269039154053, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 676, \"mu_intercept_per_group\": -0.8869007229804993, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 677, \"mu_intercept_per_group\": -3.622464656829834, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 678, \"mu_intercept_per_group\": -6.170212745666504, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 679, \"mu_intercept_per_group\": -8.245932579040527, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 680, \"mu_intercept_per_group\": -15.151115417480469, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 681, \"mu_intercept_per_group\": 5.21836519241333, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 682, \"mu_intercept_per_group\": -16.357988357543945, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 683, \"mu_intercept_per_group\": -1.631963849067688, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 684, \"mu_intercept_per_group\": -10.513628959655762, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 685, \"mu_intercept_per_group\": -9.62197494506836, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 686, \"mu_intercept_per_group\": -20.429683685302734, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 687, \"mu_intercept_per_group\": -21.109054565429688, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 688, \"mu_intercept_per_group\": -1.9177546501159668, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 689, \"mu_intercept_per_group\": -1.488953948020935, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 690, \"mu_intercept_per_group\": 1.6919147968292236, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 691, \"mu_intercept_per_group\": 2.763578176498413, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 692, \"mu_intercept_per_group\": -3.010648012161255, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 693, \"mu_intercept_per_group\": -6.339518070220947, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 694, \"mu_intercept_per_group\": 0.133871391415596, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 695, \"mu_intercept_per_group\": -2.2540857791900635, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 696, \"mu_intercept_per_group\": 1.3386919498443604, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 697, \"mu_intercept_per_group\": -0.2260308414697647, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 698, \"mu_intercept_per_group\": -8.835453987121582, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 699, \"mu_intercept_per_group\": 1.3694179058074951, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 700, \"mu_intercept_per_group\": 1.7521642446517944, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 701, \"mu_intercept_per_group\": -0.28043603897094727, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 702, \"mu_intercept_per_group\": -1.9403650760650635, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 703, \"mu_intercept_per_group\": -6.318399906158447, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 704, \"mu_intercept_per_group\": 13.841275215148926, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 705, \"mu_intercept_per_group\": 1.4841045141220093, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 706, \"mu_intercept_per_group\": 3.645707607269287, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 707, \"mu_intercept_per_group\": 1.5687335729599, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 708, \"mu_intercept_per_group\": -3.1403298377990723, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 709, \"mu_intercept_per_group\": -2.7531683444976807, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 710, \"mu_intercept_per_group\": -18.587854385375977, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 711, \"mu_intercept_per_group\": -5.753057479858398, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 712, \"mu_intercept_per_group\": 5.228336811065674, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 713, \"mu_intercept_per_group\": 3.0528054237365723, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 714, \"mu_intercept_per_group\": -6.099391937255859, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 715, \"mu_intercept_per_group\": -8.292634010314941, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 716, \"mu_intercept_per_group\": 1.57783842086792, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 717, \"mu_intercept_per_group\": 1.708120346069336, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 718, \"mu_intercept_per_group\": -1.237881064414978, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 719, \"mu_intercept_per_group\": -13.32564640045166, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 720, \"mu_intercept_per_group\": 2.978395938873291, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 721, \"mu_intercept_per_group\": -3.8427343368530273, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 722, \"mu_intercept_per_group\": 2.4600279331207275, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 723, \"mu_intercept_per_group\": 3.6240856647491455, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 724, \"mu_intercept_per_group\": 3.1564455032348633, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 725, \"mu_intercept_per_group\": 5.206112861633301, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 726, \"mu_intercept_per_group\": -10.339628219604492, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 727, \"mu_intercept_per_group\": 10.391362190246582, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 728, \"mu_intercept_per_group\": -13.145536422729492, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 729, \"mu_intercept_per_group\": -3.039750099182129, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 730, \"mu_intercept_per_group\": -1.8714406490325928, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 731, \"mu_intercept_per_group\": 2.5062243938446045, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 732, \"mu_intercept_per_group\": 2.355806827545166, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 733, \"mu_intercept_per_group\": 4.35094690322876, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 734, \"mu_intercept_per_group\": 2.01265811920166, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 735, \"mu_intercept_per_group\": -6.302050590515137, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 736, \"mu_intercept_per_group\": 1.2704237699508667, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 737, \"mu_intercept_per_group\": -6.088379859924316, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 738, \"mu_intercept_per_group\": 1.4410150051116943, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 739, \"mu_intercept_per_group\": -4.998089790344238, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 740, \"mu_intercept_per_group\": -1.0717111825942993, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 741, \"mu_intercept_per_group\": -2.8326401710510254, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 742, \"mu_intercept_per_group\": 0.5562751293182373, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 743, \"mu_intercept_per_group\": -4.102422714233398, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 744, \"mu_intercept_per_group\": -0.6741512417793274, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 745, \"mu_intercept_per_group\": -6.860042572021484, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 746, \"mu_intercept_per_group\": -7.127810001373291, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 747, \"mu_intercept_per_group\": -5.695292949676514, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 748, \"mu_intercept_per_group\": 8.79918384552002, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 749, \"mu_intercept_per_group\": 3.3661038875579834, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 750, \"mu_intercept_per_group\": -1.9716641902923584, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 751, \"mu_intercept_per_group\": 3.977968215942383, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 752, \"mu_intercept_per_group\": -4.175975799560547, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 753, \"mu_intercept_per_group\": -3.6886377334594727, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 754, \"mu_intercept_per_group\": -1.2347979545593262, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 755, \"mu_intercept_per_group\": -5.9835991859436035, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 756, \"mu_intercept_per_group\": -10.218194961547852, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 757, \"mu_intercept_per_group\": -4.862447261810303, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 758, \"mu_intercept_per_group\": -10.775684356689453, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 759, \"mu_intercept_per_group\": -3.4646146297454834, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 760, \"mu_intercept_per_group\": -2.4840354919433594, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 3, \"draws\": 761, \"mu_intercept_per_group\": -0.9740098714828491, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 3, \"draws\": 762, \"mu_intercept_per_group\": -3.4814372062683105, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 3, \"draws\": 763, \"mu_intercept_per_group\": -5.168466091156006, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 3, \"draws\": 764, \"mu_intercept_per_group\": -11.178720474243164, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 3, \"draws\": 765, \"mu_intercept_per_group\": -14.58297348022461, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 3, \"draws\": 766, \"mu_intercept_per_group\": -7.081275463104248, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 3, \"draws\": 767, \"mu_intercept_per_group\": 2.7455029487609863, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 3, \"draws\": 768, \"mu_intercept_per_group\": -0.04195941239595413, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 3, \"draws\": 769, \"mu_intercept_per_group\": -1.5294663906097412, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 3, \"draws\": 770, \"mu_intercept_per_group\": 9.213594436645508, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 3, \"draws\": 771, \"mu_intercept_per_group\": -4.530481815338135, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 3, \"draws\": 772, \"mu_intercept_per_group\": -8.007185935974121, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 3, \"draws\": 773, \"mu_intercept_per_group\": -8.879368782043457, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 3, \"draws\": 774, \"mu_intercept_per_group\": -8.491690635681152, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 3, \"draws\": 775, \"mu_intercept_per_group\": 5.7926249504089355, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 3, \"draws\": 776, \"mu_intercept_per_group\": -11.696650505065918, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 3, \"draws\": 777, \"mu_intercept_per_group\": -2.5717172622680664, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 3, \"draws\": 778, \"mu_intercept_per_group\": -1.936160683631897, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 3, \"draws\": 779, \"mu_intercept_per_group\": -4.924736499786377, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 3, \"draws\": 780, \"mu_intercept_per_group\": -9.15251636505127, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 3, \"draws\": 781, \"mu_intercept_per_group\": -0.9256086349487305, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 3, \"draws\": 782, \"mu_intercept_per_group\": -2.718745470046997, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 3, \"draws\": 783, \"mu_intercept_per_group\": 0.4050230085849762, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 3, \"draws\": 784, \"mu_intercept_per_group\": -6.642741680145264, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 3, \"draws\": 785, \"mu_intercept_per_group\": 3.859210252761841, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 3, \"draws\": 786, \"mu_intercept_per_group\": -5.522294521331787, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 3, \"draws\": 787, \"mu_intercept_per_group\": 7.714738845825195, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 3, \"draws\": 788, \"mu_intercept_per_group\": -5.8960394859313965, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 3, \"draws\": 789, \"mu_intercept_per_group\": -2.492332696914673, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 3, \"draws\": 790, \"mu_intercept_per_group\": 6.8780364990234375, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 3, \"draws\": 791, \"mu_intercept_per_group\": 6.295490741729736, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 3, \"draws\": 792, \"mu_intercept_per_group\": 3.3202102184295654, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 3, \"draws\": 793, \"mu_intercept_per_group\": 0.27863284945487976, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 3, \"draws\": 794, \"mu_intercept_per_group\": -0.6200317144393921, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 3, \"draws\": 795, \"mu_intercept_per_group\": -0.4486876130104065, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 3, \"draws\": 796, \"mu_intercept_per_group\": -5.382551670074463, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 3, \"draws\": 797, \"mu_intercept_per_group\": 10.205591201782227, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 3, \"draws\": 798, \"mu_intercept_per_group\": -9.05825424194336, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 3, \"draws\": 799, \"mu_intercept_per_group\": 9.337186813354492, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": -10.222573280334473, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": 0.7351592779159546, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -4.840921878814697, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -2.0387380123138428, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": 1.2483538389205933, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -2.9457359313964844, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -5.501341819763184, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -8.34166431427002, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": -1.844313621520996, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -6.937033176422119, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": -3.4211442470550537, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": 0.9551476240158081, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -0.4594762623310089, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": -2.6546359062194824, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": -0.28176337480545044, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -2.703993797302246, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": 9.14089298248291, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": 6.106947422027588, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": 6.025209426879883, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -5.250345706939697, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": 6.868474960327148, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": -2.2628467082977295, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -11.139957427978516, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": 0.7120257616043091, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": 1.6031622886657715, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": -8.283370018005371, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": -1.4586102962493896, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": -1.5663509368896484, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -9.569623947143555, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": 3.1074273586273193, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": -1.128059983253479, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": 2.5137887001037598, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -1.8959046602249146, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -5.683225154876709, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -6.53802490234375, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -5.361851692199707, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -3.998962640762329, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -9.249808311462402, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -7.951653957366943, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": 6.277647495269775, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": 0.48686710000038147, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": -0.9286237955093384, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": 5.7846903800964355, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": 3.9058072566986084, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": 12.240160942077637, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": 7.2814507484436035, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -10.052249908447266, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": -10.43879222869873, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": 7.636048316955566, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": 9.484684944152832, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": 7.747954845428467, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -5.559622287750244, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -1.6774073839187622, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": 0.3476562798023224, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": -1.2113286256790161, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": 2.4230000972747803, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": 3.167386293411255, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": -1.7299370765686035, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -3.0267183780670166, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": 0.589921772480011, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -8.071708679199219, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -0.665273129940033, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -5.544233798980713, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": 0.5462062954902649, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -6.977456569671631, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -9.465309143066406, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": 2.9924938678741455, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": -0.47992295026779175, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": -0.25456222891807556, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -3.280860662460327, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": 1.5002942085266113, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -3.6058130264282227, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -0.7466505765914917, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -3.2043683528900146, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": -5.266552448272705, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": -12.962620735168457, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": -8.191950798034668, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": 1.2133440971374512, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -3.3012075424194336, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -4.116568088531494, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": 1.3200589418411255, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": 1.343465805053711, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -5.596874237060547, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -10.104131698608398, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": 3.3133914470672607, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": 5.00221061706543, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": 5.407783508300781, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -4.314720153808594, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": 18.991758346557617, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": -0.6752288937568665, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": -0.48365887999534607, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": -3.6919829845428467, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": 4.215518474578857, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -6.701752662658691, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": 4.814064979553223, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": 3.983412265777588, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -4.883889198303223, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -3.206291675567627, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": 3.3244102001190186, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": 5.707808971405029, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": 7.159797191619873, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -1.932453989982605, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": 3.110919713973999, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": -2.2059030532836914, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": 7.051965713500977, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": -4.265612602233887, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -12.290275573730469, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": 4.426063537597656, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": -2.242264747619629, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": -1.0556801557540894, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": -0.9302979111671448, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": -4.810073375701904, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": 1.5923924446105957, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": -3.728991746902466, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": 5.562324047088623, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": 3.485109329223633, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -0.3389970064163208, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -3.247162103652954, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": 1.2077232599258423, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": -1.7801531553268433, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": 0.6469892859458923, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": 0.7023070454597473, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -4.512775421142578, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -2.7560360431671143, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -1.5878812074661255, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -6.278449058532715, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -5.4340410232543945, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": -5.3703436851501465, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": 2.3976669311523438, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": -4.363067150115967, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -6.9952712059021, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -10.892335891723633, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": 3.478604793548584, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": 0.783741295337677, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": -4.214395523071289, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": 2.311872959136963, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -6.152163028717041, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": 3.9275498390197754, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": -7.379451274871826, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": 1.9290038347244263, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -5.134275913238525, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -2.58302640914917, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": 1.8919726610183716, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": 3.966975212097168, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -7.511531829833984, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -4.661186218261719, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": 4.783458232879639, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": 0.015353485941886902, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -2.604113817214966, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": 2.289116859436035, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -8.103594779968262, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": 2.359726667404175, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": -1.2524923086166382, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -3.437492847442627, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": 0.6847198605537415, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -1.9796546697616577, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": 5.471470355987549, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": -4.455415725708008, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": -2.1415693759918213, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": 5.087538719177246, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": 4.994999408721924, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": 3.9994425773620605, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": 3.4031996726989746, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -8.986064910888672, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": 3.3010106086730957, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -1.4659618139266968, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": 0.22813911736011505, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": 4.13400936126709, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -1.0655854940414429, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -5.3494873046875, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": 2.6429660320281982, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -2.794489622116089, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": 0.44388440251350403, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": 5.480645179748535, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": 2.0663249492645264, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": 3.190870761871338, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": 0.4560146629810333, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -1.3204753398895264, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": 4.639101505279541, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -2.3368122577667236, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": -0.12557123601436615, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -4.177392482757568, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -1.4043046236038208, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": 3.410184144973755, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": -4.618890762329102, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": 0.9706475734710693, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -5.469550132751465, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -10.25925350189209, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -5.198490142822266, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": 0.6035569906234741, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -4.91817045211792, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -1.833343744277954, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -1.9475245475769043, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -4.199075222015381, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -0.6295586228370667, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -7.06285285949707, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -7.332114219665527, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": -1.8951919078826904, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": -1.390397548675537, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": 5.134096145629883, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -3.130772352218628, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": -3.425441026687622, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -10.429344177246094, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -6.859905242919922, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -7.089567184448242, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -7.857722759246826, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -6.922474384307861, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": 0.9095247983932495, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": 1.1069105863571167, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -8.023462295532227, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -11.704340934753418, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": 5.241725921630859, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": 4.544750213623047, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -9.038421630859375, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -4.5517048835754395, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -2.0782558917999268, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": 4.884559154510498, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": -0.8930679559707642, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": 3.2035889625549316, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": 3.412111520767212, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": 6.3044891357421875, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -9.152482032775879, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": -0.036205701529979706, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -2.2955758571624756, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -11.870111465454102, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": 5.123497486114502, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -21.790081024169922, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -19.68638038635254, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -15.662795066833496, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": 10.203377723693848, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": 8.00701904296875, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": 5.623378276824951, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": 6.930778980255127, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": -2.4476048946380615, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": -4.406008720397949, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": -0.639160692691803, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -8.552936553955078, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -7.73972749710083, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": 1.669751524925232, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": -5.550314903259277, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -1.334588646888733, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -7.068094730377197, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -5.390186786651611, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": 1.802512764930725, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": 2.1883575916290283, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -2.4512076377868652, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": 0.2697095572948456, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": 2.4418365955352783, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": 3.1828649044036865, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -0.5853416919708252, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": -1.688409447669983, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": -0.321841835975647, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": 1.7025400400161743, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -5.3715972900390625, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -2.4557180404663086, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": -4.347818374633789, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -4.5496344566345215, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -3.889549732208252, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": -9.831265449523926, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -7.587305545806885, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -9.38453483581543, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": 11.450456619262695, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": 10.535062789916992, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -9.374042510986328, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -7.373213768005371, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -2.8359947204589844, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -3.4654200077056885, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": -1.794429898262024, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": 7.437652587890625, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": -3.163054943084717, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": 0.7324626445770264, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": 3.7192869186401367, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": 4.074527740478516, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": 3.914069890975952, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": 4.926583290100098, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": 1.005097508430481, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -6.599051475524902, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -13.909625053405762, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -14.652721405029297, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": 16.287742614746094, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": 15.183490753173828, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": 8.074374198913574, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": 7.079869747161865, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.352164268493652, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": 3.445081949234009, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": -0.13314545154571533, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": 0.12403306365013123, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": 3.615466833114624, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": 2.841648578643799, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": 6.290352821350098, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": -3.2495901584625244, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": -6.687504768371582, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": 1.56047523021698, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": -1.3200434446334839, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": -1.990303874015808, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": -0.9329994916915894, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": -0.19775116443634033, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": 4.739821434020996, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": 4.048184871673584, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": 0.6300459504127502, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": 0.37932610511779785, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": -1.1257051229476929, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": 0.17781753838062286, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.540189027786255, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -5.3517045974731445, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": 3.7807674407958984, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": 3.5766971111297607, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": 6.87188720703125, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": -0.2200179249048233, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": 4.251936435699463, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": 1.6953351497650146, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -1.2283800840377808, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": -5.675398349761963, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": 4.123122215270996, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -4.602899074554443, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": 2.192589044570923, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -5.83239221572876, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -5.904195785522461, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -6.1403422355651855, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": 2.6582698822021484, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -4.622495174407959, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -2.3200156688690186, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -10.623682975769043, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -15.656454086303711, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -11.915611267089844, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -7.29128885269165, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -9.28799057006836, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": -1.5844402313232422, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -9.355169296264648, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -9.797776222229004, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": 1.6542587280273438, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": 8.481145858764648, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": 4.470423221588135, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -1.3096708059310913, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -10.22557544708252, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -2.129939556121826, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": -3.6794984340667725, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": -2.065094470977783, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -3.083914041519165, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": 4.107353687286377, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": -1.0638706684112549, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": -1.496822714805603, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": -3.2917540073394775, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": 3.55251145362854, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": -2.9563403129577637, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": 4.9263505935668945, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": -9.568013191223145, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": -13.995607376098633, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": -4.618760108947754, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": 5.174973487854004, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -7.510647296905518, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": 5.256582260131836, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": -6.16785192489624, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": 2.0095841884613037, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": -0.8866797089576721, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": 1.922220230102539, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": 3.6239891052246094, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -8.089971542358398, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": 7.619902610778809, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -8.913562774658203, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": -8.175060272216797, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": -0.1956782341003418, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -1.8559167385101318, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": 2.4483916759490967, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": 2.8031749725341797, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": 1.4116320610046387, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": 1.2916738986968994, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": 0.016939561814069748, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -6.3288960456848145, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": -0.9084743857383728, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -2.4604382514953613, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -4.6587233543396, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -3.721674680709839, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -3.6613924503326416, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -7.367818355560303, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -2.456761598587036, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -0.811137855052948, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -3.5969862937927246, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": 3.7880971431732178, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": 2.0546035766601562, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": 3.7384068965911865, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -3.1992483139038086, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": 4.091832637786865, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": 3.10144305229187, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": 8.00448989868164, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -12.494241714477539, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": -15.75905990600586, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": -15.911749839782715, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": -14.960686683654785, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": 7.879668712615967, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": -5.545164585113525, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -8.131694793701172, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": 6.875602722167969, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": 4.374419212341309, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": 6.496573448181152, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": -5.026095390319824, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -8.928727149963379, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -11.550392150878906, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -8.368969917297363, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -6.962975025177002, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": 6.889718055725098, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": 2.922802448272705, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": -4.909971237182617, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": -2.0281882286071777, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -0.21226929128170013, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -2.285454750061035, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -0.6161280274391174, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": 2.2025299072265625, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": -2.122138738632202, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": 4.103301525115967, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": -5.548608779907227, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": 2.7988741397857666, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -8.01515007019043, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": 0.42529040575027466, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": -3.6517932415008545, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": -0.5515525341033936, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": 2.0600452423095703, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": -1.0337955951690674, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": -1.0684521198272705, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -2.2774314880371094, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": -7.314043045043945, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -2.4525113105773926, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -4.27780818939209, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": 1.5510914325714111, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": -0.1506415456533432, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -3.740121841430664, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -5.2863545417785645, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": 5.354739665985107, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": 0.6194051504135132, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -4.08737850189209, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -2.1308741569519043, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -1.3846282958984375, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -2.911750555038452, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -9.480743408203125, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -1.6755708456039429, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -5.225432395935059, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": 4.965527057647705, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": 0.765901505947113, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -0.2432432472705841, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": 1.9107531309127808, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": 1.245962142944336, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -2.8260066509246826, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": 6.900586128234863, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -5.26108455657959, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": 2.28515625, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -4.239246845245361, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": 3.115494966506958, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -2.684730052947998, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -1.2988783121109009, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.9401421546936035, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -2.1803243160247803, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -3.8678042888641357, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": 1.2255836725234985, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": 0.8233058452606201, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": 6.4001641273498535, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -3.6718525886535645, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": 3.9332029819488525, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": 6.823799133300781, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -0.9171903133392334, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": -4.349397659301758, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": 1.7256262302398682, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -3.1465160846710205, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": 0.9560574889183044, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -3.488286256790161, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": 5.763370513916016, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -6.90833044052124, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": 0.5493221879005432, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -1.9435194730758667, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": -0.7900018692016602, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -7.044142246246338, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -6.870087146759033, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -6.215428352355957, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -0.42390817403793335, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -3.4466910362243652, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": 1.4385346174240112, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": 2.753023624420166, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": 2.7223126888275146, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": -6.31094217300415, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": 6.110436916351318, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": 6.438925743103027, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": 5.934630870819092, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": 4.618720054626465, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": -4.0582733154296875, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -8.378496170043945, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -9.8966646194458, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": 1.2092821598052979, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": -4.2657575607299805, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": 7.811222076416016, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": 1.8952081203460693, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": 2.6893508434295654, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": 5.602606296539307, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": 4.052567481994629, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -2.7636845111846924, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -1.1795055866241455, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -4.659461975097656, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": 7.605453968048096, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": -1.9424526691436768, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": 1.479622721672058, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": 4.631229877471924, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": 2.5250823497772217, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": 0.3759743273258209, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -8.323416709899902, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -1.308106780052185, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": -0.3469439446926117, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": -2.320566415786743, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": -1.714707612991333, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": 1.4244813919067383, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": 1.5334476232528687, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": 3.9070937633514404, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -9.991410255432129, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -0.1964610517024994, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": -2.2191975116729736, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -5.656458854675293, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -6.365799427032471, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -0.8335336446762085, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -1.2123515605926514, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": 6.899072647094727, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": 4.415450572967529, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -14.038524627685547, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -6.8309102058410645, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -1.3698656558990479, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -10.225632667541504, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": -2.8464319705963135, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": 0.6432567238807678, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -0.3441639244556427, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": -4.115943908691406, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": -4.275806903839111, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -1.2931828498840332, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -12.119006156921387, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -19.19034767150879, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": 2.8981902599334717, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": 2.008270263671875, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": 5.80705451965332, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": 1.1107293367385864, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -6.476484775543213, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -8.136292457580566, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": 0.5145658254623413, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -5.958985328674316, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": 1.2898212671279907, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -0.7434753775596619, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": -14.839637756347656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": 9.21174430847168, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -11.331006050109863, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -12.430768013000488, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": 3.0895018577575684, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": 0.7254382371902466, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": 2.220641851425171, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": 4.793663501739502, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": 0.6892642974853516, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -2.923584222793579, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": -5.301235198974609, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -2.648239850997925, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": -15.617238998413086, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": 5.484040260314941, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": -0.8728763461112976, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -0.5054839253425598, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -0.6188060641288757, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -4.285893440246582, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -7.326533794403076, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -0.6164996027946472, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": 1.4153728485107422, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -9.29893684387207, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": -8.429384231567383, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": 5.165633201599121, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": -1.2580235004425049, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": 2.07047438621521, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": 0.11970026791095734, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": 3.7929165363311768, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -1.8149521350860596, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": 13.338642120361328, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": 6.8847150802612305, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -7.743525505065918, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -4.1702446937561035, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -5.477596282958984, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": -5.992972373962402, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": 2.686174154281616, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -5.086594104766846, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -8.534751892089844, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": 4.817463397979736, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -4.412678241729736, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -9.72543716430664, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -13.762779235839844, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": 4.749863147735596, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": -7.763848781585693, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": 9.345660209655762, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": 2.645254373550415, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -0.2019905000925064, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": 0.8105884790420532, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": 1.4256742000579834, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -3.2158706188201904, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": -0.8970597386360168, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": 0.28827059268951416, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -0.01489965058863163, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -7.373693943023682, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -0.13117434084415436, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -4.393489360809326, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -0.5609362125396729, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": 2.605276107788086, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": 2.394541025161743, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": 0.8525758385658264, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -4.941886901855469, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -4.616106986999512, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": 13.114214897155762, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -12.420550346374512, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": 2.9929749965667725, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": -0.11894222348928452, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -2.2654402256011963, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": 3.9687790870666504, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": 8.39231014251709, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": 19.870697021484375, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": 17.059907913208008, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": 0.5694618225097656, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": 5.5281548500061035, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": -3.6333203315734863, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": -10.495563507080078, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": 4.230743408203125, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": -5.583453178405762, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.991307497024536, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": 1.5501219034194946, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": 3.2045388221740723, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -6.84132194519043, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": 11.670865058898926, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -11.415975570678711, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -10.994959831237793, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -11.472407341003418, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -8.113114356994629, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": 4.982320308685303, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": 4.659554481506348, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -4.935208320617676, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": 9.936370849609375, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -10.630620956420898, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": -2.723560333251953, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -11.783170700073242, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -1.104187250137329, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -1.1529127359390259, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -7.889201641082764, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": 14.02910041809082, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": -5.565239906311035, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": -4.031822681427002, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": -1.7019822597503662, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 640, \"mu_intercept_per_group\": -0.26659125089645386, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 641, \"mu_intercept_per_group\": -4.296065330505371, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 642, \"mu_intercept_per_group\": -10.37691879272461, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 643, \"mu_intercept_per_group\": -18.959091186523438, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 644, \"mu_intercept_per_group\": 2.9422106742858887, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 645, \"mu_intercept_per_group\": -9.414095878601074, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 646, \"mu_intercept_per_group\": 5.117735385894775, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 647, \"mu_intercept_per_group\": 1.6604464054107666, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 648, \"mu_intercept_per_group\": 8.517123222351074, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 649, \"mu_intercept_per_group\": -5.795717239379883, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 650, \"mu_intercept_per_group\": -0.7973559498786926, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 651, \"mu_intercept_per_group\": 2.1765658855438232, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 652, \"mu_intercept_per_group\": -8.471039772033691, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 653, \"mu_intercept_per_group\": 2.805842638015747, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 654, \"mu_intercept_per_group\": 0.9290947318077087, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 655, \"mu_intercept_per_group\": -11.014189720153809, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 656, \"mu_intercept_per_group\": 4.851659774780273, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 657, \"mu_intercept_per_group\": -5.456446170806885, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 658, \"mu_intercept_per_group\": -7.925178527832031, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 659, \"mu_intercept_per_group\": 3.368788003921509, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 660, \"mu_intercept_per_group\": -2.5615501403808594, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 661, \"mu_intercept_per_group\": -0.13357359170913696, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 662, \"mu_intercept_per_group\": -1.440045952796936, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 663, \"mu_intercept_per_group\": -4.536013603210449, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 664, \"mu_intercept_per_group\": 3.1310298442840576, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 665, \"mu_intercept_per_group\": 3.234423875808716, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 666, \"mu_intercept_per_group\": -3.2979557514190674, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 667, \"mu_intercept_per_group\": -2.1722490787506104, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 668, \"mu_intercept_per_group\": -3.063098430633545, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 669, \"mu_intercept_per_group\": -0.7444708943367004, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 670, \"mu_intercept_per_group\": -2.700894355773926, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 671, \"mu_intercept_per_group\": -0.5761053562164307, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 672, \"mu_intercept_per_group\": 1.9821075201034546, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 673, \"mu_intercept_per_group\": 9.100384712219238, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 674, \"mu_intercept_per_group\": -8.743980407714844, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 675, \"mu_intercept_per_group\": -2.040138006210327, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 676, \"mu_intercept_per_group\": -2.3280317783355713, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 677, \"mu_intercept_per_group\": 1.358982801437378, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 678, \"mu_intercept_per_group\": -4.481082916259766, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 679, \"mu_intercept_per_group\": -0.7191506028175354, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 680, \"mu_intercept_per_group\": -3.6019070148468018, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 681, \"mu_intercept_per_group\": -7.443073749542236, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 682, \"mu_intercept_per_group\": -6.465905666351318, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 683, \"mu_intercept_per_group\": -7.507283687591553, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 684, \"mu_intercept_per_group\": -0.38660094141960144, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 685, \"mu_intercept_per_group\": 0.3696950376033783, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 686, \"mu_intercept_per_group\": -9.97179889678955, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 687, \"mu_intercept_per_group\": -9.013978958129883, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 688, \"mu_intercept_per_group\": 5.4107584953308105, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 689, \"mu_intercept_per_group\": -9.146997451782227, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 690, \"mu_intercept_per_group\": 9.48569107055664, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 691, \"mu_intercept_per_group\": -5.376854419708252, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 692, \"mu_intercept_per_group\": -6.184321880340576, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 693, \"mu_intercept_per_group\": -7.036289215087891, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 694, \"mu_intercept_per_group\": -7.786212921142578, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 695, \"mu_intercept_per_group\": -11.990128517150879, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 696, \"mu_intercept_per_group\": 10.64962387084961, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 697, \"mu_intercept_per_group\": 8.805665969848633, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 698, \"mu_intercept_per_group\": -13.136034965515137, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 699, \"mu_intercept_per_group\": -11.427478790283203, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 700, \"mu_intercept_per_group\": -11.816218376159668, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 701, \"mu_intercept_per_group\": -11.609723091125488, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 702, \"mu_intercept_per_group\": -4.233506202697754, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 703, \"mu_intercept_per_group\": 4.785616397857666, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 704, \"mu_intercept_per_group\": -4.93176794052124, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 705, \"mu_intercept_per_group\": -8.722419738769531, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 706, \"mu_intercept_per_group\": -2.6878652572631836, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 707, \"mu_intercept_per_group\": -6.328852653503418, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 708, \"mu_intercept_per_group\": 8.036919593811035, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 709, \"mu_intercept_per_group\": 0.8848922848701477, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 710, \"mu_intercept_per_group\": -11.791319847106934, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 711, \"mu_intercept_per_group\": -8.944643020629883, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 712, \"mu_intercept_per_group\": -3.957019567489624, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 713, \"mu_intercept_per_group\": -2.2577407360076904, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 714, \"mu_intercept_per_group\": -8.689230918884277, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 715, \"mu_intercept_per_group\": -3.3575379848480225, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 716, \"mu_intercept_per_group\": 3.798638343811035, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 717, \"mu_intercept_per_group\": 1.9333914518356323, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 718, \"mu_intercept_per_group\": -1.0012797117233276, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 719, \"mu_intercept_per_group\": -7.519647598266602, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 720, \"mu_intercept_per_group\": 1.144483208656311, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 721, \"mu_intercept_per_group\": -5.495861530303955, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 722, \"mu_intercept_per_group\": 7.084209442138672, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 723, \"mu_intercept_per_group\": 12.742281913757324, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 724, \"mu_intercept_per_group\": 9.369956016540527, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 725, \"mu_intercept_per_group\": 12.737908363342285, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 726, \"mu_intercept_per_group\": -6.68929386138916, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 727, \"mu_intercept_per_group\": 5.712256908416748, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 728, \"mu_intercept_per_group\": -7.096992015838623, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 729, \"mu_intercept_per_group\": -10.005788803100586, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 730, \"mu_intercept_per_group\": 5.818517684936523, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 731, \"mu_intercept_per_group\": -6.018786430358887, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 732, \"mu_intercept_per_group\": -0.7372608184814453, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 733, \"mu_intercept_per_group\": -2.1605422496795654, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 734, \"mu_intercept_per_group\": -9.852314949035645, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 735, \"mu_intercept_per_group\": -7.954211235046387, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 736, \"mu_intercept_per_group\": -0.5064754486083984, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 737, \"mu_intercept_per_group\": -4.683851718902588, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 738, \"mu_intercept_per_group\": -3.0086984634399414, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 739, \"mu_intercept_per_group\": -1.696182131767273, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 740, \"mu_intercept_per_group\": -6.719401836395264, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 741, \"mu_intercept_per_group\": 3.822751522064209, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 742, \"mu_intercept_per_group\": -4.209133148193359, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 743, \"mu_intercept_per_group\": -3.0948832035064697, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 744, \"mu_intercept_per_group\": 1.826290488243103, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 745, \"mu_intercept_per_group\": 2.9357244968414307, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 746, \"mu_intercept_per_group\": -6.093136787414551, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 747, \"mu_intercept_per_group\": -10.260705947875977, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 748, \"mu_intercept_per_group\": 8.261493682861328, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 749, \"mu_intercept_per_group\": 7.822362422943115, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 750, \"mu_intercept_per_group\": 4.961631774902344, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 751, \"mu_intercept_per_group\": -7.214239120483398, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 752, \"mu_intercept_per_group\": -6.27641487121582, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 753, \"mu_intercept_per_group\": 3.171701431274414, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 754, \"mu_intercept_per_group\": -4.702463626861572, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 755, \"mu_intercept_per_group\": 3.1011359691619873, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 756, \"mu_intercept_per_group\": 6.190070629119873, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 757, \"mu_intercept_per_group\": 4.508309364318848, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 758, \"mu_intercept_per_group\": -6.019010066986084, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 759, \"mu_intercept_per_group\": -2.8097918033599854, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 760, \"mu_intercept_per_group\": -4.367959499359131, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 4, \"draws\": 761, \"mu_intercept_per_group\": -2.824897050857544, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 4, \"draws\": 762, \"mu_intercept_per_group\": -3.17814564704895, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 4, \"draws\": 763, \"mu_intercept_per_group\": 3.206871509552002, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 4, \"draws\": 764, \"mu_intercept_per_group\": -2.970684766769409, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 4, \"draws\": 765, \"mu_intercept_per_group\": -5.780794620513916, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 4, \"draws\": 766, \"mu_intercept_per_group\": -1.0261821746826172, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 4, \"draws\": 767, \"mu_intercept_per_group\": 1.2663980722427368, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 4, \"draws\": 768, \"mu_intercept_per_group\": 1.2258639335632324, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 4, \"draws\": 769, \"mu_intercept_per_group\": -13.134469985961914, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 4, \"draws\": 770, \"mu_intercept_per_group\": 6.728440284729004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 4, \"draws\": 771, \"mu_intercept_per_group\": -5.930309295654297, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 4, \"draws\": 772, \"mu_intercept_per_group\": 2.635946273803711, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 4, \"draws\": 773, \"mu_intercept_per_group\": -11.658357620239258, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 4, \"draws\": 774, \"mu_intercept_per_group\": 5.645565032958984, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 4, \"draws\": 775, \"mu_intercept_per_group\": -13.9772367477417, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 4, \"draws\": 776, \"mu_intercept_per_group\": 6.683927059173584, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 4, \"draws\": 777, \"mu_intercept_per_group\": 3.967349052429199, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 4, \"draws\": 778, \"mu_intercept_per_group\": -2.4375128746032715, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 4, \"draws\": 779, \"mu_intercept_per_group\": 0.6895599365234375, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 4, \"draws\": 780, \"mu_intercept_per_group\": -0.7696780562400818, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 4, \"draws\": 781, \"mu_intercept_per_group\": -5.970967769622803, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 4, \"draws\": 782, \"mu_intercept_per_group\": 6.066479682922363, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 4, \"draws\": 783, \"mu_intercept_per_group\": -9.849822044372559, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 4, \"draws\": 784, \"mu_intercept_per_group\": 1.4375027418136597, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 4, \"draws\": 785, \"mu_intercept_per_group\": -2.4956202507019043, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 4, \"draws\": 786, \"mu_intercept_per_group\": 5.292853832244873, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 4, \"draws\": 787, \"mu_intercept_per_group\": -3.307516574859619, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 4, \"draws\": 788, \"mu_intercept_per_group\": 3.7796382904052734, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 4, \"draws\": 789, \"mu_intercept_per_group\": 4.240785121917725, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 4, \"draws\": 790, \"mu_intercept_per_group\": 11.235593795776367, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 4, \"draws\": 791, \"mu_intercept_per_group\": 10.83666706085205, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 4, \"draws\": 792, \"mu_intercept_per_group\": 2.236236810684204, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 4, \"draws\": 793, \"mu_intercept_per_group\": 0.5667391419410706, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 4, \"draws\": 794, \"mu_intercept_per_group\": -0.7058081030845642, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 4, \"draws\": 795, \"mu_intercept_per_group\": 7.67421817779541, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 4, \"draws\": 796, \"mu_intercept_per_group\": 2.026370048522949, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 4, \"draws\": 797, \"mu_intercept_per_group\": -1.2830697298049927, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 4, \"draws\": 798, \"mu_intercept_per_group\": 7.946447849273682, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 4, \"draws\": 799, \"mu_intercept_per_group\": 4.5653300285339355, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": -0.4936830699443817, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": 4.999171733856201, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": 0.6521782875061035, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": -1.6964330673217773, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": -1.5742603540420532, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": 5.283847808837891, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -11.31496810913086, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": -7.817002773284912, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": 0.5827797651290894, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": 0.2344091534614563, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": 6.792243003845215, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": -4.55280876159668, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": 8.97771167755127, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": -4.939431667327881, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": -6.270378589630127, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": -1.8578853607177734, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": 8.810626029968262, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": 5.960352420806885, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": 5.344428539276123, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": 2.4586939811706543, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": 2.2995917797088623, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": 8.367406845092773, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": -6.627414226531982, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": -7.080750465393066, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": 5.021615028381348, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": 6.678419589996338, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": -7.590822219848633, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": 11.360928535461426, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": -5.0973334312438965, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": -0.12444468587636948, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": 0.7130396366119385, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": -1.6190998554229736, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": -0.8674359917640686, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": -1.1215295791625977, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": -5.713323593139648, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": -0.21671302616596222, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": 5.190096855163574, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": 3.9520068168640137, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": -3.222916841506958, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": 3.779146194458008, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": 6.8436994552612305, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": -1.0128411054611206, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": 1.1723310947418213, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": 2.092717170715332, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": 2.262239456176758, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": 3.3816802501678467, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": 11.33073902130127, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": 11.15568733215332, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": 2.1022276878356934, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": 3.293247699737549, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": 8.383138656616211, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -11.438764572143555, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": 10.426858901977539, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": 2.6837852001190186, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": 1.2202776670455933, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": 3.7525627613067627, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": 6.483628273010254, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": -2.9187285900115967, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": 3.0211901664733887, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": -1.909820556640625, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": -2.5282647609710693, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": -1.0716947317123413, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": -0.8831166625022888, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": 3.354220390319824, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": -0.743996798992157, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": -0.5231768488883972, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": 8.232260704040527, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": 5.46297550201416, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": 4.69611120223999, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": 6.057387351989746, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": -4.416680335998535, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": 7.120400428771973, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": -7.168479919433594, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": -4.501968860626221, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": 8.21909236907959, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": 12.967597007751465, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": 8.842602729797363, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": -6.817704200744629, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": 0.530376672744751, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": 0.791788637638092, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": 2.006030321121216, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": 2.4872610569000244, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": -1.5326536893844604, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": 2.0414907932281494, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": -3.798283576965332, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": -1.8039244413375854, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": 2.816776752471924, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": 2.3101511001586914, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": 1.285831332206726, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": 14.7088041305542, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": 18.254072189331055, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": -7.443060398101807, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": 3.5992915630340576, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": 1.4925298690795898, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": 4.014184474945068, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": 2.11476731300354, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": 2.2457776069641113, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": 7.356701374053955, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": 10.132861137390137, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": -1.5818636417388916, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -2.462308168411255, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": 3.594944953918457, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": 1.8588958978652954, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": -0.5524792671203613, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": -0.6232576370239258, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": -13.410273551940918, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": -4.3677520751953125, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": 1.3094727993011475, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -2.6252894401550293, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -4.273194313049316, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": 2.41314959526062, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": -2.153839111328125, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": 9.022931098937988, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": -7.887650966644287, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": 10.30448055267334, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": -9.876293182373047, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": 2.5861124992370605, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": 0.7091243863105774, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": 1.57363760471344, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": -0.503716230392456, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": 2.7997069358825684, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": 1.6879323720932007, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": -1.311571478843689, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": -2.7984085083007812, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": 0.46960511803627014, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": 7.710426330566406, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": 5.7630486488342285, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": -9.305146217346191, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": -2.0171682834625244, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": 3.2463467121124268, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -3.0720536708831787, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": -3.7099852561950684, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": -2.9686715602874756, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": 0.2306564897298813, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": 2.247824192047119, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": -1.3220113515853882, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": 0.9232107400894165, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": -0.6540190577507019, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": 1.9786392450332642, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": 0.9563783407211304, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": 0.7334156632423401, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": 2.3041305541992188, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": 0.6046547889709473, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": 8.854641914367676, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": -6.714970588684082, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -3.7840960025787354, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": 6.502985954284668, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": -1.8866745233535767, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": 7.441204071044922, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": -8.213418960571289, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": 11.891451835632324, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": -0.8685718774795532, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": 3.430837631225586, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": 2.514370918273926, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": 0.09311062097549438, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": 1.293937087059021, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": 0.13305164873600006, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": 3.293895721435547, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": 4.343166828155518, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": 0.6446264386177063, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": 9.81774616241455, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": -2.293382406234741, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": -9.398703575134277, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": 0.90650874376297, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": 3.8641912937164307, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": -0.6476548910140991, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": 5.717311859130859, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": 11.154617309570312, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": 5.177521228790283, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": -5.699761867523193, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": 7.650353908538818, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": -3.251162052154541, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": 2.78304123878479, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": 8.93648624420166, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": 6.478943824768066, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": 2.8575520515441895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": 2.173811912536621, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": 0.5168248414993286, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": -0.9173110127449036, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": 1.0983010530471802, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": -1.128238320350647, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": 1.9474482536315918, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": 2.668318510055542, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": -2.6685452461242676, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": 2.5534586906433105, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": -9.7943115234375, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": -6.563799858093262, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -27.31961441040039, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -17.76662254333496, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": 8.505128860473633, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": 7.133119583129883, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": 8.601794242858887, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -2.6739165782928467, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": 2.1650185585021973, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": 4.0482635498046875, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": 9.812962532043457, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -3.7973835468292236, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": 3.87325382232666, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": 3.8319015502929688, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": 4.967145919799805, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": 3.728036403656006, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -8.574662208557129, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": 8.672873497009277, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": -7.8326802253723145, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": 12.981729507446289, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": 10.628742218017578, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": 0.11629725247621536, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": 5.866535186767578, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": 9.66776180267334, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -8.2392578125, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -8.03979778289795, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": 6.960459232330322, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": 8.417984962463379, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": -8.75178337097168, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -10.365260124206543, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": 12.472177505493164, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": -5.03244161605835, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": 5.089905738830566, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": 11.248644828796387, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": 9.39394474029541, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": 7.524884223937988, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": 3.66719388961792, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": 8.817556381225586, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -8.847822189331055, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": -1.8955214023590088, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -12.273404121398926, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": 4.217207431793213, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": -5.044497966766357, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": 2.819262742996216, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": 3.973588466644287, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": 4.765008926391602, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": 11.957687377929688, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": 3.02358078956604, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": 3.9243686199188232, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": 3.4044294357299805, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": -2.102890968322754, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": 0.602037250995636, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": -2.007368326187134, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -6.695186614990234, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": 11.105422973632812, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": -6.331599235534668, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": 5.3391571044921875, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": 2.7552473545074463, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": 8.030393600463867, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": -1.8643521070480347, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": 2.167123794555664, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": 9.887374877929688, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": 2.273650646209717, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": 1.265815019607544, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": 2.928429365158081, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": 10.590553283691406, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": 9.917350769042969, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": -4.333336353302002, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": -1.8468070030212402, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": -0.6399343013763428, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": 0.8221684098243713, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": -0.25098690390586853, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": 0.47165754437446594, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": 2.0731589794158936, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": 3.5841410160064697, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": 1.3557088375091553, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": 13.834127426147461, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": 14.456953048706055, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": -4.042296886444092, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": 6.682328701019287, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": -3.998976945877075, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": 4.560067176818848, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": 4.257584095001221, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": 0.5953791737556458, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": 8.030223846435547, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": 7.646004676818848, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": -3.9084184169769287, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": -3.7448387145996094, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": -8.0143461227417, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": -2.0092594623565674, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": 12.668036460876465, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": 9.397951126098633, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": 0.7062256932258606, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": 2.3495936393737793, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": 5.453965663909912, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": 6.526251316070557, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -9.583497047424316, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": -9.752381324768066, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": 8.808324813842773, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": -0.7570652961730957, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": -4.107381343841553, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": 7.210703372955322, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": -4.066314697265625, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": -5.4151611328125, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": -5.232656955718994, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": -1.9585570096969604, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": -3.251300573348999, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": -1.3458646535873413, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": 1.9364404678344727, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": -0.6752256155014038, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": -4.672120094299316, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": 0.4643610417842865, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": 7.394011974334717, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": 1.7245173454284668, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": 4.1162943840026855, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": 1.4681015014648438, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": 0.9539467692375183, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": -0.36705145239830017, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": 4.102670669555664, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": 6.861858367919922, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": -4.539209365844727, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": 4.347302436828613, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": 2.8213248252868652, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": 9.329455375671387, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": 1.9890902042388916, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": 0.6505970358848572, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": 2.8247857093811035, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": 3.5750627517700195, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": -1.6562188863754272, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": 3.6209089756011963, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": 0.9198087453842163, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -0.28500208258628845, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": -0.8128213882446289, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": 6.068824768066406, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": -0.8334502577781677, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": -3.7099437713623047, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": 1.714191198348999, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": 2.0969502925872803, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": 9.183207511901855, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": 10.86903190612793, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": 4.680744171142578, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": 2.815725088119507, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": -0.5970062017440796, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": 4.627745628356934, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": 3.6387157440185547, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": 2.4396767616271973, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": 5.886763572692871, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": 4.537914752960205, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": 6.9371337890625, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": -2.9177708625793457, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": 10.82784366607666, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": 8.419905662536621, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": 5.09188175201416, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": 0.40666913986206055, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": 8.009431838989258, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": -0.05580255761742592, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": 0.024308281019330025, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": 1.5205624103546143, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": 4.1790876388549805, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": 0.2244865894317627, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": 5.782747268676758, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": -7.930447101593018, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": 0.3207881450653076, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": 2.813279151916504, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -5.610894680023193, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": 7.947093486785889, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -11.681249618530273, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": 15.034317016601562, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": 0.03979386016726494, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": 14.939435958862305, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": 13.074028968811035, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": 2.1421730518341064, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": -1.7453669309616089, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": 4.593339920043945, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": 5.567477226257324, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": 5.255597114562988, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": -4.950255393981934, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": 10.510313034057617, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": 4.427967071533203, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": -0.597438395023346, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": 11.320734024047852, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": 8.22661304473877, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": -5.545265197753906, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": -8.789752006530762, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": 5.041116714477539, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": -6.190657138824463, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": 2.533984661102295, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -9.193230628967285, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -7.052367210388184, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -4.734168529510498, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -4.440606594085693, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": -3.8006691932678223, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": 1.5238863229751587, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": -1.5220943689346313, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": -0.6359741687774658, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": -7.656125068664551, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": 9.146346092224121, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": 3.1164391040802, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": 8.489348411560059, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": 1.6961735486984253, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": 8.293295860290527, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": 5.431253433227539, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": 7.830577373504639, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": 8.568206787109375, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": -7.505928993225098, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": 2.1178689002990723, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": 2.7821342945098877, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": 5.693019390106201, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": 6.2944440841674805, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": 9.706086158752441, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": -10.40073299407959, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": -3.227675437927246, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": 2.30842924118042, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": -1.5283007621765137, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": -0.5001562833786011, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": 9.165095329284668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": 1.4900716543197632, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": -0.8814666867256165, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": -2.0296337604522705, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": 1.3305256366729736, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": 5.04124641418457, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": -4.7146782875061035, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": 5.809991359710693, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": 5.043154239654541, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": -1.7293035984039307, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": 3.3898768424987793, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": -0.8397834300994873, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": 5.915778636932373, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": 1.9669221639633179, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": 3.1190719604492188, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": -0.2337658703327179, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": 6.688932418823242, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": -2.4702565670013428, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": 2.3119709491729736, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": -3.015862464904785, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": -5.686969757080078, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": 4.881800174713135, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": -6.422973155975342, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": 9.18946647644043, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": 9.735956192016602, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": -12.410496711730957, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": 11.598301887512207, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": -2.832165479660034, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": -3.3463351726531982, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": 3.6924684047698975, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": 4.8262858390808105, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": 4.859366416931152, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": 4.933337211608887, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": 5.615426063537598, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": 7.1026291847229, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": -2.526503562927246, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": 14.279303550720215, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": 14.049449920654297, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": 10.146956443786621, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": -1.6144288778305054, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": -3.103341817855835, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": -10.78703498840332, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": -2.24977445602417, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": 7.7816481590271, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": 2.440359115600586, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": 0.9812870025634766, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": 0.7519392371177673, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": 10.234559059143066, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": -0.4684623181819916, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": 4.018322467803955, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": 3.347318410873413, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": -5.998703956604004, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": 4.131516933441162, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": -3.956796884536743, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": 2.4501700401306152, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": -7.225014686584473, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": 1.4161245822906494, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": 2.6986114978790283, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": 7.647429943084717, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": 3.9245128631591797, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": -7.178640365600586, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": 6.069210052490234, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": -7.366247653961182, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": -3.059081792831421, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": -4.277634620666504, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": -4.914758682250977, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": -2.5589759349823, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -6.704737663269043, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": 5.098209857940674, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -10.468371391296387, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": -5.892239093780518, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": 2.5162999629974365, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": 3.7081711292266846, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": 3.8927412033081055, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": -1.7580379247665405, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -2.632122039794922, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": 11.085421562194824, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": -2.4329164028167725, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": 2.66679048538208, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": 1.0495461225509644, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": 0.8502023816108704, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": -5.250965118408203, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": 6.950047492980957, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": -4.0179057121276855, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": -1.5065183639526367, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": 3.951291799545288, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": -2.1402275562286377, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": 7.854623317718506, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": -2.683741807937622, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": 14.440917015075684, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": 13.877155303955078, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": 11.458995819091797, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": -3.9448370933532715, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": -2.7637362480163574, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": 1.6091384887695312, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": 10.039451599121094, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": -5.605895519256592, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": 18.840381622314453, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": 4.888682842254639, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": -0.08786775171756744, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": -2.7071421146392822, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": 1.2054929733276367, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": 5.187563896179199, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -2.718552827835083, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": 1.6928390264511108, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": 2.8258514404296875, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": -0.6238449215888977, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": 5.984460830688477, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": 0.01763044111430645, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": 5.762425422668457, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": -3.868269205093384, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": -2.518726110458374, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": 2.960270881652832, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": -3.5001561641693115, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": 7.296746730804443, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": 1.4127551317214966, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": -2.601768970489502, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": -1.4885532855987549, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": -1.7040915489196777, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -6.998692989349365, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": 2.1867520809173584, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -9.845512390136719, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": 1.1358827352523804, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": 4.276721477508545, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -1.0788450241088867, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": -1.8729008436203003, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": -0.6531848907470703, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": -4.406121730804443, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": -3.4420886039733887, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -12.418782234191895, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": 6.173922061920166, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": -8.29879093170166, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": 11.020665168762207, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": 6.808164119720459, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": 5.0015058517456055, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": -1.2744996547698975, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": 0.6806426644325256, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -7.457321643829346, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": -5.819141387939453, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": 0.915133535861969, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": -1.2011756896972656, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": 6.034015655517578, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -11.381556510925293, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": -7.319867134094238, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": 3.155782461166382, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": 7.666479110717773, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": 7.782724857330322, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": 0.21381761133670807, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": 12.560585975646973, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": -2.7401819229125977, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": 0.6657583713531494, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -3.632479667663574, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": 5.7790045738220215, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": -2.5474801063537598, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": 1.1199679374694824, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": -0.8119602799415588, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": 0.2681579887866974, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": 0.7113875150680542, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": -1.5859010219573975, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": 4.05252742767334, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": 2.554129123687744, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": 3.6585235595703125, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": 1.2316629886627197, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": -0.2994779050350189, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": 5.4572930335998535, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": -4.310985565185547, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": -0.5814806222915649, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": -4.7760329246521, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": 14.579337120056152, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": -4.133450031280518, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": -4.106779098510742, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": 6.196764945983887, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": 3.545785665512085, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": 8.385534286499023, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": 0.5849117636680603, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": 5.525136470794678, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": -6.678565979003906, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -8.455256462097168, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": 8.006284713745117, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -4.586374759674072, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": -4.955859184265137, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": -6.421501636505127, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": 3.928562879562378, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": -4.06256628036499, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": 10.368810653686523, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": 5.356241703033447, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": -2.9610393047332764, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": 0.6189560890197754, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": 3.154837131500244, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": -0.1340140551328659, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": 7.543446063995361, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": 1.466381549835205, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": 3.515272855758667, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": 2.2773630619049072, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": -2.729767322540283, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": 4.216533184051514, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": -5.651655197143555, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": -3.35032057762146, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": 7.401084899902344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": 4.6678242683410645, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": -0.03037027269601822, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": -4.2660136222839355, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": 1.8521217107772827, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": 0.3156644403934479, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": 1.9550424814224243, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": 9.87182331085205, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": -3.2301228046417236, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": 10.981620788574219, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": 8.075916290283203, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": 3.7643399238586426, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": 0.19077926874160767, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": 3.4784345626831055, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": 4.375865459442139, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": 1.0993521213531494, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": -8.167473793029785, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": 4.648540019989014, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": 0.35695895552635193, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": -2.8153913021087646, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": -2.977693796157837, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": -1.1377506256103516, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": 0.04873131215572357, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": 3.1761634349823, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": -0.020863207057118416, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": 1.351028561592102, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": 12.045791625976562, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": -0.5252058506011963, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -18.708921432495117, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": -12.27900505065918, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": 11.218646049499512, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": -7.135178089141846, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": 6.958343982696533, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": 5.1873908042907715, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": 1.2365093231201172, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -4.957011699676514, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -5.30355978012085, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": -5.12799072265625, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": 6.813993453979492, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": -4.477818965911865, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": -5.169980049133301, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": -2.9529480934143066, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 640, \"mu_intercept_per_group\": -7.506115913391113, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 641, \"mu_intercept_per_group\": 4.841949939727783, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 642, \"mu_intercept_per_group\": -5.881920337677002, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 643, \"mu_intercept_per_group\": 16.809703826904297, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 644, \"mu_intercept_per_group\": 2.511122941970825, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 645, \"mu_intercept_per_group\": 0.4887118637561798, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 646, \"mu_intercept_per_group\": 0.8064342737197876, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 647, \"mu_intercept_per_group\": 1.4259870052337646, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 648, \"mu_intercept_per_group\": 1.4857269525527954, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 649, \"mu_intercept_per_group\": 8.055587768554688, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 650, \"mu_intercept_per_group\": 12.786767959594727, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 651, \"mu_intercept_per_group\": 2.306870460510254, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 652, \"mu_intercept_per_group\": -6.979279518127441, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 653, \"mu_intercept_per_group\": -0.41045838594436646, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 654, \"mu_intercept_per_group\": -0.3673120439052582, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 655, \"mu_intercept_per_group\": 4.506551742553711, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 656, \"mu_intercept_per_group\": 6.2370924949646, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 657, \"mu_intercept_per_group\": -0.3215402066707611, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 658, \"mu_intercept_per_group\": 5.281808376312256, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 659, \"mu_intercept_per_group\": -2.4257640838623047, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 660, \"mu_intercept_per_group\": -0.3196414113044739, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 661, \"mu_intercept_per_group\": 3.8381330966949463, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 662, \"mu_intercept_per_group\": 3.275034189224243, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 663, \"mu_intercept_per_group\": 4.178934097290039, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 664, \"mu_intercept_per_group\": -3.322736978530884, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 665, \"mu_intercept_per_group\": -2.479078769683838, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 666, \"mu_intercept_per_group\": 3.148167371749878, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 667, \"mu_intercept_per_group\": 7.899265766143799, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 668, \"mu_intercept_per_group\": -3.881068706512451, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 669, \"mu_intercept_per_group\": 3.0566978454589844, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 670, \"mu_intercept_per_group\": -1.6932018995285034, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 671, \"mu_intercept_per_group\": 0.5915698409080505, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 672, \"mu_intercept_per_group\": 4.123375415802002, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 673, \"mu_intercept_per_group\": 6.35595178604126, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 674, \"mu_intercept_per_group\": -3.740208864212036, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 675, \"mu_intercept_per_group\": -3.8673324584960938, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 676, \"mu_intercept_per_group\": 2.7119503021240234, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 677, \"mu_intercept_per_group\": -1.8882607221603394, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 678, \"mu_intercept_per_group\": -2.162415027618408, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 679, \"mu_intercept_per_group\": -0.3742189109325409, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 680, \"mu_intercept_per_group\": -2.5472350120544434, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 681, \"mu_intercept_per_group\": 1.0873957872390747, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 682, \"mu_intercept_per_group\": -1.8083175420761108, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 683, \"mu_intercept_per_group\": -6.07248592376709, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 684, \"mu_intercept_per_group\": 4.208353519439697, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 685, \"mu_intercept_per_group\": 4.22807502746582, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 686, \"mu_intercept_per_group\": 13.54815673828125, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 687, \"mu_intercept_per_group\": 12.544894218444824, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 688, \"mu_intercept_per_group\": 1.6133661270141602, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 689, \"mu_intercept_per_group\": 3.921630382537842, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 690, \"mu_intercept_per_group\": 2.686460018157959, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 691, \"mu_intercept_per_group\": 7.2498884201049805, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 692, \"mu_intercept_per_group\": 10.887166976928711, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 693, \"mu_intercept_per_group\": 16.479183197021484, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 694, \"mu_intercept_per_group\": -0.018748529255390167, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 695, \"mu_intercept_per_group\": -0.6615126729011536, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 696, \"mu_intercept_per_group\": 8.400014877319336, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 697, \"mu_intercept_per_group\": 6.954907417297363, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 698, \"mu_intercept_per_group\": -8.435911178588867, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 699, \"mu_intercept_per_group\": -10.450371742248535, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 700, \"mu_intercept_per_group\": -13.0982084274292, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 701, \"mu_intercept_per_group\": -7.1084208488464355, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 702, \"mu_intercept_per_group\": 0.5757467150688171, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 703, \"mu_intercept_per_group\": 6.972298622131348, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 704, \"mu_intercept_per_group\": -2.0960466861724854, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 705, \"mu_intercept_per_group\": 11.447457313537598, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 706, \"mu_intercept_per_group\": -6.721770763397217, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 707, \"mu_intercept_per_group\": -10.405341148376465, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 708, \"mu_intercept_per_group\": 16.467519760131836, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 709, \"mu_intercept_per_group\": 3.6985721588134766, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 710, \"mu_intercept_per_group\": -2.596336841583252, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 711, \"mu_intercept_per_group\": 1.6006039381027222, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 712, \"mu_intercept_per_group\": 11.543874740600586, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 713, \"mu_intercept_per_group\": 4.0602850914001465, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 714, \"mu_intercept_per_group\": -5.451816082000732, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 715, \"mu_intercept_per_group\": -0.4832264482975006, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 716, \"mu_intercept_per_group\": -0.1277807354927063, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 717, \"mu_intercept_per_group\": 9.382996559143066, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 718, \"mu_intercept_per_group\": 2.7434017658233643, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 719, \"mu_intercept_per_group\": -13.703967094421387, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 720, \"mu_intercept_per_group\": 11.376761436462402, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 721, \"mu_intercept_per_group\": -8.271041870117188, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 722, \"mu_intercept_per_group\": 5.795229911804199, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 723, \"mu_intercept_per_group\": -4.5389933586120605, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 724, \"mu_intercept_per_group\": -0.5400820374488831, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 725, \"mu_intercept_per_group\": -0.4254120886325836, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 726, \"mu_intercept_per_group\": 3.012491464614868, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 727, \"mu_intercept_per_group\": -1.6920281648635864, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 728, \"mu_intercept_per_group\": 2.6638760566711426, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 729, \"mu_intercept_per_group\": 7.623227596282959, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 730, \"mu_intercept_per_group\": -3.2628395557403564, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 731, \"mu_intercept_per_group\": 3.5190138816833496, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 732, \"mu_intercept_per_group\": 4.912494659423828, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 733, \"mu_intercept_per_group\": 2.229353427886963, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 734, \"mu_intercept_per_group\": -2.8037805557250977, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 735, \"mu_intercept_per_group\": 4.959327220916748, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 736, \"mu_intercept_per_group\": -4.8769683837890625, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 737, \"mu_intercept_per_group\": 4.81979513168335, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 738, \"mu_intercept_per_group\": -2.942124605178833, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 739, \"mu_intercept_per_group\": 0.570166826248169, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 740, \"mu_intercept_per_group\": -7.019355297088623, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 741, \"mu_intercept_per_group\": 4.785904884338379, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 742, \"mu_intercept_per_group\": -0.14491762220859528, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 743, \"mu_intercept_per_group\": 2.900390625, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 744, \"mu_intercept_per_group\": -3.1168389320373535, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 745, \"mu_intercept_per_group\": -3.2361035346984863, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 746, \"mu_intercept_per_group\": 5.309395790100098, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 747, \"mu_intercept_per_group\": 0.4705502390861511, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 748, \"mu_intercept_per_group\": 4.199631690979004, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 749, \"mu_intercept_per_group\": -2.6365833282470703, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 750, \"mu_intercept_per_group\": 5.085790634155273, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 751, \"mu_intercept_per_group\": -13.19575023651123, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 752, \"mu_intercept_per_group\": -4.775232791900635, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 753, \"mu_intercept_per_group\": 8.22763442993164, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 754, \"mu_intercept_per_group\": -5.417640209197998, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 755, \"mu_intercept_per_group\": 3.015061378479004, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 756, \"mu_intercept_per_group\": -1.2819138765335083, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 757, \"mu_intercept_per_group\": -0.46969661116600037, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 758, \"mu_intercept_per_group\": -2.6609880924224854, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 759, \"mu_intercept_per_group\": 2.6079695224761963, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 760, \"mu_intercept_per_group\": 0.9872055053710938, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 5, \"draws\": 761, \"mu_intercept_per_group\": 2.336440086364746, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 5, \"draws\": 762, \"mu_intercept_per_group\": 6.431071758270264, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 5, \"draws\": 763, \"mu_intercept_per_group\": -8.56132984161377, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 5, \"draws\": 764, \"mu_intercept_per_group\": -6.293648719787598, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 5, \"draws\": 765, \"mu_intercept_per_group\": 1.003957748413086, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 5, \"draws\": 766, \"mu_intercept_per_group\": 5.770401477813721, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 5, \"draws\": 767, \"mu_intercept_per_group\": -11.149538040161133, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 5, \"draws\": 768, \"mu_intercept_per_group\": -11.574239730834961, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 5, \"draws\": 769, \"mu_intercept_per_group\": -0.7626160979270935, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 5, \"draws\": 770, \"mu_intercept_per_group\": 6.175403594970703, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 5, \"draws\": 771, \"mu_intercept_per_group\": -6.830533504486084, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 5, \"draws\": 772, \"mu_intercept_per_group\": 5.845097541809082, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 5, \"draws\": 773, \"mu_intercept_per_group\": -4.2466254234313965, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 5, \"draws\": 774, \"mu_intercept_per_group\": -7.769762992858887, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 5, \"draws\": 775, \"mu_intercept_per_group\": -11.193673133850098, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 5, \"draws\": 776, \"mu_intercept_per_group\": 11.781404495239258, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 5, \"draws\": 777, \"mu_intercept_per_group\": -3.0879199504852295, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 5, \"draws\": 778, \"mu_intercept_per_group\": 2.3158674240112305, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 5, \"draws\": 779, \"mu_intercept_per_group\": 0.16726243495941162, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 5, \"draws\": 780, \"mu_intercept_per_group\": 1.4833091497421265, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 5, \"draws\": 781, \"mu_intercept_per_group\": 6.84270715713501, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 5, \"draws\": 782, \"mu_intercept_per_group\": 4.334469318389893, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 5, \"draws\": 783, \"mu_intercept_per_group\": -4.612475395202637, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 5, \"draws\": 784, \"mu_intercept_per_group\": 4.77070951461792, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 5, \"draws\": 785, \"mu_intercept_per_group\": 4.148092746734619, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 5, \"draws\": 786, \"mu_intercept_per_group\": 3.746044158935547, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 5, \"draws\": 787, \"mu_intercept_per_group\": 1.091285228729248, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 5, \"draws\": 788, \"mu_intercept_per_group\": 7.053884506225586, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 5, \"draws\": 789, \"mu_intercept_per_group\": 6.179688930511475, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 5, \"draws\": 790, \"mu_intercept_per_group\": 0.5649715065956116, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 5, \"draws\": 791, \"mu_intercept_per_group\": 1.1186014413833618, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 5, \"draws\": 792, \"mu_intercept_per_group\": 3.0303378105163574, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 5, \"draws\": 793, \"mu_intercept_per_group\": -0.02562352456152439, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 5, \"draws\": 794, \"mu_intercept_per_group\": -1.4256608486175537, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 5, \"draws\": 795, \"mu_intercept_per_group\": -0.9958571791648865, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 5, \"draws\": 796, \"mu_intercept_per_group\": -7.086660861968994, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 5, \"draws\": 797, \"mu_intercept_per_group\": 0.7649232745170593, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 5, \"draws\": 798, \"mu_intercept_per_group\": 10.123893737792969, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 5, \"draws\": 799, \"mu_intercept_per_group\": 5.146012306213379, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 6.37800407409668, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 14.657581329345703, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 2.7958216667175293, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 6.326478004455566, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 8.790563583374023, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 12.298267364501953, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": -0.6363531351089478, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": -1.6876857280731201, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 2.2299373149871826, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": -1.037280559539795, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 12.031730651855469, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 15.604928016662598, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 2.234408378601074, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 19.13079261779785, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 13.048595428466797, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 9.782146453857422, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 23.940692901611328, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 17.576452255249023, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 16.891254425048828, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 2.0913727283477783, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 12.74721908569336, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 15.554927825927734, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 7.008159637451172, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 0.5297897458076477, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": -5.370870113372803, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": -3.994481086730957, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 13.420904159545898, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 6.839694023132324, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 15.62886905670166, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 15.634469032287598, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 3.7431771755218506, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 9.442510604858398, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 3.235412120819092, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": -0.009158127009868622, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 7.253016471862793, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 8.9336576461792, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 5.424819469451904, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 7.15634298324585, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 6.180077075958252, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 10.72684097290039, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 11.890353202819824, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 7.474733352661133, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 10.881460189819336, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 11.45950698852539, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 17.818603515625, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 17.873416900634766, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 14.556384086608887, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 14.053670883178711, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 16.005577087402344, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 12.597241401672363, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 18.503889083862305, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 16.201860427856445, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 13.740428924560547, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 7.90291166305542, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 11.19510269165039, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 6.94672155380249, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 6.028234481811523, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 13.192073822021484, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 6.797860622406006, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 11.186580657958984, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 7.806375026702881, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 4.5859832763671875, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 3.5664408206939697, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 11.656661033630371, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 6.3669753074646, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 6.91317081451416, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 15.8410062789917, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 13.86631965637207, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 13.010332107543945, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 11.788223266601562, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 8.941932678222656, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 1.099101185798645, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 15.243159294128418, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 4.105511665344238, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 13.89879035949707, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 16.440013885498047, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 11.504037857055664, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 6.29906702041626, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 12.811902046203613, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 9.99511432647705, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 8.57177734375, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 5.0281853675842285, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 8.839679718017578, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 3.568502902984619, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 13.581151008605957, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 14.884998321533203, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 13.430789947509766, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 17.065746307373047, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 8.434178352355957, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 16.63286590576172, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 17.54259490966797, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 11.752270698547363, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 7.332230567932129, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 24.714874267578125, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 4.795590877532959, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 7.172306537628174, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 14.201985359191895, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 19.431533813476562, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 17.595199584960938, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 4.940769195556641, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 6.646292209625244, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 12.10807991027832, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 20.925168991088867, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 17.2150936126709, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 15.789444923400879, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": -0.5448676943778992, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 10.840235710144043, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 3.77411150932312, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 9.024848937988281, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 8.971269607543945, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 6.913607597351074, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 7.734762668609619, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 8.881319999694824, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 14.19491958618164, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 6.7448530197143555, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 18.282974243164062, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 2.9279086589813232, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 5.77211856842041, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 3.1763241291046143, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 12.246147155761719, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 8.492447853088379, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 7.793917179107666, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 3.3679537773132324, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 7.766360282897949, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 8.348556518554688, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 11.928165435791016, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 2.9560039043426514, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 6.947440147399902, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 6.06493616104126, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 7.14630126953125, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 14.731822967529297, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": -5.351778507232666, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 17.632570266723633, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 15.330568313598633, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 5.837926864624023, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 5.051054000854492, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 2.8629238605499268, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 13.25622844696045, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 6.890820503234863, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 17.45374870300293, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 4.656808853149414, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 5.447736740112305, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 10.446636199951172, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 17.325050354003906, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 4.206713676452637, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 9.519606590270996, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 4.474648952484131, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 8.139266014099121, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 9.792088508605957, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 7.3324737548828125, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 9.299038887023926, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 21.717971801757812, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": -3.0196897983551025, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 2.3027780055999756, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 16.383344650268555, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 5.840900421142578, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 16.744478225708008, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 1.3772361278533936, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 16.889774322509766, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 3.7015507221221924, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 8.963178634643555, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 23.01374626159668, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 28.747516632080078, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 3.696038246154785, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 18.486228942871094, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 9.797303199768066, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 3.586526393890381, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 6.628138542175293, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 5.736710071563721, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 18.295204162597656, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 4.394664764404297, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 10.175525665283203, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 8.979989051818848, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 12.775808334350586, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 15.53598690032959, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 10.567465782165527, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 6.854046821594238, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 9.789966583251953, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 8.406659126281738, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 9.414752006530762, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 8.134831428527832, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 5.053690433502197, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 12.37542724609375, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 19.121780395507812, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 8.219120025634766, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": -4.113567352294922, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 12.86084270477295, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 6.4124274253845215, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 14.1568603515625, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 6.179751873016357, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 6.407765865325928, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 4.514246940612793, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 9.066909790039062, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 8.447477340698242, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": -0.7427571415901184, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 2.9169552326202393, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 5.465841770172119, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 7.129478454589844, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 7.043885707855225, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 18.49075698852539, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 5.5466132164001465, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 9.107548713684082, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": -0.9509438872337341, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 8.018399238586426, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 16.792940139770508, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 15.597270965576172, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 12.17685604095459, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 11.676979064941406, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 13.785839080810547, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 1.019270896911621, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": -0.9723620414733887, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 15.839048385620117, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 15.420255661010742, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 8.705223083496094, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 8.651837348937988, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.884833335876465, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 18.371557235717773, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 19.368759155273438, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 21.158721923828125, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 21.188085556030273, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 9.712406158447266, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 3.391413450241089, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 9.882966995239258, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 6.421112537384033, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 10.008955955505371, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": -3.7429559230804443, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 9.174446105957031, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 3.8171348571777344, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": -7.909400939941406, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 23.378190994262695, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 22.460115432739258, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 14.530881881713867, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 17.945173263549805, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 11.54576587677002, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.558603286743164, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 10.420690536499023, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 7.529940605163574, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.042562961578369, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 10.79625129699707, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 17.17136001586914, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 3.307905673980713, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 10.444380760192871, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 11.840070724487305, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 7.593770503997803, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 13.43736457824707, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 2.7093143463134766, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 7.846211910247803, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 9.694792747497559, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 13.173310279846191, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 11.132068634033203, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 12.776078224182129, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 12.271164894104004, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 8.114533424377441, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 10.828557014465332, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 13.942134857177734, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 13.534577369689941, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 9.729780197143555, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 8.994977951049805, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 10.113740921020508, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 6.392364501953125, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 9.727726936340332, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 17.571500778198242, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 18.674175262451172, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 9.110492706298828, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 7.621195316314697, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 21.381479263305664, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 15.83483600616455, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 15.66517448425293, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 12.354133605957031, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 18.962139129638672, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 18.399394989013672, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 9.42381477355957, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 12.00529956817627, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 14.56803035736084, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 12.271184921264648, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 12.291250228881836, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 12.071014404296875, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 15.146749496459961, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 17.343830108642578, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": -1.333060622215271, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 4.346193313598633, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 8.044883728027344, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 8.11178970336914, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 10.069868087768555, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 11.644989013671875, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 16.928489685058594, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 4.277830600738525, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 11.038383483886719, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 5.344930171966553, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 1.1706016063690186, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 6.807243347167969, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 3.9913034439086914, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 4.187417984008789, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 3.5455243587493896, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 8.3716459274292, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 8.537477493286133, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 14.718498229980469, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 16.58214569091797, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 14.316944122314453, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 9.237370491027832, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 8.002992630004883, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 6.624277114868164, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 4.020396709442139, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 11.198153495788574, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 9.070198059082031, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 8.491692543029785, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 17.469974517822266, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 11.335356712341309, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 17.74886703491211, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 9.17672348022461, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 13.998625755310059, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 8.742243766784668, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 2.12756609916687, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 17.68233871459961, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 4.9308319091796875, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 12.931241035461426, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 1.631303071975708, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 3.1112074851989746, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 10.88212776184082, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 10.226880073547363, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 3.8558602333068848, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 5.853753089904785, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 5.873215198516846, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 10.582910537719727, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 15.885552406311035, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 15.327390670776367, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 15.514052391052246, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 7.55764102935791, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 18.369102478027344, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 5.824795722961426, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 15.2969970703125, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 10.23908519744873, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 8.089719772338867, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 8.985725402832031, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 9.877602577209473, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 2.4321155548095703, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 3.6842031478881836, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 3.603825807571411, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 14.202850341796875, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 1.3368322849273682, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 14.970987319946289, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 15.470149040222168, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 8.07016658782959, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 9.706025123596191, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.609657287597656, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 8.33421516418457, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 8.960545539855957, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 8.190251350402832, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 5.345642566680908, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 16.278417587280273, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 9.505990028381348, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.281876564025879, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 15.586712837219238, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 19.380855560302734, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 22.9998722076416, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 21.67023277282715, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 7.986322402954102, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 7.836185932159424, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 13.142619132995605, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 5.911583423614502, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 6.9293131828308105, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 5.969613075256348, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 7.467096328735352, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 16.103960037231445, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 16.114681243896484, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 13.09213924407959, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 13.893994331359863, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 8.880234718322754, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 9.530762672424316, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 6.0966315269470215, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 4.595323085784912, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 2.449854612350464, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": -0.11971868574619293, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": -0.2585868835449219, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": -0.2848990857601166, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 3.782630681991577, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 3.4688425064086914, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 5.765459060668945, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 6.903364181518555, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 4.840702056884766, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 7.454947471618652, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 11.113530158996582, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 10.848203659057617, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 17.729427337646484, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 11.753292083740234, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 9.986661911010742, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": -7.832437038421631, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": -3.5750222206115723, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 0.8440127968788147, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 15.552513122558594, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 6.221508026123047, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 12.048630714416504, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 2.756791114807129, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 10.313526153564453, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 11.103602409362793, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 11.494327545166016, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": -3.0313894748687744, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": -1.2790906429290771, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": -2.8456315994262695, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 1.3038175106048584, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 10.289814949035645, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 10.481236457824707, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 7.539891719818115, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 9.063453674316406, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 5.2259440422058105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 7.041718006134033, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 6.661810874938965, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 4.747824192047119, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 8.413098335266113, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 16.330535888671875, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 1.163423776626587, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 16.63500213623047, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 14.909673690795898, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 6.084036350250244, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 5.330334663391113, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 10.525945663452148, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 6.898045063018799, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 4.190566062927246, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 2.7932097911834717, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 11.941429138183594, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 14.172198295593262, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 11.211122512817383, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 11.090378761291504, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 7.951909065246582, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 7.437392234802246, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 12.96187973022461, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 18.34876823425293, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 15.859905242919922, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 15.521785736083984, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 14.366753578186035, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 16.387638092041016, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 19.00131607055664, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 17.261402130126953, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 20.201961517333984, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 14.736574172973633, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 8.490274429321289, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 19.20979118347168, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 14.432631492614746, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 12.758526802062988, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 10.280341148376465, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 3.8434054851531982, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 4.33111572265625, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 12.005300521850586, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 13.142613410949707, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 16.458255767822266, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 7.13403844833374, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 11.828633308410645, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 21.70359992980957, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 1.3618173599243164, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 12.378552436828613, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 15.441965103149414, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 2.402390241622925, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 6.716982841491699, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 4.186927795410156, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 10.02583122253418, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 11.852301597595215, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 16.920223236083984, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 9.352701187133789, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 12.044156074523926, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 3.900907516479492, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 9.73930835723877, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 5.769766807556152, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 11.501866340637207, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 10.019037246704102, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 8.516297340393066, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 11.029529571533203, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.796485424041748, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 4.365727424621582, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.171832084655762, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 11.5953369140625, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 9.907891273498535, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 11.074311256408691, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 16.388078689575195, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 10.061064720153809, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 6.634213447570801, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 13.056344985961914, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 9.078526496887207, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 6.434875965118408, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 12.41024398803711, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 12.15449047088623, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 12.135732650756836, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 11.424830436706543, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 6.585651397705078, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 11.337423324584961, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 5.740451335906982, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 8.813603401184082, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 13.212648391723633, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 8.048795700073242, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 13.886929512023926, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 12.967419624328613, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 10.155488014221191, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 10.331839561462402, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 9.788475036621094, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 9.635385513305664, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 1.454776644706726, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 24.48976707458496, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 10.624290466308594, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 0.38632020354270935, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 5.080892086029053, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 8.836256980895996, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 10.883007049560547, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 2.214138984680176, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 0.55355304479599, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 11.85208797454834, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 15.452204704284668, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 15.978493690490723, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 17.14012908935547, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 19.22150993347168, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 6.54447603225708, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 11.839815139770508, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 9.87878704071045, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 11.059840202331543, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 13.870463371276855, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 6.411136627197266, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 10.61187744140625, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": -1.4397786855697632, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 6.009209632873535, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 6.391894817352295, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 7.629478931427002, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 17.496248245239258, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 0.5062999725341797, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 19.641016006469727, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": -0.46578502655029297, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 2.3438477516174316, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 5.278593063354492, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 11.609603881835938, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 10.233970642089844, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 5.613235950469971, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 5.573513031005859, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 13.94971752166748, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 1.6410958766937256, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 11.310317039489746, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 15.228354454040527, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 18.357946395874023, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 8.508772850036621, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 7.611819267272949, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 6.46488094329834, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 15.272871971130371, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 8.657197952270508, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 9.182524681091309, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 2.5536835193634033, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 7.748277187347412, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": -0.5391780734062195, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 5.00656270980835, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 15.768522262573242, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 16.949798583984375, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 11.616355895996094, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 5.791330337524414, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 24.58285903930664, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 3.07306170463562, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 8.841790199279785, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 6.011405944824219, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 16.98671531677246, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 4.259638786315918, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 15.975602149963379, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 7.204800605773926, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 8.972975730895996, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 7.0830559730529785, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 13.438091278076172, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 13.647506713867188, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 10.081512451171875, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 5.370123386383057, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 4.815537929534912, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 9.213953971862793, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 10.0669527053833, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 4.305802822113037, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 11.277573585510254, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 6.878101825714111, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 18.96354866027832, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 5.82699728012085, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 5.001354694366455, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 15.142876625061035, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 12.358677864074707, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 14.71912956237793, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 12.808987617492676, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.95818042755127, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 13.814603805541992, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 10.320548057556152, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 8.806737899780273, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 6.535454273223877, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 7.609572887420654, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 0.3184982240200043, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 14.00516128540039, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 11.082520484924316, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 13.876301765441895, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 11.884879112243652, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 2.0137856006622314, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 14.816924095153809, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 12.356063842773438, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 7.032673358917236, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 16.042600631713867, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 14.192509651184082, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 4.965102672576904, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 5.56322717666626, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 12.508365631103516, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 5.104037761688232, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 12.051085472106934, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 11.058951377868652, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 8.062950134277344, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 6.636124610900879, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 5.17345666885376, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 10.239788055419922, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 8.55694580078125, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 15.09982681274414, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 8.833052635192871, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 20.978830337524414, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 6.275857448577881, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 16.890836715698242, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 23.01714324951172, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 22.67757225036621, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 20.975807189941406, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 2.482130765914917, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 10.07733154296875, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 13.909623146057129, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 1.9945781230926514, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 14.202008247375488, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 7.961235046386719, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 10.419793128967285, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 5.2984619140625, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 3.3702874183654785, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 8.156440734863281, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 19.221630096435547, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 4.177761077880859, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 0.9088281393051147, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": -9.801112174987793, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": -4.177274227142334, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 6.679325103759766, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 9.05578327178955, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 10.858011245727539, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 18.257614135742188, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 6.315979480743408, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 8.230443954467773, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 0.6772663593292236, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 18.805233001708984, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 18.02728843688965, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 12.855727195739746, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 10.447681427001953, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 12.989734649658203, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 10.456489562988281, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 5.5458149909973145, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 640, \"mu_intercept_per_group\": 6.737189769744873, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 641, \"mu_intercept_per_group\": 9.193177223205566, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 642, \"mu_intercept_per_group\": 12.069136619567871, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 643, \"mu_intercept_per_group\": 6.221860408782959, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 644, \"mu_intercept_per_group\": 13.383099555969238, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 645, \"mu_intercept_per_group\": 16.529314041137695, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 646, \"mu_intercept_per_group\": 15.19991397857666, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 647, \"mu_intercept_per_group\": 11.386703491210938, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 648, \"mu_intercept_per_group\": 15.04826545715332, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 649, \"mu_intercept_per_group\": 4.552347660064697, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 650, \"mu_intercept_per_group\": 3.780327558517456, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 651, \"mu_intercept_per_group\": 5.112100601196289, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 652, \"mu_intercept_per_group\": 11.999035835266113, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 653, \"mu_intercept_per_group\": 13.317060470581055, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 654, \"mu_intercept_per_group\": 7.893313407897949, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 655, \"mu_intercept_per_group\": 12.060137748718262, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 656, \"mu_intercept_per_group\": 9.420783042907715, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 657, \"mu_intercept_per_group\": 8.989302635192871, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 658, \"mu_intercept_per_group\": 15.081155776977539, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 659, \"mu_intercept_per_group\": 6.784265041351318, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 660, \"mu_intercept_per_group\": 12.24379825592041, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 661, \"mu_intercept_per_group\": 2.469707727432251, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 662, \"mu_intercept_per_group\": 3.566190004348755, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 663, \"mu_intercept_per_group\": 8.301640510559082, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 664, \"mu_intercept_per_group\": 5.845261573791504, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 665, \"mu_intercept_per_group\": 4.558312892913818, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 666, \"mu_intercept_per_group\": 3.4723405838012695, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 667, \"mu_intercept_per_group\": 11.847676277160645, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 668, \"mu_intercept_per_group\": 11.610284805297852, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 669, \"mu_intercept_per_group\": 2.2657830715179443, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 670, \"mu_intercept_per_group\": 10.631192207336426, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 671, \"mu_intercept_per_group\": 13.213122367858887, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 672, \"mu_intercept_per_group\": 13.68525505065918, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 673, \"mu_intercept_per_group\": 10.926741600036621, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 674, \"mu_intercept_per_group\": 14.190625190734863, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 675, \"mu_intercept_per_group\": 5.748699188232422, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 676, \"mu_intercept_per_group\": 14.493550300598145, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 677, \"mu_intercept_per_group\": 10.242263793945312, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 678, \"mu_intercept_per_group\": 9.60313892364502, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 679, \"mu_intercept_per_group\": 16.792964935302734, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 680, \"mu_intercept_per_group\": 13.379315376281738, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 681, \"mu_intercept_per_group\": 1.0710054636001587, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 682, \"mu_intercept_per_group\": 15.035201072692871, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 683, \"mu_intercept_per_group\": -0.387957900762558, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 684, \"mu_intercept_per_group\": 15.181492805480957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 685, \"mu_intercept_per_group\": 16.71505355834961, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 686, \"mu_intercept_per_group\": 11.101946830749512, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 687, \"mu_intercept_per_group\": 12.336786270141602, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 688, \"mu_intercept_per_group\": 6.484126091003418, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 689, \"mu_intercept_per_group\": 15.515594482421875, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 690, \"mu_intercept_per_group\": 7.741927146911621, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 691, \"mu_intercept_per_group\": 17.842140197753906, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 692, \"mu_intercept_per_group\": 11.315420150756836, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 693, \"mu_intercept_per_group\": 16.897253036499023, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 694, \"mu_intercept_per_group\": -1.6949474811553955, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 695, \"mu_intercept_per_group\": -5.276398658752441, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 696, \"mu_intercept_per_group\": 25.23772621154785, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 697, \"mu_intercept_per_group\": 23.200729370117188, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 698, \"mu_intercept_per_group\": 2.4280004501342773, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 699, \"mu_intercept_per_group\": 6.299410343170166, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 700, \"mu_intercept_per_group\": 5.133821964263916, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 701, \"mu_intercept_per_group\": 1.0711069107055664, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 702, \"mu_intercept_per_group\": 10.13552188873291, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 703, \"mu_intercept_per_group\": 6.255331039428711, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 704, \"mu_intercept_per_group\": 25.757722854614258, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 705, \"mu_intercept_per_group\": 6.712465763092041, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 706, \"mu_intercept_per_group\": 10.238642692565918, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 707, \"mu_intercept_per_group\": 10.30508041381836, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 708, \"mu_intercept_per_group\": 17.740585327148438, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 709, \"mu_intercept_per_group\": 17.416980743408203, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 710, \"mu_intercept_per_group\": 2.7176008224487305, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 711, \"mu_intercept_per_group\": 9.658129692077637, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 712, \"mu_intercept_per_group\": 20.566896438598633, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 713, \"mu_intercept_per_group\": 15.501233100891113, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 714, \"mu_intercept_per_group\": 9.931512832641602, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 715, \"mu_intercept_per_group\": 4.31850528717041, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 716, \"mu_intercept_per_group\": 8.438852310180664, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 717, \"mu_intercept_per_group\": 5.479158878326416, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 718, \"mu_intercept_per_group\": 13.189408302307129, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 719, \"mu_intercept_per_group\": -0.5001488924026489, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 720, \"mu_intercept_per_group\": 18.273456573486328, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 721, \"mu_intercept_per_group\": 9.747213363647461, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 722, \"mu_intercept_per_group\": 9.510597229003906, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 723, \"mu_intercept_per_group\": 16.200960159301758, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 724, \"mu_intercept_per_group\": 13.500121116638184, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 725, \"mu_intercept_per_group\": 12.953968048095703, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 726, \"mu_intercept_per_group\": 7.8639631271362305, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 727, \"mu_intercept_per_group\": 5.070074081420898, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 728, \"mu_intercept_per_group\": 15.302668571472168, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 729, \"mu_intercept_per_group\": 7.512243270874023, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 730, \"mu_intercept_per_group\": 11.778135299682617, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 731, \"mu_intercept_per_group\": 1.2225472927093506, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 732, \"mu_intercept_per_group\": 6.62372350692749, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 733, \"mu_intercept_per_group\": 5.657873630523682, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 734, \"mu_intercept_per_group\": 5.344048500061035, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 735, \"mu_intercept_per_group\": 8.548877716064453, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 736, \"mu_intercept_per_group\": 9.904463768005371, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 737, \"mu_intercept_per_group\": 19.767704010009766, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 738, \"mu_intercept_per_group\": 10.717267036437988, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 739, \"mu_intercept_per_group\": 10.820258140563965, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 740, \"mu_intercept_per_group\": 2.6831698417663574, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 741, \"mu_intercept_per_group\": 9.101056098937988, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 742, \"mu_intercept_per_group\": 2.4662649631500244, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 743, \"mu_intercept_per_group\": 10.721576690673828, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 744, \"mu_intercept_per_group\": 8.200984001159668, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 745, \"mu_intercept_per_group\": 15.698253631591797, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 746, \"mu_intercept_per_group\": 9.935863494873047, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 747, \"mu_intercept_per_group\": 17.09223175048828, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 748, \"mu_intercept_per_group\": 9.965093612670898, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 749, \"mu_intercept_per_group\": 21.839853286743164, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 750, \"mu_intercept_per_group\": 23.14823341369629, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 751, \"mu_intercept_per_group\": 6.278114318847656, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 752, \"mu_intercept_per_group\": 6.992970943450928, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 753, \"mu_intercept_per_group\": 8.06745433807373, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 754, \"mu_intercept_per_group\": 7.554111957550049, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 755, \"mu_intercept_per_group\": 12.436790466308594, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 756, \"mu_intercept_per_group\": 13.463346481323242, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 757, \"mu_intercept_per_group\": 11.4485445022583, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 758, \"mu_intercept_per_group\": 6.842139720916748, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 759, \"mu_intercept_per_group\": 11.513456344604492, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 760, \"mu_intercept_per_group\": 11.867603302001953, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 6, \"draws\": 761, \"mu_intercept_per_group\": 9.222723007202148, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 6, \"draws\": 762, \"mu_intercept_per_group\": 13.940552711486816, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 6, \"draws\": 763, \"mu_intercept_per_group\": 13.071642875671387, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 6, \"draws\": 764, \"mu_intercept_per_group\": 16.73880958557129, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 6, \"draws\": 765, \"mu_intercept_per_group\": 9.071429252624512, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 6, \"draws\": 766, \"mu_intercept_per_group\": 17.341548919677734, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 6, \"draws\": 767, \"mu_intercept_per_group\": -0.18725790083408356, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 6, \"draws\": 768, \"mu_intercept_per_group\": 1.9522686004638672, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 6, \"draws\": 769, \"mu_intercept_per_group\": 14.188538551330566, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 6, \"draws\": 770, \"mu_intercept_per_group\": 6.566876411437988, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 6, \"draws\": 771, \"mu_intercept_per_group\": 3.8686840534210205, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 6, \"draws\": 772, \"mu_intercept_per_group\": 12.66661262512207, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 6, \"draws\": 773, \"mu_intercept_per_group\": 9.155329704284668, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 6, \"draws\": 774, \"mu_intercept_per_group\": 4.318933963775635, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 6, \"draws\": 775, \"mu_intercept_per_group\": 0.6530895233154297, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 6, \"draws\": 776, \"mu_intercept_per_group\": 19.313690185546875, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 6, \"draws\": 777, \"mu_intercept_per_group\": 11.354860305786133, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 6, \"draws\": 778, \"mu_intercept_per_group\": 8.88536548614502, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 6, \"draws\": 779, \"mu_intercept_per_group\": 13.623076438903809, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 6, \"draws\": 780, \"mu_intercept_per_group\": 8.875946998596191, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 6, \"draws\": 781, \"mu_intercept_per_group\": 17.30560874938965, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 6, \"draws\": 782, \"mu_intercept_per_group\": 14.880852699279785, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 6, \"draws\": 783, \"mu_intercept_per_group\": -0.4047471284866333, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 6, \"draws\": 784, \"mu_intercept_per_group\": 8.562387466430664, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 6, \"draws\": 785, \"mu_intercept_per_group\": 9.902952194213867, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 6, \"draws\": 786, \"mu_intercept_per_group\": 7.32205057144165, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 6, \"draws\": 787, \"mu_intercept_per_group\": 8.498106956481934, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 6, \"draws\": 788, \"mu_intercept_per_group\": 7.786909103393555, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 6, \"draws\": 789, \"mu_intercept_per_group\": 9.666537284851074, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 6, \"draws\": 790, \"mu_intercept_per_group\": 10.754192352294922, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 6, \"draws\": 791, \"mu_intercept_per_group\": 9.705094337463379, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 6, \"draws\": 792, \"mu_intercept_per_group\": 8.534967422485352, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 6, \"draws\": 793, \"mu_intercept_per_group\": 23.202211380004883, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 6, \"draws\": 794, \"mu_intercept_per_group\": 15.786867141723633, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 6, \"draws\": 795, \"mu_intercept_per_group\": 15.403228759765625, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 6, \"draws\": 796, \"mu_intercept_per_group\": 11.287784576416016, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 6, \"draws\": 797, \"mu_intercept_per_group\": 8.130427360534668, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 6, \"draws\": 798, \"mu_intercept_per_group\": 21.378206253051758, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 6, \"draws\": 799, \"mu_intercept_per_group\": 10.32075023651123, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 13.365216255187988, \"sigma_intercept_per_group\": 0.006280555855482817, \"sigma_obs\": 0.0035742195323109627, \"slope\": 0.1812562793493271, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 15.986224174499512, \"sigma_intercept_per_group\": 0.020741412416100502, \"sigma_obs\": 0.004363304935395718, \"slope\": 0.20433184504508972, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 13.506922721862793, \"sigma_intercept_per_group\": 0.020002827048301697, \"sigma_obs\": 0.0037581929937005043, \"slope\": 0.17958903312683105, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 12.583298683166504, \"sigma_intercept_per_group\": 0.020825332030653954, \"sigma_obs\": 0.003970699850469828, \"slope\": 0.18189583718776703, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 13.145959854125977, \"sigma_intercept_per_group\": 0.02462773583829403, \"sigma_obs\": 0.003731143195182085, \"slope\": 0.108681820333004, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 10.314718246459961, \"sigma_intercept_per_group\": 0.01817772537469864, \"sigma_obs\": 0.004192177671939135, \"slope\": 0.35787248611450195, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 11.695979118347168, \"sigma_intercept_per_group\": 0.007248743902891874, \"sigma_obs\": 0.0036843169946223497, \"slope\": 0.13871614634990692, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 1.184268832206726, \"sigma_intercept_per_group\": 0.010973872616887093, \"sigma_obs\": 0.003856769995763898, \"slope\": 0.24061177670955658, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 6.262317180633545, \"sigma_intercept_per_group\": 0.028714444488286972, \"sigma_obs\": 0.003596370806917548, \"slope\": 0.30433234572410583, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 6.309609889984131, \"sigma_intercept_per_group\": 0.030657678842544556, \"sigma_obs\": 0.003723040921613574, \"slope\": 0.27905023097991943, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 21.440279006958008, \"sigma_intercept_per_group\": 0.019464338198304176, \"sigma_obs\": 0.004110683687031269, \"slope\": 0.2202565222978592, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 17.677780151367188, \"sigma_intercept_per_group\": 0.013736375607550144, \"sigma_obs\": 0.004364876076579094, \"slope\": 0.2666195034980774, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 7.256966590881348, \"sigma_intercept_per_group\": 0.02426101081073284, \"sigma_obs\": 0.003610448446124792, \"slope\": 0.16894955933094025, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 19.48111343383789, \"sigma_intercept_per_group\": 0.01732379011809826, \"sigma_obs\": 0.004241017159074545, \"slope\": 0.2203577756881714, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 15.224678039550781, \"sigma_intercept_per_group\": 0.008920997381210327, \"sigma_obs\": 0.0041586910374462605, \"slope\": 0.2426823079586029, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 16.807680130004883, \"sigma_intercept_per_group\": 0.01981933042407036, \"sigma_obs\": 0.004225494340062141, \"slope\": 0.2627943158149719, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 17.123653411865234, \"sigma_intercept_per_group\": 0.008656803518533707, \"sigma_obs\": 0.004008525051176548, \"slope\": 0.13495418429374695, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 15.230988502502441, \"sigma_intercept_per_group\": 0.013712861575186253, \"sigma_obs\": 0.004099524114280939, \"slope\": 0.16604876518249512, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 15.25283432006836, \"sigma_intercept_per_group\": 0.0136976083740592, \"sigma_obs\": 0.004084916785359383, \"slope\": 0.1588754504919052, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 4.390932559967041, \"sigma_intercept_per_group\": 0.030664894729852676, \"sigma_obs\": 0.003818865166977048, \"slope\": 0.2059391438961029, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 20.541927337646484, \"sigma_intercept_per_group\": 0.01211362425237894, \"sigma_obs\": 0.003941479604691267, \"slope\": 0.09188627451658249, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 18.01485252380371, \"sigma_intercept_per_group\": 0.01625412330031395, \"sigma_obs\": 0.004019678104668856, \"slope\": 0.23434428870677948, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 10.836176872253418, \"sigma_intercept_per_group\": 0.011156076565384865, \"sigma_obs\": 0.0037360372953116894, \"slope\": 0.2307799905538559, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 1.6970674991607666, \"sigma_intercept_per_group\": 0.005189873278141022, \"sigma_obs\": 0.003592199180275202, \"slope\": 0.07434956729412079, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 15.565256118774414, \"sigma_intercept_per_group\": 0.0020756791345775127, \"sigma_obs\": 0.004030343610793352, \"slope\": 0.2294382005929947, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 6.240877628326416, \"sigma_intercept_per_group\": 0.006793199572712183, \"sigma_obs\": 0.003625991754233837, \"slope\": 0.023172326385974884, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 4.461719512939453, \"sigma_intercept_per_group\": 0.001540574710816145, \"sigma_obs\": 0.004439963959157467, \"slope\": 0.33069509267807007, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 21.099756240844727, \"sigma_intercept_per_group\": 0.020797565579414368, \"sigma_obs\": 0.0035083587281405926, \"slope\": 0.022608162835240364, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 12.546746253967285, \"sigma_intercept_per_group\": 0.011485125869512558, \"sigma_obs\": 0.0039468188770115376, \"slope\": 0.14107735455036163, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 8.020142555236816, \"sigma_intercept_per_group\": 0.02743096835911274, \"sigma_obs\": 0.0038794882129877806, \"slope\": 0.12645751237869263, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 6.100507736206055, \"sigma_intercept_per_group\": 0.029233863577246666, \"sigma_obs\": 0.003969673998653889, \"slope\": 0.17629249393939972, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 8.693058967590332, \"sigma_intercept_per_group\": 0.03820938244462013, \"sigma_obs\": 0.003994371276348829, \"slope\": 0.20693060755729675, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 5.853026390075684, \"sigma_intercept_per_group\": 0.021155133843421936, \"sigma_obs\": 0.0037421276792883873, \"slope\": 0.1687612533569336, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 8.21872329711914, \"sigma_intercept_per_group\": 0.019796356558799744, \"sigma_obs\": 0.0037278495728969574, \"slope\": 0.33259880542755127, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 6.160982608795166, \"sigma_intercept_per_group\": 0.014632709324359894, \"sigma_obs\": 0.0035812295973300934, \"slope\": 0.20611460506916046, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 9.93838119506836, \"sigma_intercept_per_group\": 0.025001972913742065, \"sigma_obs\": 0.003479606006294489, \"slope\": 0.11823052167892456, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 7.362545967102051, \"sigma_intercept_per_group\": 0.016211042180657387, \"sigma_obs\": 0.0031065326184034348, \"slope\": 0.07121790200471878, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 13.141714096069336, \"sigma_intercept_per_group\": 0.014088930562138557, \"sigma_obs\": 0.003702061250805855, \"slope\": 0.12241384387016296, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 10.554520606994629, \"sigma_intercept_per_group\": 0.017305832356214523, \"sigma_obs\": 0.003814915893599391, \"slope\": 0.2908492684364319, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 10.737625122070312, \"sigma_intercept_per_group\": 0.029219292104244232, \"sigma_obs\": 0.003930492792278528, \"slope\": 0.12030200660228729, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 6.138772964477539, \"sigma_intercept_per_group\": 0.02268797717988491, \"sigma_obs\": 0.004112510941922665, \"slope\": 0.10068574547767639, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 11.563729286193848, \"sigma_intercept_per_group\": 0.01493111439049244, \"sigma_obs\": 0.0038914105389267206, \"slope\": 0.2636779844760895, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 15.39007568359375, \"sigma_intercept_per_group\": 0.018568024039268494, \"sigma_obs\": 0.004214620217680931, \"slope\": 0.1482623964548111, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 18.455303192138672, \"sigma_intercept_per_group\": 0.018096361309289932, \"sigma_obs\": 0.004192615393549204, \"slope\": 0.14308059215545654, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 20.07542610168457, \"sigma_intercept_per_group\": 0.019302144646644592, \"sigma_obs\": 0.00446079857647419, \"slope\": 0.1760302186012268, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 21.19367790222168, \"sigma_intercept_per_group\": 0.01792687363922596, \"sigma_obs\": 0.004575131926685572, \"slope\": 0.1565500646829605, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 24.960893630981445, \"sigma_intercept_per_group\": 0.007495015859603882, \"sigma_obs\": 0.0040478953160345554, \"slope\": 0.18636192381381989, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 24.519468307495117, \"sigma_intercept_per_group\": 0.006762070581316948, \"sigma_obs\": 0.003977245185524225, \"slope\": 0.17696408927440643, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 0.24309951066970825, \"sigma_intercept_per_group\": 0.009348978288471699, \"sigma_obs\": 0.004037774633616209, \"slope\": 0.11809538304805756, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 0.8245984315872192, \"sigma_intercept_per_group\": 0.00772590097039938, \"sigma_obs\": 0.004172744695097208, \"slope\": 0.140041321516037, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 5.754743576049805, \"sigma_intercept_per_group\": 0.009164109826087952, \"sigma_obs\": 0.003796621458604932, \"slope\": 0.17993776500225067, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 15.474645614624023, \"sigma_intercept_per_group\": 0.013164359144866467, \"sigma_obs\": 0.003909210674464703, \"slope\": 0.12646055221557617, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 14.499691009521484, \"sigma_intercept_per_group\": 0.02181226573884487, \"sigma_obs\": 0.0038476132322102785, \"slope\": 0.08964287489652634, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 15.87287712097168, \"sigma_intercept_per_group\": 0.021216996014118195, \"sigma_obs\": 0.004396268632262945, \"slope\": 0.05506477132439613, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 9.5660982131958, \"sigma_intercept_per_group\": 0.012712985277175903, \"sigma_obs\": 0.0038391391281038523, \"slope\": 0.245893657207489, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 11.276510238647461, \"sigma_intercept_per_group\": 0.023873139172792435, \"sigma_obs\": 0.004355372861027718, \"slope\": 0.17205271124839783, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 9.343570709228516, \"sigma_intercept_per_group\": 0.029897812753915787, \"sigma_obs\": 0.004125981591641903, \"slope\": 0.18106567859649658, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 14.340816497802734, \"sigma_intercept_per_group\": 0.0186465997248888, \"sigma_obs\": 0.004627536982297897, \"slope\": 0.30547958612442017, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 10.232099533081055, \"sigma_intercept_per_group\": 0.013551143929362297, \"sigma_obs\": 0.0036037093959748745, \"slope\": 0.08114514499902725, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 11.092317581176758, \"sigma_intercept_per_group\": 0.017351683229207993, \"sigma_obs\": 0.004146491643041372, \"slope\": 0.36090317368507385, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 8.64330768585205, \"sigma_intercept_per_group\": 0.021767184138298035, \"sigma_obs\": 0.0038898279890418053, \"slope\": 0.18372683227062225, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 6.819952487945557, \"sigma_intercept_per_group\": 0.02503170445561409, \"sigma_obs\": 0.003355784807354212, \"slope\": 0.20813818275928497, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 10.860028266906738, \"sigma_intercept_per_group\": 0.018651757389307022, \"sigma_obs\": 0.003626449964940548, \"slope\": 0.15452787280082703, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 8.841946601867676, \"sigma_intercept_per_group\": 0.021686777472496033, \"sigma_obs\": 0.0038186905439943075, \"slope\": 0.14946140348911285, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 29.787004470825195, \"sigma_intercept_per_group\": 0.004491197876632214, \"sigma_obs\": 0.004062368534505367, \"slope\": 0.23931217193603516, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 27.973697662353516, \"sigma_intercept_per_group\": 0.009224958717823029, \"sigma_obs\": 0.004011473618447781, \"slope\": 0.2265884280204773, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 25.696727752685547, \"sigma_intercept_per_group\": 0.00676236767321825, \"sigma_obs\": 0.0038100837264209986, \"slope\": 0.1259249448776245, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 22.549034118652344, \"sigma_intercept_per_group\": 0.022345053032040596, \"sigma_obs\": 0.004584592301398516, \"slope\": 0.21846409142017365, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 22.398578643798828, \"sigma_intercept_per_group\": 0.02247961238026619, \"sigma_obs\": 0.004574922379106283, \"slope\": 0.22617881000041962, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 2.423912763595581, \"sigma_intercept_per_group\": 0.01565605401992798, \"sigma_obs\": 0.0036383040715008974, \"slope\": 0.1976058930158615, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 12.322992324829102, \"sigma_intercept_per_group\": 0.008334334008395672, \"sigma_obs\": 0.0042026592418551445, \"slope\": 0.30799296498298645, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 22.30177879333496, \"sigma_intercept_per_group\": 0.009840012528002262, \"sigma_obs\": 0.0036012735217809677, \"slope\": 0.16722917556762695, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 5.9411940574646, \"sigma_intercept_per_group\": 0.022164884954690933, \"sigma_obs\": 0.004023605491966009, \"slope\": 0.3630908131599426, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 12.70667552947998, \"sigma_intercept_per_group\": 0.014472891576588154, \"sigma_obs\": 0.004181735683232546, \"slope\": 0.3059484660625458, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 6.396772384643555, \"sigma_intercept_per_group\": 0.01445670984685421, \"sigma_obs\": 0.003947867546230555, \"slope\": 0.2879239022731781, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 15.689356803894043, \"sigma_intercept_per_group\": 0.008197386749088764, \"sigma_obs\": 0.004157261457294226, \"slope\": 0.30715370178222656, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 13.98384952545166, \"sigma_intercept_per_group\": 0.010607969015836716, \"sigma_obs\": 0.004039958585053682, \"slope\": 0.16426001489162445, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 11.223548889160156, \"sigma_intercept_per_group\": 0.014406228438019753, \"sigma_obs\": 0.00404234416782856, \"slope\": 0.30502697825431824, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 9.327942848205566, \"sigma_intercept_per_group\": 0.01958533748984337, \"sigma_obs\": 0.0037542383652180433, \"slope\": 0.10496410727500916, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 9.253957748413086, \"sigma_intercept_per_group\": 0.023984815925359726, \"sigma_obs\": 0.003699731780216098, \"slope\": 0.09595070034265518, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 14.580586433410645, \"sigma_intercept_per_group\": 0.015742436051368713, \"sigma_obs\": 0.004306125454604626, \"slope\": 0.1189388707280159, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 11.812888145446777, \"sigma_intercept_per_group\": 0.02154270000755787, \"sigma_obs\": 0.004060919862240553, \"slope\": 0.1488202065229416, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 6.036093235015869, \"sigma_intercept_per_group\": 0.025553908199071884, \"sigma_obs\": 0.003669485915452242, \"slope\": 0.2065383791923523, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 9.360658645629883, \"sigma_intercept_per_group\": 0.013158660382032394, \"sigma_obs\": 0.003661983646452427, \"slope\": 0.22769282758235931, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 13.683189392089844, \"sigma_intercept_per_group\": 0.022345084697008133, \"sigma_obs\": 0.004206917714327574, \"slope\": 0.23451071977615356, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 3.668138027191162, \"sigma_intercept_per_group\": 0.01901174709200859, \"sigma_obs\": 0.004033700563013554, \"slope\": 0.2086494415998459, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 20.079404830932617, \"sigma_intercept_per_group\": 0.01320632640272379, \"sigma_obs\": 0.004226151388138533, \"slope\": 0.20421427488327026, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 19.732669830322266, \"sigma_intercept_per_group\": 0.006693275645375252, \"sigma_obs\": 0.004338670056313276, \"slope\": 0.23089846968650818, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": -7.2844624519348145, \"sigma_intercept_per_group\": 0.006552023813128471, \"sigma_obs\": 0.00387556292116642, \"slope\": 0.08107046782970428, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 19.907825469970703, \"sigma_intercept_per_group\": 0.010037917643785477, \"sigma_obs\": 0.00414095725864172, \"slope\": 0.19086046516895294, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 17.325971603393555, \"sigma_intercept_per_group\": 0.008964920416474342, \"sigma_obs\": 0.004018492065370083, \"slope\": 0.17200247943401337, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 16.28411865234375, \"sigma_intercept_per_group\": 0.016724439337849617, \"sigma_obs\": 0.004323003813624382, \"slope\": 0.24015796184539795, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 10.153678894042969, \"sigma_intercept_per_group\": 0.018773049116134644, \"sigma_obs\": 0.003975068684667349, \"slope\": 0.1773165762424469, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 28.808917999267578, \"sigma_intercept_per_group\": 0.013248125091195107, \"sigma_obs\": 0.0044110496528446674, \"slope\": 0.1544879674911499, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 4.39420223236084, \"sigma_intercept_per_group\": 0.017145279794931412, \"sigma_obs\": 0.0038520905654877424, \"slope\": 0.289080947637558, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 4.0098161697387695, \"sigma_intercept_per_group\": 0.013509226962924004, \"sigma_obs\": 0.0039110006764531136, \"slope\": 0.24832263588905334, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 20.725873947143555, \"sigma_intercept_per_group\": 0.021843455731868744, \"sigma_obs\": 0.0040501621551811695, \"slope\": 0.147111713886261, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 5.349339485168457, \"sigma_intercept_per_group\": 0.008922895416617393, \"sigma_obs\": 0.00395754212513566, \"slope\": 0.24633222818374634, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 13.390400886535645, \"sigma_intercept_per_group\": 0.015340411104261875, \"sigma_obs\": 0.004080865066498518, \"slope\": 0.14468590915203094, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 25.936500549316406, \"sigma_intercept_per_group\": 0.010102257132530212, \"sigma_obs\": 0.0036484114825725555, \"slope\": 0.1277361810207367, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 27.692113876342773, \"sigma_intercept_per_group\": 0.009759391658008099, \"sigma_obs\": 0.0036830750759691, \"slope\": 0.12357696890830994, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 0.6892843246459961, \"sigma_intercept_per_group\": 0.014383707195520401, \"sigma_obs\": 0.004300308413803577, \"slope\": 0.2576723098754883, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 7.705946922302246, \"sigma_intercept_per_group\": 0.013715451583266258, \"sigma_obs\": 0.003905767574906349, \"slope\": 0.2145192176103592, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 8.074809074401855, \"sigma_intercept_per_group\": 0.008324040099978447, \"sigma_obs\": 0.004148312844336033, \"slope\": 0.22424472868442535, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 8.449516296386719, \"sigma_intercept_per_group\": 0.013033797964453697, \"sigma_obs\": 0.003737405641004443, \"slope\": 0.23807446658611298, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 10.009151458740234, \"sigma_intercept_per_group\": 0.018157262355089188, \"sigma_obs\": 0.004173229914158583, \"slope\": 0.3267922103404999, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 13.588265419006348, \"sigma_intercept_per_group\": 0.014727861620485783, \"sigma_obs\": 0.0037055511493235826, \"slope\": 0.26958054304122925, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 8.753445625305176, \"sigma_intercept_per_group\": 0.033363696187734604, \"sigma_obs\": 0.004392524249851704, \"slope\": 0.3003959059715271, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 7.985311985015869, \"sigma_intercept_per_group\": 0.02423204854130745, \"sigma_obs\": 0.00422377185896039, \"slope\": 0.2512650787830353, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 7.765178680419922, \"sigma_intercept_per_group\": 0.025913231074810028, \"sigma_obs\": 0.00420888839289546, \"slope\": 0.246553435921669, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 12.855842590332031, \"sigma_intercept_per_group\": 0.02475365251302719, \"sigma_obs\": 0.003999458160251379, \"slope\": 0.25101858377456665, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 5.831816673278809, \"sigma_intercept_per_group\": 0.029573138803243637, \"sigma_obs\": 0.003939698450267315, \"slope\": 0.20409615337848663, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 19.002710342407227, \"sigma_intercept_per_group\": 0.022874170914292336, \"sigma_obs\": 0.004283520393073559, \"slope\": 0.1885790079832077, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 7.596777439117432, \"sigma_intercept_per_group\": 0.01992371305823326, \"sigma_obs\": 0.0038179331459105015, \"slope\": 0.21834222972393036, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 18.083946228027344, \"sigma_intercept_per_group\": 0.021552009508013725, \"sigma_obs\": 0.004266535863280296, \"slope\": 0.17688533663749695, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 18.949031829833984, \"sigma_intercept_per_group\": 0.015538056381046772, \"sigma_obs\": 0.004052401054650545, \"slope\": 0.24027802050113678, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 16.835479736328125, \"sigma_intercept_per_group\": 0.01561953965574503, \"sigma_obs\": 0.00430662464350462, \"slope\": 0.2951468825340271, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 3.3367068767547607, \"sigma_intercept_per_group\": 0.0391787514090538, \"sigma_obs\": 0.0038482353556901217, \"slope\": 0.1971053034067154, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 8.004900932312012, \"sigma_intercept_per_group\": 0.04732625186443329, \"sigma_obs\": 0.004189014434814453, \"slope\": 0.2874542474746704, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 8.072371482849121, \"sigma_intercept_per_group\": 0.018443867564201355, \"sigma_obs\": 0.004038691055029631, \"slope\": 0.14426466822624207, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 9.917716026306152, \"sigma_intercept_per_group\": 0.039588719606399536, \"sigma_obs\": 0.004099047277122736, \"slope\": 0.19102758169174194, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 9.116827964782715, \"sigma_intercept_per_group\": 0.02959314174950123, \"sigma_obs\": 0.003755205078050494, \"slope\": 0.16145767271518707, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 7.921419143676758, \"sigma_intercept_per_group\": 0.024934453889727592, \"sigma_obs\": 0.0036925955209881067, \"slope\": 0.24903976917266846, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 6.825031280517578, \"sigma_intercept_per_group\": 0.03392001613974571, \"sigma_obs\": 0.003970385529100895, \"slope\": 0.22013771533966064, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 6.757511615753174, \"sigma_intercept_per_group\": 0.036330025643110275, \"sigma_obs\": 0.004188109654933214, \"slope\": 0.28973469138145447, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 11.041048049926758, \"sigma_intercept_per_group\": 0.015607530251145363, \"sigma_obs\": 0.003666180418804288, \"slope\": 0.19491009414196014, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 13.748991012573242, \"sigma_intercept_per_group\": 0.01851589046418667, \"sigma_obs\": 0.0035273388493806124, \"slope\": 0.17295067012310028, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 5.216953754425049, \"sigma_intercept_per_group\": 0.026850944384932518, \"sigma_obs\": 0.004053641576319933, \"slope\": 0.27507632970809937, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 7.218094825744629, \"sigma_intercept_per_group\": 0.022476118057966232, \"sigma_obs\": 0.0037827612832188606, \"slope\": 0.3725869059562683, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 4.133030891418457, \"sigma_intercept_per_group\": 0.015125122852623463, \"sigma_obs\": 0.003925693687051535, \"slope\": 0.12862806022167206, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 8.278654098510742, \"sigma_intercept_per_group\": 0.020364033058285713, \"sigma_obs\": 0.0036178554873913527, \"slope\": 0.25897929072380066, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 10.353484153747559, \"sigma_intercept_per_group\": 0.017812158912420273, \"sigma_obs\": 0.0038063356187194586, \"slope\": 0.16394512355327606, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 8.205766677856445, \"sigma_intercept_per_group\": 0.018321339040994644, \"sigma_obs\": 0.00374590908177197, \"slope\": 0.2288193255662918, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 9.113909721374512, \"sigma_intercept_per_group\": 0.017085295170545578, \"sigma_obs\": 0.003971652593463659, \"slope\": 0.1498556137084961, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 13.435678482055664, \"sigma_intercept_per_group\": 0.01750551164150238, \"sigma_obs\": 0.004465632140636444, \"slope\": 0.3846896290779114, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 7.472805500030518, \"sigma_intercept_per_group\": 0.026303835213184357, \"sigma_obs\": 0.003867018036544323, \"slope\": 0.23164455592632294, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 6.2927374839782715, \"sigma_intercept_per_group\": 0.024425702169537544, \"sigma_obs\": 0.0038871802389621735, \"slope\": 0.13334456086158752, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 12.961935997009277, \"sigma_intercept_per_group\": 0.01814909093081951, \"sigma_obs\": 0.004011703189462423, \"slope\": 0.3038797378540039, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 13.134321212768555, \"sigma_intercept_per_group\": 0.021554507315158844, \"sigma_obs\": 0.003509737551212311, \"slope\": 0.2614832818508148, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 3.311103582382202, \"sigma_intercept_per_group\": 0.014858025126159191, \"sigma_obs\": 0.004095684736967087, \"slope\": 0.1890162229537964, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 20.138322830200195, \"sigma_intercept_per_group\": 0.021079789847135544, \"sigma_obs\": 0.004036059603095055, \"slope\": 0.12030896544456482, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 15.088541030883789, \"sigma_intercept_per_group\": 0.023184463381767273, \"sigma_obs\": 0.0038895090110599995, \"slope\": 0.08197829872369766, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 7.937490463256836, \"sigma_intercept_per_group\": 0.026239175349473953, \"sigma_obs\": 0.0038223413284868, \"slope\": 0.08178292959928513, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 24.575151443481445, \"sigma_intercept_per_group\": 0.01682271435856819, \"sigma_obs\": 0.004344588611274958, \"slope\": 0.1641494780778885, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 1.3120315074920654, \"sigma_intercept_per_group\": 0.020448092371225357, \"sigma_obs\": 0.003816036507487297, \"slope\": 0.2607724964618683, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 8.991385459899902, \"sigma_intercept_per_group\": 0.022301919758319855, \"sigma_obs\": 0.004055492114275694, \"slope\": 0.11153015494346619, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 7.200927734375, \"sigma_intercept_per_group\": 0.043477244675159454, \"sigma_obs\": 0.004154330585151911, \"slope\": 0.13055899739265442, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 9.841200828552246, \"sigma_intercept_per_group\": 0.031264778226614, \"sigma_obs\": 0.003980929963290691, \"slope\": 0.16643954813480377, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 8.015582084655762, \"sigma_intercept_per_group\": 0.022793594747781754, \"sigma_obs\": 0.004230145364999771, \"slope\": 0.2081937938928604, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 8.205357551574707, \"sigma_intercept_per_group\": 0.028755750507116318, \"sigma_obs\": 0.0037520460318773985, \"slope\": 0.19925938546657562, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 13.542074203491211, \"sigma_intercept_per_group\": 0.017120296135544777, \"sigma_obs\": 0.004360156133770943, \"slope\": 0.3609609007835388, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 11.515954971313477, \"sigma_intercept_per_group\": 0.018185215070843697, \"sigma_obs\": 0.0042762248776853085, \"slope\": 0.1512264758348465, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 16.647682189941406, \"sigma_intercept_per_group\": 0.014095952734351158, \"sigma_obs\": 0.0038248426280915737, \"slope\": 0.21975961327552795, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 15.563435554504395, \"sigma_intercept_per_group\": 0.02114333026111126, \"sigma_obs\": 0.004152656998485327, \"slope\": 0.27701371908187866, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 2.6132571697235107, \"sigma_intercept_per_group\": 0.021702580153942108, \"sigma_obs\": 0.004375716671347618, \"slope\": 0.34089264273643494, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 25.538162231445312, \"sigma_intercept_per_group\": 0.016592366620898247, \"sigma_obs\": 0.003755145939067006, \"slope\": 0.0471639521420002, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 5.821999549865723, \"sigma_intercept_per_group\": 0.01921919174492359, \"sigma_obs\": 0.004155362956225872, \"slope\": 0.20842453837394714, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 16.785518646240234, \"sigma_intercept_per_group\": 0.0192825086414814, \"sigma_obs\": 0.004150918684899807, \"slope\": 0.2915632128715515, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 13.999275207519531, \"sigma_intercept_per_group\": 0.01913117803633213, \"sigma_obs\": 0.00367317465133965, \"slope\": 0.12988963723182678, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 15.952714920043945, \"sigma_intercept_per_group\": 0.010810664854943752, \"sigma_obs\": 0.00421273335814476, \"slope\": 0.3471464216709137, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 21.79082489013672, \"sigma_intercept_per_group\": 0.010120279155671597, \"sigma_obs\": 0.004666066728532314, \"slope\": 0.21018755435943604, \"chain\": 0, \"draw\": 160}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 13.224407196044922, \"sigma_intercept_per_group\": 0.01011057011783123, \"sigma_obs\": 0.004094493575394154, \"slope\": 0.15774889290332794, \"chain\": 0, \"draw\": 161}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 13.463597297668457, \"sigma_intercept_per_group\": 0.011682696640491486, \"sigma_obs\": 0.003788364352658391, \"slope\": 0.15563488006591797, \"chain\": 0, \"draw\": 162}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 17.405467987060547, \"sigma_intercept_per_group\": 0.015048112720251083, \"sigma_obs\": 0.004100069869309664, \"slope\": 0.26877105236053467, \"chain\": 0, \"draw\": 163}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 15.356319427490234, \"sigma_intercept_per_group\": 0.014054562896490097, \"sigma_obs\": 0.00391880189999938, \"slope\": 0.11683540046215057, \"chain\": 0, \"draw\": 164}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 10.860158920288086, \"sigma_intercept_per_group\": 0.023085840046405792, \"sigma_obs\": 0.004128152038902044, \"slope\": 0.2500842809677124, \"chain\": 0, \"draw\": 165}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 11.327224731445312, \"sigma_intercept_per_group\": 0.021823158487677574, \"sigma_obs\": 0.0038811813574284315, \"slope\": 0.17530444264411926, \"chain\": 0, \"draw\": 166}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 12.218438148498535, \"sigma_intercept_per_group\": 0.015531025826931, \"sigma_obs\": 0.003817035583779216, \"slope\": 0.1862916350364685, \"chain\": 0, \"draw\": 167}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 7.225792407989502, \"sigma_intercept_per_group\": 0.008852291852235794, \"sigma_obs\": 0.003786524059250951, \"slope\": 0.21563735604286194, \"chain\": 0, \"draw\": 168}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 15.116665840148926, \"sigma_intercept_per_group\": 0.01767479069530964, \"sigma_obs\": 0.004192689433693886, \"slope\": 0.19499555230140686, \"chain\": 0, \"draw\": 169}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 12.125268936157227, \"sigma_intercept_per_group\": 0.014409374445676804, \"sigma_obs\": 0.0038378669414669275, \"slope\": 0.2667956054210663, \"chain\": 0, \"draw\": 170}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 20.32888412475586, \"sigma_intercept_per_group\": 0.018599092960357666, \"sigma_obs\": 0.004290517885237932, \"slope\": 0.17169250547885895, \"chain\": 0, \"draw\": 171}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 11.944461822509766, \"sigma_intercept_per_group\": 0.025455309078097343, \"sigma_obs\": 0.0041959634982049465, \"slope\": 0.18586213886737823, \"chain\": 0, \"draw\": 172}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 19.531972885131836, \"sigma_intercept_per_group\": 0.022506244480609894, \"sigma_obs\": 0.004359869286417961, \"slope\": 0.06815337389707565, \"chain\": 0, \"draw\": 173}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 15.50171947479248, \"sigma_intercept_per_group\": 0.02208586223423481, \"sigma_obs\": 0.004284100607037544, \"slope\": 0.04250950366258621, \"chain\": 0, \"draw\": 174}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 14.030842781066895, \"sigma_intercept_per_group\": 0.023634128272533417, \"sigma_obs\": 0.00445770937949419, \"slope\": 0.257958322763443, \"chain\": 0, \"draw\": 175}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 8.110709190368652, \"sigma_intercept_per_group\": 0.027297671884298325, \"sigma_obs\": 0.004165613558143377, \"slope\": 0.22014805674552917, \"chain\": 0, \"draw\": 176}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 11.908056259155273, \"sigma_intercept_per_group\": 0.02649039402604103, \"sigma_obs\": 0.003982671070843935, \"slope\": 0.14250682294368744, \"chain\": 0, \"draw\": 177}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 6.210599422454834, \"sigma_intercept_per_group\": 0.02317325584590435, \"sigma_obs\": 0.004051885101944208, \"slope\": 0.16360117495059967, \"chain\": 0, \"draw\": 178}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 11.965696334838867, \"sigma_intercept_per_group\": 0.027843160554766655, \"sigma_obs\": 0.0041703833267092705, \"slope\": 0.27661851048469543, \"chain\": 0, \"draw\": 179}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 8.917381286621094, \"sigma_intercept_per_group\": 0.024067441001534462, \"sigma_obs\": 0.004492358770221472, \"slope\": 0.2988663911819458, \"chain\": 0, \"draw\": 180}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 7.367876052856445, \"sigma_intercept_per_group\": 0.018396958708763123, \"sigma_obs\": 0.004314367193728685, \"slope\": 0.32739606499671936, \"chain\": 0, \"draw\": 181}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 20.438995361328125, \"sigma_intercept_per_group\": 0.016267864033579826, \"sigma_obs\": 0.0037758341059088707, \"slope\": 0.10514557361602783, \"chain\": 0, \"draw\": 182}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 8.617547035217285, \"sigma_intercept_per_group\": 0.010844467207789421, \"sigma_obs\": 0.0038418748881667852, \"slope\": 0.16417774558067322, \"chain\": 0, \"draw\": 183}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 12.958555221557617, \"sigma_intercept_per_group\": 0.02894553542137146, \"sigma_obs\": 0.004033252596855164, \"slope\": 0.3006693422794342, \"chain\": 0, \"draw\": 184}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 14.83244514465332, \"sigma_intercept_per_group\": 0.004025799222290516, \"sigma_obs\": 0.004013421013951302, \"slope\": 0.22473064064979553, \"chain\": 0, \"draw\": 185}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 18.258625030517578, \"sigma_intercept_per_group\": 0.0030033676885068417, \"sigma_obs\": 0.004454908426851034, \"slope\": 0.33052492141723633, \"chain\": 0, \"draw\": 186}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 8.951822280883789, \"sigma_intercept_per_group\": 0.008722945116460323, \"sigma_obs\": 0.004108477383852005, \"slope\": 0.2795225977897644, \"chain\": 0, \"draw\": 187}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 11.939066886901855, \"sigma_intercept_per_group\": 0.010249554179608822, \"sigma_obs\": 0.004082110710442066, \"slope\": 0.24354971945285797, \"chain\": 0, \"draw\": 188}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 15.721117973327637, \"sigma_intercept_per_group\": 0.022251136600971222, \"sigma_obs\": 0.0038982562255114317, \"slope\": 0.15745221078395844, \"chain\": 0, \"draw\": 189}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 16.21558952331543, \"sigma_intercept_per_group\": 0.009866859763860703, \"sigma_obs\": 0.004137029405683279, \"slope\": 0.24751999974250793, \"chain\": 0, \"draw\": 190}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 15.323904991149902, \"sigma_intercept_per_group\": 0.012358983978629112, \"sigma_obs\": 0.004143279977142811, \"slope\": 0.2147594839334488, \"chain\": 0, \"draw\": 191}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 17.336997985839844, \"sigma_intercept_per_group\": 0.02087060920894146, \"sigma_obs\": 0.0038704380858689547, \"slope\": 0.2557360827922821, \"chain\": 0, \"draw\": 192}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 11.583391189575195, \"sigma_intercept_per_group\": 0.021181508898735046, \"sigma_obs\": 0.003883619327098131, \"slope\": 0.23468166589736938, \"chain\": 0, \"draw\": 193}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 11.544178009033203, \"sigma_intercept_per_group\": 0.01181392278522253, \"sigma_obs\": 0.0037176443729549646, \"slope\": 0.19767971336841583, \"chain\": 0, \"draw\": 194}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 7.748281002044678, \"sigma_intercept_per_group\": 0.01630452647805214, \"sigma_obs\": 0.0037101551424711943, \"slope\": 0.13150109350681305, \"chain\": 0, \"draw\": 195}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 9.992754936218262, \"sigma_intercept_per_group\": 0.02829599194228649, \"sigma_obs\": 0.003777078352868557, \"slope\": 0.17577412724494934, \"chain\": 0, \"draw\": 196}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 4.86784029006958, \"sigma_intercept_per_group\": 0.024172276258468628, \"sigma_obs\": 0.0041151102632284164, \"slope\": 0.2792840301990509, \"chain\": 0, \"draw\": 197}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 4.973636627197266, \"sigma_intercept_per_group\": 0.024488793686032295, \"sigma_obs\": 0.004117106087505817, \"slope\": 0.2899342477321625, \"chain\": 0, \"draw\": 198}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 21.17041015625, \"sigma_intercept_per_group\": 0.01444044429808855, \"sigma_obs\": 0.004299094434827566, \"slope\": 0.16627614200115204, \"chain\": 0, \"draw\": 199}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 8.69924545288086, \"sigma_intercept_per_group\": 0.030348535627126694, \"sigma_obs\": 0.0041834269650280476, \"slope\": 0.2991151511669159, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.4944429397583, \"sigma_intercept_per_group\": 0.018236849457025528, \"sigma_obs\": 0.003815850941464305, \"slope\": 0.19012336432933807, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 8.063563346862793, \"sigma_intercept_per_group\": 0.017043519765138626, \"sigma_obs\": 0.003530352609232068, \"slope\": 0.19791510701179504, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 7.062926769256592, \"sigma_intercept_per_group\": 0.01908688433468342, \"sigma_obs\": 0.004224190954118967, \"slope\": 0.3171539306640625, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 19.731889724731445, \"sigma_intercept_per_group\": 0.013539562933146954, \"sigma_obs\": 0.003953200299292803, \"slope\": 0.1780279576778412, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 18.291259765625, \"sigma_intercept_per_group\": 0.013730266131460667, \"sigma_obs\": 0.003947120159864426, \"slope\": 0.1925610452890396, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 8.747230529785156, \"sigma_intercept_per_group\": 0.015672210603952408, \"sigma_obs\": 0.004359846469014883, \"slope\": 0.2624925673007965, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 18.810197830200195, \"sigma_intercept_per_group\": 0.011400748044252396, \"sigma_obs\": 0.0039533586241304874, \"slope\": 0.169840008020401, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 15.205920219421387, \"sigma_intercept_per_group\": 0.012436811812222004, \"sigma_obs\": 0.004103345796465874, \"slope\": 0.1927609145641327, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 11.039413452148438, \"sigma_intercept_per_group\": 0.018969105556607246, \"sigma_obs\": 0.003922975156456232, \"slope\": 0.253617525100708, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 12.377477645874023, \"sigma_intercept_per_group\": 0.016826018691062927, \"sigma_obs\": 0.004074040800333023, \"slope\": 0.3198545277118683, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 11.87043285369873, \"sigma_intercept_per_group\": 0.018410244956612587, \"sigma_obs\": 0.004098226316273212, \"slope\": 0.20568010210990906, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 14.266119956970215, \"sigma_intercept_per_group\": 0.01701345108449459, \"sigma_obs\": 0.004124482627958059, \"slope\": 0.1984551101922989, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 4.876817226409912, \"sigma_intercept_per_group\": 0.020145786926150322, \"sigma_obs\": 0.0038939942605793476, \"slope\": 0.35600796341896057, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 4.9253435134887695, \"sigma_intercept_per_group\": 0.023937184363603592, \"sigma_obs\": 0.0037731071934103966, \"slope\": 0.3654574155807495, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 16.296428680419922, \"sigma_intercept_per_group\": 0.019640136510133743, \"sigma_obs\": 0.004186558071523905, \"slope\": 0.16876672208309174, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 9.956404685974121, \"sigma_intercept_per_group\": 0.018186083063483238, \"sigma_obs\": 0.003916812129318714, \"slope\": 0.09316078573465347, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 27.900943756103516, \"sigma_intercept_per_group\": 0.011144406162202358, \"sigma_obs\": 0.004119627643376589, \"slope\": 0.19867679476737976, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 19.01661491394043, \"sigma_intercept_per_group\": 0.02253946289420128, \"sigma_obs\": 0.004766630474478006, \"slope\": 0.1297292411327362, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 19.096683502197266, \"sigma_intercept_per_group\": 0.01522788405418396, \"sigma_obs\": 0.004480842500925064, \"slope\": 0.1603345423936844, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 8.70776081085205, \"sigma_intercept_per_group\": 0.020260531455278397, \"sigma_obs\": 0.0038105687126517296, \"slope\": 0.20419807732105255, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 6.189742088317871, \"sigma_intercept_per_group\": 0.013300800696015358, \"sigma_obs\": 0.004121771547943354, \"slope\": 0.24797910451889038, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 10.95691967010498, \"sigma_intercept_per_group\": 0.02206597849726677, \"sigma_obs\": 0.004082659725099802, \"slope\": 0.27669188380241394, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 14.771323204040527, \"sigma_intercept_per_group\": 0.016738824546337128, \"sigma_obs\": 0.003863353980705142, \"slope\": 0.31321293115615845, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 9.063048362731934, \"sigma_intercept_per_group\": 0.014512475579977036, \"sigma_obs\": 0.004163452889770269, \"slope\": 0.2469380646944046, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 3.1430015563964844, \"sigma_intercept_per_group\": 0.025417648255825043, \"sigma_obs\": 0.003757162718102336, \"slope\": 0.410501629114151, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 18.078941345214844, \"sigma_intercept_per_group\": 0.010575221851468086, \"sigma_obs\": 0.00430361507460475, \"slope\": 0.15854749083518982, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 23.35120964050293, \"sigma_intercept_per_group\": 0.005356696434319019, \"sigma_obs\": 0.003668483579531312, \"slope\": 0.22663885354995728, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 25.607166290283203, \"sigma_intercept_per_group\": 0.01236414723098278, \"sigma_obs\": 0.004329056479036808, \"slope\": 0.24476827681064606, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 4.532476425170898, \"sigma_intercept_per_group\": 0.02240314520895481, \"sigma_obs\": 0.0040289852768182755, \"slope\": 0.046187225729227066, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 8.57311725616455, \"sigma_intercept_per_group\": 0.020323993638157845, \"sigma_obs\": 0.004020011983811855, \"slope\": 0.037746988236904144, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 9.384215354919434, \"sigma_intercept_per_group\": 0.015192186459898949, \"sigma_obs\": 0.003910996951162815, \"slope\": 0.06287336349487305, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 18.20131492614746, \"sigma_intercept_per_group\": 0.014112094417214394, \"sigma_obs\": 0.004475301131606102, \"slope\": 0.19713537395000458, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 16.084205627441406, \"sigma_intercept_per_group\": 0.01944858394563198, \"sigma_obs\": 0.004092290066182613, \"slope\": 0.22507421672344208, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 12.738502502441406, \"sigma_intercept_per_group\": 0.020822269842028618, \"sigma_obs\": 0.004073856398463249, \"slope\": 0.262733519077301, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 11.328948020935059, \"sigma_intercept_per_group\": 0.02720170095562935, \"sigma_obs\": 0.004068412818014622, \"slope\": 0.24225300550460815, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 10.262983322143555, \"sigma_intercept_per_group\": 0.016521966084837914, \"sigma_obs\": 0.004082128405570984, \"slope\": 0.32833051681518555, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 4.377212047576904, \"sigma_intercept_per_group\": 0.02286958508193493, \"sigma_obs\": 0.00427978252992034, \"slope\": 0.2818152606487274, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 17.15158462524414, \"sigma_intercept_per_group\": 0.01214391179382801, \"sigma_obs\": 0.0039010788314044476, \"slope\": 0.2457575649023056, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 17.101268768310547, \"sigma_intercept_per_group\": 0.008478023111820221, \"sigma_obs\": 0.003961782902479172, \"slope\": 0.20583955943584442, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 10.145792007446289, \"sigma_intercept_per_group\": 0.025184178724884987, \"sigma_obs\": 0.0038417375180870295, \"slope\": 0.3142719864845276, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.732828140258789, \"sigma_intercept_per_group\": 0.016656171530485153, \"sigma_obs\": 0.004065715242177248, \"slope\": 0.26154541969299316, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 11.779470443725586, \"sigma_intercept_per_group\": 0.02825181931257248, \"sigma_obs\": 0.004038939718157053, \"slope\": 0.1838742047548294, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 16.50186538696289, \"sigma_intercept_per_group\": 0.02017640694975853, \"sigma_obs\": 0.004282164387404919, \"slope\": 0.1232033297419548, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 10.43493938446045, \"sigma_intercept_per_group\": 0.02207549288868904, \"sigma_obs\": 0.00442767608910799, \"slope\": 0.2728300094604492, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 11.151856422424316, \"sigma_intercept_per_group\": 0.018940109759569168, \"sigma_obs\": 0.003822683822363615, \"slope\": 0.17536561191082, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 16.47918701171875, \"sigma_intercept_per_group\": 0.021047066897153854, \"sigma_obs\": 0.004148813430219889, \"slope\": 0.14294426143169403, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 12.971174240112305, \"sigma_intercept_per_group\": 0.01850816234946251, \"sigma_obs\": 0.004268876276910305, \"slope\": 0.25600048899650574, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 13.91413688659668, \"sigma_intercept_per_group\": 0.018529942259192467, \"sigma_obs\": 0.0041664675809443, \"slope\": 0.26078230142593384, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 15.176945686340332, \"sigma_intercept_per_group\": 0.02026282250881195, \"sigma_obs\": 0.004250382538884878, \"slope\": 0.19630473852157593, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 7.0839128494262695, \"sigma_intercept_per_group\": 0.021551229059696198, \"sigma_obs\": 0.003851135727018118, \"slope\": 0.13789157569408417, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 7.607177257537842, \"sigma_intercept_per_group\": 0.019610699266195297, \"sigma_obs\": 0.0038872358854860067, \"slope\": 0.1336231380701065, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 11.361753463745117, \"sigma_intercept_per_group\": 0.033328332006931305, \"sigma_obs\": 0.00390729121863842, \"slope\": 0.1305423229932785, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 3.4405832290649414, \"sigma_intercept_per_group\": 0.02096748538315296, \"sigma_obs\": 0.0038866836111992598, \"slope\": 0.18167202174663544, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 11.53730583190918, \"sigma_intercept_per_group\": 0.01577659696340561, \"sigma_obs\": 0.004069524817168713, \"slope\": 0.2786186635494232, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 12.28682804107666, \"sigma_intercept_per_group\": 0.022817865014076233, \"sigma_obs\": 0.004037489648908377, \"slope\": 0.21616609394550323, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 10.009668350219727, \"sigma_intercept_per_group\": 0.0101445522159338, \"sigma_obs\": 0.004014990758150816, \"slope\": 0.12780988216400146, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 8.554157257080078, \"sigma_intercept_per_group\": 0.010842998512089252, \"sigma_obs\": 0.003976799547672272, \"slope\": 0.13429348170757294, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 21.14964485168457, \"sigma_intercept_per_group\": 0.01792498491704464, \"sigma_obs\": 0.0038101745303720236, \"slope\": 0.16793887317180634, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 12.436086654663086, \"sigma_intercept_per_group\": 0.017211908474564552, \"sigma_obs\": 0.003763544373214245, \"slope\": 0.14853623509407043, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 11.749343872070312, \"sigma_intercept_per_group\": 0.026044093072414398, \"sigma_obs\": 0.00393863907083869, \"slope\": 0.16795259714126587, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 21.76825523376465, \"sigma_intercept_per_group\": 0.012346919625997543, \"sigma_obs\": 0.004257997963577509, \"slope\": 0.190261572599411, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 22.942338943481445, \"sigma_intercept_per_group\": 0.008739006705582142, \"sigma_obs\": 0.004376457538455725, \"slope\": 0.2762998044490814, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 9.235554695129395, \"sigma_intercept_per_group\": 0.022399839013814926, \"sigma_obs\": 0.0036982009187340736, \"slope\": 0.1303059309720993, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 6.003686904907227, \"sigma_intercept_per_group\": 0.016437184065580368, \"sigma_obs\": 0.0037702980916947126, \"slope\": 0.17513619363307953, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 9.031157493591309, \"sigma_intercept_per_group\": 0.01805156283080578, \"sigma_obs\": 0.004293415695428848, \"slope\": 0.2466617226600647, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 8.527295112609863, \"sigma_intercept_per_group\": 0.015071861445903778, \"sigma_obs\": 0.004124219063669443, \"slope\": 0.11304516345262527, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 14.437241554260254, \"sigma_intercept_per_group\": 0.021291568875312805, \"sigma_obs\": 0.00421147421002388, \"slope\": 0.22994981706142426, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 19.985258102416992, \"sigma_intercept_per_group\": 0.017748799175024033, \"sigma_obs\": 0.00445586908608675, \"slope\": 0.12652412056922913, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 13.9501953125, \"sigma_intercept_per_group\": 0.01594097912311554, \"sigma_obs\": 0.004297912120819092, \"slope\": 0.1920861452817917, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 16.466049194335938, \"sigma_intercept_per_group\": 0.013779752887785435, \"sigma_obs\": 0.004350970033556223, \"slope\": 0.2818288803100586, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.188323020935059, \"sigma_intercept_per_group\": 0.017374509945511818, \"sigma_obs\": 0.004286714363843203, \"slope\": 0.13657917082309723, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 3.650052785873413, \"sigma_intercept_per_group\": 0.018216615542769432, \"sigma_obs\": 0.0036489751655608416, \"slope\": 0.23261521756649017, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": -0.5641259551048279, \"sigma_intercept_per_group\": 0.018929800018668175, \"sigma_obs\": 0.003611283376812935, \"slope\": 0.23237761855125427, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 6.5888471603393555, \"sigma_intercept_per_group\": 0.012263290584087372, \"sigma_obs\": 0.004164652433246374, \"slope\": 0.2270064651966095, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 11.593375205993652, \"sigma_intercept_per_group\": 0.014173563569784164, \"sigma_obs\": 0.003787091001868248, \"slope\": 0.1378147006034851, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 12.203052520751953, \"sigma_intercept_per_group\": 0.012401671148836613, \"sigma_obs\": 0.003930254839360714, \"slope\": 0.16019423305988312, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 8.825818061828613, \"sigma_intercept_per_group\": 0.014454593881964684, \"sigma_obs\": 0.003699387889355421, \"slope\": 0.1642666608095169, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 3.8262438774108887, \"sigma_intercept_per_group\": 0.016594281420111656, \"sigma_obs\": 0.00386199657805264, \"slope\": 0.1580708771944046, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 19.703861236572266, \"sigma_intercept_per_group\": 0.005496570374816656, \"sigma_obs\": 0.004068787209689617, \"slope\": 0.31456243991851807, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 13.764286994934082, \"sigma_intercept_per_group\": 0.006648196838796139, \"sigma_obs\": 0.003863239660859108, \"slope\": 0.20383399724960327, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 18.42430305480957, \"sigma_intercept_per_group\": 0.008893021382391453, \"sigma_obs\": 0.004263288341462612, \"slope\": 0.24779467284679413, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 22.307876586914062, \"sigma_intercept_per_group\": 0.008532078936696053, \"sigma_obs\": 0.0043039885349571705, \"slope\": 0.21093258261680603, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 4.6359429359436035, \"sigma_intercept_per_group\": 0.0194255243986845, \"sigma_obs\": 0.00426676357164979, \"slope\": 0.28903433680534363, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 20.210790634155273, \"sigma_intercept_per_group\": 0.017111988738179207, \"sigma_obs\": 0.004221921321004629, \"slope\": 0.1582026481628418, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 8.959261894226074, \"sigma_intercept_per_group\": 0.017309002578258514, \"sigma_obs\": 0.004084478598088026, \"slope\": 0.28487956523895264, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 11.98414421081543, \"sigma_intercept_per_group\": 0.02879701741039753, \"sigma_obs\": 0.004330179654061794, \"slope\": 0.21984697878360748, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 7.425361633300781, \"sigma_intercept_per_group\": 0.024613454937934875, \"sigma_obs\": 0.004085450433194637, \"slope\": 0.2437492460012436, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 9.654972076416016, \"sigma_intercept_per_group\": 0.02596443146467209, \"sigma_obs\": 0.003923988901078701, \"slope\": 0.2174694687128067, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 9.502685546875, \"sigma_intercept_per_group\": 0.017612390220165253, \"sigma_obs\": 0.0038577651139348745, \"slope\": 0.1501520872116089, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 6.0089263916015625, \"sigma_intercept_per_group\": 0.031213304027915, \"sigma_obs\": 0.003927187994122505, \"slope\": 0.2834181487560272, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 0.37518641352653503, \"sigma_intercept_per_group\": 0.023232746869325638, \"sigma_obs\": 0.003674234263598919, \"slope\": 0.278099924325943, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 8.947497367858887, \"sigma_intercept_per_group\": 0.041121963411569595, \"sigma_obs\": 0.003619741415604949, \"slope\": 0.141538605093956, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 1.1788791418075562, \"sigma_intercept_per_group\": 0.02754833735525608, \"sigma_obs\": 0.0035526063293218613, \"slope\": 0.1606786549091339, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 13.108702659606934, \"sigma_intercept_per_group\": 0.02822914719581604, \"sigma_obs\": 0.003715744474902749, \"slope\": 0.08640477061271667, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 15.722833633422852, \"sigma_intercept_per_group\": 0.021440962329506874, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.05618796870112419, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 17.616113662719727, \"sigma_intercept_per_group\": 0.015952173620462418, \"sigma_obs\": 0.0037414676044136286, \"slope\": 0.08486730605363846, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 18.214561462402344, \"sigma_intercept_per_group\": 0.015224464237689972, \"sigma_obs\": 0.003948691766709089, \"slope\": 0.04887751489877701, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 18.49821662902832, \"sigma_intercept_per_group\": 0.02060498669743538, \"sigma_obs\": 0.004061663523316383, \"slope\": 0.05434323102235794, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 15.843475341796875, \"sigma_intercept_per_group\": 0.014933855272829533, \"sigma_obs\": 0.004236746113747358, \"slope\": 0.2238340526819229, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 12.071490287780762, \"sigma_intercept_per_group\": 0.02684435062110424, \"sigma_obs\": 0.004070776514708996, \"slope\": 0.17309452593326569, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 7.961061954498291, \"sigma_intercept_per_group\": 0.03890248388051987, \"sigma_obs\": 0.004553517792373896, \"slope\": 0.3367815911769867, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 7.763580322265625, \"sigma_intercept_per_group\": 0.03962904214859009, \"sigma_obs\": 0.0042466651648283005, \"slope\": 0.273954302072525, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 8.794839859008789, \"sigma_intercept_per_group\": 0.015754172578454018, \"sigma_obs\": 0.0039191474206745625, \"slope\": 0.191666841506958, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 8.805477142333984, \"sigma_intercept_per_group\": 0.023456629365682602, \"sigma_obs\": 0.003929999656975269, \"slope\": 0.1660217046737671, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 15.065488815307617, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.004285179544240236, \"slope\": 0.21786846220493317, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 19.071840286254883, \"sigma_intercept_per_group\": 0.01737412065267563, \"sigma_obs\": 0.004162154626101255, \"slope\": 0.13531547784805298, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 15.21051025390625, \"sigma_intercept_per_group\": 0.018816914409399033, \"sigma_obs\": 0.004176377318799496, \"slope\": 0.162367045879364, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 17.50092315673828, \"sigma_intercept_per_group\": 0.01693582907319069, \"sigma_obs\": 0.004645699635148048, \"slope\": 0.26351383328437805, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 10.562623023986816, \"sigma_intercept_per_group\": 0.03392411023378372, \"sigma_obs\": 0.004310599993914366, \"slope\": 0.16812315583229065, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 12.626243591308594, \"sigma_intercept_per_group\": 0.006118082441389561, \"sigma_obs\": 0.004026935901492834, \"slope\": 0.2627924978733063, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.377864837646484, \"sigma_intercept_per_group\": 0.03014899045228958, \"sigma_obs\": 0.003863799851387739, \"slope\": 0.20957162976264954, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 3.399231433868408, \"sigma_intercept_per_group\": 0.026002585887908936, \"sigma_obs\": 0.003644038923084736, \"slope\": 0.14869043231010437, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 19.375444412231445, \"sigma_intercept_per_group\": 0.011174609884619713, \"sigma_obs\": 0.0045690229162573814, \"slope\": 0.2943640351295471, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 6.916561603546143, \"sigma_intercept_per_group\": 0.026236804202198982, \"sigma_obs\": 0.0040517207235097885, \"slope\": 0.18386463820934296, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 11.265032768249512, \"sigma_intercept_per_group\": 0.022660229355096817, \"sigma_obs\": 0.0038904736284166574, \"slope\": 0.12919041514396667, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 7.75400972366333, \"sigma_intercept_per_group\": 0.020279809832572937, \"sigma_obs\": 0.0037453696131706238, \"slope\": 0.21016745269298553, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 8.189379692077637, \"sigma_intercept_per_group\": 0.018828416243195534, \"sigma_obs\": 0.003862712997943163, \"slope\": 0.21976540982723236, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 14.990594863891602, \"sigma_intercept_per_group\": 0.010901887901127338, \"sigma_obs\": 0.003949614707380533, \"slope\": 0.25260287523269653, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 11.744601249694824, \"sigma_intercept_per_group\": 0.02344524674117565, \"sigma_obs\": 0.0038789352402091026, \"slope\": 0.17624129354953766, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 15.621774673461914, \"sigma_intercept_per_group\": 0.01799684949219227, \"sigma_obs\": 0.004005338065326214, \"slope\": 0.251279354095459, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 14.313191413879395, \"sigma_intercept_per_group\": 0.02219567820429802, \"sigma_obs\": 0.0041473559103906155, \"slope\": 0.21053506433963776, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 13.430397033691406, \"sigma_intercept_per_group\": 0.009735947474837303, \"sigma_obs\": 0.0037356738466769457, \"slope\": 0.26608121395111084, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 13.630142211914062, \"sigma_intercept_per_group\": 0.0123088164255023, \"sigma_obs\": 0.0038146446458995342, \"slope\": 0.19361887872219086, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 3.9672305583953857, \"sigma_intercept_per_group\": 0.006313311401754618, \"sigma_obs\": 0.003911248873919249, \"slope\": 0.16468580067157745, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 20.56456756591797, \"sigma_intercept_per_group\": 0.015062801539897919, \"sigma_obs\": 0.004101692698895931, \"slope\": 0.18297769129276276, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 17.591711044311523, \"sigma_intercept_per_group\": 0.01576201058924198, \"sigma_obs\": 0.0039347195997834206, \"slope\": 0.18773016333580017, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 10.485973358154297, \"sigma_intercept_per_group\": 0.019231613725423813, \"sigma_obs\": 0.004112203139811754, \"slope\": 0.28429415822029114, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 15.693488121032715, \"sigma_intercept_per_group\": 0.015183387324213982, \"sigma_obs\": 0.004068309906870127, \"slope\": 0.21770338714122772, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 15.7683744430542, \"sigma_intercept_per_group\": 0.014726324006915092, \"sigma_obs\": 0.004098929930478334, \"slope\": 0.14990808069705963, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 8.538536071777344, \"sigma_intercept_per_group\": 0.012178409844636917, \"sigma_obs\": 0.004382333718240261, \"slope\": 0.26002222299575806, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 7.237646579742432, \"sigma_intercept_per_group\": 0.005792699288576841, \"sigma_obs\": 0.004086526110768318, \"slope\": 0.2688092887401581, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 11.395334243774414, \"sigma_intercept_per_group\": 0.00808236375451088, \"sigma_obs\": 0.0042105782777071, \"slope\": 0.19535866379737854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 18.211868286132812, \"sigma_intercept_per_group\": 0.02547106146812439, \"sigma_obs\": 0.0041677155531942844, \"slope\": 0.2287038415670395, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": -3.2171363830566406, \"sigma_intercept_per_group\": 0.012189541012048721, \"sigma_obs\": 0.0038122900296002626, \"slope\": 0.23957717418670654, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 9.60183334350586, \"sigma_intercept_per_group\": 0.014475424773991108, \"sigma_obs\": 0.003904694924131036, \"slope\": 0.2545371651649475, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 9.18093490600586, \"sigma_intercept_per_group\": 0.012567318975925446, \"sigma_obs\": 0.0039024464786052704, \"slope\": 0.24870626628398895, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 10.53969955444336, \"sigma_intercept_per_group\": 0.012627730146050453, \"sigma_obs\": 0.003886305494233966, \"slope\": 0.18758533895015717, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 14.215615272521973, \"sigma_intercept_per_group\": 0.018420277163386345, \"sigma_obs\": 0.004062382038682699, \"slope\": 0.13208967447280884, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 14.209391593933105, \"sigma_intercept_per_group\": 0.015488700941205025, \"sigma_obs\": 0.00423895288258791, \"slope\": 0.19517730176448822, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 12.1614990234375, \"sigma_intercept_per_group\": 0.019068431109189987, \"sigma_obs\": 0.00422442052513361, \"slope\": 0.07947352528572083, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 15.070243835449219, \"sigma_intercept_per_group\": 0.021702175959944725, \"sigma_obs\": 0.004029498435556889, \"slope\": 0.20647640526294708, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.062638282775879, \"sigma_intercept_per_group\": 0.01485813781619072, \"sigma_obs\": 0.004136459436267614, \"slope\": 0.13840332627296448, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 13.224609375, \"sigma_intercept_per_group\": 0.01681147888302803, \"sigma_obs\": 0.004224616102874279, \"slope\": 0.29649826884269714, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 12.972430229187012, \"sigma_intercept_per_group\": 0.023797541856765747, \"sigma_obs\": 0.004035895690321922, \"slope\": 0.14136187732219696, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 12.639427185058594, \"sigma_intercept_per_group\": 0.02979956939816475, \"sigma_obs\": 0.004305443726480007, \"slope\": 0.17794498801231384, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 15.804996490478516, \"sigma_intercept_per_group\": 0.01568572036921978, \"sigma_obs\": 0.004074987024068832, \"slope\": 0.21095187962055206, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 10.741495132446289, \"sigma_intercept_per_group\": 0.014117862097918987, \"sigma_obs\": 0.0037899452727288008, \"slope\": 0.1926650106906891, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 15.48204517364502, \"sigma_intercept_per_group\": 0.019742146134376526, \"sigma_obs\": 0.004089804831892252, \"slope\": 0.2719341814517975, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 18.317256927490234, \"sigma_intercept_per_group\": 0.015333792194724083, \"sigma_obs\": 0.0038093551993370056, \"slope\": 0.13711099326610565, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 9.277792930603027, \"sigma_intercept_per_group\": 0.0181940458714962, \"sigma_obs\": 0.004099584650248289, \"slope\": 0.33620432019233704, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 16.801820755004883, \"sigma_intercept_per_group\": 0.013676149770617485, \"sigma_obs\": 0.003880076576024294, \"slope\": 0.23554643988609314, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 13.283445358276367, \"sigma_intercept_per_group\": 0.010029870085418224, \"sigma_obs\": 0.004144404083490372, \"slope\": 0.19405600428581238, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 28.56692886352539, \"sigma_intercept_per_group\": 0.016129741445183754, \"sigma_obs\": 0.004422485362738371, \"slope\": 0.14121970534324646, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 18.216144561767578, \"sigma_intercept_per_group\": 0.01382842194288969, \"sigma_obs\": 0.004032979253679514, \"slope\": 0.20695586502552032, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 15.145745277404785, \"sigma_intercept_per_group\": 0.01726504974067211, \"sigma_obs\": 0.004056116566061974, \"slope\": 0.23628439009189606, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 18.28443717956543, \"sigma_intercept_per_group\": 0.008980442769825459, \"sigma_obs\": 0.003975223749876022, \"slope\": 0.157798171043396, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 4.058918476104736, \"sigma_intercept_per_group\": 0.020947668701410294, \"sigma_obs\": 0.0037591448053717613, \"slope\": 0.2611106038093567, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 21.306411743164062, \"sigma_intercept_per_group\": 0.019222784787416458, \"sigma_obs\": 0.004512716084718704, \"slope\": 0.2594519555568695, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 8.525124549865723, \"sigma_intercept_per_group\": 0.022236179560422897, \"sigma_obs\": 0.003941729664802551, \"slope\": 0.1829969882965088, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 8.66665267944336, \"sigma_intercept_per_group\": 0.02056596428155899, \"sigma_obs\": 0.003940981812775135, \"slope\": 0.19820526242256165, \"chain\": 1, \"draw\": 160}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 8.395552635192871, \"sigma_intercept_per_group\": 0.027392011135816574, \"sigma_obs\": 0.003737587481737137, \"slope\": 0.22695466876029968, \"chain\": 1, \"draw\": 161}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 9.192790985107422, \"sigma_intercept_per_group\": 0.013445508666336536, \"sigma_obs\": 0.004214097745716572, \"slope\": 0.13015198707580566, \"chain\": 1, \"draw\": 162}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 19.66211700439453, \"sigma_intercept_per_group\": 0.013842461630702019, \"sigma_obs\": 0.0041459063068032265, \"slope\": 0.24802285432815552, \"chain\": 1, \"draw\": 163}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 12.06894302368164, \"sigma_intercept_per_group\": 0.018579887226223946, \"sigma_obs\": 0.0042939623817801476, \"slope\": 0.22836044430732727, \"chain\": 1, \"draw\": 164}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 21.557912826538086, \"sigma_intercept_per_group\": 0.014453484676778316, \"sigma_obs\": 0.0043242513202130795, \"slope\": 0.1629568338394165, \"chain\": 1, \"draw\": 165}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 16.0334529876709, \"sigma_intercept_per_group\": 0.0225725956261158, \"sigma_obs\": 0.005065936129540205, \"slope\": 0.18644531071186066, \"chain\": 1, \"draw\": 166}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 9.502646446228027, \"sigma_intercept_per_group\": 0.015348679386079311, \"sigma_obs\": 0.003792237490415573, \"slope\": 0.1644805371761322, \"chain\": 1, \"draw\": 167}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": -7.473568439483643, \"sigma_intercept_per_group\": 0.012437660247087479, \"sigma_obs\": 0.0037599389906972647, \"slope\": 0.21989800035953522, \"chain\": 1, \"draw\": 168}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 27.26302146911621, \"sigma_intercept_per_group\": 0.01108329277485609, \"sigma_obs\": 0.004273809026926756, \"slope\": 0.21008118987083435, \"chain\": 1, \"draw\": 169}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 5.679250717163086, \"sigma_intercept_per_group\": 0.022392593324184418, \"sigma_obs\": 0.003590111853554845, \"slope\": 0.23471547663211823, \"chain\": 1, \"draw\": 170}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 3.9864566326141357, \"sigma_intercept_per_group\": 0.03491555526852608, \"sigma_obs\": 0.0035089158918708563, \"slope\": 0.3021821677684784, \"chain\": 1, \"draw\": 171}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 4.962776184082031, \"sigma_intercept_per_group\": 0.031244441866874695, \"sigma_obs\": 0.0035206996835768223, \"slope\": 0.324438214302063, \"chain\": 1, \"draw\": 172}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 5.602456092834473, \"sigma_intercept_per_group\": 0.031058253720402718, \"sigma_obs\": 0.003600619500502944, \"slope\": 0.30488866567611694, \"chain\": 1, \"draw\": 173}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 3.574613571166992, \"sigma_intercept_per_group\": 0.03408166021108627, \"sigma_obs\": 0.0036938742268830538, \"slope\": 0.3144707977771759, \"chain\": 1, \"draw\": 174}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 6.0953803062438965, \"sigma_intercept_per_group\": 0.035050712525844574, \"sigma_obs\": 0.0038018771447241306, \"slope\": 0.2794552445411682, \"chain\": 1, \"draw\": 175}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 4.117492198944092, \"sigma_intercept_per_group\": 0.02947290614247322, \"sigma_obs\": 0.003686786163598299, \"slope\": 0.2790108621120453, \"chain\": 1, \"draw\": 176}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 4.3790388107299805, \"sigma_intercept_per_group\": 0.03100084513425827, \"sigma_obs\": 0.003865709062665701, \"slope\": 0.23363003134727478, \"chain\": 1, \"draw\": 177}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 12.84201431274414, \"sigma_intercept_per_group\": 0.011615196242928505, \"sigma_obs\": 0.0037316058296710253, \"slope\": 0.14073917269706726, \"chain\": 1, \"draw\": 178}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 12.414887428283691, \"sigma_intercept_per_group\": 0.01455320231616497, \"sigma_obs\": 0.0037390419747680426, \"slope\": 0.13648420572280884, \"chain\": 1, \"draw\": 179}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 10.326018333435059, \"sigma_intercept_per_group\": 0.02087576501071453, \"sigma_obs\": 0.003909262828528881, \"slope\": 0.18767492473125458, \"chain\": 1, \"draw\": 180}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 15.752734184265137, \"sigma_intercept_per_group\": 0.016250737011432648, \"sigma_obs\": 0.0043753162026405334, \"slope\": 0.23903657495975494, \"chain\": 1, \"draw\": 181}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 6.478569984436035, \"sigma_intercept_per_group\": 0.020777475088834763, \"sigma_obs\": 0.004142305813729763, \"slope\": 0.26049238443374634, \"chain\": 1, \"draw\": 182}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 25.24509620666504, \"sigma_intercept_per_group\": 0.019717080518603325, \"sigma_obs\": 0.0046875085681676865, \"slope\": 0.15285158157348633, \"chain\": 1, \"draw\": 183}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 15.745749473571777, \"sigma_intercept_per_group\": 0.011777957901358604, \"sigma_obs\": 0.004056389443576336, \"slope\": 0.26178276538848877, \"chain\": 1, \"draw\": 184}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 19.16963768005371, \"sigma_intercept_per_group\": 0.007270066998898983, \"sigma_obs\": 0.0038740497548133135, \"slope\": 0.28354087471961975, \"chain\": 1, \"draw\": 185}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 9.519261360168457, \"sigma_intercept_per_group\": 0.009544145315885544, \"sigma_obs\": 0.0039005433209240437, \"slope\": 0.31455373764038086, \"chain\": 1, \"draw\": 186}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 4.866501808166504, \"sigma_intercept_per_group\": 0.010757939890027046, \"sigma_obs\": 0.003774068085476756, \"slope\": 0.33184874057769775, \"chain\": 1, \"draw\": 187}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 5.31254243850708, \"sigma_intercept_per_group\": 0.012654699385166168, \"sigma_obs\": 0.003842085599899292, \"slope\": 0.266744464635849, \"chain\": 1, \"draw\": 188}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 13.689255714416504, \"sigma_intercept_per_group\": 0.005680661182850599, \"sigma_obs\": 0.0040544169023633, \"slope\": 0.14562451839447021, \"chain\": 1, \"draw\": 189}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 14.95084285736084, \"sigma_intercept_per_group\": 0.01591399498283863, \"sigma_obs\": 0.004152446985244751, \"slope\": 0.27182185649871826, \"chain\": 1, \"draw\": 190}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 13.250029563903809, \"sigma_intercept_per_group\": 0.01271546445786953, \"sigma_obs\": 0.0036831418983638287, \"slope\": 0.14675240218639374, \"chain\": 1, \"draw\": 191}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 10.449140548706055, \"sigma_intercept_per_group\": 0.01849202811717987, \"sigma_obs\": 0.004172726534307003, \"slope\": 0.29060009121894836, \"chain\": 1, \"draw\": 192}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 12.422623634338379, \"sigma_intercept_per_group\": 0.013902815990149975, \"sigma_obs\": 0.0038581090047955513, \"slope\": 0.26170435547828674, \"chain\": 1, \"draw\": 193}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 14.220320701599121, \"sigma_intercept_per_group\": 0.012964152731001377, \"sigma_obs\": 0.003890768624842167, \"slope\": 0.2417418211698532, \"chain\": 1, \"draw\": 194}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 13.78234577178955, \"sigma_intercept_per_group\": 0.017959600314497948, \"sigma_obs\": 0.004258444532752037, \"slope\": 0.35067084431648254, \"chain\": 1, \"draw\": 195}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 8.764466285705566, \"sigma_intercept_per_group\": 0.00668156985193491, \"sigma_obs\": 0.004211939871311188, \"slope\": 0.2142767459154129, \"chain\": 1, \"draw\": 196}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 17.219280242919922, \"sigma_intercept_per_group\": 0.01272539421916008, \"sigma_obs\": 0.0037123565562069416, \"slope\": 0.205419659614563, \"chain\": 1, \"draw\": 197}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 18.36520004272461, \"sigma_intercept_per_group\": 0.013673508539795876, \"sigma_obs\": 0.003754331497475505, \"slope\": 0.2326548546552658, \"chain\": 1, \"draw\": 198}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 15.676915168762207, \"sigma_intercept_per_group\": 0.012899897992610931, \"sigma_obs\": 0.0041182017885148525, \"slope\": 0.26218366622924805, \"chain\": 1, \"draw\": 199}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 13.910944938659668, \"sigma_intercept_per_group\": 0.02336452528834343, \"sigma_obs\": 0.00391376530751586, \"slope\": 0.07599802315235138, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 14.644582748413086, \"sigma_intercept_per_group\": 0.018625415861606598, \"sigma_obs\": 0.0041630142368376255, \"slope\": 0.1946958303451538, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 11.859487533569336, \"sigma_intercept_per_group\": 0.02397056482732296, \"sigma_obs\": 0.0038279900327324867, \"slope\": 0.154178187251091, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 12.685654640197754, \"sigma_intercept_per_group\": 0.020889097824692726, \"sigma_obs\": 0.0038442774675786495, \"slope\": 0.16931475698947906, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 5.6109538078308105, \"sigma_intercept_per_group\": 0.020118925720453262, \"sigma_obs\": 0.0039367275312542915, \"slope\": 0.27624794840812683, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 5.270198345184326, \"sigma_intercept_per_group\": 0.028482504189014435, \"sigma_obs\": 0.0036722079385071993, \"slope\": 0.14594127237796783, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 14.604692459106445, \"sigma_intercept_per_group\": 0.01819767989218235, \"sigma_obs\": 0.0038905588444322348, \"slope\": 0.14092768728733063, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 13.351242065429688, \"sigma_intercept_per_group\": 0.02148405835032463, \"sigma_obs\": 0.004358062986284494, \"slope\": 0.23152104020118713, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 14.131821632385254, \"sigma_intercept_per_group\": 0.022587761282920837, \"sigma_obs\": 0.004278657957911491, \"slope\": 0.21334807574748993, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 11.933043479919434, \"sigma_intercept_per_group\": 0.012518436647951603, \"sigma_obs\": 0.0037143626250326633, \"slope\": 0.1603400558233261, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 9.581589698791504, \"sigma_intercept_per_group\": 0.021844256669282913, \"sigma_obs\": 0.004068440292030573, \"slope\": 0.19609864056110382, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 11.551580429077148, \"sigma_intercept_per_group\": 0.014804764650762081, \"sigma_obs\": 0.00462779076769948, \"slope\": 0.3416309952735901, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 13.48715877532959, \"sigma_intercept_per_group\": 0.022643789649009705, \"sigma_obs\": 0.004185141064226627, \"slope\": 0.2942267060279846, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 17.530794143676758, \"sigma_intercept_per_group\": 0.012935791164636612, \"sigma_obs\": 0.003932371269911528, \"slope\": 0.1765318512916565, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 23.088489532470703, \"sigma_intercept_per_group\": 0.018109438940882683, \"sigma_obs\": 0.0039818789809942245, \"slope\": 0.22539781033992767, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 10.952017784118652, \"sigma_intercept_per_group\": 0.020230894908308983, \"sigma_obs\": 0.004234391264617443, \"slope\": 0.2028864026069641, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 7.797173023223877, \"sigma_intercept_per_group\": 0.036860618740320206, \"sigma_obs\": 0.004114591982215643, \"slope\": 0.1740458607673645, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 7.918060779571533, \"sigma_intercept_per_group\": 0.039316464215517044, \"sigma_obs\": 0.004237075336277485, \"slope\": 0.19360244274139404, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 3.837857961654663, \"sigma_intercept_per_group\": 0.04206808656454086, \"sigma_obs\": 0.0038524800911545753, \"slope\": 0.30223068594932556, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 14.90882682800293, \"sigma_intercept_per_group\": 0.013380967080593109, \"sigma_obs\": 0.004263637587428093, \"slope\": 0.2089148759841919, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.232527732849121, \"sigma_intercept_per_group\": 0.020281342789530754, \"sigma_obs\": 0.004074703436344862, \"slope\": 0.27072542905807495, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 11.916237831115723, \"sigma_intercept_per_group\": 0.01770065724849701, \"sigma_obs\": 0.004077088087797165, \"slope\": 0.1896013766527176, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 11.307418823242188, \"sigma_intercept_per_group\": 0.0164454635232687, \"sigma_obs\": 0.0037049257662147284, \"slope\": 0.18721981346607208, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 10.764622688293457, \"sigma_intercept_per_group\": 0.0256035178899765, \"sigma_obs\": 0.004282940644770861, \"slope\": 0.2058519870042801, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 12.162664413452148, \"sigma_intercept_per_group\": 0.032850589603185654, \"sigma_obs\": 0.004268094431608915, \"slope\": 0.2781914472579956, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 11.911325454711914, \"sigma_intercept_per_group\": 0.012767964974045753, \"sigma_obs\": 0.003947163466364145, \"slope\": 0.15657177567481995, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 6.723698616027832, \"sigma_intercept_per_group\": 0.01238317508250475, \"sigma_obs\": 0.0037342507857829332, \"slope\": 0.158015176653862, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 18.798871994018555, \"sigma_intercept_per_group\": 0.012175767682492733, \"sigma_obs\": 0.004487182013690472, \"slope\": 0.3453679382801056, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 20.45260238647461, \"sigma_intercept_per_group\": 0.010833918116986752, \"sigma_obs\": 0.0045404499396681786, \"slope\": 0.3505573570728302, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 12.415254592895508, \"sigma_intercept_per_group\": 0.016735950484871864, \"sigma_obs\": 0.003750945907086134, \"slope\": 0.04153376445174217, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 11.33404541015625, \"sigma_intercept_per_group\": 0.016465330496430397, \"sigma_obs\": 0.003745148191228509, \"slope\": 0.09216680377721786, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 16.511070251464844, \"sigma_intercept_per_group\": 0.0202634297311306, \"sigma_obs\": 0.0038575646467506886, \"slope\": 0.11604887992143631, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 22.255979537963867, \"sigma_intercept_per_group\": 0.010357004590332508, \"sigma_obs\": 0.004185015335679054, \"slope\": 0.19551755487918854, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 7.811313629150391, \"sigma_intercept_per_group\": 0.017960961908102036, \"sigma_obs\": 0.003821632359176874, \"slope\": 0.25405749678611755, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 9.574859619140625, \"sigma_intercept_per_group\": 0.01127578318119049, \"sigma_obs\": 0.0038893662858754396, \"slope\": 0.2680409848690033, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 16.238346099853516, \"sigma_intercept_per_group\": 0.01923864521086216, \"sigma_obs\": 0.004109498113393784, \"slope\": 0.16786545515060425, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 16.363250732421875, \"sigma_intercept_per_group\": 0.013729696162045002, \"sigma_obs\": 0.004114174284040928, \"slope\": 0.1591661274433136, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 22.377403259277344, \"sigma_intercept_per_group\": 0.014835342764854431, \"sigma_obs\": 0.0044074817560613155, \"slope\": 0.13693462312221527, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 23.27312469482422, \"sigma_intercept_per_group\": 0.01707298867404461, \"sigma_obs\": 0.00413605896756053, \"slope\": 0.1636897772550583, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 7.275153636932373, \"sigma_intercept_per_group\": 0.02832282893359661, \"sigma_obs\": 0.004139138851314783, \"slope\": 0.2518126666545868, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 12.187787055969238, \"sigma_intercept_per_group\": 0.020366329699754715, \"sigma_obs\": 0.00397573783993721, \"slope\": 0.23942352831363678, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 13.263769149780273, \"sigma_intercept_per_group\": 0.026969658210873604, \"sigma_obs\": 0.0039021840784698725, \"slope\": 0.23585155606269836, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 19.850170135498047, \"sigma_intercept_per_group\": 0.018824847415089607, \"sigma_obs\": 0.004223274532705545, \"slope\": 0.17531251907348633, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 10.637458801269531, \"sigma_intercept_per_group\": 0.02169581688940525, \"sigma_obs\": 0.004285277333110571, \"slope\": 0.23494787514209747, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 21.424161911010742, \"sigma_intercept_per_group\": 0.015085025690495968, \"sigma_obs\": 0.004444105084985495, \"slope\": 0.2651079297065735, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 2.3877055644989014, \"sigma_intercept_per_group\": 0.02859610877931118, \"sigma_obs\": 0.004147563129663467, \"slope\": 0.28496018052101135, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 17.00070571899414, \"sigma_intercept_per_group\": 0.010778499767184258, \"sigma_obs\": 0.004056085832417011, \"slope\": 0.1616985946893692, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 16.119211196899414, \"sigma_intercept_per_group\": 0.014663365669548512, \"sigma_obs\": 0.00418012123554945, \"slope\": 0.11495734006166458, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 4.714224338531494, \"sigma_intercept_per_group\": 0.0413602776825428, \"sigma_obs\": 0.004070813301950693, \"slope\": 0.20613990724086761, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 9.48280143737793, \"sigma_intercept_per_group\": 0.02213359624147415, \"sigma_obs\": 0.0038509115111082792, \"slope\": 0.25501948595046997, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 11.932138442993164, \"sigma_intercept_per_group\": 0.022556282579898834, \"sigma_obs\": 0.003746200120076537, \"slope\": 0.23655980825424194, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 11.462850570678711, \"sigma_intercept_per_group\": 0.017298918217420578, \"sigma_obs\": 0.004419879987835884, \"slope\": 0.2726401686668396, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 4.972246170043945, \"sigma_intercept_per_group\": 0.02560572884976864, \"sigma_obs\": 0.00374517310410738, \"slope\": 0.30372732877731323, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 11.98072624206543, \"sigma_intercept_per_group\": 0.021768953651189804, \"sigma_obs\": 0.003935757093131542, \"slope\": 0.24061301350593567, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 17.432313919067383, \"sigma_intercept_per_group\": 0.011799758300185204, \"sigma_obs\": 0.004066791385412216, \"slope\": 0.23189741373062134, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 24.201007843017578, \"sigma_intercept_per_group\": 0.013069894164800644, \"sigma_obs\": 0.0044242870062589645, \"slope\": 0.3833073377609253, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 1.2842515707015991, \"sigma_intercept_per_group\": 0.013737155124545097, \"sigma_obs\": 0.0038537937216460705, \"slope\": 0.19874000549316406, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 17.438961029052734, \"sigma_intercept_per_group\": 0.010284224525094032, \"sigma_obs\": 0.004052642732858658, \"slope\": 0.1604567915201187, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.19468879699707, \"sigma_intercept_per_group\": 0.017049778252840042, \"sigma_obs\": 0.0039664688520133495, \"slope\": 0.1445707231760025, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 8.123538970947266, \"sigma_intercept_per_group\": 0.033062662929296494, \"sigma_obs\": 0.00412588519975543, \"slope\": 0.2980225682258606, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 9.121965408325195, \"sigma_intercept_per_group\": 0.019709546118974686, \"sigma_obs\": 0.003921678755432367, \"slope\": 0.17181888222694397, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 9.764420509338379, \"sigma_intercept_per_group\": 0.031237976625561714, \"sigma_obs\": 0.003631679341197014, \"slope\": 0.1615196019411087, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 15.511746406555176, \"sigma_intercept_per_group\": 0.017448434606194496, \"sigma_obs\": 0.003988465294241905, \"slope\": 0.19912263751029968, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 16.831241607666016, \"sigma_intercept_per_group\": 0.014076716266572475, \"sigma_obs\": 0.0038477289490401745, \"slope\": 0.23725375533103943, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 14.679157257080078, \"sigma_intercept_per_group\": 0.018300911411643028, \"sigma_obs\": 0.0037019148003309965, \"slope\": 0.06740780919790268, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 15.384532928466797, \"sigma_intercept_per_group\": 0.01723511703312397, \"sigma_obs\": 0.0034931914415210485, \"slope\": 0.10930270701646805, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 12.670796394348145, \"sigma_intercept_per_group\": 0.022803176194429398, \"sigma_obs\": 0.003344937227666378, \"slope\": 0.1267566680908203, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 14.077652931213379, \"sigma_intercept_per_group\": 0.020659279078245163, \"sigma_obs\": 0.0034491312690079212, \"slope\": 0.15400096774101257, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 9.785552978515625, \"sigma_intercept_per_group\": 0.0053193639032542706, \"sigma_obs\": 0.0043771336786448956, \"slope\": 0.33409610390663147, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 20.56226921081543, \"sigma_intercept_per_group\": 0.019944922998547554, \"sigma_obs\": 0.0037549042608588934, \"slope\": 0.15607869625091553, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 13.46574878692627, \"sigma_intercept_per_group\": 0.01586938463151455, \"sigma_obs\": 0.003633056301623583, \"slope\": 0.09999097883701324, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 9.305739402770996, \"sigma_intercept_per_group\": 0.022162843495607376, \"sigma_obs\": 0.0037287669256329536, \"slope\": 0.17891383171081543, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 5.643798828125, \"sigma_intercept_per_group\": 0.007755037397146225, \"sigma_obs\": 0.004336868412792683, \"slope\": 0.32158172130584717, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 10.33972454071045, \"sigma_intercept_per_group\": 0.016350165009498596, \"sigma_obs\": 0.0036069173365831375, \"slope\": 0.1582452803850174, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 14.556548118591309, \"sigma_intercept_per_group\": 0.01610720530152321, \"sigma_obs\": 0.004163488745689392, \"slope\": 0.23216313123703003, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 24.412067413330078, \"sigma_intercept_per_group\": 0.011966320686042309, \"sigma_obs\": 0.004034087061882019, \"slope\": 0.17415973544120789, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 8.456341743469238, \"sigma_intercept_per_group\": 0.020777186378836632, \"sigma_obs\": 0.0042711831629276276, \"slope\": 0.1930074244737625, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 17.468503952026367, \"sigma_intercept_per_group\": 0.009554841555655003, \"sigma_obs\": 0.0038513285107910633, \"slope\": 0.24369564652442932, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 12.381575584411621, \"sigma_intercept_per_group\": 0.01714147813618183, \"sigma_obs\": 0.0039794230833649635, \"slope\": 0.12248209863901138, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 18.401273727416992, \"sigma_intercept_per_group\": 0.021524110808968544, \"sigma_obs\": 0.004148415755480528, \"slope\": 0.162536159157753, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 20.803680419921875, \"sigma_intercept_per_group\": 0.0217779241502285, \"sigma_obs\": 0.00419192761182785, \"slope\": 0.16744571924209595, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 16.706371307373047, \"sigma_intercept_per_group\": 0.013987644575536251, \"sigma_obs\": 0.004252559971064329, \"slope\": 0.1590552031993866, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 7.785616874694824, \"sigma_intercept_per_group\": 0.022051677107810974, \"sigma_obs\": 0.0040865023620426655, \"slope\": 0.23850083351135254, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 5.340003490447998, \"sigma_intercept_per_group\": 0.02865663357079029, \"sigma_obs\": 0.0040087103843688965, \"slope\": 0.2907477915287018, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 5.669518947601318, \"sigma_intercept_per_group\": 0.021294964477419853, \"sigma_obs\": 0.0038882035296410322, \"slope\": 0.2540043890476227, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 11.059185981750488, \"sigma_intercept_per_group\": 0.014172651804983616, \"sigma_obs\": 0.0037941692862659693, \"slope\": 0.1548149734735489, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 16.556629180908203, \"sigma_intercept_per_group\": 0.012260548770427704, \"sigma_obs\": 0.004528121557086706, \"slope\": 0.27653178572654724, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 16.046810150146484, \"sigma_intercept_per_group\": 0.015615145675837994, \"sigma_obs\": 0.004515170119702816, \"slope\": 0.3183816373348236, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 21.35782814025879, \"sigma_intercept_per_group\": 0.01576397195458412, \"sigma_obs\": 0.004446370992809534, \"slope\": 0.13676925003528595, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 12.369587898254395, \"sigma_intercept_per_group\": 0.005788234528154135, \"sigma_obs\": 0.0038131990004330873, \"slope\": 0.13326503336429596, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 15.511539459228516, \"sigma_intercept_per_group\": 0.004640578757971525, \"sigma_obs\": 0.0038628196343779564, \"slope\": 0.18311484158039093, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 5.071626663208008, \"sigma_intercept_per_group\": 0.009868910536170006, \"sigma_obs\": 0.004142542835325003, \"slope\": 0.21408012509346008, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 15.501636505126953, \"sigma_intercept_per_group\": 0.024037960916757584, \"sigma_obs\": 0.003868164960294962, \"slope\": 0.13456642627716064, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 7.410902500152588, \"sigma_intercept_per_group\": 0.01754734106361866, \"sigma_obs\": 0.0039611500687897205, \"slope\": 0.14304505288600922, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 18.73247718811035, \"sigma_intercept_per_group\": 0.01490019727498293, \"sigma_obs\": 0.004104644991457462, \"slope\": 0.3184421956539154, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 16.048852920532227, \"sigma_intercept_per_group\": 0.014618064276874065, \"sigma_obs\": 0.003947652876377106, \"slope\": 0.10114085674285889, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 18.88574981689453, \"sigma_intercept_per_group\": 0.016970282420516014, \"sigma_obs\": 0.0038353167474269867, \"slope\": 0.18168692290782928, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 10.08126449584961, \"sigma_intercept_per_group\": 0.010728530585765839, \"sigma_obs\": 0.0038518591318279505, \"slope\": 0.23521006107330322, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 15.35366153717041, \"sigma_intercept_per_group\": 0.009387318976223469, \"sigma_obs\": 0.003943780902773142, \"slope\": 0.19838184118270874, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 11.917501449584961, \"sigma_intercept_per_group\": 0.027869049459695816, \"sigma_obs\": 0.003783533349633217, \"slope\": 0.12075822055339813, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 9.132963180541992, \"sigma_intercept_per_group\": 0.020478971302509308, \"sigma_obs\": 0.003786621615290642, \"slope\": 0.17742730677127838, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 10.450651168823242, \"sigma_intercept_per_group\": 0.015114935114979744, \"sigma_obs\": 0.004140096250921488, \"slope\": 0.3515426516532898, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 13.810266494750977, \"sigma_intercept_per_group\": 0.01811174303293228, \"sigma_obs\": 0.0040966905653476715, \"slope\": 0.22909195721149445, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 2.6890766620635986, \"sigma_intercept_per_group\": 0.015004714019596577, \"sigma_obs\": 0.004042280372232199, \"slope\": 0.1372486650943756, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": -1.9913395643234253, \"sigma_intercept_per_group\": 0.01971118152141571, \"sigma_obs\": 0.0039047731552273035, \"slope\": 0.1839430034160614, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": -0.07536953687667847, \"sigma_intercept_per_group\": 0.019866274669766426, \"sigma_obs\": 0.003946314565837383, \"slope\": 0.17354856431484222, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 10.385358810424805, \"sigma_intercept_per_group\": 0.01467637624591589, \"sigma_obs\": 0.0038928433787077665, \"slope\": 0.11890947818756104, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 13.682313919067383, \"sigma_intercept_per_group\": 0.01323495339602232, \"sigma_obs\": 0.0038974867202341557, \"slope\": 0.14372518658638, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 8.612662315368652, \"sigma_intercept_per_group\": 0.025178294628858566, \"sigma_obs\": 0.004144761711359024, \"slope\": 0.20424729585647583, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 21.080904006958008, \"sigma_intercept_per_group\": 0.014208650216460228, \"sigma_obs\": 0.004147171974182129, \"slope\": 0.2844855785369873, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 2.9666049480438232, \"sigma_intercept_per_group\": 0.015032406896352768, \"sigma_obs\": 0.003603970631957054, \"slope\": 0.19010309875011444, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 8.247576713562012, \"sigma_intercept_per_group\": 0.011439455673098564, \"sigma_obs\": 0.003981994930654764, \"slope\": 0.18620717525482178, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 5.297784328460693, \"sigma_intercept_per_group\": 0.013771489262580872, \"sigma_obs\": 0.004063311964273453, \"slope\": 0.2500639855861664, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 10.691640853881836, \"sigma_intercept_per_group\": 0.02992342785000801, \"sigma_obs\": 0.003475417383015156, \"slope\": 0.1327744573354721, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 11.432547569274902, \"sigma_intercept_per_group\": 0.008974133059382439, \"sigma_obs\": 0.004375268239527941, \"slope\": 0.22962415218353271, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 3.5715322494506836, \"sigma_intercept_per_group\": 0.01979675143957138, \"sigma_obs\": 0.004032114055007696, \"slope\": 0.18809831142425537, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 8.139065742492676, \"sigma_intercept_per_group\": 0.01841278187930584, \"sigma_obs\": 0.0037041325122117996, \"slope\": 0.19358126819133759, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 7.719079971313477, \"sigma_intercept_per_group\": 0.019207103177905083, \"sigma_obs\": 0.0038511042948812246, \"slope\": 0.17584876716136932, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 10.299744606018066, \"sigma_intercept_per_group\": 0.013521349057555199, \"sigma_obs\": 0.003648602869361639, \"slope\": 0.20533594489097595, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 10.130926132202148, \"sigma_intercept_per_group\": 0.014555860310792923, \"sigma_obs\": 0.0038022594526410103, \"slope\": 0.210581973195076, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 11.452608108520508, \"sigma_intercept_per_group\": 0.027340922504663467, \"sigma_obs\": 0.004026676528155804, \"slope\": 0.3223755359649658, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 10.793584823608398, \"sigma_intercept_per_group\": 0.007965258322656155, \"sigma_obs\": 0.0036829961463809013, \"slope\": 0.1277514100074768, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 8.838262557983398, \"sigma_intercept_per_group\": 0.020346537232398987, \"sigma_obs\": 0.003737951163202524, \"slope\": 0.2669747769832611, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 7.482108116149902, \"sigma_intercept_per_group\": 0.020786011591553688, \"sigma_obs\": 0.0037319990806281567, \"slope\": 0.2977018654346466, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 11.77778148651123, \"sigma_intercept_per_group\": 0.0278000645339489, \"sigma_obs\": 0.0037752902135252953, \"slope\": 0.24450770020484924, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 5.817020893096924, \"sigma_intercept_per_group\": 0.009869268164038658, \"sigma_obs\": 0.0038552090991288424, \"slope\": 0.14864113926887512, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 13.539782524108887, \"sigma_intercept_per_group\": 0.009878143668174744, \"sigma_obs\": 0.003796641482040286, \"slope\": 0.1897091269493103, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 2.742051601409912, \"sigma_intercept_per_group\": 0.004475956317037344, \"sigma_obs\": 0.004007154610008001, \"slope\": 0.21538226306438446, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 2.0724174976348877, \"sigma_intercept_per_group\": 0.006612351164221764, \"sigma_obs\": 0.004077498335391283, \"slope\": 0.2460496574640274, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": -3.768800735473633, \"sigma_intercept_per_group\": 0.011267496272921562, \"sigma_obs\": 0.0040811472572386265, \"slope\": 0.3399559259414673, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 21.81544303894043, \"sigma_intercept_per_group\": 0.015152611769735813, \"sigma_obs\": 0.003742825472727418, \"slope\": 0.13428129255771637, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 4.7506608963012695, \"sigma_intercept_per_group\": 0.011390098370611668, \"sigma_obs\": 0.003825364401564002, \"slope\": 0.29860174655914307, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 19.60413360595703, \"sigma_intercept_per_group\": 0.016004439443349838, \"sigma_obs\": 0.0045046694576740265, \"slope\": 0.23937435448169708, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 11.72191333770752, \"sigma_intercept_per_group\": 0.013487542048096657, \"sigma_obs\": 0.0041376035660505295, \"slope\": 0.21502500772476196, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 8.40286636352539, \"sigma_intercept_per_group\": 0.015955572947859764, \"sigma_obs\": 0.004018861800432205, \"slope\": 0.18831461668014526, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 7.327067852020264, \"sigma_intercept_per_group\": 0.025910446420311928, \"sigma_obs\": 0.0038361086044460535, \"slope\": 0.24086713790893555, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 9.15285587310791, \"sigma_intercept_per_group\": 0.022641576826572418, \"sigma_obs\": 0.003887944156304002, \"slope\": 0.2427748590707779, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 14.349908828735352, \"sigma_intercept_per_group\": 0.015585056506097317, \"sigma_obs\": 0.00407145032659173, \"slope\": 0.22507986426353455, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 8.631303787231445, \"sigma_intercept_per_group\": 0.016738161444664, \"sigma_obs\": 0.004426620900630951, \"slope\": 0.2810653746128082, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 11.943130493164062, \"sigma_intercept_per_group\": 0.024640709161758423, \"sigma_obs\": 0.00377124035730958, \"slope\": 0.22852560877799988, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 10.730412483215332, \"sigma_intercept_per_group\": 0.009143228642642498, \"sigma_obs\": 0.003908673767000437, \"slope\": 0.1990649253129959, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 16.227359771728516, \"sigma_intercept_per_group\": 0.018539845943450928, \"sigma_obs\": 0.0036246501840651035, \"slope\": 0.17465826869010925, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 8.550874710083008, \"sigma_intercept_per_group\": 0.013266760855913162, \"sigma_obs\": 0.0038428516127169132, \"slope\": 0.1725885570049286, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 11.79819107055664, \"sigma_intercept_per_group\": 0.01780667155981064, \"sigma_obs\": 0.0035867581609636545, \"slope\": 0.18757843971252441, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 14.002288818359375, \"sigma_intercept_per_group\": 0.020170647650957108, \"sigma_obs\": 0.004610399249941111, \"slope\": 0.2761976420879364, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 16.46881675720215, \"sigma_intercept_per_group\": 0.017994403839111328, \"sigma_obs\": 0.0048284512013196945, \"slope\": 0.3146805167198181, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 11.568902015686035, \"sigma_intercept_per_group\": 0.024362459778785706, \"sigma_obs\": 0.004353312775492668, \"slope\": 0.15077348053455353, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 17.494281768798828, \"sigma_intercept_per_group\": 0.026326604187488556, \"sigma_obs\": 0.004341776482760906, \"slope\": 0.15777675807476044, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 14.894147872924805, \"sigma_intercept_per_group\": 0.01505048107355833, \"sigma_obs\": 0.004077292047441006, \"slope\": 0.18441662192344666, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 1.7984572649002075, \"sigma_intercept_per_group\": 0.012604888528585434, \"sigma_obs\": 0.0038838046602904797, \"slope\": 0.28693485260009766, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 12.85037899017334, \"sigma_intercept_per_group\": 0.027293527498841286, \"sigma_obs\": 0.0040937382727861404, \"slope\": 0.290661484003067, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 8.293396949768066, \"sigma_intercept_per_group\": 0.01260497234761715, \"sigma_obs\": 0.0034537145402282476, \"slope\": 0.2026028335094452, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 18.77876853942871, \"sigma_intercept_per_group\": 0.009833933785557747, \"sigma_obs\": 0.004013423342257738, \"slope\": 0.2027885466814041, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 6.6899333000183105, \"sigma_intercept_per_group\": 0.01916232891380787, \"sigma_obs\": 0.003971968777477741, \"slope\": 0.25734129548072815, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 11.464505195617676, \"sigma_intercept_per_group\": 0.01427893340587616, \"sigma_obs\": 0.003978809807449579, \"slope\": 0.16876579821109772, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 19.049238204956055, \"sigma_intercept_per_group\": 0.011215243488550186, \"sigma_obs\": 0.004003547132015228, \"slope\": 0.2640152871608734, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 5.571662902832031, \"sigma_intercept_per_group\": 0.027507560327649117, \"sigma_obs\": 0.003813908202573657, \"slope\": 0.18017242848873138, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 6.56072998046875, \"sigma_intercept_per_group\": 0.024310529232025146, \"sigma_obs\": 0.0037329369224607944, \"slope\": 0.17117439210414886, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 19.446683883666992, \"sigma_intercept_per_group\": 0.01180507056415081, \"sigma_obs\": 0.004250858910381794, \"slope\": 0.2575354278087616, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 15.765954971313477, \"sigma_intercept_per_group\": 0.022209737449884415, \"sigma_obs\": 0.004155751317739487, \"slope\": 0.20342740416526794, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 12.330999374389648, \"sigma_intercept_per_group\": 0.01668957807123661, \"sigma_obs\": 0.004019860178232193, \"slope\": 0.20285066962242126, \"chain\": 2, \"draw\": 160}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 9.6436128616333, \"sigma_intercept_per_group\": 0.022883225232362747, \"sigma_obs\": 0.0038615914527326822, \"slope\": 0.1571885049343109, \"chain\": 2, \"draw\": 161}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 9.47997760772705, \"sigma_intercept_per_group\": 0.020654411986470222, \"sigma_obs\": 0.0038654454983770847, \"slope\": 0.29166990518569946, \"chain\": 2, \"draw\": 162}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 10.60527515411377, \"sigma_intercept_per_group\": 0.022638190537691116, \"sigma_obs\": 0.004001758527010679, \"slope\": 0.1548173427581787, \"chain\": 2, \"draw\": 163}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.060279846191406, \"sigma_intercept_per_group\": 0.03546755015850067, \"sigma_obs\": 0.003756302874535322, \"slope\": 0.0780581682920456, \"chain\": 2, \"draw\": 164}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 9.786256790161133, \"sigma_intercept_per_group\": 0.02558242529630661, \"sigma_obs\": 0.004152409732341766, \"slope\": 0.20785477757453918, \"chain\": 2, \"draw\": 165}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 15.614481925964355, \"sigma_intercept_per_group\": 0.019922416657209396, \"sigma_obs\": 0.003928989637643099, \"slope\": 0.1717156022787094, \"chain\": 2, \"draw\": 166}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 12.415962219238281, \"sigma_intercept_per_group\": 0.01984388381242752, \"sigma_obs\": 0.003922748379409313, \"slope\": 0.13846223056316376, \"chain\": 2, \"draw\": 167}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 16.422975540161133, \"sigma_intercept_per_group\": 0.013541867956519127, \"sigma_obs\": 0.0040482389740645885, \"slope\": 0.1948154866695404, \"chain\": 2, \"draw\": 168}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 20.262948989868164, \"sigma_intercept_per_group\": 0.01581317000091076, \"sigma_obs\": 0.004056168720126152, \"slope\": 0.14511044323444366, \"chain\": 2, \"draw\": 169}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 17.315725326538086, \"sigma_intercept_per_group\": 0.015324903652071953, \"sigma_obs\": 0.0039012297056615353, \"slope\": 0.16328078508377075, \"chain\": 2, \"draw\": 170}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 8.132803916931152, \"sigma_intercept_per_group\": 0.01522365864366293, \"sigma_obs\": 0.0042521157301962376, \"slope\": 0.29189610481262207, \"chain\": 2, \"draw\": 171}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 21.46075439453125, \"sigma_intercept_per_group\": 0.013411073014140129, \"sigma_obs\": 0.0038201201241463423, \"slope\": 0.160374253988266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 9.42358684539795, \"sigma_intercept_per_group\": 0.018718233332037926, \"sigma_obs\": 0.004190077073872089, \"slope\": 0.2724388539791107, \"chain\": 2, \"draw\": 173}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 19.435306549072266, \"sigma_intercept_per_group\": 0.01265436690300703, \"sigma_obs\": 0.0041925194673240185, \"slope\": 0.25100985169410706, \"chain\": 2, \"draw\": 174}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 14.325714111328125, \"sigma_intercept_per_group\": 0.018249591812491417, \"sigma_obs\": 0.004482319112867117, \"slope\": 0.2969828248023987, \"chain\": 2, \"draw\": 175}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 14.777213096618652, \"sigma_intercept_per_group\": 0.018188484013080597, \"sigma_obs\": 0.004001098219305277, \"slope\": 0.21073627471923828, \"chain\": 2, \"draw\": 176}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 22.450634002685547, \"sigma_intercept_per_group\": 0.01281607337296009, \"sigma_obs\": 0.0041341702453792095, \"slope\": 0.219413623213768, \"chain\": 2, \"draw\": 177}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 9.621647834777832, \"sigma_intercept_per_group\": 0.02187458798289299, \"sigma_obs\": 0.003976947162300348, \"slope\": 0.19536420702934265, \"chain\": 2, \"draw\": 178}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 14.37435245513916, \"sigma_intercept_per_group\": 0.010725108906626701, \"sigma_obs\": 0.004006621893495321, \"slope\": 0.23511157929897308, \"chain\": 2, \"draw\": 179}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 18.603113174438477, \"sigma_intercept_per_group\": 0.008569570258259773, \"sigma_obs\": 0.003907410427927971, \"slope\": 0.22919198870658875, \"chain\": 2, \"draw\": 180}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 16.760051727294922, \"sigma_intercept_per_group\": 0.011218046769499779, \"sigma_obs\": 0.004168866202235222, \"slope\": 0.2500597834587097, \"chain\": 2, \"draw\": 181}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 7.971218585968018, \"sigma_intercept_per_group\": 0.019317645579576492, \"sigma_obs\": 0.004078124184161425, \"slope\": 0.2213311791419983, \"chain\": 2, \"draw\": 182}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 20.94237518310547, \"sigma_intercept_per_group\": 0.013479904271662235, \"sigma_obs\": 0.003938219975680113, \"slope\": 0.18574795126914978, \"chain\": 2, \"draw\": 183}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 7.376929759979248, \"sigma_intercept_per_group\": 0.015562287531793118, \"sigma_obs\": 0.004234460182487965, \"slope\": 0.15892279148101807, \"chain\": 2, \"draw\": 184}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 10.206183433532715, \"sigma_intercept_per_group\": 0.01994818076491356, \"sigma_obs\": 0.004182691220194101, \"slope\": 0.19947108626365662, \"chain\": 2, \"draw\": 185}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 11.28425407409668, \"sigma_intercept_per_group\": 0.02789686992764473, \"sigma_obs\": 0.0041783154010772705, \"slope\": 0.2658209502696991, \"chain\": 2, \"draw\": 186}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 15.896408081054688, \"sigma_intercept_per_group\": 0.01833820715546608, \"sigma_obs\": 0.0038653735537081957, \"slope\": 0.15327472984790802, \"chain\": 2, \"draw\": 187}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 15.541982650756836, \"sigma_intercept_per_group\": 0.016905363649129868, \"sigma_obs\": 0.004074559547007084, \"slope\": 0.22625944018363953, \"chain\": 2, \"draw\": 188}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 8.340100288391113, \"sigma_intercept_per_group\": 0.02172219380736351, \"sigma_obs\": 0.0035948946606367826, \"slope\": 0.1656804233789444, \"chain\": 2, \"draw\": 189}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 17.229333877563477, \"sigma_intercept_per_group\": 0.016004035249352455, \"sigma_obs\": 0.004258846398442984, \"slope\": 0.14796306192874908, \"chain\": 2, \"draw\": 190}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 17.312515258789062, \"sigma_intercept_per_group\": 0.018942058086395264, \"sigma_obs\": 0.0040863994508981705, \"slope\": 0.15420298278331757, \"chain\": 2, \"draw\": 191}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 9.402052879333496, \"sigma_intercept_per_group\": 0.03219425678253174, \"sigma_obs\": 0.004095114767551422, \"slope\": 0.250742107629776, \"chain\": 2, \"draw\": 192}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 8.678874969482422, \"sigma_intercept_per_group\": 0.022784411907196045, \"sigma_obs\": 0.0038398108445107937, \"slope\": 0.2204967439174652, \"chain\": 2, \"draw\": 193}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 9.498290061950684, \"sigma_intercept_per_group\": 0.021235989406704903, \"sigma_obs\": 0.0038173487409949303, \"slope\": 0.18087927997112274, \"chain\": 2, \"draw\": 194}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 11.953205108642578, \"sigma_intercept_per_group\": 0.02023433893918991, \"sigma_obs\": 0.003948880359530449, \"slope\": 0.2622988522052765, \"chain\": 2, \"draw\": 195}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 10.073935508728027, \"sigma_intercept_per_group\": 0.016914531588554382, \"sigma_obs\": 0.0037808443885296583, \"slope\": 0.1768590658903122, \"chain\": 2, \"draw\": 196}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 16.469165802001953, \"sigma_intercept_per_group\": 0.007579236291348934, \"sigma_obs\": 0.003914426080882549, \"slope\": 0.21379004418849945, \"chain\": 2, \"draw\": 197}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 15.24312686920166, \"sigma_intercept_per_group\": 0.01600741595029831, \"sigma_obs\": 0.0038398639298975468, \"slope\": 0.06997475028038025, \"chain\": 2, \"draw\": 198}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 17.935504913330078, \"sigma_intercept_per_group\": 0.015466175973415375, \"sigma_obs\": 0.0037357842084020376, \"slope\": 0.06997033208608627, \"chain\": 2, \"draw\": 199}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 9.6416015625, \"sigma_intercept_per_group\": 0.015251406468451023, \"sigma_obs\": 0.0037069402169436216, \"slope\": 0.16902433335781097, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 18.07929801940918, \"sigma_intercept_per_group\": 0.017361566424369812, \"sigma_obs\": 0.004017319530248642, \"slope\": 0.22414498031139374, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 18.751453399658203, \"sigma_intercept_per_group\": 0.010081607848405838, \"sigma_obs\": 0.0041815005242824554, \"slope\": 0.24686448276042938, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 9.810301780700684, \"sigma_intercept_per_group\": 0.015302726998925209, \"sigma_obs\": 0.0038715789560228586, \"slope\": 0.15693873167037964, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 11.524846076965332, \"sigma_intercept_per_group\": 0.020068427547812462, \"sigma_obs\": 0.004252409562468529, \"slope\": 0.20435674488544464, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.80354881286621, \"sigma_intercept_per_group\": 0.011821119114756584, \"sigma_obs\": 0.003664762945845723, \"slope\": 0.17416132986545563, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 8.866294860839844, \"sigma_intercept_per_group\": 0.01983581855893135, \"sigma_obs\": 0.0042310068383812904, \"slope\": 0.19426466524600983, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 16.29786491394043, \"sigma_intercept_per_group\": 0.0142155010253191, \"sigma_obs\": 0.004394311457872391, \"slope\": 0.13523636758327484, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 17.726667404174805, \"sigma_intercept_per_group\": 0.01857045851647854, \"sigma_obs\": 0.004262375645339489, \"slope\": 0.13410936295986176, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 14.024088859558105, \"sigma_intercept_per_group\": 0.008098450489342213, \"sigma_obs\": 0.004204358905553818, \"slope\": 0.15140263736248016, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 13.828648567199707, \"sigma_intercept_per_group\": 0.010473379865288734, \"sigma_obs\": 0.004083193372935057, \"slope\": 0.17086166143417358, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 24.777212142944336, \"sigma_intercept_per_group\": 0.018925679847598076, \"sigma_obs\": 0.0040605985559523106, \"slope\": 0.13667283952236176, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 21.65932273864746, \"sigma_intercept_per_group\": 0.008967570960521698, \"sigma_obs\": 0.003785076318308711, \"slope\": 0.18806791305541992, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 19.464895248413086, \"sigma_intercept_per_group\": 0.014474713243544102, \"sigma_obs\": 0.004078655503690243, \"slope\": 0.23943831026554108, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 4.741896629333496, \"sigma_intercept_per_group\": 0.013906323350965977, \"sigma_obs\": 0.0038440371863543987, \"slope\": 0.1984962671995163, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 16.82868003845215, \"sigma_intercept_per_group\": 0.015251356177031994, \"sigma_obs\": 0.004203775431960821, \"slope\": 0.22856725752353668, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.196017265319824, \"sigma_intercept_per_group\": 0.023781564086675644, \"sigma_obs\": 0.004056263715028763, \"slope\": 0.16519196331501007, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 17.72896957397461, \"sigma_intercept_per_group\": 0.01691693440079689, \"sigma_obs\": 0.004210006445646286, \"slope\": 0.27458029985427856, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 16.28904151916504, \"sigma_intercept_per_group\": 0.019883405417203903, \"sigma_obs\": 0.003979885950684547, \"slope\": 0.25456273555755615, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 16.36051368713379, \"sigma_intercept_per_group\": 0.011738917790353298, \"sigma_obs\": 0.004071630537509918, \"slope\": 0.22168223559856415, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 20.730735778808594, \"sigma_intercept_per_group\": 0.015108263120055199, \"sigma_obs\": 0.0038387435488402843, \"slope\": 0.14681214094161987, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 10.248053550720215, \"sigma_intercept_per_group\": 0.010306340642273426, \"sigma_obs\": 0.004458338487893343, \"slope\": 0.306752473115921, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 13.69138240814209, \"sigma_intercept_per_group\": 0.009273305535316467, \"sigma_obs\": 0.0035565674770623446, \"slope\": 0.14475344121456146, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 15.790809631347656, \"sigma_intercept_per_group\": 0.008358930237591267, \"sigma_obs\": 0.003882458433508873, \"slope\": 0.168976828455925, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 10.307531356811523, \"sigma_intercept_per_group\": 0.016074374318122864, \"sigma_obs\": 0.003910021856427193, \"slope\": 0.23771029710769653, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 7.823513507843018, \"sigma_intercept_per_group\": 0.005736282095313072, \"sigma_obs\": 0.0035472791641950607, \"slope\": 0.10444711148738861, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 18.52081871032715, \"sigma_intercept_per_group\": 0.00779694365337491, \"sigma_obs\": 0.004112418740987778, \"slope\": 0.25308114290237427, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 14.538589477539062, \"sigma_intercept_per_group\": 0.00832054391503334, \"sigma_obs\": 0.004025221336632967, \"slope\": 0.20617616176605225, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 13.096989631652832, \"sigma_intercept_per_group\": 0.018755177035927773, \"sigma_obs\": 0.004331699572503567, \"slope\": 0.17606528103351593, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 18.64503288269043, \"sigma_intercept_per_group\": 0.013613811694085598, \"sigma_obs\": 0.004225375596433878, \"slope\": 0.16884444653987885, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 11.959044456481934, \"sigma_intercept_per_group\": 0.021893596276640892, \"sigma_obs\": 0.003989945165812969, \"slope\": 0.24525535106658936, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 6.970203399658203, \"sigma_intercept_per_group\": 0.01273313257843256, \"sigma_obs\": 0.004043641500174999, \"slope\": 0.26127907633781433, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 9.345170974731445, \"sigma_intercept_per_group\": 0.019696848466992378, \"sigma_obs\": 0.0038881609216332436, \"slope\": 0.2695038616657257, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 2.3109419345855713, \"sigma_intercept_per_group\": 0.010053332895040512, \"sigma_obs\": 0.0036285948008298874, \"slope\": 0.246914803981781, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 3.450174331665039, \"sigma_intercept_per_group\": 0.009492391720414162, \"sigma_obs\": 0.003643621690571308, \"slope\": 0.23611685633659363, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 1.402164101600647, \"sigma_intercept_per_group\": 0.006990818306803703, \"sigma_obs\": 0.003973258659243584, \"slope\": 0.21711765229701996, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 19.996816635131836, \"sigma_intercept_per_group\": 0.013297870755195618, \"sigma_obs\": 0.004376793280243874, \"slope\": 0.2879253625869751, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 5.368474006652832, \"sigma_intercept_per_group\": 0.023662172257900238, \"sigma_obs\": 0.003600943833589554, \"slope\": 0.17422553896903992, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 8.667400360107422, \"sigma_intercept_per_group\": 0.021476807072758675, \"sigma_obs\": 0.0036260902415961027, \"slope\": 0.1648811399936676, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 8.736454963684082, \"sigma_intercept_per_group\": 0.032071664929389954, \"sigma_obs\": 0.003611362772062421, \"slope\": 0.22772452235221863, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 640, \"mu_intercept_per_group\": 6.383976936340332, \"sigma_intercept_per_group\": 0.02832024171948433, \"sigma_obs\": 0.00382924429140985, \"slope\": 0.1674828976392746, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 641, \"mu_intercept_per_group\": 17.02939796447754, \"sigma_intercept_per_group\": 0.013926954939961433, \"sigma_obs\": 0.0036447409074753523, \"slope\": 0.18513649702072144, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 642, \"mu_intercept_per_group\": 15.558263778686523, \"sigma_intercept_per_group\": 0.013953909277915955, \"sigma_obs\": 0.004012003540992737, \"slope\": 0.1264553666114807, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 643, \"mu_intercept_per_group\": 11.166762351989746, \"sigma_intercept_per_group\": 0.008200827986001968, \"sigma_obs\": 0.003780916566029191, \"slope\": 0.24750970304012299, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 644, \"mu_intercept_per_group\": 17.25875473022461, \"sigma_intercept_per_group\": 0.016778500750660896, \"sigma_obs\": 0.0038865890819579363, \"slope\": 0.2637716233730316, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 645, \"mu_intercept_per_group\": 10.982369422912598, \"sigma_intercept_per_group\": 0.014179282821714878, \"sigma_obs\": 0.003956692758947611, \"slope\": 0.07881752401590347, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 646, \"mu_intercept_per_group\": 9.999495506286621, \"sigma_intercept_per_group\": 0.019154760986566544, \"sigma_obs\": 0.003954453859478235, \"slope\": 0.18291249871253967, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 647, \"mu_intercept_per_group\": 6.820811748504639, \"sigma_intercept_per_group\": 0.015904134139418602, \"sigma_obs\": 0.004278149921447039, \"slope\": 0.23914065957069397, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 648, \"mu_intercept_per_group\": 10.358931541442871, \"sigma_intercept_per_group\": 0.012116801925003529, \"sigma_obs\": 0.004151427652686834, \"slope\": 0.2740675210952759, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 649, \"mu_intercept_per_group\": 23.390565872192383, \"sigma_intercept_per_group\": 0.012898717075586319, \"sigma_obs\": 0.0038989700842648745, \"slope\": 0.18213464319705963, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 650, \"mu_intercept_per_group\": 23.66953468322754, \"sigma_intercept_per_group\": 0.011162498965859413, \"sigma_obs\": 0.004399007651954889, \"slope\": 0.16860611736774445, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 651, \"mu_intercept_per_group\": 24.429710388183594, \"sigma_intercept_per_group\": 0.009458937682211399, \"sigma_obs\": 0.004348535090684891, \"slope\": 0.20171070098876953, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 652, \"mu_intercept_per_group\": 0.06105119735002518, \"sigma_intercept_per_group\": 0.014757703058421612, \"sigma_obs\": 0.003807786153629422, \"slope\": 0.14552807807922363, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 653, \"mu_intercept_per_group\": 2.505930185317993, \"sigma_intercept_per_group\": 0.017460603266954422, \"sigma_obs\": 0.004446175880730152, \"slope\": 0.24275866150856018, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 654, \"mu_intercept_per_group\": 11.448205947875977, \"sigma_intercept_per_group\": 0.0238561499863863, \"sigma_obs\": 0.004346171859651804, \"slope\": 0.2949008047580719, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 655, \"mu_intercept_per_group\": 7.88395357131958, \"sigma_intercept_per_group\": 0.02201468124985695, \"sigma_obs\": 0.004187009297311306, \"slope\": 0.26419976353645325, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 656, \"mu_intercept_per_group\": 14.944862365722656, \"sigma_intercept_per_group\": 0.014357256703078747, \"sigma_obs\": 0.0042931558564305305, \"slope\": 0.274528831243515, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 657, \"mu_intercept_per_group\": 9.908576011657715, \"sigma_intercept_per_group\": 0.0154859758913517, \"sigma_obs\": 0.004043670371174812, \"slope\": 0.26324620842933655, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 658, \"mu_intercept_per_group\": 8.306763648986816, \"sigma_intercept_per_group\": 0.01617317833006382, \"sigma_obs\": 0.0038756332360208035, \"slope\": 0.2597503662109375, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 659, \"mu_intercept_per_group\": 2.9190523624420166, \"sigma_intercept_per_group\": 0.013915995135903358, \"sigma_obs\": 0.004036338534206152, \"slope\": 0.2055683434009552, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 660, \"mu_intercept_per_group\": 11.979454040527344, \"sigma_intercept_per_group\": 0.0304962620139122, \"sigma_obs\": 0.004077933728694916, \"slope\": 0.21845273673534393, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 661, \"mu_intercept_per_group\": 8.05868911743164, \"sigma_intercept_per_group\": 0.0244053453207016, \"sigma_obs\": 0.004461783915758133, \"slope\": 0.2510484457015991, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 662, \"mu_intercept_per_group\": 7.530640602111816, \"sigma_intercept_per_group\": 0.024053627625107765, \"sigma_obs\": 0.0044443486258387566, \"slope\": 0.24497652053833008, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 663, \"mu_intercept_per_group\": 9.62185001373291, \"sigma_intercept_per_group\": 0.03073156252503395, \"sigma_obs\": 0.00443115271627903, \"slope\": 0.26740527153015137, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 664, \"mu_intercept_per_group\": 7.768664836883545, \"sigma_intercept_per_group\": 0.035627204924821854, \"sigma_obs\": 0.004162978380918503, \"slope\": 0.1891600489616394, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 665, \"mu_intercept_per_group\": 7.691366672515869, \"sigma_intercept_per_group\": 0.028147907927632332, \"sigma_obs\": 0.004133342299610376, \"slope\": 0.19378267228603363, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 666, \"mu_intercept_per_group\": 6.324993133544922, \"sigma_intercept_per_group\": 0.04468374699354172, \"sigma_obs\": 0.003984338603913784, \"slope\": 0.25921908020973206, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 667, \"mu_intercept_per_group\": 15.22071361541748, \"sigma_intercept_per_group\": 0.017766335979104042, \"sigma_obs\": 0.004098939709365368, \"slope\": 0.16628456115722656, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 668, \"mu_intercept_per_group\": 4.694248199462891, \"sigma_intercept_per_group\": 0.02494017407298088, \"sigma_obs\": 0.003819041885435581, \"slope\": 0.25976377725601196, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 669, \"mu_intercept_per_group\": 5.925929069519043, \"sigma_intercept_per_group\": 0.03894132748246193, \"sigma_obs\": 0.003703058697283268, \"slope\": 0.05673741549253464, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 670, \"mu_intercept_per_group\": 12.40772819519043, \"sigma_intercept_per_group\": 0.023910198360681534, \"sigma_obs\": 0.003747200593352318, \"slope\": 0.1387222409248352, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 671, \"mu_intercept_per_group\": 6.877628326416016, \"sigma_intercept_per_group\": 0.02551352232694626, \"sigma_obs\": 0.0038147703744471073, \"slope\": 0.07694428414106369, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 672, \"mu_intercept_per_group\": 20.603790283203125, \"sigma_intercept_per_group\": 0.014689153991639614, \"sigma_obs\": 0.003970440477132797, \"slope\": 0.14948590099811554, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 673, \"mu_intercept_per_group\": 20.2160587310791, \"sigma_intercept_per_group\": 0.01588461734354496, \"sigma_obs\": 0.004604140296578407, \"slope\": 0.24703432619571686, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 674, \"mu_intercept_per_group\": 10.677534103393555, \"sigma_intercept_per_group\": 0.01647014543414116, \"sigma_obs\": 0.0035725957714021206, \"slope\": 0.14082904160022736, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 675, \"mu_intercept_per_group\": 9.891088485717773, \"sigma_intercept_per_group\": 0.026380203664302826, \"sigma_obs\": 0.004060911945998669, \"slope\": 0.3314683437347412, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 676, \"mu_intercept_per_group\": 14.76111888885498, \"sigma_intercept_per_group\": 0.02361820824444294, \"sigma_obs\": 0.0038663377054035664, \"slope\": 0.120294488966465, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 677, \"mu_intercept_per_group\": 5.17296028137207, \"sigma_intercept_per_group\": 0.01597416400909424, \"sigma_obs\": 0.004225458018481731, \"slope\": 0.2586852014064789, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 678, \"mu_intercept_per_group\": 21.503398895263672, \"sigma_intercept_per_group\": 0.022498346865177155, \"sigma_obs\": 0.004006086848676205, \"slope\": 0.1670248955488205, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 679, \"mu_intercept_per_group\": 13.5818452835083, \"sigma_intercept_per_group\": 0.013640888966619968, \"sigma_obs\": 0.004284108988940716, \"slope\": 0.20618878304958344, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 680, \"mu_intercept_per_group\": 11.979031562805176, \"sigma_intercept_per_group\": 0.01853584125638008, \"sigma_obs\": 0.004428843967616558, \"slope\": 0.3027714490890503, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 681, \"mu_intercept_per_group\": 13.752204895019531, \"sigma_intercept_per_group\": 0.014113884419202805, \"sigma_obs\": 0.004067208617925644, \"slope\": 0.23407647013664246, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 682, \"mu_intercept_per_group\": 6.729361534118652, \"sigma_intercept_per_group\": 0.013629419729113579, \"sigma_obs\": 0.003714656690135598, \"slope\": 0.14405488967895508, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 683, \"mu_intercept_per_group\": 14.156052589416504, \"sigma_intercept_per_group\": 0.02026834897696972, \"sigma_obs\": 0.003995681647211313, \"slope\": 0.34785670042037964, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 684, \"mu_intercept_per_group\": 12.361424446105957, \"sigma_intercept_per_group\": 0.016970161348581314, \"sigma_obs\": 0.003466846887022257, \"slope\": 0.1132165789604187, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 685, \"mu_intercept_per_group\": 10.60273551940918, \"sigma_intercept_per_group\": 0.0176589023321867, \"sigma_obs\": 0.003365384880453348, \"slope\": 0.15502841770648956, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 686, \"mu_intercept_per_group\": 17.63189125061035, \"sigma_intercept_per_group\": 0.008526116609573364, \"sigma_obs\": 0.00404028594493866, \"slope\": 0.1767309606075287, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 687, \"mu_intercept_per_group\": 17.9906005859375, \"sigma_intercept_per_group\": 0.011127371340990067, \"sigma_obs\": 0.004002800676971674, \"slope\": 0.22330905497074127, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 688, \"mu_intercept_per_group\": 17.58872413635254, \"sigma_intercept_per_group\": 0.014984029345214367, \"sigma_obs\": 0.003990641795098782, \"slope\": 0.2547208368778229, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 689, \"mu_intercept_per_group\": 10.29228687286377, \"sigma_intercept_per_group\": 0.019252868369221687, \"sigma_obs\": 0.003964322619140148, \"slope\": 0.2017338126897812, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 690, \"mu_intercept_per_group\": 16.375364303588867, \"sigma_intercept_per_group\": 0.026384029537439346, \"sigma_obs\": 0.004042902961373329, \"slope\": 0.11601316183805466, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 691, \"mu_intercept_per_group\": 11.047507286071777, \"sigma_intercept_per_group\": 0.02065119706094265, \"sigma_obs\": 0.004196073394268751, \"slope\": 0.20011769235134125, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 692, \"mu_intercept_per_group\": 14.359484672546387, \"sigma_intercept_per_group\": 0.013607114553451538, \"sigma_obs\": 0.004359060432761908, \"slope\": 0.16056589782238007, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 693, \"mu_intercept_per_group\": 13.661771774291992, \"sigma_intercept_per_group\": 0.017055127769708633, \"sigma_obs\": 0.003835598472505808, \"slope\": 0.14249861240386963, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 694, \"mu_intercept_per_group\": 18.88800621032715, \"sigma_intercept_per_group\": 0.00571843795478344, \"sigma_obs\": 0.004005345515906811, \"slope\": 0.1658293753862381, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 695, \"mu_intercept_per_group\": 17.933658599853516, \"sigma_intercept_per_group\": 0.005905293859541416, \"sigma_obs\": 0.003819832345470786, \"slope\": 0.1826002299785614, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 696, \"mu_intercept_per_group\": 14.136847496032715, \"sigma_intercept_per_group\": 0.017482364550232887, \"sigma_obs\": 0.004931061528623104, \"slope\": 0.1270705908536911, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 697, \"mu_intercept_per_group\": 14.391809463500977, \"sigma_intercept_per_group\": 0.01773468777537346, \"sigma_obs\": 0.004819062072783709, \"slope\": 0.11067038774490356, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 698, \"mu_intercept_per_group\": 9.188444137573242, \"sigma_intercept_per_group\": 0.020384322851896286, \"sigma_obs\": 0.0035350252874195576, \"slope\": 0.23751793801784515, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 699, \"mu_intercept_per_group\": 2.5345370769500732, \"sigma_intercept_per_group\": 0.015058061107993126, \"sigma_obs\": 0.0035736726131290197, \"slope\": 0.24918995797634125, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 700, \"mu_intercept_per_group\": -1.8914897441864014, \"sigma_intercept_per_group\": 0.01630186103284359, \"sigma_obs\": 0.00342403631657362, \"slope\": 0.2988780736923218, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 701, \"mu_intercept_per_group\": 11.63975715637207, \"sigma_intercept_per_group\": 0.015428434126079082, \"sigma_obs\": 0.003427082672715187, \"slope\": 0.20149476826190948, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 702, \"mu_intercept_per_group\": 12.190738677978516, \"sigma_intercept_per_group\": 0.01174665056169033, \"sigma_obs\": 0.003892035922035575, \"slope\": 0.18597978353500366, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 703, \"mu_intercept_per_group\": 13.46512222290039, \"sigma_intercept_per_group\": 0.0324004702270031, \"sigma_obs\": 0.004391789436340332, \"slope\": 0.2809170186519623, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 704, \"mu_intercept_per_group\": 14.594451904296875, \"sigma_intercept_per_group\": 0.007774549536406994, \"sigma_obs\": 0.0036702051293104887, \"slope\": 0.212888702750206, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 705, \"mu_intercept_per_group\": 26.660480499267578, \"sigma_intercept_per_group\": 0.011040467768907547, \"sigma_obs\": 0.004481547512114048, \"slope\": 0.14634104073047638, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 706, \"mu_intercept_per_group\": -1.8297244310379028, \"sigma_intercept_per_group\": 0.008600792847573757, \"sigma_obs\": 0.003683812916278839, \"slope\": 0.22932054102420807, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 707, \"mu_intercept_per_group\": 18.88283920288086, \"sigma_intercept_per_group\": 0.018462613224983215, \"sigma_obs\": 0.004585281014442444, \"slope\": 0.3658302426338196, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 708, \"mu_intercept_per_group\": 13.798812866210938, \"sigma_intercept_per_group\": 0.012386033311486244, \"sigma_obs\": 0.003899896051734686, \"slope\": -0.015203998424112797, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 709, \"mu_intercept_per_group\": 6.7603912353515625, \"sigma_intercept_per_group\": 0.010512642562389374, \"sigma_obs\": 0.0044775125570595264, \"slope\": 0.4093158543109894, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 710, \"mu_intercept_per_group\": 26.519031524658203, \"sigma_intercept_per_group\": 0.012336309999227524, \"sigma_obs\": 0.003940806724131107, \"slope\": 0.20350828766822815, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 711, \"mu_intercept_per_group\": 9.139301300048828, \"sigma_intercept_per_group\": 0.012054073624312878, \"sigma_obs\": 0.00399352191016078, \"slope\": 0.30212706327438354, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 712, \"mu_intercept_per_group\": 23.089824676513672, \"sigma_intercept_per_group\": 0.015296701341867447, \"sigma_obs\": 0.004364772234112024, \"slope\": 0.16232150793075562, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 713, \"mu_intercept_per_group\": 17.76047134399414, \"sigma_intercept_per_group\": 0.011538553051650524, \"sigma_obs\": 0.004002022091299295, \"slope\": 0.17366358637809753, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 714, \"mu_intercept_per_group\": 6.20468807220459, \"sigma_intercept_per_group\": 0.023061057552695274, \"sigma_obs\": 0.004097628407180309, \"slope\": 0.2944923937320709, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 715, \"mu_intercept_per_group\": 10.100860595703125, \"sigma_intercept_per_group\": 0.01790802739560604, \"sigma_obs\": 0.0040596770122647285, \"slope\": 0.260923832654953, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 716, \"mu_intercept_per_group\": 7.2865166664123535, \"sigma_intercept_per_group\": 0.0350007601082325, \"sigma_obs\": 0.0038879180792719126, \"slope\": 0.2166832685470581, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 717, \"mu_intercept_per_group\": 20.1359806060791, \"sigma_intercept_per_group\": 0.01323771197348833, \"sigma_obs\": 0.004557729698717594, \"slope\": 0.18668155372142792, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 718, \"mu_intercept_per_group\": 10.927922248840332, \"sigma_intercept_per_group\": 0.024650122970342636, \"sigma_obs\": 0.004220979288220406, \"slope\": 0.3060205280780792, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 719, \"mu_intercept_per_group\": 9.282352447509766, \"sigma_intercept_per_group\": 0.011697908863425255, \"sigma_obs\": 0.0037276719231158495, \"slope\": 0.25666797161102295, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 720, \"mu_intercept_per_group\": 10.734169006347656, \"sigma_intercept_per_group\": 0.011420901864767075, \"sigma_obs\": 0.004448701627552509, \"slope\": 0.19897453486919403, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 721, \"mu_intercept_per_group\": 8.391326904296875, \"sigma_intercept_per_group\": 0.025098396465182304, \"sigma_obs\": 0.003616285976022482, \"slope\": 0.23622991144657135, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 722, \"mu_intercept_per_group\": 12.880885124206543, \"sigma_intercept_per_group\": 0.014164497144520283, \"sigma_obs\": 0.00421229749917984, \"slope\": 0.28004106879234314, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 723, \"mu_intercept_per_group\": 12.003371238708496, \"sigma_intercept_per_group\": 0.015749666839838028, \"sigma_obs\": 0.004655183758586645, \"slope\": 0.25399351119995117, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 724, \"mu_intercept_per_group\": 14.61378002166748, \"sigma_intercept_per_group\": 0.01347574032843113, \"sigma_obs\": 0.004573369398713112, \"slope\": 0.23581673204898834, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 725, \"mu_intercept_per_group\": 12.166694641113281, \"sigma_intercept_per_group\": 0.017188459634780884, \"sigma_obs\": 0.00454358384013176, \"slope\": 0.23514600098133087, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 726, \"mu_intercept_per_group\": 15.044477462768555, \"sigma_intercept_per_group\": 0.012231631204485893, \"sigma_obs\": 0.003936044406145811, \"slope\": 0.11587150394916534, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 727, \"mu_intercept_per_group\": 10.959748268127441, \"sigma_intercept_per_group\": 0.011929727159440517, \"sigma_obs\": 0.004284797236323357, \"slope\": 0.23647868633270264, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 728, \"mu_intercept_per_group\": 14.52094554901123, \"sigma_intercept_per_group\": 0.013462047092616558, \"sigma_obs\": 0.004020913038402796, \"slope\": 0.13516682386398315, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 729, \"mu_intercept_per_group\": 8.486616134643555, \"sigma_intercept_per_group\": 0.017294423654675484, \"sigma_obs\": 0.003651150967925787, \"slope\": 0.16763709485530853, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 730, \"mu_intercept_per_group\": 15.75002384185791, \"sigma_intercept_per_group\": 0.015141742303967476, \"sigma_obs\": 0.0036831998731940985, \"slope\": 0.19575797021389008, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 731, \"mu_intercept_per_group\": 14.097485542297363, \"sigma_intercept_per_group\": 0.013214856386184692, \"sigma_obs\": 0.003993237856775522, \"slope\": 0.19754445552825928, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 732, \"mu_intercept_per_group\": 2.0235254764556885, \"sigma_intercept_per_group\": 0.015335035510361195, \"sigma_obs\": 0.003973404411226511, \"slope\": 0.22068457305431366, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 733, \"mu_intercept_per_group\": 3.8014142513275146, \"sigma_intercept_per_group\": 0.01656130887567997, \"sigma_obs\": 0.003636094508692622, \"slope\": 0.2512564957141876, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 734, \"mu_intercept_per_group\": -0.5554197430610657, \"sigma_intercept_per_group\": 0.019017700105905533, \"sigma_obs\": 0.0035729773808270693, \"slope\": 0.18720825016498566, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 735, \"mu_intercept_per_group\": 17.080961227416992, \"sigma_intercept_per_group\": 0.018339384347200394, \"sigma_obs\": 0.004161952529102564, \"slope\": 0.29188042879104614, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 736, \"mu_intercept_per_group\": 5.849990367889404, \"sigma_intercept_per_group\": 0.014834733679890633, \"sigma_obs\": 0.0037176797632128, \"slope\": 0.13646619021892548, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 737, \"mu_intercept_per_group\": 19.19090461730957, \"sigma_intercept_per_group\": 0.012591822072863579, \"sigma_obs\": 0.0040017664432525635, \"slope\": 0.10517071932554245, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 738, \"mu_intercept_per_group\": 10.918693542480469, \"sigma_intercept_per_group\": 0.015266955830156803, \"sigma_obs\": 0.004203936085104942, \"slope\": 0.21495191752910614, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 739, \"mu_intercept_per_group\": 13.553671836853027, \"sigma_intercept_per_group\": 0.014136589132249355, \"sigma_obs\": 0.0041474089957773685, \"slope\": 0.2200038880109787, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 740, \"mu_intercept_per_group\": 4.7978081703186035, \"sigma_intercept_per_group\": 0.034422993659973145, \"sigma_obs\": 0.003398529253900051, \"slope\": 0.16647808253765106, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 741, \"mu_intercept_per_group\": 9.526103019714355, \"sigma_intercept_per_group\": 0.030757738277316093, \"sigma_obs\": 0.003986739087849855, \"slope\": 0.11440956592559814, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 742, \"mu_intercept_per_group\": 6.554520130157471, \"sigma_intercept_per_group\": 0.03260805830359459, \"sigma_obs\": 0.0037615331821143627, \"slope\": 0.14874789118766785, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 743, \"mu_intercept_per_group\": 12.684871673583984, \"sigma_intercept_per_group\": 0.0234580896794796, \"sigma_obs\": 0.0038196775130927563, \"slope\": 0.1984865665435791, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 744, \"mu_intercept_per_group\": 9.742919921875, \"sigma_intercept_per_group\": 0.027387889102101326, \"sigma_obs\": 0.004108786582946777, \"slope\": 0.15331658720970154, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 745, \"mu_intercept_per_group\": 19.76345443725586, \"sigma_intercept_per_group\": 0.018353503197431564, \"sigma_obs\": 0.004091909620910883, \"slope\": 0.22410818934440613, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 746, \"mu_intercept_per_group\": 10.143475532531738, \"sigma_intercept_per_group\": 0.013699162751436234, \"sigma_obs\": 0.0038661384023725986, \"slope\": 0.18141242861747742, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 747, \"mu_intercept_per_group\": 17.446884155273438, \"sigma_intercept_per_group\": 0.015220820903778076, \"sigma_obs\": 0.004192393273115158, \"slope\": 0.1972808539867401, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 748, \"mu_intercept_per_group\": 18.710128784179688, \"sigma_intercept_per_group\": 0.025141721591353416, \"sigma_obs\": 0.004424567334353924, \"slope\": 0.16105321049690247, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 749, \"mu_intercept_per_group\": 14.642775535583496, \"sigma_intercept_per_group\": 0.014138227328658104, \"sigma_obs\": 0.004390105605125427, \"slope\": 0.14699280261993408, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 750, \"mu_intercept_per_group\": 19.100881576538086, \"sigma_intercept_per_group\": 0.011096031405031681, \"sigma_obs\": 0.0037601504009217024, \"slope\": 0.092697873711586, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 751, \"mu_intercept_per_group\": 8.402298927307129, \"sigma_intercept_per_group\": 0.012071064673364162, \"sigma_obs\": 0.0043154433369636536, \"slope\": 0.26760372519493103, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 752, \"mu_intercept_per_group\": 10.15411376953125, \"sigma_intercept_per_group\": 0.020437506958842278, \"sigma_obs\": 0.00356741389259696, \"slope\": 0.2516768276691437, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 753, \"mu_intercept_per_group\": 6.538330554962158, \"sigma_intercept_per_group\": 0.01740887574851513, \"sigma_obs\": 0.0041076564230024815, \"slope\": 0.25305312871932983, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 754, \"mu_intercept_per_group\": 12.712666511535645, \"sigma_intercept_per_group\": 0.029696635901927948, \"sigma_obs\": 0.0038685635663568974, \"slope\": 0.210035040974617, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 755, \"mu_intercept_per_group\": 7.455203533172607, \"sigma_intercept_per_group\": 0.01377884577959776, \"sigma_obs\": 0.004132024012506008, \"slope\": 0.221086323261261, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 756, \"mu_intercept_per_group\": 3.2716078758239746, \"sigma_intercept_per_group\": 0.022596340626478195, \"sigma_obs\": 0.0041901650838553905, \"slope\": 0.17539212107658386, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 757, \"mu_intercept_per_group\": 4.844691276550293, \"sigma_intercept_per_group\": 0.024588316679000854, \"sigma_obs\": 0.004140978679060936, \"slope\": 0.15189418196678162, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 758, \"mu_intercept_per_group\": 17.15043067932129, \"sigma_intercept_per_group\": 0.009735232219099998, \"sigma_obs\": 0.003967802040278912, \"slope\": 0.21785977482795715, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 759, \"mu_intercept_per_group\": 9.833940505981445, \"sigma_intercept_per_group\": 0.01900612749159336, \"sigma_obs\": 0.0034982438664883375, \"slope\": 0.033605918288230896, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 760, \"mu_intercept_per_group\": 8.629639625549316, \"sigma_intercept_per_group\": 0.018573209643363953, \"sigma_obs\": 0.0034512749407440424, \"slope\": 0.024825165048241615, \"chain\": 3, \"draw\": 160}, {\"mouse\": 7, \"draws\": 761, \"mu_intercept_per_group\": 8.8025541305542, \"sigma_intercept_per_group\": 0.026457609608769417, \"sigma_obs\": 0.0034104075748473406, \"slope\": 0.06335864216089249, \"chain\": 3, \"draw\": 161}, {\"mouse\": 7, \"draws\": 762, \"mu_intercept_per_group\": 13.855545043945312, \"sigma_intercept_per_group\": 0.015036887489259243, \"sigma_obs\": 0.004807322286069393, \"slope\": 0.3576884865760803, \"chain\": 3, \"draw\": 162}, {\"mouse\": 7, \"draws\": 763, \"mu_intercept_per_group\": 17.514272689819336, \"sigma_intercept_per_group\": 0.012809572741389275, \"sigma_obs\": 0.003793823765590787, \"slope\": 0.12251713871955872, \"chain\": 3, \"draw\": 163}, {\"mouse\": 7, \"draws\": 764, \"mu_intercept_per_group\": 14.950531959533691, \"sigma_intercept_per_group\": 0.011506328359246254, \"sigma_obs\": 0.0038250633515417576, \"slope\": 0.22518716752529144, \"chain\": 3, \"draw\": 164}, {\"mouse\": 7, \"draws\": 765, \"mu_intercept_per_group\": 15.36071491241455, \"sigma_intercept_per_group\": 0.012708621099591255, \"sigma_obs\": 0.003818382741883397, \"slope\": 0.06216159462928772, \"chain\": 3, \"draw\": 165}, {\"mouse\": 7, \"draws\": 766, \"mu_intercept_per_group\": 17.131275177001953, \"sigma_intercept_per_group\": 0.016470758244395256, \"sigma_obs\": 0.003674651263281703, \"slope\": 0.20900848507881165, \"chain\": 3, \"draw\": 166}, {\"mouse\": 7, \"draws\": 767, \"mu_intercept_per_group\": 6.334132671356201, \"sigma_intercept_per_group\": 0.01190806832164526, \"sigma_obs\": 0.003916214685887098, \"slope\": 0.250479131937027, \"chain\": 3, \"draw\": 167}, {\"mouse\": 7, \"draws\": 768, \"mu_intercept_per_group\": 4.500664234161377, \"sigma_intercept_per_group\": 0.012924803420901299, \"sigma_obs\": 0.0040300036780536175, \"slope\": 0.21833553910255432, \"chain\": 3, \"draw\": 168}, {\"mouse\": 7, \"draws\": 769, \"mu_intercept_per_group\": 31.4747314453125, \"sigma_intercept_per_group\": 0.011925348080694675, \"sigma_obs\": 0.004013928584754467, \"slope\": 0.22119835019111633, \"chain\": 3, \"draw\": 169}, {\"mouse\": 7, \"draws\": 770, \"mu_intercept_per_group\": 5.083420753479004, \"sigma_intercept_per_group\": 0.01359693706035614, \"sigma_obs\": 0.004310745745897293, \"slope\": 0.17697720229625702, \"chain\": 3, \"draw\": 170}, {\"mouse\": 7, \"draws\": 771, \"mu_intercept_per_group\": 6.722559928894043, \"sigma_intercept_per_group\": 0.012249480932950974, \"sigma_obs\": 0.0037034526467323303, \"slope\": 0.19305431842803955, \"chain\": 3, \"draw\": 171}, {\"mouse\": 7, \"draws\": 772, \"mu_intercept_per_group\": 9.143126487731934, \"sigma_intercept_per_group\": 0.01004192978143692, \"sigma_obs\": 0.004257311578840017, \"slope\": 0.25210797786712646, \"chain\": 3, \"draw\": 172}, {\"mouse\": 7, \"draws\": 773, \"mu_intercept_per_group\": 18.33839988708496, \"sigma_intercept_per_group\": 0.014915145933628082, \"sigma_obs\": 0.0036361413076519966, \"slope\": 0.22310875356197357, \"chain\": 3, \"draw\": 173}, {\"mouse\": 7, \"draws\": 774, \"mu_intercept_per_group\": 1.0376254320144653, \"sigma_intercept_per_group\": 0.013339729979634285, \"sigma_obs\": 0.004035289864987135, \"slope\": 0.2666647434234619, \"chain\": 3, \"draw\": 174}, {\"mouse\": 7, \"draws\": 775, \"mu_intercept_per_group\": 24.4460391998291, \"sigma_intercept_per_group\": 0.015219652093946934, \"sigma_obs\": 0.00377079239115119, \"slope\": 0.20277561247348785, \"chain\": 3, \"draw\": 175}, {\"mouse\": 7, \"draws\": 776, \"mu_intercept_per_group\": 3.071709394454956, \"sigma_intercept_per_group\": 0.007597469724714756, \"sigma_obs\": 0.00431041931733489, \"slope\": 0.2703627645969391, \"chain\": 3, \"draw\": 176}, {\"mouse\": 7, \"draws\": 777, \"mu_intercept_per_group\": 11.179348945617676, \"sigma_intercept_per_group\": 0.009053545072674751, \"sigma_obs\": 0.004162668716162443, \"slope\": 0.29042482376098633, \"chain\": 3, \"draw\": 177}, {\"mouse\": 7, \"draws\": 778, \"mu_intercept_per_group\": 11.647317886352539, \"sigma_intercept_per_group\": 0.033385083079338074, \"sigma_obs\": 0.003984359558671713, \"slope\": 0.2051612138748169, \"chain\": 3, \"draw\": 178}, {\"mouse\": 7, \"draws\": 779, \"mu_intercept_per_group\": 11.261837005615234, \"sigma_intercept_per_group\": 0.021620165556669235, \"sigma_obs\": 0.004220226779580116, \"slope\": 0.22138261795043945, \"chain\": 3, \"draw\": 179}, {\"mouse\": 7, \"draws\": 780, \"mu_intercept_per_group\": 14.204532623291016, \"sigma_intercept_per_group\": 0.020508425310254097, \"sigma_obs\": 0.004421975463628769, \"slope\": 0.27132779359817505, \"chain\": 3, \"draw\": 180}, {\"mouse\": 7, \"draws\": 781, \"mu_intercept_per_group\": 10.796290397644043, \"sigma_intercept_per_group\": 0.015187413431704044, \"sigma_obs\": 0.004207794554531574, \"slope\": 0.19140709936618805, \"chain\": 3, \"draw\": 181}, {\"mouse\": 7, \"draws\": 782, \"mu_intercept_per_group\": 12.963516235351562, \"sigma_intercept_per_group\": 0.01947193592786789, \"sigma_obs\": 0.004162099212408066, \"slope\": 0.14653469622135162, \"chain\": 3, \"draw\": 182}, {\"mouse\": 7, \"draws\": 783, \"mu_intercept_per_group\": 6.624403953552246, \"sigma_intercept_per_group\": 0.016312917694449425, \"sigma_obs\": 0.003891685279086232, \"slope\": 0.3270106911659241, \"chain\": 3, \"draw\": 183}, {\"mouse\": 7, \"draws\": 784, \"mu_intercept_per_group\": 20.135610580444336, \"sigma_intercept_per_group\": 0.01871105469763279, \"sigma_obs\": 0.003964812029153109, \"slope\": 0.15102443099021912, \"chain\": 3, \"draw\": 184}, {\"mouse\": 7, \"draws\": 785, \"mu_intercept_per_group\": 11.501521110534668, \"sigma_intercept_per_group\": 0.02765609882771969, \"sigma_obs\": 0.004218898713588715, \"slope\": 0.22981972992420197, \"chain\": 3, \"draw\": 185}, {\"mouse\": 7, \"draws\": 786, \"mu_intercept_per_group\": 9.679304122924805, \"sigma_intercept_per_group\": 0.0261685848236084, \"sigma_obs\": 0.00439738854765892, \"slope\": 0.1579972803592682, \"chain\": 3, \"draw\": 186}, {\"mouse\": 7, \"draws\": 787, \"mu_intercept_per_group\": 9.904572486877441, \"sigma_intercept_per_group\": 0.031194059178233147, \"sigma_obs\": 0.004230990540236235, \"slope\": 0.25579696893692017, \"chain\": 3, \"draw\": 187}, {\"mouse\": 7, \"draws\": 788, \"mu_intercept_per_group\": 11.821760177612305, \"sigma_intercept_per_group\": 0.024284616112709045, \"sigma_obs\": 0.004835452884435654, \"slope\": 0.26909300684928894, \"chain\": 3, \"draw\": 188}, {\"mouse\": 7, \"draws\": 789, \"mu_intercept_per_group\": 10.323616027832031, \"sigma_intercept_per_group\": 0.027641531080007553, \"sigma_obs\": 0.004464780446141958, \"slope\": 0.2259359061717987, \"chain\": 3, \"draw\": 189}, {\"mouse\": 7, \"draws\": 790, \"mu_intercept_per_group\": 15.954474449157715, \"sigma_intercept_per_group\": 0.02087101712822914, \"sigma_obs\": 0.004323560744524002, \"slope\": 0.16159775853157043, \"chain\": 3, \"draw\": 190}, {\"mouse\": 7, \"draws\": 791, \"mu_intercept_per_group\": 17.040075302124023, \"sigma_intercept_per_group\": 0.01903153769671917, \"sigma_obs\": 0.004293448757380247, \"slope\": 0.16555149853229523, \"chain\": 3, \"draw\": 191}, {\"mouse\": 7, \"draws\": 792, \"mu_intercept_per_group\": 13.847721099853516, \"sigma_intercept_per_group\": 0.012503540143370628, \"sigma_obs\": 0.004401273559778929, \"slope\": 0.19765491783618927, \"chain\": 3, \"draw\": 192}, {\"mouse\": 7, \"draws\": 793, \"mu_intercept_per_group\": 16.707489013671875, \"sigma_intercept_per_group\": 0.008911427110433578, \"sigma_obs\": 0.0041757263243198395, \"slope\": 0.16325800120830536, \"chain\": 3, \"draw\": 193}, {\"mouse\": 7, \"draws\": 794, \"mu_intercept_per_group\": 11.388129234313965, \"sigma_intercept_per_group\": 0.015857011079788208, \"sigma_obs\": 0.004103907383978367, \"slope\": 0.23929862678050995, \"chain\": 3, \"draw\": 194}, {\"mouse\": 7, \"draws\": 795, \"mu_intercept_per_group\": 10.363701820373535, \"sigma_intercept_per_group\": 0.01752406172454357, \"sigma_obs\": 0.004166950471699238, \"slope\": 0.16976960003376007, \"chain\": 3, \"draw\": 195}, {\"mouse\": 7, \"draws\": 796, \"mu_intercept_per_group\": 16.580825805664062, \"sigma_intercept_per_group\": 0.019222909584641457, \"sigma_obs\": 0.0037020843010395765, \"slope\": 0.17197339236736298, \"chain\": 3, \"draw\": 196}, {\"mouse\": 7, \"draws\": 797, \"mu_intercept_per_group\": 7.494189739227295, \"sigma_intercept_per_group\": 0.011503925547003746, \"sigma_obs\": 0.0041913362219929695, \"slope\": 0.1865624636411667, \"chain\": 3, \"draw\": 197}, {\"mouse\": 7, \"draws\": 798, \"mu_intercept_per_group\": 26.840944290161133, \"sigma_intercept_per_group\": 0.01215433981269598, \"sigma_obs\": 0.004376315511763096, \"slope\": 0.11375395208597183, \"chain\": 3, \"draw\": 198}, {\"mouse\": 7, \"draws\": 799, \"mu_intercept_per_group\": 16.009048461914062, \"sigma_intercept_per_group\": 0.013601534999907017, \"sigma_obs\": 0.0043487027287483215, \"slope\": 0.26614096760749817, \"chain\": 3, \"draw\": 199}], \"data-4b9cbfc1c4897c0672d6a06e25fe8ad5\": [{\"index\": \"C(stim, Treatment)[T.1]\", \"center interval\": 0.16, \"Std.Err.\": 0.027, \"z\": 5.863, \"p\": 0.0, \"higher interval\": 0.107, \"lower interval\": 0.214, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 21,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "window.chart_posterior_intercept | chart_power_difference | chart_power_difference_lme"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "## Check for false-positives with null model\n",
    "They sometimes appear with non-transformed data + \"normal\" model"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-4bfef15ff8dd48c3ab24cdfea6fd22ca\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-4bfef15ff8dd48c3ab24cdfea6fd22ca\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-4bfef15ff8dd48c3ab24cdfea6fd22ca\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-b08ca2a8be9f13445d2d12f026c8661d\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-80.26519775390625, 0], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-b08ca2a8be9f13445d2d12f026c8661d\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-80.26519775390625, 0], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-b08ca2a8be9f13445d2d12f026c8661d\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-80.26519775390625, 0], \"zero\": true}}}}, {\"data\": {\"name\": \"data-e7eaf72d8e565e39c910dd9719ab3b44\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [-80.26519775390625, 0], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [-80.26519775390625, -31.132892608642578], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-b08ca2a8be9f13445d2d12f026c8661d\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-490.50158019438845, 262.66033766992655], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-b08ca2a8be9f13445d2d12f026c8661d\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-490.50158019438845, 262.66033766992655], \"zero\": false}}}}, {\"data\": {\"name\": \"data-b08ca2a8be9f13445d2d12f026c8661d\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-490.50158019438845, 262.66033766992655], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\", \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-b08ca2a8be9f13445d2d12f026c8661d\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 373.1024771699109, \"mu_intercept_per_group higher interval\": 12.845458030700684, \"mu_intercept_per_group lower interval\": 4.5105109214782715, \"mu_intercept_per_group center interval\": 7.83314847946167, \"mu_intercept_per_group higher interval75\": 10.981689453125, \"mu_intercept_per_group lower interval75\": 5.766022205352783, \"sigma_intercept_per_group higher interval\": 62.894935607910156, \"sigma_intercept_per_group lower interval\": 21.43952751159668, \"sigma_intercept_per_group center interval\": 37.8387451171875, \"sigma_obs higher interval\": 150.50741577148438, \"sigma_obs lower interval\": 148.57261657714844, \"sigma_obs center interval\": 149.57894897460938, \"higher interval\": -31.132892608642578, \"lower interval\": -80.26519775390625, \"center interval\": -54.346832275390625, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 6.461420296542826, \"mu_intercept_per_group higher interval\": 6.26956033706665, \"mu_intercept_per_group lower interval\": 1.8739292621612549, \"mu_intercept_per_group center interval\": 3.5804433822631836, \"mu_intercept_per_group higher interval75\": 5.472024917602539, \"mu_intercept_per_group lower interval75\": 2.746957540512085, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": -4.794562915542059, \"mu_intercept_per_group higher interval\": 7.161080837249756, \"mu_intercept_per_group lower interval\": 2.3366360664367676, \"mu_intercept_per_group center interval\": 4.212461948394775, \"mu_intercept_per_group higher interval75\": 5.906421184539795, \"mu_intercept_per_group lower interval75\": 2.906783103942871, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": -25.16081796364446, \"mu_intercept_per_group higher interval\": 9.285981178283691, \"mu_intercept_per_group lower interval\": 2.9649128913879395, \"mu_intercept_per_group center interval\": 5.948874473571777, \"mu_intercept_per_group higher interval75\": 7.463964462280273, \"mu_intercept_per_group lower interval75\": 3.615079879760742, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 57.553507169956106, \"mu_intercept_per_group higher interval\": 8.593442916870117, \"mu_intercept_per_group lower interval\": 2.7164230346679688, \"mu_intercept_per_group center interval\": 4.9649152755737305, \"mu_intercept_per_group higher interval75\": 6.7468485832214355, \"mu_intercept_per_group lower interval75\": 3.2267422676086426, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -66.20482985488388, \"mu_intercept_per_group higher interval\": 15.243149757385254, \"mu_intercept_per_group lower interval\": 5.096168518066406, \"mu_intercept_per_group center interval\": 11.107730865478516, \"mu_intercept_per_group higher interval75\": 12.883514404296875, \"mu_intercept_per_group lower interval75\": 6.544693946838379, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -693.6727465366484, \"mu_intercept_per_group higher interval\": 25.23527717590332, \"mu_intercept_per_group lower interval\": 8.888345718383789, \"mu_intercept_per_group center interval\": 16.253198623657227, \"mu_intercept_per_group higher interval75\": 21.508182525634766, \"mu_intercept_per_group lower interval75\": 11.329413414001465, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": -113.18369984447719, \"mu_intercept_per_group higher interval\": 15.375848770141602, \"mu_intercept_per_group lower interval\": 5.096001148223877, \"mu_intercept_per_group center interval\": 9.798494338989258, \"mu_intercept_per_group higher interval75\": 13.068041801452637, \"mu_intercept_per_group lower interval75\": 6.735915184020996, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-e7eaf72d8e565e39c910dd9719ab3b44\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": 8.934333801269531, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": 11.02304744720459, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": 10.599905014038086, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": 10.027129173278809, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": 9.850064277648926, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": 11.350857734680176, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": 15.17533016204834, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": 13.125112533569336, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": 14.270275115966797, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": 9.603541374206543, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": 9.660429000854492, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": 10.918331146240234, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": 10.773183822631836, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": 9.496898651123047, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": 9.039571762084961, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": 9.300226211547852, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": 4.770740032196045, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": 4.539904594421387, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": 4.483384132385254, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": 4.710255146026611, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": 4.158257484436035, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": 3.9571633338928223, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": 4.454404354095459, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": 6.262598514556885, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": 5.529003143310547, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": 6.304434776306152, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": 6.068268775939941, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": 7.638446807861328, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": 6.790628910064697, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": 6.600759506225586, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": 4.8502726554870605, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": 5.637138843536377, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": 5.860856533050537, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": 8.565123558044434, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": 5.298003673553467, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": 5.197033882141113, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": 5.318228244781494, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": 7.557604789733887, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": 7.912603855133057, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": 7.995064735412598, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": 7.972058296203613, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": 7.3045806884765625, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": 4.032954692840576, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": 4.366214275360107, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": 5.951070308685303, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": 6.038238525390625, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": 10.67529582977295, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": 11.810263633728027, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": 9.829071998596191, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": 9.493147850036621, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": 9.97325611114502, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": 11.63824462890625, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": 12.404047012329102, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": 10.427755355834961, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": 10.318582534790039, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": 11.064675331115723, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": 9.989717483520508, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": 9.761395454406738, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": 11.358161926269531, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": 11.690741539001465, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": 8.484912872314453, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": 7.304275035858154, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": 8.519704818725586, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": 8.465591430664062, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": 8.901399612426758, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": 8.233535766601562, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": 7.177846908569336, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": 8.031048774719238, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": 8.1265287399292, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": 8.281498908996582, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": 7.754683494567871, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": 8.03343677520752, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": 7.256385326385498, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": 6.764657020568848, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": 6.734627723693848, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": 8.485661506652832, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": 10.262259483337402, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": 10.17380428314209, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": 10.039579391479492, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": 7.8006439208984375, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": 8.59201717376709, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": 6.663082122802734, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": 6.986236095428467, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": 5.469359874725342, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": 5.976818084716797, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": 5.5428690910339355, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": 5.124209880828857, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": 9.575316429138184, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": 9.025819778442383, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": 9.368419647216797, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": 10.073945999145508, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": 9.786324501037598, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": 10.021650314331055, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": 12.712525367736816, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": 6.234796047210693, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": 6.147214889526367, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": 6.133243083953857, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": 5.738249778747559, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": 7.9734673500061035, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": 7.119941711425781, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": 6.13254976272583, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": 6.499625205993652, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": 6.427006244659424, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": 7.51284646987915, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": 8.471966743469238, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": 8.898069381713867, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": 9.49880599975586, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": 8.839727401733398, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": 9.571952819824219, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": 9.502557754516602, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": 9.75220012664795, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": 11.15877914428711, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": 9.862152099609375, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": 9.61523723602295, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": 9.754908561706543, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": 9.090307235717773, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": 8.231836318969727, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": 9.235176086425781, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": 9.007299423217773, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": 9.092073440551758, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": 8.923662185668945, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": 9.022313117980957, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": 6.515135765075684, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": 5.797276973724365, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": 5.804698467254639, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": 6.318418979644775, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": 6.61092472076416, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": 6.919384002685547, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": 7.36699104309082, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": 7.163618564605713, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": 7.818188190460205, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": 6.887734889984131, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": 7.444891929626465, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": 4.549746036529541, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": 3.852864980697632, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": 4.574697971343994, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": 6.323906898498535, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": 5.197919845581055, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": 5.615312099456787, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": 5.6896796226501465, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": 6.367926597595215, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": 5.4810566902160645, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": 5.766022205352783, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": 5.685670852661133, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": 4.561509609222412, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": 6.918951034545898, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": 6.451135635375977, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": 6.347196578979492, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": 7.0291900634765625, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": 6.498240947723389, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": 6.160048961639404, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": 9.399412155151367, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": 8.28016471862793, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": 7.979730606079102, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": 9.15335464477539, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": 6.8138041496276855, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": 7.322122097015381, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": 10.51278018951416, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": 10.169363975524902, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": 10.783068656921387, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": 6.023126125335693, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": 6.627154350280762, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": 6.5583343505859375, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": 7.056426048278809, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": 5.8006510734558105, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": 6.928471565246582, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": 6.399191379547119, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": 6.814026355743408, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": 6.899907112121582, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": 8.149519920349121, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": 6.943185329437256, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": 8.99499797821045, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": 7.913482666015625, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": 4.204648494720459, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": 4.793181896209717, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": 4.695389747619629, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": 4.686628341674805, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": 4.835262298583984, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": 4.72741174697876, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": 4.5105109214782715, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": 4.9091668128967285, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": 6.554235935211182, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": 7.977143287658691, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": 6.961164474487305, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": 7.145411491394043, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": 7.087214946746826, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": 8.943537712097168, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": 12.26187801361084, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": 11.900310516357422, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": 11.274721145629883, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": 10.185368537902832, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": 11.503300666809082, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": 10.506786346435547, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": 11.822066307067871, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": 10.39646053314209, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": 10.788430213928223, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": 10.637438774108887, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": 10.787751197814941, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": 11.978904724121094, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": 12.804718017578125, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": 7.013082981109619, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": 7.266763210296631, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": 7.747598648071289, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": 7.456511974334717, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": 7.722862243652344, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": 7.716724395751953, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": 6.115877628326416, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": 7.587344169616699, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": 6.904138088226318, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": 12.714916229248047, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": 12.472980499267578, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": 11.279900550842285, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": 7.788392066955566, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": 9.178013801574707, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": 9.614901542663574, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": 10.3825044631958, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": 9.707016944885254, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": 8.083216667175293, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": 7.668212890625, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": 6.9262471199035645, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": 6.716186046600342, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": 4.97849702835083, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": 4.3916826248168945, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": 5.956775188446045, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": 5.566441535949707, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": 4.928189754486084, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": 5.595010757446289, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": 5.04160737991333, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": 6.0535888671875, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": 7.2530694007873535, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": 7.350789546966553, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": 6.801681995391846, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": 7.235620021820068, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": 7.569859027862549, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": 7.7405829429626465, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": 5.7494072914123535, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": 5.471227169036865, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": 5.37867546081543, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": 6.406583309173584, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": 6.511958122253418, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": 5.493657112121582, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": 5.8039374351501465, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": 5.265112400054932, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": 9.649666786193848, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": 8.86827278137207, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": 9.058809280395508, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": 7.060083389282227, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": 6.825472831726074, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": 7.571417331695557, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": 6.568513870239258, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": 6.539710521697998, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": 9.117846488952637, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": 9.017962455749512, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": 12.198802947998047, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": 15.053078651428223, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": 13.427862167358398, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": 13.176308631896973, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": 14.975969314575195, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": 12.982919692993164, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": 11.974063873291016, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": 12.82200813293457, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": 13.148666381835938, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": 12.599773406982422, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": 12.787334442138672, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": 10.927983283996582, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": 11.69610595703125, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": 11.644165992736816, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": 11.800661087036133, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": 9.677374839782715, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": 10.453887939453125, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": 11.90306568145752, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": 12.499113082885742, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": 9.806288719177246, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": 8.512640953063965, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": 8.704233169555664, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": 7.514252185821533, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": 7.9029860496521, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": 8.469837188720703, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": 8.076166152954102, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": 9.197842597961426, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": 8.308639526367188, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": 8.269596099853516, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": 8.859039306640625, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": 7.571041584014893, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": 9.809298515319824, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": 11.131245613098145, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": 10.683557510375977, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": 9.889042854309082, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": 10.288844108581543, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": 10.680879592895508, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": 10.93109130859375, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": 8.011656761169434, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": 8.017533302307129, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": 8.164556503295898, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": 5.991147994995117, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": 6.784536361694336, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": 4.861959457397461, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": 3.1356019973754883, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": 3.3702473640441895, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": 5.704863548278809, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": 4.551052093505859, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": 4.5760393142700195, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": 4.139472484588623, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": 4.5659050941467285, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": 5.683526515960693, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": 6.017929553985596, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": 5.905301094055176, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": 6.536037921905518, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": 5.713473796844482, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": 5.607133388519287, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": 5.766883850097656, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": 8.756086349487305, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": 8.418929100036621, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": 9.669027328491211, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": 10.119200706481934, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": 9.76385498046875, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": 7.7869873046875, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": 7.697734832763672, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": 8.472904205322266, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": 7.1296772956848145, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": 7.583602428436279, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": 7.360597610473633, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": 7.407452583312988, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": 7.789451599121094, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": 8.21805477142334, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": 7.861818790435791, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": 10.051464080810547, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": 9.268733978271484, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": 7.157123565673828, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": 10.293569564819336, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": 9.57891845703125, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": 10.645181655883789, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": 10.950542449951172, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": 10.27206039428711, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": 6.385634899139404, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": 6.577535629272461, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": 6.286449432373047, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": 6.740172863006592, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": 6.803609848022461, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": 6.033847808837891, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": 4.960147857666016, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": 4.345619201660156, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": 3.1952991485595703, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": 5.831509590148926, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": 5.331605911254883, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": 6.699835777282715, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": 7.82942008972168, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": 8.3385009765625, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": 10.385029792785645, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": 10.67190933227539, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": 8.247235298156738, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": 12.519013404846191, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": 14.464720726013184, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": 15.079670906066895, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": 11.138510704040527, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": 14.773754119873047, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": 10.55093765258789, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": 12.09972858428955, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": 9.515527725219727, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": 10.802581787109375, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": 8.21414566040039, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": 8.807629585266113, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": 10.75525951385498, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": 8.94067096710205, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": 9.440253257751465, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": 10.665759086608887, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": 12.587366104125977, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": 11.899248123168945, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": 9.560357093811035, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": 8.344371795654297, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": 10.798633575439453, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": 9.749465942382812, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": 12.535103797912598, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": 10.29137897491455, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": 9.715188980102539, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": 9.823493003845215, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": 9.467924118041992, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": 10.608842849731445, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": 11.116721153259277, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": 10.451518058776855, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": 9.414118766784668, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": 11.015325546264648, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": 9.612275123596191, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": 12.845458030700684, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": 14.333747863769531, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": 11.320904731750488, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": 12.402619361877441, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": 14.469494819641113, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": 11.327208518981934, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": 10.773123741149902, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": 9.054316520690918, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": 10.469478607177734, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": 10.175240516662598, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": 9.247353553771973, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": 10.956111907958984, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": 8.484081268310547, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": 11.30527114868164, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": 10.831488609313965, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": 7.852831840515137, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": 8.632250785827637, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": 10.093210220336914, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": 10.482171058654785, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": 8.606908798217773, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": 8.764700889587402, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": 10.16685962677002, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": 10.972234725952148, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": 10.20903205871582, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": 9.5874605178833, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": 9.370330810546875, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": 9.129380226135254, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": 8.571160316467285, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": 9.44753646850586, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": 9.205510139465332, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": 7.903508186340332, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": 8.197322845458984, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": 9.178634643554688, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": 8.825647354125977, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": 7.868351459503174, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": 8.973020553588867, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": 8.461371421813965, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": 9.223389625549316, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": 10.643832206726074, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": 8.663021087646484, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": 10.297518730163574, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": 11.2002592086792, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": 9.624855041503906, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": 9.630546569824219, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": 8.031351089477539, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": 8.011687278747559, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": 8.603995323181152, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": 8.626729011535645, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": 7.114595890045166, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": 5.871570110321045, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": 5.534793376922607, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": 6.507149696350098, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": 7.739416122436523, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": 8.282334327697754, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": 7.588201999664307, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": 8.668298721313477, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": 8.622699737548828, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": 9.256979942321777, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": 11.497318267822266, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": 11.220803260803223, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": 12.413074493408203, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": 12.164970397949219, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": 13.342342376708984, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": 13.032879829406738, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": 13.679511070251465, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": 13.321502685546875, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": 16.242652893066406, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": 14.686956405639648, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": 9.554343223571777, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": 10.558870315551758, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": 11.601480484008789, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": 12.346647262573242, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": 9.562967300415039, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": 10.110261917114258, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": 10.457014083862305, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": 9.854558944702148, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": 11.025108337402344, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": 11.86406421661377, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": 9.422867774963379, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": 9.150517463684082, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": 9.487810134887695, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": 11.00781536102295, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": 9.484530448913574, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": 10.695940971374512, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": 8.563010215759277, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": 8.198151588439941, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": 7.9164605140686035, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": 8.470719337463379, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": 9.064268112182617, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": 9.137096405029297, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": 9.413338661193848, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": 9.829933166503906, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": 11.055642127990723, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": 9.920685768127441, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": 10.214340209960938, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": 8.394750595092773, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": 9.805205345153809, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": 9.918706893920898, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": 7.683204650878906, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": 6.269748687744141, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": 6.526193618774414, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": 5.557790279388428, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": 5.804886817932129, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": 6.13130521774292, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": 9.878602027893066, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": 8.47450065612793, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": 8.002392768859863, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": 8.102885246276855, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": 9.705480575561523, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": 8.269388198852539, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": 8.839335441589355, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": 8.34572982788086, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": 4.550026893615723, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": 5.643490314483643, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": 5.132314682006836, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": 6.268450736999512, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": 4.562326431274414, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": 5.297577857971191, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": 6.1654372215271, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": 7.226354598999023, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": 6.416819095611572, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": 6.163207530975342, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": 6.259945869445801, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": 7.033049583435059, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": 7.26560640335083, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": 7.243765830993652, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": 8.924492835998535, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": 7.70196533203125, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": 9.028454780578613, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": 8.78004264831543, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": 9.728388786315918, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": 7.504950523376465, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": 6.883121013641357, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": 7.252743721008301, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": 6.798031330108643, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": 7.100615978240967, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": 7.057490825653076, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": 5.836513996124268, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": 6.829620361328125, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": 5.387843132019043, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": 7.526763916015625, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": 6.912313461303711, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": 6.809117317199707, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": 7.496047019958496, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": 7.807818412780762, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": 7.638280868530273, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": 6.502231121063232, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": 5.124721050262451, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": 8.339218139648438, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": 9.362725257873535, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": 10.533246040344238, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": 9.656888008117676, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": 10.895814895629883, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": 8.915520668029785, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": 8.37943172454834, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": 7.6713433265686035, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": 7.658791542053223, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": 8.333288192749023, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": 9.577908515930176, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": 10.232880592346191, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": 7.232245922088623, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": 9.485386848449707, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": 5.581411838531494, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": 5.374273300170898, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": 5.943228721618652, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": 9.192543029785156, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": 6.384767055511475, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": 7.197942733764648, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": 6.22918176651001, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": 6.831324100494385, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": 6.390550136566162, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": 7.0099101066589355, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": 6.544769763946533, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": 6.824018955230713, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": 6.461296558380127, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": 7.091960430145264, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": 7.157072067260742, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": 7.244670867919922, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": 8.488802909851074, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": 8.244112014770508, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": 6.9334845542907715, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": 6.934881210327148, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": 9.4852876663208, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": 6.173010349273682, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": 7.745075225830078, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": 6.281347274780273, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": 5.947500705718994, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": 6.553248882293701, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": 5.994840621948242, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": 6.7923455238342285, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": 6.759724140167236, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": 5.834151744842529, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": 5.901318073272705, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": 6.895207405090332, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": 7.238199234008789, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": 6.0247344970703125, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": 5.900015354156494, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": 9.12263011932373, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": 8.925928115844727, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": 9.754800796508789, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": 7.279817581176758, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": 9.588829040527344, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": 8.2059965133667, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": 7.513296127319336, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": 7.194331169128418, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": 8.030342102050781, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": 6.9223785400390625, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": 8.670220375061035, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": 8.411176681518555, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": 7.503709316253662, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": 8.24371337890625, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": 8.616463661193848, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": 8.951379776000977, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": 9.46656608581543, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": 9.4905424118042, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": 8.870760917663574, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": 9.951848983764648, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": 7.782155990600586, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": 7.459709167480469, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": 8.119146347045898, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": 9.632015228271484, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": 7.78341817855835, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": 9.23090648651123, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": 9.524534225463867, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": 10.407574653625488, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": 10.31816291809082, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": 8.70957088470459, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": 9.203736305236816, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": 10.852048873901367, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": 10.302404403686523, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": 10.356239318847656, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": 10.0831298828125, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": 9.699685096740723, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": 10.015216827392578, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": 9.65539264678955, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": 10.981689453125, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": 10.40744400024414, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": 10.977622032165527, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": 10.32175350189209, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": 10.12378978729248, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": 9.817440032958984, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": 10.117619514465332, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": 8.256340026855469, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": 9.388427734375, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": 9.698078155517578, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": 8.50004768371582, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": 6.6289873123168945, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": 6.396984577178955, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": 6.582727432250977, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": 6.056090831756592, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": 4.600154876708984, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": 4.569044589996338, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": 7.361044406890869, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": 6.48881721496582, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": 9.976033210754395, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": 10.807844161987305, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": 10.369461059570312, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 640, \"mu_intercept_per_group\": 10.438226699829102, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 641, \"mu_intercept_per_group\": 9.620943069458008, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 642, \"mu_intercept_per_group\": 7.775053977966309, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 643, \"mu_intercept_per_group\": 8.864582061767578, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 644, \"mu_intercept_per_group\": 9.001733779907227, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 645, \"mu_intercept_per_group\": 7.862656116485596, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 646, \"mu_intercept_per_group\": 7.576634883880615, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 647, \"mu_intercept_per_group\": 4.7155609130859375, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 648, \"mu_intercept_per_group\": 4.647423267364502, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 649, \"mu_intercept_per_group\": 5.8311767578125, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 650, \"mu_intercept_per_group\": 5.20388650894165, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 651, \"mu_intercept_per_group\": 4.903508186340332, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 652, \"mu_intercept_per_group\": 4.726509094238281, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 653, \"mu_intercept_per_group\": 8.050079345703125, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 654, \"mu_intercept_per_group\": 4.545556545257568, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 655, \"mu_intercept_per_group\": 5.186356067657471, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 656, \"mu_intercept_per_group\": 4.802087783813477, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 657, \"mu_intercept_per_group\": 7.651790618896484, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 658, \"mu_intercept_per_group\": 6.539711952209473, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 659, \"mu_intercept_per_group\": 6.836719036102295, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 660, \"mu_intercept_per_group\": 6.440494060516357, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 661, \"mu_intercept_per_group\": 5.209011077880859, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 662, \"mu_intercept_per_group\": 5.553289413452148, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 663, \"mu_intercept_per_group\": 5.124308109283447, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 664, \"mu_intercept_per_group\": 5.380335807800293, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 665, \"mu_intercept_per_group\": 5.199644565582275, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 666, \"mu_intercept_per_group\": 9.582822799682617, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 667, \"mu_intercept_per_group\": 6.537871837615967, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 668, \"mu_intercept_per_group\": 6.37721586227417, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 669, \"mu_intercept_per_group\": 5.217401504516602, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 670, \"mu_intercept_per_group\": 4.7917280197143555, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 671, \"mu_intercept_per_group\": 6.23301887512207, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 672, \"mu_intercept_per_group\": 6.507321834564209, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 673, \"mu_intercept_per_group\": 5.25542688369751, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 674, \"mu_intercept_per_group\": 5.973603248596191, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 675, \"mu_intercept_per_group\": 6.14934778213501, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 676, \"mu_intercept_per_group\": 5.5973687171936035, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 677, \"mu_intercept_per_group\": 5.783695220947266, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 678, \"mu_intercept_per_group\": 5.775590419769287, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 679, \"mu_intercept_per_group\": 5.7203545570373535, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 680, \"mu_intercept_per_group\": 5.156655311584473, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 681, \"mu_intercept_per_group\": 7.087917804718018, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 682, \"mu_intercept_per_group\": 7.27161979675293, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 683, \"mu_intercept_per_group\": 8.082870483398438, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 684, \"mu_intercept_per_group\": 7.4315385818481445, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 685, \"mu_intercept_per_group\": 9.8906831741333, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 686, \"mu_intercept_per_group\": 9.50379753112793, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 687, \"mu_intercept_per_group\": 10.34216594696045, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 688, \"mu_intercept_per_group\": 10.940821647644043, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 689, \"mu_intercept_per_group\": 10.577322006225586, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 690, \"mu_intercept_per_group\": 10.869551658630371, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 691, \"mu_intercept_per_group\": 10.51529598236084, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 692, \"mu_intercept_per_group\": 11.500896453857422, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 693, \"mu_intercept_per_group\": 12.064535140991211, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 694, \"mu_intercept_per_group\": 12.710232734680176, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 695, \"mu_intercept_per_group\": 9.42823314666748, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 696, \"mu_intercept_per_group\": 13.19914722442627, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 697, \"mu_intercept_per_group\": 12.237534523010254, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 698, \"mu_intercept_per_group\": 12.271700859069824, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 699, \"mu_intercept_per_group\": 12.575749397277832, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 700, \"mu_intercept_per_group\": 12.69010066986084, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 701, \"mu_intercept_per_group\": 13.356430053710938, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 702, \"mu_intercept_per_group\": 13.69306468963623, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 703, \"mu_intercept_per_group\": 12.58249568939209, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 704, \"mu_intercept_per_group\": 15.00076675415039, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 705, \"mu_intercept_per_group\": 10.772056579589844, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 706, \"mu_intercept_per_group\": 9.889603614807129, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 707, \"mu_intercept_per_group\": 8.588135719299316, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 708, \"mu_intercept_per_group\": 11.027253150939941, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 709, \"mu_intercept_per_group\": 10.59164047241211, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 710, \"mu_intercept_per_group\": 10.433356285095215, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 711, \"mu_intercept_per_group\": 9.53547191619873, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 712, \"mu_intercept_per_group\": 8.915664672851562, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 713, \"mu_intercept_per_group\": 8.551093101501465, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 714, \"mu_intercept_per_group\": 8.271305084228516, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 715, \"mu_intercept_per_group\": 9.631625175476074, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 716, \"mu_intercept_per_group\": 9.988361358642578, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 717, \"mu_intercept_per_group\": 10.764389038085938, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 718, \"mu_intercept_per_group\": 10.554655075073242, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 719, \"mu_intercept_per_group\": 13.762746810913086, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 720, \"mu_intercept_per_group\": 11.429964065551758, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 721, \"mu_intercept_per_group\": 11.441949844360352, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 722, \"mu_intercept_per_group\": 11.659873962402344, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 723, \"mu_intercept_per_group\": 10.935676574707031, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 724, \"mu_intercept_per_group\": 12.071048736572266, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 725, \"mu_intercept_per_group\": 10.70810604095459, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 726, \"mu_intercept_per_group\": 12.096076965332031, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 727, \"mu_intercept_per_group\": 12.144731521606445, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 728, \"mu_intercept_per_group\": 11.731182098388672, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 729, \"mu_intercept_per_group\": 12.500836372375488, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 730, \"mu_intercept_per_group\": 12.212411880493164, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 731, \"mu_intercept_per_group\": 9.682707786560059, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 732, \"mu_intercept_per_group\": 9.884366989135742, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 733, \"mu_intercept_per_group\": 10.009505271911621, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 734, \"mu_intercept_per_group\": 8.11837387084961, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 735, \"mu_intercept_per_group\": 7.755582332611084, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 736, \"mu_intercept_per_group\": 8.19232177734375, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 737, \"mu_intercept_per_group\": 7.960494518280029, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 738, \"mu_intercept_per_group\": 8.105032920837402, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 739, \"mu_intercept_per_group\": 7.487884044647217, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 740, \"mu_intercept_per_group\": 7.393585205078125, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 741, \"mu_intercept_per_group\": 8.217540740966797, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 742, \"mu_intercept_per_group\": 8.231687545776367, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 743, \"mu_intercept_per_group\": 8.644607543945312, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 744, \"mu_intercept_per_group\": 8.705353736877441, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 745, \"mu_intercept_per_group\": 9.983856201171875, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 746, \"mu_intercept_per_group\": 9.58742618560791, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 747, \"mu_intercept_per_group\": 9.47968864440918, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 748, \"mu_intercept_per_group\": 7.377474308013916, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 749, \"mu_intercept_per_group\": 6.9484758377075195, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 750, \"mu_intercept_per_group\": 8.124462127685547, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 751, \"mu_intercept_per_group\": 7.723828315734863, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 752, \"mu_intercept_per_group\": 7.533578872680664, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 753, \"mu_intercept_per_group\": 8.29623031616211, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 754, \"mu_intercept_per_group\": 7.855452537536621, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 755, \"mu_intercept_per_group\": 7.777742862701416, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 756, \"mu_intercept_per_group\": 8.458526611328125, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 757, \"mu_intercept_per_group\": 9.019604682922363, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 758, \"mu_intercept_per_group\": 9.346248626708984, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 759, \"mu_intercept_per_group\": 9.688501358032227, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 0, \"draws\": 760, \"mu_intercept_per_group\": 9.358317375183105, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 0, \"draws\": 761, \"mu_intercept_per_group\": 9.392106056213379, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 0, \"draws\": 762, \"mu_intercept_per_group\": 6.831840991973877, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 0, \"draws\": 763, \"mu_intercept_per_group\": 6.761003017425537, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 0, \"draws\": 764, \"mu_intercept_per_group\": 10.9080228805542, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 0, \"draws\": 765, \"mu_intercept_per_group\": 10.137432098388672, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 0, \"draws\": 766, \"mu_intercept_per_group\": 11.636035919189453, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 0, \"draws\": 767, \"mu_intercept_per_group\": 12.20499324798584, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 0, \"draws\": 768, \"mu_intercept_per_group\": 11.174549102783203, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 0, \"draws\": 769, \"mu_intercept_per_group\": 11.655959129333496, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 0, \"draws\": 770, \"mu_intercept_per_group\": 12.714143753051758, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 0, \"draws\": 771, \"mu_intercept_per_group\": 10.125333786010742, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 0, \"draws\": 772, \"mu_intercept_per_group\": 12.789338111877441, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 0, \"draws\": 773, \"mu_intercept_per_group\": 8.222536087036133, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 0, \"draws\": 774, \"mu_intercept_per_group\": 6.545950412750244, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 0, \"draws\": 775, \"mu_intercept_per_group\": 6.6811323165893555, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 0, \"draws\": 776, \"mu_intercept_per_group\": 7.325632572174072, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 0, \"draws\": 777, \"mu_intercept_per_group\": 7.524218559265137, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 0, \"draws\": 778, \"mu_intercept_per_group\": 7.77108097076416, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 0, \"draws\": 779, \"mu_intercept_per_group\": 8.332540512084961, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 0, \"draws\": 780, \"mu_intercept_per_group\": 9.783806800842285, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 0, \"draws\": 781, \"mu_intercept_per_group\": 9.287257194519043, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 0, \"draws\": 782, \"mu_intercept_per_group\": 9.497451782226562, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 0, \"draws\": 783, \"mu_intercept_per_group\": 8.179574966430664, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 0, \"draws\": 784, \"mu_intercept_per_group\": 8.714727401733398, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 0, \"draws\": 785, \"mu_intercept_per_group\": 6.697094917297363, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 0, \"draws\": 786, \"mu_intercept_per_group\": 7.649954795837402, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 0, \"draws\": 787, \"mu_intercept_per_group\": 7.578032493591309, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 0, \"draws\": 788, \"mu_intercept_per_group\": 8.401204109191895, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 0, \"draws\": 789, \"mu_intercept_per_group\": 7.781020641326904, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 0, \"draws\": 790, \"mu_intercept_per_group\": 7.651695728302002, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 0, \"draws\": 791, \"mu_intercept_per_group\": 7.848090171813965, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 0, \"draws\": 792, \"mu_intercept_per_group\": 8.00944995880127, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 0, \"draws\": 793, \"mu_intercept_per_group\": 6.808152198791504, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 0, \"draws\": 794, \"mu_intercept_per_group\": 5.55003547668457, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 0, \"draws\": 795, \"mu_intercept_per_group\": 6.926416397094727, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 0, \"draws\": 796, \"mu_intercept_per_group\": 8.285894393920898, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 0, \"draws\": 797, \"mu_intercept_per_group\": 7.674686431884766, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 0, \"draws\": 798, \"mu_intercept_per_group\": 7.960581302642822, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 0, \"draws\": 799, \"mu_intercept_per_group\": 8.169412612915039, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": 5.9956841468811035, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": 5.245181083679199, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": 5.155781269073486, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": 5.047390460968018, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": 4.82559061050415, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": 5.255263328552246, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": 7.149071216583252, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": 6.812637805938721, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": 7.126446723937988, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": 4.636025428771973, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": 4.454877853393555, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": 4.5669379234313965, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": 4.35899019241333, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": 4.438933372497559, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": 4.158507823944092, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": 4.282660961151123, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": 3.087769031524658, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": 3.2208802700042725, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": 3.1812903881073, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": 1.541157603263855, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": 2.046861171722412, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": 1.940749168395996, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": 2.086909532546997, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": 3.262455701828003, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": 2.782060384750366, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": 2.2869937419891357, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": 3.928346633911133, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": 3.4882009029388428, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": 3.373767137527466, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": 3.1991467475891113, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": 2.84798526763916, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": 2.674485683441162, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": 2.8808391094207764, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": 3.5991451740264893, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": 2.031270742416382, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": 2.9173083305358887, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": 2.66921329498291, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": 3.7372870445251465, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": 3.697706937789917, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": 3.190920352935791, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": 4.891040325164795, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": 4.460851669311523, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": 2.3946380615234375, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": 2.3107104301452637, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": 3.0988898277282715, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": 2.7709250450134277, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": 5.788235187530518, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": 5.174530029296875, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": 5.350489616394043, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": 5.1369757652282715, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": 4.810123443603516, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": 4.5022478103637695, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": 7.006904125213623, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": 4.815419673919678, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": 4.911084175109863, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": 5.125185489654541, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": 5.589155673980713, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": 5.222195625305176, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": 4.134364604949951, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": 4.598647117614746, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": 6.170227527618408, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": 2.7626168727874756, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": 3.283348560333252, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": 4.878992080688477, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": 3.8627400398254395, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": 3.5708470344543457, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": 4.541629314422607, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": 4.669644355773926, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": 4.653277397155762, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": 3.766819953918457, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": 4.061638832092285, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": 3.98557186126709, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": 3.6719415187835693, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": 3.8352229595184326, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": 3.6965925693511963, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": 3.8555073738098145, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": 4.339083671569824, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": 5.101183891296387, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": 3.965299606323242, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": 5.062772274017334, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": 3.4535913467407227, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": 3.8941595554351807, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": 4.37596321105957, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": 2.8581008911132812, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": 2.2113685607910156, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": 2.5489606857299805, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": 2.964479446411133, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": 3.7256951332092285, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": 3.429140567779541, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": 3.883084297180176, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": 4.802230358123779, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": 4.353038787841797, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": 4.161646366119385, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": 6.875093936920166, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": 3.254260778427124, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": 3.249035358428955, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": 3.160477876663208, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": 3.063217878341675, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": 4.3249077796936035, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": 3.3047218322753906, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": 3.444746255874634, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": 2.4846582412719727, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": 2.634864568710327, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": 4.155972003936768, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": 3.4972877502441406, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": 3.4194345474243164, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": 3.557314872741699, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": 3.864457607269287, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": 3.580962896347046, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": 4.157644271850586, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": 5.537652015686035, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": 5.472024917602539, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": 4.515717506408691, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": 5.693596839904785, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": 5.199727535247803, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": 4.9610443115234375, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": 3.4714372158050537, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": 4.589200496673584, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": 4.981534957885742, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": 4.775201320648193, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": 4.550929546356201, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": 5.2154459953308105, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": 3.0065643787384033, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": 3.193880081176758, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": 2.7052786350250244, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": 3.164754867553711, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": 3.3276658058166504, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": 3.1276907920837402, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": 3.9763424396514893, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": 4.033781051635742, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": 3.5507314205169678, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": 3.809828758239746, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": 3.0897481441497803, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": 2.3948166370391846, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": 1.8378548622131348, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": 2.0001823902130127, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": 3.681084632873535, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": 3.191558837890625, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": 3.2686939239501953, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": 2.8000943660736084, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": 3.0958147048950195, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": 2.6324329376220703, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": 2.589693546295166, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": 2.3041632175445557, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": 2.6863605976104736, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": 3.8881912231445312, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": 2.9627974033355713, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": 3.6747376918792725, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": 3.6983211040496826, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": 3.4057061672210693, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": 3.5169448852539062, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": 3.2963998317718506, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": 3.88444185256958, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": 3.787851095199585, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": 4.208136558532715, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": 2.7194602489471436, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": 3.1476590633392334, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": 5.057535171508789, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": 5.066457271575928, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": 3.75795316696167, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": 2.8936855792999268, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": 2.958327054977417, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": 3.199730396270752, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": 3.3484299182891846, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": 3.9536538124084473, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": 3.725701093673706, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": 3.539768695831299, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": 3.956766366958618, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": 3.6698925495147705, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": 2.9618442058563232, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": 3.2083306312561035, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": 3.9334607124328613, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": 4.136428356170654, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": 2.031877040863037, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": 2.2572901248931885, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": 2.336599588394165, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": 2.765164852142334, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": 2.5901684761047363, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": 2.0958502292633057, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": 2.2412753105163574, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": 2.599005937576294, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": 3.0189414024353027, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": 4.378842830657959, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": 3.8553638458251953, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": 3.8327488899230957, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": 4.585590362548828, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": 3.3481080532073975, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": 6.192414283752441, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": 6.525032997131348, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": 6.2682061195373535, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": 5.364019870758057, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": 5.007989406585693, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": 5.499509811401367, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": 4.838191509246826, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": 5.592400550842285, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": 5.473212718963623, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": 5.324798583984375, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": 5.375687122344971, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": 5.176657199859619, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": 5.469358921051025, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": 3.6956026554107666, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": 3.9173219203948975, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": 3.687612533569336, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": 3.906663417816162, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": 4.292710781097412, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": 4.608139991760254, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": 3.3681373596191406, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": 3.68951153755188, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": 3.5541625022888184, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": 5.165499210357666, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": 5.423028469085693, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": 5.03337287902832, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": 4.146637916564941, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": 4.390139102935791, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": 5.217798233032227, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": 4.026449203491211, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": 5.432453155517578, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": 2.695303201675415, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": 2.5721731185913086, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": 4.263974189758301, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": 2.7002310752868652, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": 2.614438056945801, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": 2.078399419784546, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": 2.5394182205200195, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": 2.4608025550842285, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": 1.8739292621612549, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": 3.310152053833008, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": 2.885294198989868, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": 2.6335082054138184, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": 3.3441054821014404, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": 3.544895648956299, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": 3.6302168369293213, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": 3.1882410049438477, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": 4.0233283042907715, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": 3.3699676990509033, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": 3.133133888244629, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": 2.855436086654663, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": 2.678802013397217, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": 3.0643606185913086, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": 3.0477395057678223, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": 3.023898124694824, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": 2.746957540512085, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": 2.7650973796844482, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": 4.40466833114624, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": 5.042825698852539, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": 4.075438976287842, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": 2.8866312503814697, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": 3.6338839530944824, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": 3.2754595279693604, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": 3.4842851161956787, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": 3.5772390365600586, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": 4.67243766784668, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": 4.626542091369629, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": 5.37755823135376, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": 5.633685111999512, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": 6.836776256561279, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": 6.720676898956299, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": 6.326479434967041, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": 5.443126678466797, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": 6.995018005371094, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": 4.888206958770752, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": 4.791074752807617, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": 6.821173191070557, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": 6.1471943855285645, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": 5.64192533493042, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": 5.848080635070801, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": 6.918001651763916, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": 6.127066612243652, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": 4.35573673248291, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": 4.86116886138916, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": 5.561885833740234, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": 5.2444376945495605, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": 4.549773693084717, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": 4.447120189666748, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": 3.936283826828003, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": 4.284780025482178, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": 4.717123508453369, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": 4.7052459716796875, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": 3.7253925800323486, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": 2.7826015949249268, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": 3.5366148948669434, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": 3.9133012294769287, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": 3.869178056716919, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": 2.96675181388855, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": 5.917480945587158, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": 5.289690017700195, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": 5.06082820892334, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": 5.516273498535156, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": 5.774918079376221, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": 4.442232608795166, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": 5.321990013122559, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": 3.699141025543213, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": 4.047189235687256, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": 4.032206058502197, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": 2.3235650062561035, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": 2.761625051498413, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": 2.153494119644165, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": 0.9786218404769897, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": 1.8005520105361938, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": 3.0659403800964355, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": 1.979300618171692, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": 1.9986155033111572, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": 1.7363677024841309, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": 2.2407407760620117, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": 2.878169059753418, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": 3.2609453201293945, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": 2.7096781730651855, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": 2.366712808609009, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": 3.373403549194336, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": 2.395122528076172, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": 2.937767267227173, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": 4.559340000152588, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": 4.772249698638916, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": 4.017635345458984, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": 3.955108165740967, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": 3.853487014770508, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": 3.3021035194396973, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": 3.3824141025543213, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": 3.795403242111206, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": 3.604556083679199, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": 3.401005506515503, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": 3.3506479263305664, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": 3.668470859527588, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": 3.745330333709717, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": 3.6419620513916016, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": 4.026770114898682, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": 4.259651184082031, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": 4.610616207122803, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": 4.886985778808594, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": 3.5454752445220947, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": 5.617048263549805, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": 3.8453526496887207, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": 5.415094375610352, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": 5.313406467437744, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": 2.4844348430633545, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": 2.868579864501953, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": 3.0215375423431396, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": 3.2648441791534424, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": 2.7842419147491455, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": 2.9286084175109863, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": 1.9483710527420044, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": 2.5970077514648438, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": 1.8866090774536133, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": 2.5935215950012207, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": 2.6894783973693848, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": 3.108530044555664, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": 3.4007346630096436, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": 3.492064952850342, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": 3.9352571964263916, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": 3.699260950088501, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": 4.54947566986084, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": 6.439126491546631, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": 7.460468292236328, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": 7.667887210845947, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": 6.643030166625977, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": 5.868123531341553, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": 6.499358177185059, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": 5.020058631896973, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": 5.6605048179626465, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": 5.437069892883301, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": 4.029716491699219, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": 3.876774549484253, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": 4.682914733886719, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": 4.848716735839844, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": 4.621708869934082, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": 5.856326103210449, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": 5.832029342651367, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": 5.807265758514404, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": 4.989963054656982, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": 4.525295734405518, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": 6.398329734802246, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": 4.40385627746582, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": 4.6176934242248535, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": 5.9264044761657715, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": 4.4999847412109375, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": 4.433618068695068, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": 5.306657314300537, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": 5.358303070068359, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": 5.0584869384765625, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": 5.580028057098389, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": 4.700397968292236, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": 4.995601177215576, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": 5.740496635437012, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": 6.3758697509765625, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": 7.174998760223389, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": 3.8214287757873535, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": 8.111714363098145, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": 5.407468795776367, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": 7.112710475921631, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": 4.680932998657227, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": 5.853228569030762, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": 5.016485691070557, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": 4.627421855926514, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": 4.8150739669799805, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": 4.902873516082764, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": 5.3871750831604, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": 5.663383483886719, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": 5.692990303039551, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": 4.695089817047119, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": 4.097631454467773, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": 6.26956033706665, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": 3.066567897796631, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": 5.712369918823242, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": 5.348607540130615, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": 5.043258190155029, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": 4.835561752319336, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": 5.21068811416626, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": 5.30023193359375, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": 4.192007064819336, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": 5.43159294128418, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": 4.868594169616699, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": 4.279069423675537, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": 3.9956798553466797, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": 4.444711685180664, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": 4.344756126403809, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": 3.9284861087799072, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": 3.964772939682007, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": 3.9432759284973145, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": 3.7938241958618164, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": 4.507740497589111, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": 4.375950336456299, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": 5.36531925201416, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": 4.006608486175537, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": 5.562915325164795, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": 5.6571760177612305, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": 4.846370697021484, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": 5.246186256408691, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": 3.653419256210327, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": 4.025940418243408, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": 3.8415372371673584, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": 3.4708032608032227, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": 3.2548611164093018, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": 3.0460338592529297, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": 2.438356637954712, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": 2.906344413757324, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": 4.586903095245361, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": 4.570770740509033, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": 3.492182970046997, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": 4.113938331604004, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": 5.3729119300842285, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": 3.4562766551971436, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": 6.349578380584717, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": 5.9578118324279785, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": 5.67307186126709, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": 4.4967122077941895, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": 4.495957374572754, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": 4.44001579284668, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": 7.622312545776367, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": 6.874166488647461, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": 5.751407146453857, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": 9.076692581176758, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": 4.60161018371582, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": 4.6055073738098145, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": 5.505973815917969, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": 3.7335093021392822, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": 6.609859466552734, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": 5.418720245361328, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": 4.555192947387695, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": 4.575777053833008, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": 5.33267068862915, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": 5.0333380699157715, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": 4.587420463562012, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": 4.57119083404541, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": 5.852663040161133, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": 4.036681175231934, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": 4.800068378448486, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": 5.983288288116455, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": 2.976407289505005, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": 5.966129302978516, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": 5.88332986831665, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": 5.224300384521484, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": 4.706351280212402, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": 4.596063613891602, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": 4.780701637268066, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": 4.086398124694824, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": 5.331795692443848, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": 4.820346355438232, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": 5.126481533050537, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": 5.022340297698975, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": 4.219794750213623, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": 4.224660873413086, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": 3.6208434104919434, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": 3.417001962661743, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": 3.193005323410034, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": 3.643594980239868, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": 2.9024791717529297, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": 3.4764089584350586, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": 5.2209954261779785, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": 4.839977264404297, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": 4.92850923538208, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": 5.1052446365356445, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": 4.346416473388672, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": 4.687470436096191, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": 4.226688861846924, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": 3.4995503425598145, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": 2.9340949058532715, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": 2.1557722091674805, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": 1.8918721675872803, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": 2.40674090385437, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": 2.286586046218872, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": 2.787524938583374, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": 3.14959979057312, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": 3.4554600715637207, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": 3.4460556507110596, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": 2.799823760986328, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": 2.509216547012329, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": 4.129934310913086, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": 4.1259331703186035, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": 2.9790353775024414, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": 3.7846529483795166, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": 3.367816925048828, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": 3.779035806655884, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": 3.806363105773926, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": 3.3901703357696533, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": 3.960200548171997, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": 3.335744857788086, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": 3.3457226753234863, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": 3.4027669429779053, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": 3.4206459522247314, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": 3.394023895263672, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": 3.07179594039917, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": 2.5940308570861816, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": 3.274181604385376, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": 3.6838059425354004, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": 3.4371142387390137, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": 4.302480220794678, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": 3.7104578018188477, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": 3.6582186222076416, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": 3.333656072616577, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": 3.2814807891845703, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": 2.1727001667022705, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": 3.5814473628997803, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": 5.155740261077881, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": 5.743738174438477, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": 4.706345081329346, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": 5.442760467529297, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": 4.85503625869751, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": 3.8545262813568115, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": 3.470224618911743, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": 4.812314510345459, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": 3.4931552410125732, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": 4.744278907775879, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": 3.863635540008545, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": 4.581291675567627, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": 4.711556434631348, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": 2.747645616531372, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": 2.9410061836242676, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": 2.298591136932373, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": 5.016613483428955, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": 2.538517951965332, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": 3.5620031356811523, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": 3.1907119750976562, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": 3.231503486633301, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": 3.1181859970092773, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": 3.546471118927002, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": 2.5104758739471436, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": 2.663165330886841, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": 3.3576745986938477, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": 3.1384851932525635, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": 3.1046676635742188, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": 3.6002233028411865, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": 3.3818485736846924, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": 4.337643146514893, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": 4.5833587646484375, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": 2.9575083255767822, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": 3.944283962249756, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": 3.1858325004577637, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": 3.215543031692505, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": 3.659466028213501, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": 2.5137014389038086, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": 3.2761282920837402, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": 3.3913414478302, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": 3.246253252029419, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": 3.053109884262085, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": 2.8412599563598633, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": 2.9136552810668945, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": 2.8794777393341064, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": 2.8664419651031494, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": 2.7921698093414307, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": 3.4535796642303467, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": 5.803417205810547, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": 3.3779516220092773, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": 4.517271995544434, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": 3.7226624488830566, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": 5.329113960266113, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": 5.240406036376953, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": 2.549718141555786, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": 3.758603572845459, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": 3.78542423248291, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": 4.097487449645996, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": 2.9763736724853516, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": 2.7825095653533936, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": 4.257573127746582, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": 3.960125684738159, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": 4.584196090698242, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": 4.615582466125488, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": 4.811914920806885, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": 4.006603240966797, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": 4.162917613983154, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": 4.462348461151123, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": 2.8500730991363525, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": 4.243032455444336, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": 3.1315274238586426, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": 3.5303962230682373, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": 3.940201997756958, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": 3.635739326477051, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": 3.719189167022705, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": 6.041320323944092, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": 5.372686386108398, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": 4.551640033721924, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": 5.755851745605469, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": 4.511547565460205, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": 5.175807952880859, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": 5.308356285095215, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": 5.419105529785156, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": 5.148967266082764, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": 4.958951473236084, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": 5.222594261169434, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": 5.384122371673584, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": 5.125606536865234, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": 4.929055690765381, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": 4.880945205688477, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": 4.3080525398254395, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": 4.540008544921875, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": 4.2740068435668945, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": 4.395963191986084, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": 4.962136268615723, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": 4.693114280700684, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": 4.105095863342285, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": 3.4548137187957764, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": 3.2938404083251953, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": 3.432178020477295, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": 3.9118173122406006, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": 1.9429984092712402, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": 1.9416924715042114, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": 3.6225552558898926, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": 3.0348000526428223, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": 4.255663871765137, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": 4.531406402587891, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": 5.78549337387085, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 640, \"mu_intercept_per_group\": 4.349238872528076, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 641, \"mu_intercept_per_group\": 3.641977548599243, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 642, \"mu_intercept_per_group\": 5.192312240600586, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 643, \"mu_intercept_per_group\": 4.467072010040283, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 644, \"mu_intercept_per_group\": 4.495045185089111, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 645, \"mu_intercept_per_group\": 3.500246047973633, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 646, \"mu_intercept_per_group\": 4.1075334548950195, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 647, \"mu_intercept_per_group\": 1.9562052488327026, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 648, \"mu_intercept_per_group\": 2.292948007583618, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 649, \"mu_intercept_per_group\": 3.0383667945861816, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 650, \"mu_intercept_per_group\": 2.551008701324463, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 651, \"mu_intercept_per_group\": 2.4936821460723877, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 652, \"mu_intercept_per_group\": 2.606417417526245, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 653, \"mu_intercept_per_group\": 4.04994010925293, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 654, \"mu_intercept_per_group\": 2.0557408332824707, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 655, \"mu_intercept_per_group\": 2.0295050144195557, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 656, \"mu_intercept_per_group\": 2.145430088043213, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 657, \"mu_intercept_per_group\": 3.982713460922241, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 658, \"mu_intercept_per_group\": 3.033951759338379, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 659, \"mu_intercept_per_group\": 2.811795473098755, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 660, \"mu_intercept_per_group\": 3.004666566848755, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 661, \"mu_intercept_per_group\": 2.9164488315582275, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 662, \"mu_intercept_per_group\": 2.6345107555389404, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 663, \"mu_intercept_per_group\": 2.535066843032837, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 664, \"mu_intercept_per_group\": 2.9746460914611816, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 665, \"mu_intercept_per_group\": 2.078094482421875, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 666, \"mu_intercept_per_group\": 5.1618218421936035, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 667, \"mu_intercept_per_group\": 3.6335036754608154, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 668, \"mu_intercept_per_group\": 2.309326171875, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 669, \"mu_intercept_per_group\": 2.4220595359802246, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 670, \"mu_intercept_per_group\": 2.400315046310425, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 671, \"mu_intercept_per_group\": 3.464568614959717, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 672, \"mu_intercept_per_group\": 4.515565872192383, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 673, \"mu_intercept_per_group\": 2.751887083053589, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 674, \"mu_intercept_per_group\": 2.6625146865844727, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 675, \"mu_intercept_per_group\": 2.644059419631958, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 676, \"mu_intercept_per_group\": 3.256760835647583, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 677, \"mu_intercept_per_group\": 3.185328722000122, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 678, \"mu_intercept_per_group\": 2.661853075027466, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 679, \"mu_intercept_per_group\": 2.590489625930786, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 680, \"mu_intercept_per_group\": 2.0382323265075684, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 681, \"mu_intercept_per_group\": 2.8976449966430664, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 682, \"mu_intercept_per_group\": 2.49155330657959, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 683, \"mu_intercept_per_group\": 3.0713396072387695, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 684, \"mu_intercept_per_group\": 4.653432846069336, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 685, \"mu_intercept_per_group\": 3.7172582149505615, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 686, \"mu_intercept_per_group\": 5.352817535400391, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 687, \"mu_intercept_per_group\": 6.029092311859131, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 688, \"mu_intercept_per_group\": 5.884344100952148, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 689, \"mu_intercept_per_group\": 4.465651512145996, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 690, \"mu_intercept_per_group\": 5.987077236175537, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 691, \"mu_intercept_per_group\": 5.430440425872803, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 692, \"mu_intercept_per_group\": 5.761049270629883, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 693, \"mu_intercept_per_group\": 5.222854137420654, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 694, \"mu_intercept_per_group\": 5.062178134918213, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 695, \"mu_intercept_per_group\": 5.448363780975342, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 696, \"mu_intercept_per_group\": 5.415176868438721, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 697, \"mu_intercept_per_group\": 6.163834095001221, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 698, \"mu_intercept_per_group\": 6.162524700164795, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 699, \"mu_intercept_per_group\": 5.763887882232666, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 700, \"mu_intercept_per_group\": 6.131997108459473, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 701, \"mu_intercept_per_group\": 4.980908393859863, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 702, \"mu_intercept_per_group\": 7.255486965179443, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 703, \"mu_intercept_per_group\": 6.533474922180176, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 704, \"mu_intercept_per_group\": 4.9433417320251465, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 705, \"mu_intercept_per_group\": 5.374956130981445, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 706, \"mu_intercept_per_group\": 3.593233585357666, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 707, \"mu_intercept_per_group\": 4.300279140472412, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 708, \"mu_intercept_per_group\": 4.991854667663574, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 709, \"mu_intercept_per_group\": 4.670608997344971, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 710, \"mu_intercept_per_group\": 5.504281997680664, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 711, \"mu_intercept_per_group\": 6.044050216674805, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 712, \"mu_intercept_per_group\": 5.056150913238525, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 713, \"mu_intercept_per_group\": 4.161261081695557, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 714, \"mu_intercept_per_group\": 3.7237768173217773, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 715, \"mu_intercept_per_group\": 4.104984760284424, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 716, \"mu_intercept_per_group\": 4.557700157165527, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 717, \"mu_intercept_per_group\": 4.627538681030273, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 718, \"mu_intercept_per_group\": 5.792690753936768, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 719, \"mu_intercept_per_group\": 6.86405611038208, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 720, \"mu_intercept_per_group\": 6.103392601013184, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 721, \"mu_intercept_per_group\": 5.959476947784424, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 722, \"mu_intercept_per_group\": 7.201678276062012, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 723, \"mu_intercept_per_group\": 4.330888748168945, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 724, \"mu_intercept_per_group\": 4.996179580688477, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 725, \"mu_intercept_per_group\": 5.60515022277832, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 726, \"mu_intercept_per_group\": 6.257294654846191, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 727, \"mu_intercept_per_group\": 6.38296365737915, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 728, \"mu_intercept_per_group\": 5.292409420013428, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 729, \"mu_intercept_per_group\": 4.7972235679626465, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 730, \"mu_intercept_per_group\": 3.910398483276367, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 731, \"mu_intercept_per_group\": 6.132894992828369, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 732, \"mu_intercept_per_group\": 5.910895824432373, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 733, \"mu_intercept_per_group\": 5.378269195556641, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 734, \"mu_intercept_per_group\": 5.101635932922363, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 735, \"mu_intercept_per_group\": 4.714192867279053, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 736, \"mu_intercept_per_group\": 3.443747043609619, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 737, \"mu_intercept_per_group\": 4.260137557983398, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 738, \"mu_intercept_per_group\": 3.939805507659912, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 739, \"mu_intercept_per_group\": 4.153054237365723, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 740, \"mu_intercept_per_group\": 3.9346632957458496, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 741, \"mu_intercept_per_group\": 3.6705162525177, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 742, \"mu_intercept_per_group\": 3.5434634685516357, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 743, \"mu_intercept_per_group\": 3.7037744522094727, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 744, \"mu_intercept_per_group\": 4.657769680023193, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 745, \"mu_intercept_per_group\": 4.757020950317383, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 746, \"mu_intercept_per_group\": 4.424149036407471, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 747, \"mu_intercept_per_group\": 4.380407333374023, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 748, \"mu_intercept_per_group\": 2.9786176681518555, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 749, \"mu_intercept_per_group\": 3.4326581954956055, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 750, \"mu_intercept_per_group\": 4.382137298583984, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 751, \"mu_intercept_per_group\": 2.8533997535705566, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 752, \"mu_intercept_per_group\": 4.485067844390869, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 753, \"mu_intercept_per_group\": 4.355191230773926, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 754, \"mu_intercept_per_group\": 4.826065540313721, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 755, \"mu_intercept_per_group\": 4.852812767028809, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 756, \"mu_intercept_per_group\": 3.6256823539733887, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 757, \"mu_intercept_per_group\": 2.9161882400512695, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 758, \"mu_intercept_per_group\": 3.4636454582214355, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 759, \"mu_intercept_per_group\": 3.7883200645446777, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 760, \"mu_intercept_per_group\": 4.150429725646973, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 1, \"draws\": 761, \"mu_intercept_per_group\": 5.149163722991943, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 1, \"draws\": 762, \"mu_intercept_per_group\": 2.641939878463745, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 1, \"draws\": 763, \"mu_intercept_per_group\": 3.374640941619873, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 1, \"draws\": 764, \"mu_intercept_per_group\": 4.98391056060791, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 1, \"draws\": 765, \"mu_intercept_per_group\": 6.05281400680542, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 1, \"draws\": 766, \"mu_intercept_per_group\": 5.442039489746094, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 1, \"draws\": 767, \"mu_intercept_per_group\": 6.38454008102417, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 1, \"draws\": 768, \"mu_intercept_per_group\": 5.920280456542969, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 1, \"draws\": 769, \"mu_intercept_per_group\": 6.196600914001465, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 1, \"draws\": 770, \"mu_intercept_per_group\": 5.782930374145508, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 1, \"draws\": 771, \"mu_intercept_per_group\": 6.388350963592529, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 1, \"draws\": 772, \"mu_intercept_per_group\": 5.736772060394287, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 1, \"draws\": 773, \"mu_intercept_per_group\": 3.7221531867980957, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 1, \"draws\": 774, \"mu_intercept_per_group\": 3.6168789863586426, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 1, \"draws\": 775, \"mu_intercept_per_group\": 3.611821174621582, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 1, \"draws\": 776, \"mu_intercept_per_group\": 3.81052827835083, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 1, \"draws\": 777, \"mu_intercept_per_group\": 3.803060293197632, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 1, \"draws\": 778, \"mu_intercept_per_group\": 4.14324951171875, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 1, \"draws\": 779, \"mu_intercept_per_group\": 3.9427757263183594, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 1, \"draws\": 780, \"mu_intercept_per_group\": 5.068049907684326, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 1, \"draws\": 781, \"mu_intercept_per_group\": 3.5495145320892334, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 1, \"draws\": 782, \"mu_intercept_per_group\": 5.213399887084961, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 1, \"draws\": 783, \"mu_intercept_per_group\": 3.628740072250366, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 1, \"draws\": 784, \"mu_intercept_per_group\": 3.7289116382598877, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 1, \"draws\": 785, \"mu_intercept_per_group\": 3.7500369548797607, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 1, \"draws\": 786, \"mu_intercept_per_group\": 2.9686622619628906, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 1, \"draws\": 787, \"mu_intercept_per_group\": 3.345241069793701, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 1, \"draws\": 788, \"mu_intercept_per_group\": 3.9775683879852295, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 1, \"draws\": 789, \"mu_intercept_per_group\": 3.9904770851135254, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 1, \"draws\": 790, \"mu_intercept_per_group\": 3.683849573135376, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 1, \"draws\": 791, \"mu_intercept_per_group\": 3.5452353954315186, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 1, \"draws\": 792, \"mu_intercept_per_group\": 3.529256582260132, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 1, \"draws\": 793, \"mu_intercept_per_group\": 3.4006218910217285, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 1, \"draws\": 794, \"mu_intercept_per_group\": 3.214585542678833, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 1, \"draws\": 795, \"mu_intercept_per_group\": 3.81485915184021, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 1, \"draws\": 796, \"mu_intercept_per_group\": 4.64376974105835, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 1, \"draws\": 797, \"mu_intercept_per_group\": 4.733599662780762, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 1, \"draws\": 798, \"mu_intercept_per_group\": 3.219022750854492, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 1, \"draws\": 799, \"mu_intercept_per_group\": 3.4451076984405518, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": 5.491110324859619, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": 4.608251571655273, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": 4.5350141525268555, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": 5.613311767578125, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": 5.084421634674072, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": 4.786646366119385, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": 9.293766975402832, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": 7.161080837249756, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": 8.596720695495605, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": 5.115427494049072, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": 5.56956148147583, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": 4.364606857299805, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": 4.467990398406982, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": 5.342655181884766, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": 5.058698654174805, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": 4.9615631103515625, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": 2.5958685874938965, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": 2.4960758686065674, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": 2.4610393047332764, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": 2.4982235431671143, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": 2.4394071102142334, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": 2.537140369415283, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": 2.3533613681793213, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": 3.63181209564209, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": 3.314380645751953, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": 3.2616846561431885, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": 3.5589420795440674, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": 3.1350975036621094, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": 4.058241367340088, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": 3.8854103088378906, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": 3.547527313232422, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": 3.7414751052856445, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": 3.782675266265869, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": 5.020786762237549, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": 3.291421413421631, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": 2.081432580947876, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": 1.862257957458496, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": 3.4072840213775635, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": 4.091591835021973, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": 3.7244722843170166, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": 4.76419734954834, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": 3.975062608718872, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": 1.747851014137268, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": 2.091777801513672, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": 3.1262598037719727, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": 3.5785813331604004, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": 6.093879222869873, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": 4.884094715118408, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": 5.854949474334717, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": 6.014701843261719, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": 7.064685821533203, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": 5.402772426605225, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": 7.495841979980469, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": 5.464284896850586, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": 5.662315845489502, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": 5.534363269805908, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": 5.918851375579834, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": 6.602722644805908, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": 4.246342182159424, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": 4.559049129486084, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": 5.992889881134033, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": 4.378774642944336, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": 4.725996017456055, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": 4.600977897644043, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": 6.1798787117004395, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": 6.387662410736084, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": 4.864864349365234, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": 4.355860710144043, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": 4.33195161819458, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": 4.197412967681885, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": 4.175170421600342, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": 4.333992958068848, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": 4.02144193649292, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": 4.148867130279541, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": 3.6105947494506836, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": 5.295596599578857, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": 5.391640663146973, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": 5.68848991394043, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": 4.669758319854736, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": 4.554072380065918, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": 5.279735088348389, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": 4.245957374572754, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": 3.7698168754577637, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": 3.2392425537109375, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": 3.0758183002471924, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": 2.8303635120391846, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": 2.6560277938842773, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": 4.353312015533447, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": 4.411088466644287, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": 4.539573669433594, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": 6.244691848754883, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": 5.140427112579346, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": 5.179046630859375, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": 6.834153652191162, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": 3.093762159347534, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": 4.031715393066406, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": 3.667315721511841, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": 2.9108119010925293, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": 4.5295867919921875, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": 3.396977663040161, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": 4.09788703918457, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": 3.516728401184082, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": 3.133629322052002, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": 3.7026305198669434, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": 4.783272743225098, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": 4.3672308921813965, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": 4.026648044586182, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": 4.888004302978516, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": 4.7078447341918945, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": 5.095430850982666, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": 5.926361083984375, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": 5.27025032043457, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": 5.741665840148926, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": 5.278299808502197, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": 5.016388893127441, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": 4.929328441619873, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": 4.474250316619873, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": 4.431046009063721, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": 3.7500417232513428, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": 5.419310569763184, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": 5.305386066436768, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": 5.5862274169921875, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": 3.5419721603393555, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": 3.7006676197052, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": 3.707317590713501, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": 3.1106138229370117, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": 3.9614832401275635, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": 4.272961139678955, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": 4.057682037353516, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": 3.880499839782715, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": 4.666107654571533, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": 4.077410697937012, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": 3.557166814804077, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": 2.5642025470733643, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": 2.0860342979431152, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": 2.380864381790161, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": 3.2771880626678467, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": 3.5020649433135986, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": 3.563021421432495, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": 2.6842217445373535, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": 3.2811901569366455, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": 2.912423849105835, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": 2.701500415802002, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": 2.7096304893493652, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": 2.8910064697265625, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": 3.6370046138763428, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": 4.026036739349365, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": 3.294090509414673, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": 3.5355420112609863, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": 3.7049002647399902, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": 3.3141238689422607, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": 4.319262981414795, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": 4.656495094299316, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": 4.943360328674316, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": 4.519351005554199, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": 3.4964945316314697, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": 4.255041599273682, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": 6.332934379577637, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": 5.90041446685791, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": 4.392333984375, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": 4.219803333282471, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": 2.9108667373657227, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": 3.3257696628570557, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": 3.127373218536377, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": 3.7142581939697266, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": 3.5785460472106934, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": 3.9483888149261475, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": 4.048152446746826, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": 3.6752192974090576, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": 4.610559940338135, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": 4.561591148376465, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": 3.740049362182617, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": 5.223349094390869, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": 2.6414544582366943, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": 1.9985600709915161, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": 2.906783103942871, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": 2.397284984588623, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": 2.934694528579712, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": 2.3697898387908936, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": 2.529407262802124, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": 2.1891438961029053, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": 4.32611608505249, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": 3.2201554775238037, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": 3.5281007289886475, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": 3.7170186042785645, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": 3.0316524505615234, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": 5.1412739753723145, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": 7.566197395324707, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": 6.7184529304504395, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": 6.8235955238342285, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": 6.301156520843506, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": 6.02409553527832, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": 7.751801013946533, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": 5.251357555389404, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": 7.191341876983643, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": 5.190541744232178, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": 5.883517742156982, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": 7.087972164154053, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": 5.936930179595947, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": 6.331014633178711, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": 3.2800588607788086, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": 4.679605960845947, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": 4.592977523803711, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": 4.128255367279053, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": 4.987798690795898, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": 5.096523761749268, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": 3.047868013381958, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": 4.088223934173584, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": 4.297848701477051, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": 6.640705108642578, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": 6.437690734863281, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": 6.879817008972168, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": 4.508017539978027, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": 4.036153316497803, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": 6.186410903930664, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": 4.824279308319092, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": 5.773669719696045, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": 3.681303024291992, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": 3.634427070617676, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": 4.200300693511963, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": 3.3543450832366943, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": 2.0075876712799072, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": 2.3394100666046143, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": 3.264335870742798, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": 3.6986734867095947, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": 2.6638035774230957, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": 2.8996636867523193, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": 3.088176965713501, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": 3.446903705596924, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": 4.461012840270996, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": 4.348775863647461, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": 4.152603626251221, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": 4.213436603546143, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": 3.958171844482422, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": 4.329267978668213, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": 2.9667346477508545, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": 3.5249674320220947, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": 3.6754703521728516, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": 3.030439853668213, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": 3.469181537628174, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": 2.9500489234924316, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": 3.748983383178711, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": 2.4041249752044678, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": 4.048110485076904, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": 4.857947826385498, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": 5.557613372802734, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": 3.7322728633880615, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": 3.8943071365356445, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": 3.658147096633911, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": 3.5952506065368652, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": 3.8224427700042725, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": 6.144280910491943, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": 6.551680088043213, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": 5.266688823699951, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": 6.759881019592285, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": 6.814666271209717, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": 5.998313903808594, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": 7.0044403076171875, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": 7.791937828063965, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": 6.612525463104248, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": 6.851400852203369, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": 6.900821685791016, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": 5.489501953125, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": 9.382261276245117, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": 6.580254554748535, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": 6.444807052612305, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": 6.7032294273376465, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": 7.100037574768066, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": 4.410199165344238, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": 5.954219818115234, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": 5.964581489562988, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": 6.176028251647949, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": 4.676859378814697, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": 4.938149452209473, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": 4.120901107788086, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": 3.83073091506958, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": 3.967550039291382, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": 4.787783622741699, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": 5.175476551055908, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": 3.156834125518799, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": 3.3561766147613525, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": 3.3368918895721436, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": 3.6965553760528564, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": 4.746114730834961, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": 5.252532005310059, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": 5.83026647567749, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": 6.620624542236328, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": 5.966211318969727, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": 6.085444450378418, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": 5.303489685058594, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": 5.4981889724731445, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": 4.475924015045166, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": 4.802462577819824, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": 4.703258037567139, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": 3.4304277896881104, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": 3.5247039794921875, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": 2.580585241317749, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": 1.5453064441680908, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": 1.667297601699829, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": 3.2300260066986084, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": 2.3366360664367676, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": 2.3839547634124756, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": 2.2515010833740234, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": 3.295557975769043, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": 2.5105440616607666, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": 3.958634853363037, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": 3.3557653427124023, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": 3.366347312927246, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": 3.047145366668701, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": 2.7050068378448486, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": 3.1370880603790283, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": 4.125575542449951, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": 3.861391305923462, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": 4.768209457397461, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": 4.754197597503662, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": 4.458795547485352, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": 3.940443515777588, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": 3.8506624698638916, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": 4.427637100219727, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": 3.5244362354278564, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": 4.3285603523254395, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": 4.426497936248779, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": 4.2545342445373535, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": 4.237994194030762, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": 5.044897556304932, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": 4.107949256896973, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": 5.3017144203186035, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": 4.585388660430908, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": 4.627035140991211, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": 5.12982177734375, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": 5.71134614944458, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": 5.623270034790039, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": 5.446824550628662, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": 5.201445579528809, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": 4.401966094970703, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": 3.5503900051116943, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": 3.3222975730895996, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": 3.668436288833618, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": 3.6916847229003906, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": 3.888349771499634, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": 2.5400924682617188, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": 2.51289963722229, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": 1.8932071924209595, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": 3.0338363647460938, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": 3.7777488231658936, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": 3.4383022785186768, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": 3.8088135719299316, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": 3.893726110458374, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": 4.174651622772217, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": 4.251948356628418, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": 6.4887800216674805, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": 7.548005104064941, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": 6.265397548675537, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": 8.23094367980957, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": 7.393285751342773, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": 6.63418436050415, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": 6.433682918548584, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": 6.728479385375977, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": 5.757619857788086, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": 5.83036994934082, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": 4.3781561851501465, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": 3.8585398197174072, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": 5.591882228851318, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": 5.7432427406311035, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": 5.360896110534668, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": 6.30830192565918, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": 6.27955436706543, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": 6.620069980621338, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": 5.607804775238037, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": 5.49064826965332, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": 6.435279846191406, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": 5.566745758056641, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": 6.198448181152344, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": 5.801583290100098, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": 4.968048572540283, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": 4.327708721160889, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": 6.702013969421387, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": 6.7603759765625, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": 5.6820902824401855, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": 5.767344951629639, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": 5.349858283996582, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": 5.260830879211426, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": 5.538628101348877, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": 7.7460527420043945, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": 7.516079425811768, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": 7.4638261795043945, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": 6.623555660247803, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": 8.902355194091797, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": 5.046901226043701, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": 6.996097564697266, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": 4.920955181121826, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": 6.491883754730225, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": 5.515554428100586, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": 5.7280426025390625, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": 6.378855228424072, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": 4.966180801391602, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": 5.77947998046875, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": 6.0489349365234375, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": 5.202733516693115, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": 4.481355667114258, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": 5.845652103424072, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": 5.245207786560059, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": 5.368634223937988, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": 5.013961315155029, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": 5.297046184539795, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": 5.586629867553711, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": 5.694199085235596, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": 5.765579700469971, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": 5.668144702911377, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": 5.647345542907715, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": 5.328804016113281, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": 4.271951198577881, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": 4.412493705749512, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": 4.4972243309021, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": 4.296200752258301, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": 5.5701398849487305, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": 5.189590930938721, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": 3.8003997802734375, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": 5.426905155181885, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": 5.660933017730713, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": 5.522150039672852, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": 5.131476879119873, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": 5.406421184539795, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": 5.193324565887451, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": 5.340524196624756, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": 5.364480018615723, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": 5.409587383270264, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": 4.039460182189941, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": 3.9045798778533936, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": 4.943999290466309, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": 4.5634074211120605, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": 4.4729509353637695, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": 3.0868189334869385, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": 2.9245755672454834, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": 3.52297043800354, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": 4.597667217254639, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": 4.870513439178467, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": 4.167374134063721, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": 3.8120315074920654, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": 5.156826972961426, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": 4.7151923179626465, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": 6.651610374450684, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": 6.274223327636719, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": 6.504261016845703, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": 6.577728748321533, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": 6.947271823883057, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": 5.786006450653076, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": 9.657309532165527, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": 7.404240131378174, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": 6.107522964477539, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": 10.679645538330078, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": 7.1955671310424805, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": 6.873592376708984, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": 6.592921733856201, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": 6.080991268157959, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": 5.931951999664307, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": 5.961352348327637, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": 5.9986090660095215, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": 4.550329208374023, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": 6.2415666580200195, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": 5.406833171844482, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": 5.324390888214111, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": 5.3886799812316895, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": 5.406778812408447, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": 5.878503799438477, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": 4.205962181091309, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": 7.194407939910889, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": 4.935629367828369, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": 4.65464973449707, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": 4.966233253479004, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": 5.368403434753418, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": 4.209583759307861, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": 6.207740783691406, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": 4.414272308349609, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": 5.652195453643799, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": 4.690794944763184, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": 5.906421184539795, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": 5.317846298217773, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": 4.780796527862549, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": 4.942859172821045, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": 4.798429489135742, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": 4.394049167633057, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": 3.456979990005493, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": 3.584721326828003, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": 3.442572832107544, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": 2.917215585708618, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": 3.57055926322937, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": 4.8423638343811035, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": 5.2570929527282715, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": 5.503917694091797, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": 5.463780403137207, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": 4.663094520568848, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": 4.048736572265625, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": 5.004655361175537, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": 3.7998313903808594, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": 1.6356139183044434, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": 3.1054952144622803, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": 2.6921005249023438, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": 2.7689566612243652, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": 2.8544137477874756, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": 3.4097845554351807, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": 3.1074182987213135, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": 3.5512430667877197, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": 3.9228603839874268, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": 2.438718557357788, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": 3.543612241744995, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": 4.064530849456787, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": 3.4838709831237793, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": 3.7803332805633545, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": 4.237429618835449, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": 4.240047454833984, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": 4.291396141052246, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": 4.138537883758545, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": 4.7361297607421875, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": 3.878976345062256, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": 4.005259990692139, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": 3.9395391941070557, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": 4.705358505249023, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": 2.9153003692626953, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": 2.824979305267334, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": 3.5340774059295654, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": 3.2544548511505127, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": 2.9621636867523193, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": 4.1925048828125, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": 3.8266398906707764, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": 3.940711498260498, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": 3.2523672580718994, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": 4.008778095245361, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": 4.391695976257324, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": 2.8049187660217285, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": 3.221400737762451, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": 4.724935531616211, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": 5.2381510734558105, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": 5.888681888580322, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": 6.345682621002197, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": 5.889353275299072, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": 5.6807122230529785, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": 3.619107246398926, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": 3.821631669998169, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": 4.484899997711182, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": 4.641234397888184, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": 4.745833396911621, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": 4.960393905639648, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": 3.4788060188293457, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": 3.5747056007385254, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": 2.8000786304473877, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": 3.452352285385132, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": 3.0523085594177246, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": 4.351971626281738, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": 3.7042829990386963, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": 3.4781746864318848, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": 3.807560443878174, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": 3.1541128158569336, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": 3.8858628273010254, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": 2.6981394290924072, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": 4.086287498474121, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": 3.8020668029785156, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": 3.846501588821411, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": 3.486720561981201, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": 3.459459066390991, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": 4.399269104003906, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": 4.056945323944092, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": 4.724264621734619, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": 4.494024276733398, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": 4.009613037109375, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": 5.009897708892822, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": 3.450845956802368, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": 4.138195991516113, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": 3.6478404998779297, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": 2.6929261684417725, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": 3.959306240081787, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": 3.4555201530456543, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": 3.3324387073516846, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": 2.9456076622009277, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": 2.574554204940796, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": 2.5793683528900146, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": 2.9792909622192383, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": 3.1035149097442627, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": 3.777956962585449, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": 3.096311092376709, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": 5.682947635650635, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": 4.834072113037109, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": 4.470929145812988, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": 4.556861877441406, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": 4.460587024688721, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": 4.873969078063965, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": 3.723194122314453, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": 3.9419493675231934, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": 4.209687232971191, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": 3.4153683185577393, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": 5.3706889152526855, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": 5.375904560089111, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": 3.7741763591766357, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": 4.835967063903809, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": 4.4426679611206055, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": 4.656981468200684, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": 5.935782432556152, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": 5.684715747833252, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": 4.8739471435546875, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": 5.808054447174072, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": 4.3022308349609375, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": 3.3972008228302, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": 5.253214359283447, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": 4.8810343742370605, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": 4.167862415313721, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": 4.1084771156311035, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": 3.867013692855835, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": 6.902225494384766, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": 5.1656694412231445, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": 5.715981483459473, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": 4.946696758270264, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": 5.855330944061279, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": 5.69160795211792, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": 5.651338577270508, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": 5.146207332611084, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": 5.319007396697998, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": 4.514697551727295, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": 5.277587413787842, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": 6.578232765197754, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": 6.389302730560303, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": 4.207660675048828, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": 6.619046211242676, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": 3.7406773567199707, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": 5.011325836181641, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": 4.924465179443359, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": 4.926854133605957, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": 5.175532341003418, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": 5.571560859680176, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": 4.150428295135498, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": 3.706332206726074, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": 3.909287452697754, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": 3.404649496078491, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": 3.3119618892669678, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": 3.203073501586914, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": 3.1790764331817627, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": 3.999551773071289, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": 4.1692328453063965, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": 5.796780109405518, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": 5.709681034088135, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": 5.611907958984375, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 640, \"mu_intercept_per_group\": 5.211333274841309, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 641, \"mu_intercept_per_group\": 4.461251258850098, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 642, \"mu_intercept_per_group\": 5.280077934265137, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 643, \"mu_intercept_per_group\": 4.923666477203369, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 644, \"mu_intercept_per_group\": 4.537814617156982, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 645, \"mu_intercept_per_group\": 4.3949055671691895, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 646, \"mu_intercept_per_group\": 3.8956353664398193, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 647, \"mu_intercept_per_group\": 2.684389591217041, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 648, \"mu_intercept_per_group\": 2.732252597808838, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 649, \"mu_intercept_per_group\": 3.007965087890625, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 650, \"mu_intercept_per_group\": 2.753089427947998, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 651, \"mu_intercept_per_group\": 2.7792530059814453, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 652, \"mu_intercept_per_group\": 2.8297929763793945, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 653, \"mu_intercept_per_group\": 3.8797223567962646, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 654, \"mu_intercept_per_group\": 2.6339564323425293, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 655, \"mu_intercept_per_group\": 2.636838912963867, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 656, \"mu_intercept_per_group\": 2.8639883995056152, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 657, \"mu_intercept_per_group\": 3.6777994632720947, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 658, \"mu_intercept_per_group\": 4.197859287261963, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 659, \"mu_intercept_per_group\": 3.3466241359710693, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 660, \"mu_intercept_per_group\": 3.4635214805603027, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 661, \"mu_intercept_per_group\": 3.1615991592407227, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 662, \"mu_intercept_per_group\": 2.712599515914917, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 663, \"mu_intercept_per_group\": 3.0102479457855225, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 664, \"mu_intercept_per_group\": 2.9595401287078857, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 665, \"mu_intercept_per_group\": 2.98626446723938, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 666, \"mu_intercept_per_group\": 5.00075626373291, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 667, \"mu_intercept_per_group\": 3.335627317428589, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 668, \"mu_intercept_per_group\": 3.2581162452697754, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 669, \"mu_intercept_per_group\": 3.1416029930114746, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 670, \"mu_intercept_per_group\": 2.7905285358428955, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 671, \"mu_intercept_per_group\": 3.794146776199341, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 672, \"mu_intercept_per_group\": 4.025572776794434, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 673, \"mu_intercept_per_group\": 3.045529365539551, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 674, \"mu_intercept_per_group\": 3.3686654567718506, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 675, \"mu_intercept_per_group\": 3.1644043922424316, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 676, \"mu_intercept_per_group\": 3.2702417373657227, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 677, \"mu_intercept_per_group\": 3.2466115951538086, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 678, \"mu_intercept_per_group\": 2.500688076019287, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 679, \"mu_intercept_per_group\": 3.151276111602783, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 680, \"mu_intercept_per_group\": 2.2550501823425293, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 681, \"mu_intercept_per_group\": 3.0167839527130127, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 682, \"mu_intercept_per_group\": 2.9916396141052246, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 683, \"mu_intercept_per_group\": 4.466655731201172, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 684, \"mu_intercept_per_group\": 4.33569860458374, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 685, \"mu_intercept_per_group\": 4.414296627044678, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 686, \"mu_intercept_per_group\": 5.669224262237549, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 687, \"mu_intercept_per_group\": 5.275136947631836, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 688, \"mu_intercept_per_group\": 6.278802394866943, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 689, \"mu_intercept_per_group\": 5.996719837188721, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 690, \"mu_intercept_per_group\": 5.660432815551758, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 691, \"mu_intercept_per_group\": 5.019646167755127, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 692, \"mu_intercept_per_group\": 7.006028175354004, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 693, \"mu_intercept_per_group\": 6.933067321777344, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 694, \"mu_intercept_per_group\": 7.0349016189575195, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 695, \"mu_intercept_per_group\": 4.880467414855957, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 696, \"mu_intercept_per_group\": 7.567882537841797, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 697, \"mu_intercept_per_group\": 6.169914722442627, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 698, \"mu_intercept_per_group\": 6.155434608459473, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 699, \"mu_intercept_per_group\": 6.684178829193115, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 700, \"mu_intercept_per_group\": 7.376518249511719, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 701, \"mu_intercept_per_group\": 6.954663276672363, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 702, \"mu_intercept_per_group\": 7.744585990905762, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 703, \"mu_intercept_per_group\": 6.764809608459473, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 704, \"mu_intercept_per_group\": 5.684453010559082, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 705, \"mu_intercept_per_group\": 4.355164051055908, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 706, \"mu_intercept_per_group\": 4.80187463760376, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 707, \"mu_intercept_per_group\": 4.526444435119629, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 708, \"mu_intercept_per_group\": 5.031768798828125, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 709, \"mu_intercept_per_group\": 3.5492420196533203, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 710, \"mu_intercept_per_group\": 5.893328666687012, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 711, \"mu_intercept_per_group\": 5.060178756713867, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 712, \"mu_intercept_per_group\": 5.100919723510742, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 713, \"mu_intercept_per_group\": 3.766498565673828, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 714, \"mu_intercept_per_group\": 4.657840728759766, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 715, \"mu_intercept_per_group\": 4.057231426239014, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 716, \"mu_intercept_per_group\": 5.584107398986816, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 717, \"mu_intercept_per_group\": 5.863407611846924, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 718, \"mu_intercept_per_group\": 6.278954982757568, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 719, \"mu_intercept_per_group\": 7.0928826332092285, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 720, \"mu_intercept_per_group\": 7.878025054931641, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 721, \"mu_intercept_per_group\": 5.659267425537109, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 722, \"mu_intercept_per_group\": 5.6130757331848145, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 723, \"mu_intercept_per_group\": 6.6801533699035645, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 724, \"mu_intercept_per_group\": 6.820883750915527, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 725, \"mu_intercept_per_group\": 6.48648738861084, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 726, \"mu_intercept_per_group\": 7.0196099281311035, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 727, \"mu_intercept_per_group\": 5.900278568267822, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 728, \"mu_intercept_per_group\": 7.304617404937744, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 729, \"mu_intercept_per_group\": 5.84628438949585, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 730, \"mu_intercept_per_group\": 6.8072590827941895, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 731, \"mu_intercept_per_group\": 4.486907958984375, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 732, \"mu_intercept_per_group\": 4.4848313331604, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 733, \"mu_intercept_per_group\": 6.2616496086120605, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 734, \"mu_intercept_per_group\": 5.277303695678711, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 735, \"mu_intercept_per_group\": 5.248604774475098, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 736, \"mu_intercept_per_group\": 4.841206073760986, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 737, \"mu_intercept_per_group\": 4.006636142730713, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 738, \"mu_intercept_per_group\": 4.423091888427734, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 739, \"mu_intercept_per_group\": 4.585536479949951, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 740, \"mu_intercept_per_group\": 4.7240824699401855, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 741, \"mu_intercept_per_group\": 4.177626609802246, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 742, \"mu_intercept_per_group\": 4.1754374504089355, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 743, \"mu_intercept_per_group\": 4.815305233001709, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 744, \"mu_intercept_per_group\": 4.550400257110596, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 745, \"mu_intercept_per_group\": 4.8960065841674805, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 746, \"mu_intercept_per_group\": 5.105051040649414, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 747, \"mu_intercept_per_group\": 5.0693583488464355, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 748, \"mu_intercept_per_group\": 3.3275763988494873, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 749, \"mu_intercept_per_group\": 3.6561036109924316, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 750, \"mu_intercept_per_group\": 3.9944586753845215, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 751, \"mu_intercept_per_group\": 4.166662693023682, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 752, \"mu_intercept_per_group\": 3.9349875450134277, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 753, \"mu_intercept_per_group\": 5.158694267272949, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 754, \"mu_intercept_per_group\": 4.560831546783447, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 755, \"mu_intercept_per_group\": 4.570562839508057, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 756, \"mu_intercept_per_group\": 4.742827892303467, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 757, \"mu_intercept_per_group\": 5.146974086761475, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 758, \"mu_intercept_per_group\": 4.496945858001709, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 759, \"mu_intercept_per_group\": 4.481623649597168, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 760, \"mu_intercept_per_group\": 5.191347599029541, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 2, \"draws\": 761, \"mu_intercept_per_group\": 4.327315807342529, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 2, \"draws\": 762, \"mu_intercept_per_group\": 4.602949142456055, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 2, \"draws\": 763, \"mu_intercept_per_group\": 3.8582258224487305, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 2, \"draws\": 764, \"mu_intercept_per_group\": 6.171248435974121, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 2, \"draws\": 765, \"mu_intercept_per_group\": 6.555273056030273, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 2, \"draws\": 766, \"mu_intercept_per_group\": 7.011019229888916, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 2, \"draws\": 767, \"mu_intercept_per_group\": 6.582667827606201, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 2, \"draws\": 768, \"mu_intercept_per_group\": 6.7848358154296875, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 2, \"draws\": 769, \"mu_intercept_per_group\": 6.34314489364624, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 2, \"draws\": 770, \"mu_intercept_per_group\": 6.395041465759277, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 2, \"draws\": 771, \"mu_intercept_per_group\": 6.737040996551514, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 2, \"draws\": 772, \"mu_intercept_per_group\": 6.18736457824707, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 2, \"draws\": 773, \"mu_intercept_per_group\": 3.8077199459075928, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 2, \"draws\": 774, \"mu_intercept_per_group\": 3.844346284866333, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 2, \"draws\": 775, \"mu_intercept_per_group\": 3.9347188472747803, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 2, \"draws\": 776, \"mu_intercept_per_group\": 3.878713846206665, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 2, \"draws\": 777, \"mu_intercept_per_group\": 4.470711708068848, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 2, \"draws\": 778, \"mu_intercept_per_group\": 4.4401445388793945, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 2, \"draws\": 779, \"mu_intercept_per_group\": 4.743907928466797, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 2, \"draws\": 780, \"mu_intercept_per_group\": 5.137904167175293, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 2, \"draws\": 781, \"mu_intercept_per_group\": 4.575784683227539, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 2, \"draws\": 782, \"mu_intercept_per_group\": 5.100752353668213, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 2, \"draws\": 783, \"mu_intercept_per_group\": 4.36627721786499, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 2, \"draws\": 784, \"mu_intercept_per_group\": 4.449328899383545, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 2, \"draws\": 785, \"mu_intercept_per_group\": 4.167068958282471, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 2, \"draws\": 786, \"mu_intercept_per_group\": 4.467510223388672, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 2, \"draws\": 787, \"mu_intercept_per_group\": 3.4681124687194824, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 2, \"draws\": 788, \"mu_intercept_per_group\": 4.948057174682617, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 2, \"draws\": 789, \"mu_intercept_per_group\": 4.006404399871826, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 2, \"draws\": 790, \"mu_intercept_per_group\": 4.6797776222229, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 2, \"draws\": 791, \"mu_intercept_per_group\": 4.131082057952881, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 2, \"draws\": 792, \"mu_intercept_per_group\": 3.9904634952545166, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 2, \"draws\": 793, \"mu_intercept_per_group\": 2.6224265098571777, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 2, \"draws\": 794, \"mu_intercept_per_group\": 3.7310380935668945, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 2, \"draws\": 795, \"mu_intercept_per_group\": 3.559307336807251, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 2, \"draws\": 796, \"mu_intercept_per_group\": 4.697439670562744, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 2, \"draws\": 797, \"mu_intercept_per_group\": 4.06179666519165, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 2, \"draws\": 798, \"mu_intercept_per_group\": 4.324584007263184, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 2, \"draws\": 799, \"mu_intercept_per_group\": 4.332640171051025, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": 6.372817516326904, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": 7.798015594482422, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": 8.201911926269531, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": 6.890011310577393, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": 7.043295860290527, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": 8.303194999694824, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": 12.465627670288086, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": 10.088950157165527, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": 8.968477249145508, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": 6.109943866729736, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": 6.23734188079834, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": 6.553068161010742, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": 6.496861457824707, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": 5.663347244262695, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": 7.2847394943237305, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": 6.924831867218018, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": 3.4202866554260254, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": 3.1852829456329346, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": 3.2430005073547363, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": 2.9972994327545166, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": 2.312472105026245, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": 2.773881196975708, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": 3.0383317470550537, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": 4.56336784362793, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": 3.970856189727783, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": 4.356171131134033, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": 3.895524024963379, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": 4.265542984008789, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": 4.625636100769043, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": 4.366748332977295, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": 4.134594917297363, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": 3.7053589820861816, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": 3.4199376106262207, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": 5.388879299163818, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": 3.669590950012207, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": 3.194597005844116, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": 3.086132287979126, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": 4.7542290687561035, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": 5.870779514312744, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": 5.455431938171387, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": 5.167360782623291, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": 5.374492645263672, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": 3.22111439704895, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": 3.009063720703125, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": 4.1473236083984375, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": 4.185036659240723, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": 8.290266990661621, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": 8.32822322845459, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": 9.767133712768555, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": 9.396679878234863, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": 7.868791103363037, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": 7.556901931762695, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": 8.178389549255371, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": 6.497574329376221, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": 6.615699768066406, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": 6.044878005981445, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": 8.003179550170898, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": 7.459864139556885, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": 8.212385177612305, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": 8.054081916809082, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": 6.179901123046875, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": 5.801980495452881, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": 5.194498538970947, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": 5.74112606048584, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": 5.615077495574951, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": 5.805073261260986, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": 4.117743015289307, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": 5.0657243728637695, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": 5.116894721984863, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": 5.8884992599487305, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": 4.881086349487305, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": 4.77980899810791, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": 5.321953296661377, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": 5.672936916351318, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": 4.955756187438965, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": 6.268511772155762, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": 6.304672718048096, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": 6.701750755310059, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": 6.12089729309082, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": 6.509214878082275, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": 6.074277400970459, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": 4.225059509277344, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": 4.2968668937683105, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": 3.18095064163208, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": 4.5510711669921875, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": 4.107351779937744, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": 4.085229873657227, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": 6.377809047698975, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": 6.07235050201416, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": 7.29680061340332, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": 5.87687873840332, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": 7.758587837219238, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": 6.163783550262451, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": 9.533560752868652, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": 3.3657991886138916, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": 4.911524295806885, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": 3.445310592651367, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": 3.7511043548583984, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": 6.213600158691406, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": 5.066411972045898, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": 4.041198253631592, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": 5.171648979187012, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": 4.578385353088379, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": 4.89188814163208, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": 5.35080099105835, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": 6.337993621826172, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": 5.827486991882324, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": 5.906543254852295, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": 6.696115970611572, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": 7.0991082191467285, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": 6.646178722381592, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": 7.463964462280273, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": 7.356168746948242, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": 6.7420501708984375, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": 6.394396781921387, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": 6.637855052947998, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": 6.221904754638672, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": 5.709245204925537, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": 6.96919584274292, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": 7.18173885345459, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": 7.311249732971191, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": 5.837635040283203, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": 3.615079879760742, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": 3.8174021244049072, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": 3.997283458709717, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": 4.602899551391602, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": 4.200929641723633, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": 4.346896648406982, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": 5.643089294433594, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": 5.3049235343933105, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": 3.9735589027404785, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": 5.1665544509887695, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": 5.121788024902344, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": 3.0021212100982666, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": 2.6748785972595215, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": 3.0472230911254883, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": 4.586276054382324, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": 3.888882875442505, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": 4.149841785430908, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": 3.764192581176758, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": 4.210570335388184, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": 3.9225993156433105, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": 4.116454601287842, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": 2.8813185691833496, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": 2.989905595779419, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": 5.376457691192627, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": 4.609072685241699, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": 4.790755748748779, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": 4.624814510345459, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": 4.9297003746032715, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": 3.4772746562957764, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": 5.654822826385498, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": 5.198472499847412, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": 5.78829288482666, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": 5.924619197845459, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": 4.365190029144287, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": 4.572319507598877, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": 6.845259189605713, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": 7.814947128295898, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": 8.236522674560547, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": 4.0092244148254395, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": 4.716495513916016, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": 4.197831630706787, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": 4.036447048187256, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": 4.784811019897461, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": 4.721908092498779, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": 4.068602085113525, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": 4.697247505187988, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": 5.450225353240967, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": 4.838786602020264, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": 4.866490364074707, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": 6.102753162384033, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": 5.265790939331055, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": 2.6652650833129883, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": 3.4195988178253174, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": 3.0922560691833496, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": 2.980369806289673, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": 2.8264710903167725, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": 3.141918659210205, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": 3.108445644378662, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": 3.277021646499634, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": 5.086787223815918, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": 4.778462886810303, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": 4.628090858459473, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": 4.899940013885498, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": 4.902947425842285, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": 5.7574357986450195, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": 8.306953430175781, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": 8.738258361816406, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": 7.725285053253174, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": 7.221996307373047, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": 8.59239387512207, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": 7.986995697021484, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": 7.909682273864746, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": 8.334005355834961, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": 7.332986831665039, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": 7.437364101409912, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": 7.023005485534668, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": 8.51624870300293, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": 7.924102783203125, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": 5.588596820831299, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": 4.463504791259766, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": 6.122378349304199, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": 5.331482887268066, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": 6.247829914093018, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": 6.042479991912842, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": 4.91115665435791, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": 4.3010053634643555, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": 5.53366756439209, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": 8.284704208374023, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": 8.819925308227539, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": 8.731829643249512, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": 6.706535339355469, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": 6.322098731994629, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": 6.977673530578613, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": 6.6778693199157715, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": 6.403573036193848, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": 5.938631534576416, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": 6.126518726348877, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": 3.820300579071045, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": 5.01495361328125, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": 3.3613944053649902, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": 2.9649128913879395, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": 4.06849479675293, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": 3.6852872371673584, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": 3.0551888942718506, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": 4.048690319061279, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": 3.474236011505127, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": 4.185314178466797, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": 5.580507755279541, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": 4.53754186630249, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": 4.606260299682617, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": 5.3229827880859375, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": 4.963900566101074, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": 5.381051063537598, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": 4.131528854370117, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": 3.6775424480438232, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": 3.325932025909424, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": 5.066133975982666, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": 3.4035608768463135, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": 4.943119525909424, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": 3.059175729751587, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": 4.727502822875977, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": 6.5876688957214355, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": 6.5220184326171875, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": 6.389976978302002, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": 4.571046352386475, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": 4.619311809539795, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": 5.014915943145752, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": 4.483795642852783, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": 4.557519912719727, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": 7.296747207641602, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": 7.028537273406982, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": 7.641228675842285, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": 10.049551010131836, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": 10.022098541259766, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": 9.424578666687012, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": 9.18696403503418, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": 9.980940818786621, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": 8.27736759185791, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": 9.53046989440918, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": 9.46872615814209, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": 8.159786224365234, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": 8.960057258605957, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": 8.156641960144043, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": 7.489951133728027, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": 9.285981178283691, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": 7.715997695922852, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": 7.103480815887451, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": 7.139054298400879, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": 7.910886764526367, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": 7.083974361419678, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": 6.468080997467041, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": 6.494182109832764, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": 4.449218273162842, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": 5.191504001617432, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": 5.679626941680908, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": 5.587284088134766, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": 6.894678592681885, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": 5.624899864196777, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": 5.59102725982666, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": 6.009110927581787, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": 5.992033004760742, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": 5.685347557067871, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": 6.219442367553711, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": 7.706079483032227, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": 7.201580047607422, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": 6.502054691314697, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": 6.55487585067749, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": 7.502823829650879, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": 7.124013900756836, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": 5.363536834716797, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": 6.380829334259033, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": 6.332576751708984, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": 3.887359142303467, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": 4.75024938583374, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": 2.8549108505249023, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": 2.152283191680908, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": 2.1196506023406982, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": 3.974606513977051, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": 3.0927581787109375, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": 3.2855963706970215, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": 3.139484167098999, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": 3.318880319595337, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": 4.152376651763916, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": 4.135140895843506, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": 4.685494422912598, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": 4.334017276763916, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": 4.059706687927246, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": 3.8186233043670654, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": 4.275460720062256, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": 5.851537704467773, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": 6.304200649261475, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": 5.779279708862305, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": 5.679065227508545, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": 5.094315052032471, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": 4.9163618087768555, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": 4.676615238189697, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": 3.6408047676086426, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": 6.752710819244385, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": 3.66607928276062, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": 5.600276947021484, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": 5.126420021057129, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": 5.236746788024902, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": 6.117652416229248, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": 5.358564853668213, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": 6.236123085021973, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": 6.630967140197754, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": 6.199634552001953, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": 5.911494255065918, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": 7.271186828613281, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": 8.023597717285156, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": 7.055609703063965, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": 6.981822967529297, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": 4.316717624664307, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": 4.5473833084106445, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": 4.275480270385742, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": 4.60748291015625, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": 4.408933639526367, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": 4.145960807800293, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": 2.6843841075897217, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": 3.379284381866455, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": 2.135161876678467, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": 3.7851791381835938, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": 3.848174810409546, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": 4.5506696701049805, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": 4.612029552459717, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": 4.269049167633057, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": 6.309304237365723, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": 5.9391279220581055, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": 6.441128730773926, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": 8.954524040222168, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": 9.747511863708496, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": 11.638484954833984, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": 8.717535018920898, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": 8.598236083984375, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": 8.255128860473633, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": 7.411366939544678, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": 8.1741943359375, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": 8.566030502319336, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": 6.525538921356201, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": 6.298711776733398, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": 5.2424726486206055, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": 5.33679723739624, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": 6.4102911949157715, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": 8.988680839538574, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": 6.992595195770264, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": 7.621551036834717, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": 7.953612327575684, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": 6.684493064880371, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": 8.153037071228027, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": 7.354208469390869, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": 8.248141288757324, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": 6.552796840667725, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": 7.452115058898926, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": 7.404848575592041, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": 6.4207048416137695, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": 6.596434593200684, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": 7.81859016418457, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": 7.041211128234863, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": 6.9543890953063965, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": 5.879883766174316, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": 7.715909004211426, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": 9.191065788269043, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": 10.479092597961426, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": 7.541409015655518, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": 9.730222702026367, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": 9.196030616760254, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": 8.051835060119629, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": 7.4017815589904785, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": 7.66617488861084, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": 6.586638927459717, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": 6.70248556137085, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": 6.891785144805908, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": 6.434250831604004, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": 6.919911861419678, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": 6.875731468200684, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": 6.975607872009277, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": 5.826382160186768, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": 5.641814231872559, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": 7.680572986602783, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": 6.941436767578125, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": 6.030797004699707, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": 5.88323450088501, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": 6.60249662399292, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": 6.89972448348999, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": 6.447628974914551, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": 7.079176425933838, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": 6.951949596405029, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": 5.15120792388916, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": 6.3142852783203125, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": 6.2779927253723145, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": 6.133879661560059, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": 6.238668918609619, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": 5.986863136291504, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": 6.110901832580566, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": 5.779666900634766, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": 5.245981693267822, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": 6.265839576721191, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": 6.523055553436279, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": 6.0730767250061035, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": 6.564935207366943, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": 7.030528545379639, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": 5.4840087890625, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": 7.841848373413086, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": 5.894506454467773, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": 7.120850086212158, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": 6.900913715362549, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": 6.985990524291992, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": 4.192154407501221, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": 5.376739025115967, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": 5.285654067993164, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": 4.369077205657959, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": 3.128016471862793, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": 3.9915571212768555, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": 5.984132766723633, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": 4.817948818206787, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": 6.034378528594971, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": 6.166374683380127, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": 5.3792405128479, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": 7.20229959487915, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": 7.356508255004883, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": 7.580737113952637, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": 6.868556022644043, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": 8.933188438415527, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": 9.02723217010498, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": 9.170550346374512, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": 9.565688133239746, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": 9.933150291442871, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": 10.356209754943848, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": 11.299186706542969, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": 8.09616470336914, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": 8.057755470275879, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": 8.116886138916016, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": 7.006263732910156, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": 8.723069190979004, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": 7.7785234451293945, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": 4.994362831115723, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": 6.44239616394043, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": 6.954372406005859, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": 7.1200103759765625, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": 5.9589009284973145, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": 6.139529228210449, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": 7.572422504425049, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": 7.43223762512207, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": 6.73041296005249, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": 7.980677604675293, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": 5.968235015869141, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": 5.6857380867004395, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": 5.793918132781982, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": 5.868239402770996, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": 7.151503562927246, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": 6.336531639099121, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": 6.860991477966309, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": 7.389306545257568, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": 7.0904340744018555, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": 6.719387054443359, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": 6.448228359222412, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": 6.5312581062316895, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": 6.282383918762207, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": 6.497544765472412, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": 5.643086910247803, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": 4.0798659324646, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": 4.465384006500244, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": 4.622020721435547, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": 3.5081167221069336, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": 4.453481197357178, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": 5.698011875152588, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": 4.444822788238525, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": 4.4580488204956055, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": 4.667484283447266, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": 7.336151599884033, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": 5.486295700073242, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": 4.961713790893555, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": 5.246609210968018, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": 3.1124160289764404, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": 3.9397974014282227, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": 3.3889734745025635, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": 3.821014642715454, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": 3.840437889099121, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": 3.8412795066833496, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": 4.538444995880127, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": 4.292660236358643, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": 4.690988540649414, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": 4.32303524017334, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": 4.2794189453125, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": 5.2306928634643555, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": 5.197391510009766, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": 3.9695191383361816, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": 4.784024715423584, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": 6.642359733581543, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": 4.830143451690674, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": 4.672066688537598, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": 6.3242621421813965, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": 5.148505210876465, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": 5.036901950836182, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": 4.701457977294922, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": 4.178882598876953, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": 4.7439751625061035, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": 4.63011360168457, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": 4.17998743057251, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": 4.750853538513184, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": 3.3999950885772705, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": 4.611809253692627, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": 4.378335952758789, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": 5.2386369705200195, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": 5.411483287811279, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": 5.61414098739624, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": 5.399312496185303, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": 4.309813022613525, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": 3.673022508621216, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": 6.038267135620117, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": 6.931402683258057, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": 7.037639617919922, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": 6.9159722328186035, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": 7.886524677276611, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": 6.542992115020752, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": 5.6890363693237305, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": 5.439457416534424, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": 5.808444976806641, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": 5.8857421875, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": 6.540366172790527, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": 5.342748165130615, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": 6.184462547302246, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": 6.4491071701049805, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": 4.37503719329834, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": 4.096431255340576, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": 3.493915557861328, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": 5.386264324188232, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": 4.693169116973877, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": 4.270864486694336, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": 4.867702007293701, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": 4.439742565155029, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": 4.352115631103516, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": 4.505616664886475, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": 4.742751598358154, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": 4.184406280517578, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": 5.256972789764404, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": 3.818164587020874, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": 4.041019439697266, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": 5.356821537017822, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": 5.3671369552612305, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": 5.870721817016602, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": 5.524842262268066, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": 5.467594623565674, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": 7.174121379852295, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": 5.4963483810424805, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": 5.030324459075928, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": 4.82444953918457, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": 3.7589871883392334, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": 4.597790241241455, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": 5.147703647613525, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": 5.314079284667969, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": 4.405562400817871, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": 4.4875407218933105, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": 4.599557876586914, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": 4.238059997558594, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": 4.408138751983643, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": 4.521586894989014, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": 4.186000347137451, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": 7.058803558349609, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": 6.0842604637146, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": 6.343858242034912, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": 5.631422519683838, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": 5.142126083374023, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": 6.720828533172607, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": 4.242660999298096, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": 6.08359956741333, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": 3.8815929889678955, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": 5.810343265533447, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": 4.77284049987793, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": 4.713494777679443, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": 6.45425271987915, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": 4.374340057373047, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": 7.7404327392578125, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": 7.894077777862549, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": 4.912182331085205, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": 7.322635650634766, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": 5.732247352600098, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": 7.110691070556641, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": 4.438967227935791, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": 5.9720778465271, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": 4.695112228393555, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": 4.798870086669922, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": 7.165490627288818, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": 5.4017415046691895, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": 5.672310829162598, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": 7.708034515380859, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": 6.436028480529785, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": 6.249398231506348, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": 6.472283363342285, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": 6.907718658447266, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": 8.308969497680664, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": 8.023701667785645, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": 7.103206157684326, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": 7.005008220672607, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": 6.764583110809326, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": 7.182011604309082, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": 7.282787322998047, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": 6.960952281951904, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": 8.012600898742676, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": 5.764819622039795, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": 7.542036533355713, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": 6.750257968902588, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": 6.873584270477295, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": 6.044455528259277, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": 7.2592244148254395, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": 6.222452640533447, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": 5.875028610229492, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": 4.324853897094727, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": 5.109541416168213, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": 4.222133159637451, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": 4.713464736938477, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": 3.705390214920044, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": 3.686326742172241, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": 5.201413631439209, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": 4.642209053039551, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": 8.6796293258667, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": 8.618794441223145, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": 5.41340446472168, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 640, \"mu_intercept_per_group\": 7.407533645629883, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 641, \"mu_intercept_per_group\": 7.403486728668213, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 642, \"mu_intercept_per_group\": 5.859908580780029, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 643, \"mu_intercept_per_group\": 5.189518928527832, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 644, \"mu_intercept_per_group\": 6.747848033905029, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 645, \"mu_intercept_per_group\": 4.461283206939697, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 646, \"mu_intercept_per_group\": 5.7523722648620605, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 647, \"mu_intercept_per_group\": 3.1757259368896484, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 648, \"mu_intercept_per_group\": 3.449521541595459, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 649, \"mu_intercept_per_group\": 4.5059003829956055, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 650, \"mu_intercept_per_group\": 3.2806520462036133, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 651, \"mu_intercept_per_group\": 3.7332448959350586, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 652, \"mu_intercept_per_group\": 3.5176799297332764, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 653, \"mu_intercept_per_group\": 5.4727582931518555, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 654, \"mu_intercept_per_group\": 3.438347578048706, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 655, \"mu_intercept_per_group\": 3.0379433631896973, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 656, \"mu_intercept_per_group\": 2.8495776653289795, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 657, \"mu_intercept_per_group\": 4.651127815246582, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 658, \"mu_intercept_per_group\": 4.439712047576904, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 659, \"mu_intercept_per_group\": 4.510061740875244, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 660, \"mu_intercept_per_group\": 4.548348903656006, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 661, \"mu_intercept_per_group\": 3.563572883605957, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 662, \"mu_intercept_per_group\": 3.8799901008605957, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 663, \"mu_intercept_per_group\": 4.224437236785889, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 664, \"mu_intercept_per_group\": 3.622408390045166, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 665, \"mu_intercept_per_group\": 3.6747891902923584, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 666, \"mu_intercept_per_group\": 6.38543701171875, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 667, \"mu_intercept_per_group\": 4.701521396636963, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 668, \"mu_intercept_per_group\": 4.008321285247803, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 669, \"mu_intercept_per_group\": 3.6517815589904785, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 670, \"mu_intercept_per_group\": 4.2962188720703125, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 671, \"mu_intercept_per_group\": 3.9817655086517334, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 672, \"mu_intercept_per_group\": 5.560882568359375, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 673, \"mu_intercept_per_group\": 3.607111930847168, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 674, \"mu_intercept_per_group\": 4.215893268585205, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 675, \"mu_intercept_per_group\": 4.164203643798828, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 676, \"mu_intercept_per_group\": 4.165553092956543, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 677, \"mu_intercept_per_group\": 4.227351665496826, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 678, \"mu_intercept_per_group\": 4.421868324279785, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 679, \"mu_intercept_per_group\": 3.4062092304229736, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 680, \"mu_intercept_per_group\": 3.5978879928588867, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 681, \"mu_intercept_per_group\": 5.483127117156982, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 682, \"mu_intercept_per_group\": 5.682024955749512, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 683, \"mu_intercept_per_group\": 5.703158378601074, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 684, \"mu_intercept_per_group\": 5.423323154449463, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 685, \"mu_intercept_per_group\": 6.634952545166016, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 686, \"mu_intercept_per_group\": 7.864182472229004, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 687, \"mu_intercept_per_group\": 5.958718299865723, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 688, \"mu_intercept_per_group\": 6.489780902862549, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 689, \"mu_intercept_per_group\": 6.544824123382568, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 690, \"mu_intercept_per_group\": 8.481928825378418, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 691, \"mu_intercept_per_group\": 8.010696411132812, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 692, \"mu_intercept_per_group\": 7.030518054962158, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 693, \"mu_intercept_per_group\": 9.646929740905762, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 694, \"mu_intercept_per_group\": 9.24629020690918, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 695, \"mu_intercept_per_group\": 6.040304660797119, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 696, \"mu_intercept_per_group\": 9.309913635253906, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 697, \"mu_intercept_per_group\": 9.505023956298828, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 698, \"mu_intercept_per_group\": 9.49521541595459, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 699, \"mu_intercept_per_group\": 10.246111869812012, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 700, \"mu_intercept_per_group\": 8.259635925292969, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 701, \"mu_intercept_per_group\": 10.287079811096191, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 702, \"mu_intercept_per_group\": 8.471307754516602, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 703, \"mu_intercept_per_group\": 9.964456558227539, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 704, \"mu_intercept_per_group\": 9.181883811950684, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 705, \"mu_intercept_per_group\": 6.718848705291748, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 706, \"mu_intercept_per_group\": 6.662708759307861, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 707, \"mu_intercept_per_group\": 6.879563331604004, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 708, \"mu_intercept_per_group\": 6.606285095214844, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 709, \"mu_intercept_per_group\": 6.963419437408447, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 710, \"mu_intercept_per_group\": 7.792697906494141, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 711, \"mu_intercept_per_group\": 6.3728203773498535, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 712, \"mu_intercept_per_group\": 5.730411529541016, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 713, \"mu_intercept_per_group\": 6.3972883224487305, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 714, \"mu_intercept_per_group\": 5.283588409423828, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 715, \"mu_intercept_per_group\": 5.783731460571289, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 716, \"mu_intercept_per_group\": 6.244128227233887, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 717, \"mu_intercept_per_group\": 7.456241130828857, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 718, \"mu_intercept_per_group\": 7.400933742523193, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 719, \"mu_intercept_per_group\": 9.20103931427002, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 720, \"mu_intercept_per_group\": 8.300681114196777, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 721, \"mu_intercept_per_group\": 7.695696830749512, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 722, \"mu_intercept_per_group\": 7.542201042175293, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 723, \"mu_intercept_per_group\": 8.565561294555664, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 724, \"mu_intercept_per_group\": 7.670793056488037, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 725, \"mu_intercept_per_group\": 8.69259262084961, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 726, \"mu_intercept_per_group\": 9.066834449768066, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 727, \"mu_intercept_per_group\": 8.613945007324219, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 728, \"mu_intercept_per_group\": 8.041496276855469, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 729, \"mu_intercept_per_group\": 8.415814399719238, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 730, \"mu_intercept_per_group\": 7.165881156921387, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 731, \"mu_intercept_per_group\": 7.541050910949707, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 732, \"mu_intercept_per_group\": 7.0695414543151855, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 733, \"mu_intercept_per_group\": 7.559047698974609, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 734, \"mu_intercept_per_group\": 6.680270671844482, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 735, \"mu_intercept_per_group\": 6.470390796661377, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 736, \"mu_intercept_per_group\": 4.707971096038818, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 737, \"mu_intercept_per_group\": 5.591123580932617, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 738, \"mu_intercept_per_group\": 5.235851287841797, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 739, \"mu_intercept_per_group\": 4.823047161102295, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 740, \"mu_intercept_per_group\": 5.185390472412109, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 741, \"mu_intercept_per_group\": 4.947401523590088, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 742, \"mu_intercept_per_group\": 4.955446243286133, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 743, \"mu_intercept_per_group\": 5.980935573577881, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 744, \"mu_intercept_per_group\": 5.863579273223877, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 745, \"mu_intercept_per_group\": 7.110388278961182, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 746, \"mu_intercept_per_group\": 5.943366527557373, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 747, \"mu_intercept_per_group\": 5.999975681304932, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 748, \"mu_intercept_per_group\": 3.6553547382354736, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 749, \"mu_intercept_per_group\": 4.92084264755249, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 750, \"mu_intercept_per_group\": 5.184471607208252, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 751, \"mu_intercept_per_group\": 4.542141914367676, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 752, \"mu_intercept_per_group\": 5.916355609893799, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 753, \"mu_intercept_per_group\": 5.967869758605957, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 754, \"mu_intercept_per_group\": 5.583237171173096, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 755, \"mu_intercept_per_group\": 5.611283779144287, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 756, \"mu_intercept_per_group\": 6.4232611656188965, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 757, \"mu_intercept_per_group\": 5.751633167266846, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 758, \"mu_intercept_per_group\": 6.025317668914795, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 759, \"mu_intercept_per_group\": 5.954617977142334, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 760, \"mu_intercept_per_group\": 6.341241359710693, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 3, \"draws\": 761, \"mu_intercept_per_group\": 6.691097736358643, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 3, \"draws\": 762, \"mu_intercept_per_group\": 5.333709239959717, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 3, \"draws\": 763, \"mu_intercept_per_group\": 4.471985816955566, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 3, \"draws\": 764, \"mu_intercept_per_group\": 7.770118713378906, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 3, \"draws\": 765, \"mu_intercept_per_group\": 7.544378280639648, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 3, \"draws\": 766, \"mu_intercept_per_group\": 7.840903282165527, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 3, \"draws\": 767, \"mu_intercept_per_group\": 7.2332844734191895, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 3, \"draws\": 768, \"mu_intercept_per_group\": 7.976465225219727, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 3, \"draws\": 769, \"mu_intercept_per_group\": 7.25405216217041, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 3, \"draws\": 770, \"mu_intercept_per_group\": 9.805700302124023, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 3, \"draws\": 771, \"mu_intercept_per_group\": 7.234973430633545, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 3, \"draws\": 772, \"mu_intercept_per_group\": 9.096428871154785, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 3, \"draws\": 773, \"mu_intercept_per_group\": 5.07411003112793, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 3, \"draws\": 774, \"mu_intercept_per_group\": 4.944116115570068, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 3, \"draws\": 775, \"mu_intercept_per_group\": 5.4220380783081055, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 3, \"draws\": 776, \"mu_intercept_per_group\": 5.544529438018799, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 3, \"draws\": 777, \"mu_intercept_per_group\": 4.941596984863281, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 3, \"draws\": 778, \"mu_intercept_per_group\": 5.4320244789123535, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 3, \"draws\": 779, \"mu_intercept_per_group\": 5.851161956787109, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 3, \"draws\": 780, \"mu_intercept_per_group\": 6.670863151550293, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 3, \"draws\": 781, \"mu_intercept_per_group\": 5.7738847732543945, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 3, \"draws\": 782, \"mu_intercept_per_group\": 6.4773030281066895, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 3, \"draws\": 783, \"mu_intercept_per_group\": 6.074578285217285, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 3, \"draws\": 784, \"mu_intercept_per_group\": 6.064509391784668, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 3, \"draws\": 785, \"mu_intercept_per_group\": 4.619283676147461, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 3, \"draws\": 786, \"mu_intercept_per_group\": 4.254492282867432, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 3, \"draws\": 787, \"mu_intercept_per_group\": 3.97697114944458, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 3, \"draws\": 788, \"mu_intercept_per_group\": 5.465265274047852, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 3, \"draws\": 789, \"mu_intercept_per_group\": 5.802673816680908, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 3, \"draws\": 790, \"mu_intercept_per_group\": 5.147307872772217, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 3, \"draws\": 791, \"mu_intercept_per_group\": 5.777414798736572, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 3, \"draws\": 792, \"mu_intercept_per_group\": 5.6253662109375, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 3, \"draws\": 793, \"mu_intercept_per_group\": 5.038989067077637, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 3, \"draws\": 794, \"mu_intercept_per_group\": 4.577472686767578, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 3, \"draws\": 795, \"mu_intercept_per_group\": 4.531900882720947, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 3, \"draws\": 796, \"mu_intercept_per_group\": 6.18878698348999, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 3, \"draws\": 797, \"mu_intercept_per_group\": 7.4194440841674805, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 3, \"draws\": 798, \"mu_intercept_per_group\": 3.3374884128570557, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 3, \"draws\": 799, \"mu_intercept_per_group\": 3.5988762378692627, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": 6.596501350402832, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": 5.916729927062988, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": 6.200881004333496, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": 6.408555507659912, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": 6.277361869812012, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": 6.515713691711426, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": 9.23158073425293, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": 8.593442916870117, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": 8.714883804321289, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": 6.156932830810547, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": 5.049054145812988, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": 6.2396769523620605, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": 6.432089805603027, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": 6.3035430908203125, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": 6.020042896270752, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": 6.099948883056641, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": 3.2760722637176514, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": 3.024836540222168, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": 3.020932674407959, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": 2.8360660076141357, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": 2.2105982303619385, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": 2.3820645809173584, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": 3.313857316970825, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": 4.7214035987854, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": 3.486628293991089, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": 4.421268939971924, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": 3.3845043182373047, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": 4.551468849182129, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": 3.710813522338867, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": 3.4403045177459717, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": 3.801114320755005, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": 3.3402411937713623, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": 3.4590651988983154, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": 5.093507766723633, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": 3.4121787548065186, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": 2.8997139930725098, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": 2.915893316268921, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": 4.673020362854004, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": 5.762032985687256, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": 3.943249464035034, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": 5.875658988952637, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": 4.853921890258789, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": 2.6765193939208984, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": 2.7164230346679688, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": 4.0928215980529785, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": 3.795858383178711, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": 7.517721176147461, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": 7.144754409790039, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": 7.835006237030029, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": 7.969758033752441, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": 7.125711917877197, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": 7.526888370513916, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": 7.658315658569336, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": 7.313686847686768, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": 7.498214244842529, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": 7.914802074432373, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": 7.3740973472595215, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": 7.52065372467041, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": 6.908719539642334, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": 6.572558879852295, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": 6.504856586456299, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": 5.580643177032471, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": 5.51556921005249, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": 5.646458148956299, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": 5.637943267822266, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": 5.383561134338379, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": 4.672183036804199, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": 4.717172145843506, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": 4.731287002563477, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": 5.511883735656738, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": 4.579609394073486, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": 4.6660356521606445, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": 4.589028358459473, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": 4.621724605560303, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": 4.439056396484375, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": 6.897433757781982, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": 6.257687091827393, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": 6.034927845001221, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": 6.083368301391602, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": 5.108047008514404, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": 5.743569374084473, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": 4.197004318237305, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": 4.828075885772705, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": 3.8735907077789307, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": 3.3216512203216553, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": 3.777878761291504, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": 4.234044551849365, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": 6.249175548553467, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": 5.41162633895874, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": 5.801335334777832, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": 6.408588886260986, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": 5.450962543487549, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": 7.616569995880127, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": 7.027707099914551, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": 4.433976650238037, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": 3.72489595413208, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": 3.7533252239227295, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": 3.6679956912994385, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": 5.547127723693848, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": 4.1902384757995605, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": 3.866051435470581, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": 4.747945785522461, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": 4.592893123626709, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": 4.540623664855957, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": 4.725039005279541, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": 5.257482051849365, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": 4.736362934112549, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": 5.172173023223877, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": 6.095942497253418, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": 5.077692031860352, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": 7.558927059173584, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": 6.744564056396484, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": 7.374525547027588, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": 5.608931064605713, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": 4.696782112121582, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": 6.201601982116699, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": 5.40232515335083, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": 5.436318397521973, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": 5.741130352020264, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": 6.965943813323975, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": 6.8519158363342285, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": 6.074604511260986, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": 3.8365375995635986, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": 3.6906793117523193, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": 4.004487037658691, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": 3.7596123218536377, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": 4.570924282073975, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": 4.168190002441406, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": 5.3274006843566895, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": 5.650604724884033, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": 4.194668769836426, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": 3.947455644607544, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": 4.253833293914795, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": 2.9910330772399902, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": 2.3182849884033203, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": 3.2267422676086426, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": 3.8487942218780518, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": 4.248516082763672, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": 4.203681945800781, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": 3.1905429363250732, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": 3.8503644466400146, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": 3.5783133506774902, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": 3.799196481704712, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": 3.11175537109375, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": 3.0892913341522217, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": 4.727402687072754, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": 4.0935282707214355, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": 4.348530292510986, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": 4.646073818206787, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": 4.654355525970459, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": 3.449671983718872, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": 5.506060600280762, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": 5.423388481140137, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": 5.113664150238037, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": 5.9805989265441895, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": 4.508223056793213, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": 4.906843662261963, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": 5.977674961090088, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": 7.3628458976745605, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": 7.0188188552856445, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": 4.200431823730469, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": 4.252715587615967, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": 4.259709358215332, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": 4.524955749511719, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": 4.41145658493042, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": 4.2144389152526855, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": 4.073808670043945, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": 3.7517340183258057, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": 4.673107624053955, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": 5.250977039337158, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": 5.029117584228516, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": 5.133106708526611, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": 5.474666118621826, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": 2.964923858642578, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": 3.072157144546509, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": 2.921562433242798, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": 3.0772969722747803, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": 3.110738515853882, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": 3.275496244430542, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": 2.5401577949523926, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": 3.3594276905059814, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": 4.353796482086182, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": 5.537916660308838, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": 5.467271327972412, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": 5.511257648468018, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": 4.598874568939209, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": 4.961237907409668, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": 7.397579669952393, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": 6.377242088317871, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": 6.3552069664001465, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": 7.861194133758545, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": 7.2531418800354, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": 7.289341926574707, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": 7.007733345031738, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": 7.616257190704346, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": 6.935456275939941, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": 6.689274311065674, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": 6.220975875854492, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": 8.15714168548584, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": 7.021938800811768, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": 4.852392196655273, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": 4.291373252868652, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": 5.566005706787109, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": 5.191485404968262, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": 5.908071517944336, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": 5.7669291496276855, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": 4.26406192779541, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": 4.05075740814209, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": 5.05207633972168, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": 8.00020980834961, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": 7.625553131103516, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": 7.123429298400879, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": 5.1861090660095215, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": 5.774616718292236, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": 6.364603042602539, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": 6.458547592163086, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": 5.797945499420166, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": 4.580686092376709, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": 4.616115093231201, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": 4.591822147369385, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": 4.833398818969727, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": 3.3239738941192627, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": 2.722628116607666, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": 3.6076130867004395, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": 4.371481418609619, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": 3.296107769012451, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": 2.716583251953125, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": 3.516678810119629, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": 3.7994260787963867, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": 4.942748546600342, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": 5.26377010345459, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": 4.745303153991699, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": 5.471063137054443, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": 4.345223903656006, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": 5.310250282287598, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": 3.3164632320404053, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": 4.235846042633057, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": 4.1781325340271, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": 3.6586921215057373, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": 4.181976318359375, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": 3.630582809448242, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": 3.0978024005889893, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": 4.140700340270996, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": 6.168396949768066, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": 7.052981376647949, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": 4.671559810638428, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": 3.313825845718384, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": 4.067891597747803, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": 4.9828057289123535, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": 4.5410566329956055, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": 4.5612263679504395, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": 6.939146518707275, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": 6.980181694030762, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": 6.860813140869141, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": 8.447720527648926, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": 8.92111873626709, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": 9.51703929901123, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": 8.095449447631836, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": 10.217530250549316, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": 6.810245513916016, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": 9.882048606872559, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": 9.412601470947266, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": 8.473456382751465, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": 8.748702049255371, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": 6.493197441101074, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": 8.875809669494629, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": 6.45861291885376, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": 9.182539939880371, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": 5.499044418334961, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": 6.84201192855835, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": 7.16967248916626, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": 7.763781547546387, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": 4.9516448974609375, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": 6.331609725952148, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": 4.488559722900391, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": 5.7365403175354, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": 4.934948444366455, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": 4.362920761108398, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": 5.52608585357666, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": 6.047499656677246, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": 6.048445224761963, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": 5.669834136962891, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": 5.658780574798584, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": 5.026833534240723, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": 6.671324729919434, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": 6.746391773223877, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": 7.08278226852417, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": 7.938436985015869, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": 7.905612468719482, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": 6.3554887771606445, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": 7.243249416351318, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": 5.015058994293213, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": 6.14005184173584, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": 6.11715841293335, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": 4.089169979095459, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": 4.049026012420654, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": 3.1291565895080566, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": 1.7233577966690063, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": 2.091646909713745, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": 3.7013041973114014, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": 2.7625956535339355, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": 2.446546792984009, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": 2.6562516689300537, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": 3.0458474159240723, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": 3.5842020511627197, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": 3.6593403816223145, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": 3.950873851776123, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": 4.41035795211792, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": 3.1814074516296387, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": 3.824416399002075, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": 2.7235805988311768, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": 6.864236354827881, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": 7.024386405944824, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": 4.791187286376953, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": 4.686063289642334, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": 5.221336364746094, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": 4.009706974029541, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": 4.0675177574157715, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": 4.9445576667785645, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": 4.828487396240234, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": 4.732262134552002, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": 4.545299530029297, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": 5.642070770263672, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": 5.142560005187988, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": 5.0576982498168945, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": 5.78882360458374, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": 7.112565040588379, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": 4.563687324523926, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": 5.938342094421387, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": 5.2917799949646, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": 6.796415328979492, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": 7.096314430236816, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": 5.868555545806885, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": 6.112779140472412, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": 4.734889984130859, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": 4.786148548126221, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": 5.069334030151367, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": 3.2142815589904785, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": 5.198938846588135, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": 4.546430587768555, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": 3.1334335803985596, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": 2.7364280223846436, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": 2.377497673034668, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": 3.807377338409424, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": 3.995044231414795, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": 4.263748645782471, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": 4.4294209480285645, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": 3.9479570388793945, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": 5.246222496032715, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": 5.347941875457764, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": 6.664307117462158, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": 9.70787525177002, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": 7.957592010498047, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": 9.417038917541504, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": 8.161686897277832, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": 7.247020721435547, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": 9.026169776916504, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": 5.865825653076172, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": 7.9254021644592285, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": 6.526855945587158, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": 4.574831485748291, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": 4.9366865158081055, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": 6.734658241271973, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": 6.404200553894043, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": 6.712976932525635, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": 7.249928951263428, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": 7.2736053466796875, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": 6.471250534057617, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": 6.663241386413574, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": 5.877630710601807, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": 7.6816511154174805, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": 7.051273822784424, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": 7.295766353607178, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": 6.5559821128845215, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": 6.422876834869385, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": 6.421128749847412, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": 6.358821868896484, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": 6.5184736251831055, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": 8.212015151977539, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": 5.662517547607422, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": 7.493063449859619, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": 6.595439434051514, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": 5.86770486831665, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": 10.084891319274902, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": 7.208676815032959, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": 7.082748889923096, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": 9.090865135192871, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": 8.661932945251465, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": 7.497446537017822, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": 6.717874526977539, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": 7.419759750366211, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": 5.860146999359131, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": 7.505344867706299, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": 5.204917907714844, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": 4.92115592956543, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": 5.90459680557251, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": 5.778528690338135, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": 5.664572715759277, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": 4.474503993988037, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": 4.517539024353027, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": 7.123661994934082, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": 6.532663822174072, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": 5.7232985496521, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": 5.592061996459961, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": 7.685232162475586, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": 7.550706386566162, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": 5.833143711090088, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": 6.3379058837890625, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": 6.839831829071045, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": 5.279751300811768, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": 5.9701972007751465, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": 5.6883463859558105, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": 4.9276347160339355, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": 5.42642879486084, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": 5.201815128326416, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": 6.505714416503906, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": 6.219608783721924, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": 4.41444206237793, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": 6.330846786499023, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": 6.541004657745361, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": 6.654066562652588, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": 7.020832538604736, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": 5.587596416473389, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": 6.960305213928223, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": 7.214287757873535, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": 6.0535783767700195, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": 5.910937309265137, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": 5.056623935699463, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": 4.779643535614014, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": 5.911928176879883, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": 5.125730991363525, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": 5.00029993057251, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": 3.934664249420166, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": 3.0650594234466553, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": 4.34111213684082, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": 6.20835018157959, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": 5.19832706451416, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": 4.990160942077637, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": 5.614925384521484, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": 5.12825345993042, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": 6.902166843414307, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": 6.546416759490967, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": 6.6473870277404785, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": 7.482943058013916, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": 7.744377613067627, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": 8.541169166564941, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": 8.272899627685547, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": 9.17527961730957, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": 8.802375793457031, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": 8.566553115844727, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": 11.28922176361084, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": 8.602136611938477, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": 7.770413875579834, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": 7.247498989105225, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": 9.005730628967285, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": 5.55098819732666, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": 6.603094577789307, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": 5.689440727233887, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": 6.539146423339844, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": 6.141064643859863, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": 6.275602340698242, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": 6.229638576507568, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": 6.062802791595459, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": 6.7869157791137695, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": 5.445260047912598, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": 8.03582763671875, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": 5.340537071228027, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": 3.7064738273620605, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": 5.622457981109619, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": 5.417690753936768, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": 5.900230884552002, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": 5.565657615661621, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": 6.083118438720703, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": 6.2270073890686035, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": 5.813892841339111, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": 7.201253414154053, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": 6.070397853851318, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": 5.978757858276367, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": 5.7367167472839355, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": 6.283362865447998, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": 6.27206563949585, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": 5.721168041229248, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": 4.624714374542236, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": 4.7898101806640625, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": 3.6652777194976807, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": 4.233988285064697, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": 3.4951930046081543, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": 6.312110900878906, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": 6.074038505554199, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": 5.989826679229736, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": 6.2031145095825195, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": 5.457259178161621, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": 5.656530380249023, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": 5.324793338775635, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": 5.257857799530029, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": 3.301659107208252, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": 3.2076475620269775, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": 3.55987286567688, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": 3.8615362644195557, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": 3.2684764862060547, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": 3.3596839904785156, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": 4.47635555267334, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": 4.453916072845459, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": 4.888490200042725, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": 3.542999505996704, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": 4.285355567932129, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": 4.505722522735596, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": 4.508161544799805, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": 4.102574825286865, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": 4.878348350524902, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": 5.043125152587891, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": 5.3893656730651855, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": 5.53110933303833, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": 6.001919269561768, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": 4.795222282409668, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": 4.544492721557617, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": 4.015474796295166, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": 4.310705184936523, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": 3.8553307056427, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": 3.803806781768799, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": 4.474124431610107, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": 3.3115828037261963, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": 4.322342395782471, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": 5.340415000915527, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": 5.0344648361206055, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": 4.003928184509277, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": 4.714569091796875, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": 4.999544143676758, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": 4.228895664215088, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": 4.045970439910889, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": 3.544630765914917, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": 5.305177211761475, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": 5.5132856369018555, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": 6.2488603591918945, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": 7.2267069816589355, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": 7.584900856018066, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": 6.0199456214904785, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": 5.277336120605469, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": 4.919957160949707, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": 5.375309467315674, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": 5.764824390411377, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": 6.6259942054748535, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": 5.007777690887451, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": 6.479783058166504, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": 6.284182548522949, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": 4.248199462890625, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": 3.642961025238037, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": 3.404738187789917, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": 5.43605375289917, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": 3.9707343578338623, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": 4.4787278175354, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": 4.166314601898193, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": 3.404139995574951, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": 4.903289318084717, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": 3.297785997390747, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": 5.389791488647461, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": 4.580945014953613, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": 3.5469589233398438, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": 4.997537612915039, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": 4.988725662231445, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": 4.676337718963623, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": 5.844844818115234, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": 4.426240921020508, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": 5.376166343688965, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": 4.507774829864502, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": 6.067420959472656, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": 4.478143692016602, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": 4.784946918487549, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": 4.469759464263916, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": 4.144762992858887, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": 5.089481830596924, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": 3.6268937587738037, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": 3.821610689163208, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": 3.6907882690429688, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": 3.536470413208008, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": 4.122539043426514, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": 3.8183817863464355, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": 3.51141095161438, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": 4.976324081420898, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": 3.309959888458252, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": 6.493810176849365, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": 6.106433391571045, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": 5.698008060455322, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": 5.374630451202393, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": 6.397883892059326, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": 5.35725212097168, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": 4.696737289428711, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": 4.4370198249816895, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": 5.501769065856934, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": 4.773354530334473, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": 4.792375087738037, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": 4.882826328277588, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": 5.15806245803833, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": 5.210235595703125, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": 6.061161518096924, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": 5.96096134185791, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": 5.8284807205200195, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": 7.03271484375, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": 4.807958602905273, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": 6.342007160186768, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": 5.435214042663574, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": 4.265471935272217, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": 6.0840744972229, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": 6.4188618659973145, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": 5.259487152099609, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": 5.769108772277832, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": 5.816112518310547, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": 6.655900001525879, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": 6.2765116691589355, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": 4.359377861022949, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": 6.445786476135254, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": 6.360595703125, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": 5.769741535186768, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": 6.421748161315918, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": 5.071603298187256, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": 5.251206398010254, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": 5.618041038513184, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": 7.497330188751221, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": 6.169944763183594, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": 6.737639427185059, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": 7.718123435974121, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": 6.373081207275391, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": 6.074113845825195, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": 6.151443004608154, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": 5.822195529937744, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": 5.979356288909912, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": 5.968313694000244, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": 6.056575298309326, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": 4.870138168334961, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": 4.749338626861572, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": 3.9631781578063965, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": 4.737250328063965, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": 4.001588344573975, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": 3.265390157699585, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": 3.2647476196289062, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": 4.4447102546691895, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": 5.801717758178711, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": 6.15723180770874, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": 6.467785835266113, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": 6.794161796569824, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 640, \"mu_intercept_per_group\": 6.683213233947754, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 641, \"mu_intercept_per_group\": 6.214095592498779, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 642, \"mu_intercept_per_group\": 5.068495273590088, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 643, \"mu_intercept_per_group\": 6.541714191436768, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 644, \"mu_intercept_per_group\": 4.612489700317383, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 645, \"mu_intercept_per_group\": 6.654151439666748, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 646, \"mu_intercept_per_group\": 5.893407344818115, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 647, \"mu_intercept_per_group\": 2.5729331970214844, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 648, \"mu_intercept_per_group\": 3.494577646255493, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 649, \"mu_intercept_per_group\": 3.763869524002075, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 650, \"mu_intercept_per_group\": 3.347055196762085, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 651, \"mu_intercept_per_group\": 3.1770472526550293, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 652, \"mu_intercept_per_group\": 3.011845111846924, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 653, \"mu_intercept_per_group\": 5.604405879974365, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 654, \"mu_intercept_per_group\": 3.302093982696533, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 655, \"mu_intercept_per_group\": 2.7222936153411865, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 656, \"mu_intercept_per_group\": 3.2769739627838135, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 657, \"mu_intercept_per_group\": 4.7416768074035645, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 658, \"mu_intercept_per_group\": 4.551481246948242, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 659, \"mu_intercept_per_group\": 3.669551372528076, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 660, \"mu_intercept_per_group\": 4.133059024810791, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 661, \"mu_intercept_per_group\": 3.628824472427368, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 662, \"mu_intercept_per_group\": 2.968238353729248, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 663, \"mu_intercept_per_group\": 2.775289535522461, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 664, \"mu_intercept_per_group\": 3.158350944519043, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 665, \"mu_intercept_per_group\": 3.3838956356048584, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 666, \"mu_intercept_per_group\": 5.781982421875, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 667, \"mu_intercept_per_group\": 3.695272445678711, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 668, \"mu_intercept_per_group\": 3.971369743347168, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 669, \"mu_intercept_per_group\": 3.4636197090148926, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 670, \"mu_intercept_per_group\": 3.680190324783325, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 671, \"mu_intercept_per_group\": 4.304810523986816, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 672, \"mu_intercept_per_group\": 4.908570289611816, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 673, \"mu_intercept_per_group\": 3.3234026432037354, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 674, \"mu_intercept_per_group\": 4.116179943084717, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 675, \"mu_intercept_per_group\": 3.8288707733154297, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 676, \"mu_intercept_per_group\": 4.233260631561279, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 677, \"mu_intercept_per_group\": 4.155706882476807, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 678, \"mu_intercept_per_group\": 4.085074424743652, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 679, \"mu_intercept_per_group\": 3.44616436958313, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 680, \"mu_intercept_per_group\": 3.0793561935424805, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 681, \"mu_intercept_per_group\": 4.819512367248535, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 682, \"mu_intercept_per_group\": 5.774663925170898, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 683, \"mu_intercept_per_group\": 5.596120357513428, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 684, \"mu_intercept_per_group\": 4.778704643249512, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 685, \"mu_intercept_per_group\": 5.849998474121094, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 686, \"mu_intercept_per_group\": 6.878535747528076, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 687, \"mu_intercept_per_group\": 6.441988468170166, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 688, \"mu_intercept_per_group\": 5.750250339508057, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 689, \"mu_intercept_per_group\": 7.675619602203369, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 690, \"mu_intercept_per_group\": 6.434590816497803, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 691, \"mu_intercept_per_group\": 6.198708534240723, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 692, \"mu_intercept_per_group\": 7.161935806274414, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 693, \"mu_intercept_per_group\": 8.09084415435791, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 694, \"mu_intercept_per_group\": 7.462317943572998, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 695, \"mu_intercept_per_group\": 6.686824321746826, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 696, \"mu_intercept_per_group\": 8.072399139404297, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 697, \"mu_intercept_per_group\": 8.737669944763184, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 698, \"mu_intercept_per_group\": 8.720551490783691, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 699, \"mu_intercept_per_group\": 7.646115779876709, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 700, \"mu_intercept_per_group\": 8.163576126098633, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 701, \"mu_intercept_per_group\": 8.889680862426758, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 702, \"mu_intercept_per_group\": 8.5759859085083, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 703, \"mu_intercept_per_group\": 7.89164400100708, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 704, \"mu_intercept_per_group\": 9.485373497009277, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 705, \"mu_intercept_per_group\": 5.90789270401001, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 706, \"mu_intercept_per_group\": 4.813386917114258, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 707, \"mu_intercept_per_group\": 4.887637615203857, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 708, \"mu_intercept_per_group\": 7.4275336265563965, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 709, \"mu_intercept_per_group\": 7.05445671081543, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 710, \"mu_intercept_per_group\": 6.720192909240723, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 711, \"mu_intercept_per_group\": 5.740262508392334, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 712, \"mu_intercept_per_group\": 6.7468485832214355, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 713, \"mu_intercept_per_group\": 4.794225215911865, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 714, \"mu_intercept_per_group\": 4.930507659912109, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 715, \"mu_intercept_per_group\": 5.519700527191162, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 716, \"mu_intercept_per_group\": 5.663295269012451, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 717, \"mu_intercept_per_group\": 6.837596893310547, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 718, \"mu_intercept_per_group\": 7.1065592765808105, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 719, \"mu_intercept_per_group\": 8.52623462677002, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 720, \"mu_intercept_per_group\": 7.989441394805908, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 721, \"mu_intercept_per_group\": 6.8426713943481445, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 722, \"mu_intercept_per_group\": 6.816575527191162, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 723, \"mu_intercept_per_group\": 9.237065315246582, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 724, \"mu_intercept_per_group\": 7.719794750213623, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 725, \"mu_intercept_per_group\": 8.701619148254395, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 726, \"mu_intercept_per_group\": 7.120447158813477, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 727, \"mu_intercept_per_group\": 7.477841377258301, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 728, \"mu_intercept_per_group\": 8.38807487487793, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 729, \"mu_intercept_per_group\": 8.007688522338867, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 730, \"mu_intercept_per_group\": 7.136189937591553, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 731, \"mu_intercept_per_group\": 6.817031383514404, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 732, \"mu_intercept_per_group\": 6.354297161102295, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 733, \"mu_intercept_per_group\": 6.48628044128418, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 734, \"mu_intercept_per_group\": 5.331488132476807, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 735, \"mu_intercept_per_group\": 5.040701866149902, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 736, \"mu_intercept_per_group\": 5.217166900634766, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 737, \"mu_intercept_per_group\": 4.884798049926758, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 738, \"mu_intercept_per_group\": 5.15556526184082, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 739, \"mu_intercept_per_group\": 5.239028453826904, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 740, \"mu_intercept_per_group\": 5.821376323699951, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 741, \"mu_intercept_per_group\": 4.90786600112915, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 742, \"mu_intercept_per_group\": 4.918335437774658, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 743, \"mu_intercept_per_group\": 5.3376030921936035, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 744, \"mu_intercept_per_group\": 5.5283355712890625, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 745, \"mu_intercept_per_group\": 6.045149803161621, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 746, \"mu_intercept_per_group\": 6.068292140960693, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 747, \"mu_intercept_per_group\": 6.164926528930664, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 748, \"mu_intercept_per_group\": 4.347446441650391, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 749, \"mu_intercept_per_group\": 4.922260284423828, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 750, \"mu_intercept_per_group\": 5.490612983703613, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 751, \"mu_intercept_per_group\": 4.402096271514893, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 752, \"mu_intercept_per_group\": 5.330268859863281, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 753, \"mu_intercept_per_group\": 5.978057384490967, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 754, \"mu_intercept_per_group\": 5.144820690155029, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 755, \"mu_intercept_per_group\": 5.129985809326172, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 756, \"mu_intercept_per_group\": 4.664745330810547, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 757, \"mu_intercept_per_group\": 5.2225775718688965, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 758, \"mu_intercept_per_group\": 6.184418678283691, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 759, \"mu_intercept_per_group\": 6.125128269195557, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 760, \"mu_intercept_per_group\": 6.886507511138916, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 4, \"draws\": 761, \"mu_intercept_per_group\": 5.242879867553711, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 4, \"draws\": 762, \"mu_intercept_per_group\": 4.545339107513428, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 4, \"draws\": 763, \"mu_intercept_per_group\": 4.838759422302246, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 4, \"draws\": 764, \"mu_intercept_per_group\": 6.49432897567749, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 4, \"draws\": 765, \"mu_intercept_per_group\": 7.733685493469238, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 4, \"draws\": 766, \"mu_intercept_per_group\": 6.857626914978027, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 4, \"draws\": 767, \"mu_intercept_per_group\": 6.432605266571045, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 4, \"draws\": 768, \"mu_intercept_per_group\": 6.669480800628662, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 4, \"draws\": 769, \"mu_intercept_per_group\": 8.277968406677246, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 4, \"draws\": 770, \"mu_intercept_per_group\": 7.0260090827941895, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 4, \"draws\": 771, \"mu_intercept_per_group\": 8.627984046936035, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 4, \"draws\": 772, \"mu_intercept_per_group\": 6.577909469604492, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 4, \"draws\": 773, \"mu_intercept_per_group\": 3.5680317878723145, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 4, \"draws\": 774, \"mu_intercept_per_group\": 6.274163722991943, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 4, \"draws\": 775, \"mu_intercept_per_group\": 5.394207000732422, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 4, \"draws\": 776, \"mu_intercept_per_group\": 5.18851375579834, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 4, \"draws\": 777, \"mu_intercept_per_group\": 4.888665199279785, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 4, \"draws\": 778, \"mu_intercept_per_group\": 4.724146366119385, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 4, \"draws\": 779, \"mu_intercept_per_group\": 4.596900463104248, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 4, \"draws\": 780, \"mu_intercept_per_group\": 6.318040370941162, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 4, \"draws\": 781, \"mu_intercept_per_group\": 5.508236408233643, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 4, \"draws\": 782, \"mu_intercept_per_group\": 5.682553768157959, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 4, \"draws\": 783, \"mu_intercept_per_group\": 5.741259574890137, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 4, \"draws\": 784, \"mu_intercept_per_group\": 5.629987716674805, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 4, \"draws\": 785, \"mu_intercept_per_group\": 4.8801045417785645, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 4, \"draws\": 786, \"mu_intercept_per_group\": 5.125990867614746, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 4, \"draws\": 787, \"mu_intercept_per_group\": 5.236260414123535, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 4, \"draws\": 788, \"mu_intercept_per_group\": 4.681770324707031, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 4, \"draws\": 789, \"mu_intercept_per_group\": 5.853734493255615, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 4, \"draws\": 790, \"mu_intercept_per_group\": 4.042459487915039, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 4, \"draws\": 791, \"mu_intercept_per_group\": 5.514225482940674, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 4, \"draws\": 792, \"mu_intercept_per_group\": 4.952247619628906, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 4, \"draws\": 793, \"mu_intercept_per_group\": 4.277527332305908, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 4, \"draws\": 794, \"mu_intercept_per_group\": 4.303385257720947, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 4, \"draws\": 795, \"mu_intercept_per_group\": 3.5323469638824463, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 4, \"draws\": 796, \"mu_intercept_per_group\": 4.8227949142456055, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 4, \"draws\": 797, \"mu_intercept_per_group\": 5.551024436950684, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 4, \"draws\": 798, \"mu_intercept_per_group\": 3.9634006023406982, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 4, \"draws\": 799, \"mu_intercept_per_group\": 3.7906887531280518, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": 12.754471778869629, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": 10.812274932861328, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": 10.765480995178223, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": 13.407353401184082, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": 13.64846134185791, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": 11.643799781799316, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": 17.618371963500977, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": 16.223796844482422, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": 16.936511993408203, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": 11.865764617919922, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": 10.343185424804688, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": 11.384011268615723, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": 12.021279335021973, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": 11.048788070678711, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": 11.413768768310547, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": 11.244612693786621, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": 5.364251136779785, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": 5.159884452819824, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": 5.108633518218994, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": 5.5873188972473145, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": 4.505524158477783, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": 5.421944618225098, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": 5.587538242340088, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": 7.597687244415283, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": 6.745656490325928, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": 7.4818878173828125, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": 7.624439239501953, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": 8.509791374206543, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": 8.352458953857422, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": 8.246423721313477, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": 6.662499904632568, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": 7.171912670135498, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": 6.978830814361572, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": 9.747051239013672, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": 6.041622638702393, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": 5.758724212646484, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": 5.265687942504883, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": 9.55948257446289, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": 9.630682945251465, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": 9.340804100036621, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": 8.252361297607422, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": 10.088528633117676, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": 5.4309587478637695, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": 5.403375148773193, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": 7.076474666595459, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": 7.576749324798584, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": 14.25172233581543, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": 13.566622734069824, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": 13.57477855682373, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": 13.581165313720703, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": 12.113871574401855, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": 13.187333106994629, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": 13.725404739379883, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": 12.824070930480957, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": 12.688304901123047, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": 13.838032722473145, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": 12.740289688110352, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": 13.234307289123535, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": 12.976680755615234, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": 12.959511756896973, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": 12.320330619812012, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": 10.24258041381836, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": 10.139050483703613, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": 10.654296875, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": 10.032133102416992, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": 9.91400146484375, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": 8.934792518615723, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": 9.765941619873047, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": 9.690390586853027, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": 9.084578514099121, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": 9.325352668762207, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": 9.350530624389648, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": 8.66736888885498, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": 8.629088401794434, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": 9.284001350402832, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": 11.897420883178711, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": 12.482081413269043, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": 12.301100730895996, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": 11.11733341217041, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": 10.712174415588379, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": 11.522868156433105, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": 8.952669143676758, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": 8.387723922729492, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": 6.834444522857666, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": 6.669429779052734, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": 6.62952184677124, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": 6.8483381271362305, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": 11.033400535583496, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": 10.934466361999512, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": 11.795970916748047, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": 10.56197738647461, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": 13.506722450256348, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": 12.398252487182617, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": 14.390361785888672, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": 7.462111949920654, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": 7.283783912658691, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": 7.305953502655029, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": 7.6616291999816895, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": 10.395944595336914, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": 7.639057636260986, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": 8.014718055725098, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": 7.359460830688477, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": 8.186440467834473, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": 8.955364227294922, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": 10.099543571472168, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": 11.661882400512695, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": 10.028159141540527, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": 11.214357376098633, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": 11.157830238342285, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": 13.420226097106934, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": 14.001496315002441, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": 11.605223655700684, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": 14.106366157531738, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": 11.988900184631348, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": 11.921481132507324, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": 10.43585205078125, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": 10.757227897644043, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": 10.284876823425293, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": 11.71646785736084, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": 11.247270584106445, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": 11.420194625854492, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": 11.083571434020996, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": 7.58147668838501, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": 6.643007755279541, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": 7.051792621612549, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": 6.416983127593994, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": 6.917922019958496, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": 8.853180885314941, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": 8.531320571899414, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": 10.52143383026123, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": 7.6953325271606445, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": 9.354044914245605, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": 8.660630226135254, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": 5.548492431640625, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": 4.260453701019287, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": 5.096168518066406, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": 6.933847427368164, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": 7.303840160369873, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": 7.316402912139893, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": 6.73203182220459, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": 6.9610748291015625, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": 6.359146595001221, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": 6.324534893035889, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": 6.606332302093506, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": 6.1824951171875, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": 9.078836441040039, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": 8.441583633422852, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": 8.352103233337402, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": 7.723376274108887, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": 7.291636943817139, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": 8.027557373046875, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": 10.739498138427734, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": 8.959558486938477, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": 10.16386890411377, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": 11.461536407470703, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": 9.149958610534668, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": 7.518442630767822, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": 11.56278133392334, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": 13.266654968261719, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": 13.25699234008789, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": 7.154526710510254, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": 7.757482528686523, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": 7.118526935577393, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": 8.475127220153809, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": 7.564292907714844, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": 8.020135879516602, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": 7.256285190582275, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": 6.898855686187744, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": 10.018549919128418, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": 8.618574142456055, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": 9.039570808410645, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": 11.175087928771973, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": 9.501220703125, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": 4.986420154571533, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": 5.713823318481445, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": 5.85908842086792, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": 5.46074104309082, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": 5.721610069274902, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": 5.17280912399292, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": 5.5590081214904785, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": 5.23777437210083, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": 8.585480690002441, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": 9.189512252807617, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": 8.446608543395996, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": 8.78895378112793, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": 8.575540542602539, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": 10.043397903442383, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": 14.093337059020996, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": 12.112841606140137, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": 12.622124671936035, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": 13.620967864990234, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": 12.138900756835938, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": 14.402388572692871, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": 11.862096786499023, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": 14.254460334777832, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": 11.46824836730957, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": 10.896063804626465, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": 14.500449180603027, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": 14.035934448242188, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": 12.574275970458984, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": 8.600549697875977, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": 9.125873565673828, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": 9.396496772766113, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": 9.37435531616211, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": 9.631682395935059, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": 9.496461868286133, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": 8.381160736083984, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": 8.298495292663574, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": 8.324088096618652, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": 13.967534065246582, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": 13.908478736877441, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": 14.559298515319824, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": 9.587355613708496, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": 11.621245384216309, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": 11.368457794189453, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": 12.53951644897461, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": 11.281333923339844, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": 9.110485076904297, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": 8.88500690460205, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": 8.351544380187988, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": 8.429883003234863, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": 5.297961711883545, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": 6.00721549987793, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": 6.512339115142822, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": 7.16555643081665, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": 5.726564407348633, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": 6.326605319976807, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": 6.670405387878418, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": 6.176193714141846, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": 8.538601875305176, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": 8.949250221252441, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": 8.719971656799316, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": 8.831399917602539, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": 8.748479843139648, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": 9.244207382202148, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": 6.405561923980713, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": 7.031032562255859, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": 7.080277919769287, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": 7.169107913970947, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": 8.069071769714355, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": 7.018426895141602, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": 6.636510848999023, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": 6.783436298370361, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": 11.057631492614746, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": 11.193134307861328, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": 11.229711532592773, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": 7.820783615112305, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": 8.257560729980469, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": 8.586447715759277, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": 8.396645545959473, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": 7.1295928955078125, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": 12.014030456542969, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": 10.449609756469727, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": 14.221282005310059, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": 17.600801467895508, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": 16.760372161865234, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": 16.830074310302734, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": 17.554752349853516, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": 15.22204875946045, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": 15.675346374511719, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": 14.881660461425781, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": 13.29870891571045, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": 17.844453811645508, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": 13.461542129516602, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": 14.419973373413086, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": 13.128293991088867, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": 14.718754768371582, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": 13.114831924438477, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": 11.648871421813965, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": 13.096183776855469, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": 14.383475303649902, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": 12.955988883972168, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": 9.997684478759766, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": 11.441263198852539, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": 9.292797088623047, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": 10.764690399169922, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": 9.574586868286133, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": 9.566259384155273, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": 10.148838996887207, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": 9.990543365478516, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": 10.31042766571045, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": 8.85507583618164, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": 9.696825981140137, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": 10.418362617492676, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": 12.633552551269531, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": 12.149823188781738, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": 13.753721237182617, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": 12.120218276977539, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": 11.504718780517578, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": 11.583142280578613, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": 13.065316200256348, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": 9.724645614624023, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": 9.693462371826172, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": 9.524703025817871, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": 7.643171787261963, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": 7.687667369842529, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": 5.426565170288086, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": 3.2930757999420166, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": 3.964745283126831, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": 7.336867332458496, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": 5.364569664001465, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": 5.363551139831543, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": 5.285802364349365, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": 6.008416652679443, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": 7.053664684295654, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": 6.877756595611572, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": 7.721710681915283, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": 7.520171642303467, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": 6.544693946838379, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": 6.813841819763184, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": 6.655545234680176, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": 10.900017738342285, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": 10.164872169494629, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": 11.476469039916992, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": 11.241775512695312, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": 10.824524879455566, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": 9.878335952758789, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": 9.771639823913574, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": 8.440337181091309, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": 9.181378364562988, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": 8.166688919067383, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": 9.439908027648926, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": 10.687252044677734, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": 11.238978385925293, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": 10.082351684570312, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": 9.414233207702637, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": 10.823429107666016, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": 10.294605255126953, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": 9.159744262695312, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": 11.98192024230957, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": 10.000511169433594, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": 14.79448413848877, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": 11.479741096496582, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": 11.376201629638672, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": 7.575257301330566, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": 9.292333602905273, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": 9.068994522094727, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": 7.580193996429443, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": 7.39561128616333, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": 8.103010177612305, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": 5.353286266326904, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": 5.574216842651367, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": 4.566730499267578, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": 6.615954399108887, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": 7.441323757171631, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": 7.165331840515137, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": 8.074827194213867, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": 9.106338500976562, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": 11.215051651000977, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": 10.477700233459473, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": 11.338593482971191, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": 14.244865417480469, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": 15.51287841796875, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": 18.771230697631836, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": 15.30240249633789, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": 15.885198593139648, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": 14.466424942016602, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": 12.7732572555542, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": 13.82003402709961, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": 13.083906173706055, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": 10.125091552734375, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": 9.137385368347168, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": 10.925599098205566, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": 12.652405738830566, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": 11.303804397583008, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": 13.109000205993652, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": 14.484018325805664, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": 15.080180168151855, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": 10.840818405151367, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": 11.022936820983887, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": 12.127559661865234, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": 12.087339401245117, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": 14.690048217773438, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": 12.517349243164062, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": 13.466961860656738, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": 13.740832328796387, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": 13.729859352111816, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": 12.897723197937012, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": 12.568623542785645, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": 12.75754451751709, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": 13.19306468963623, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": 11.361268997192383, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": 12.616965293884277, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": 16.467288970947266, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": 15.413885116577148, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": 13.448835372924805, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": 16.180543899536133, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": 16.674686431884766, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": 14.117537498474121, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": 13.649297714233398, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": 12.660552978515625, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": 13.01118278503418, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": 12.41789722442627, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": 12.206689834594727, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": 9.938240051269531, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": 13.300337791442871, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": 11.364786148071289, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": 11.528658866882324, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": 11.671773910522461, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": 8.924003601074219, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": 12.293363571166992, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": 12.882353782653809, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": 10.766984939575195, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": 10.17221736907959, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": 13.677369117736816, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": 12.356968879699707, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": 10.879618644714355, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": 12.921067237854004, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": 11.095775604248047, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": 11.32596492767334, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": 10.60232162475586, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": 10.34850788116455, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": 11.235703468322754, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": 11.168959617614746, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": 11.152137756347656, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": 9.865251541137695, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": 9.440308570861816, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": 8.402695655822754, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": 9.855902671813965, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": 9.526531219482422, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": 12.485642433166504, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": 11.661683082580566, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": 11.77519416809082, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": 13.311240196228027, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": 11.392950057983398, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": 11.271960258483887, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": 11.553342819213867, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": 11.170853614807129, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": 11.023845672607422, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": 8.92541790008545, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": 9.59786605834961, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": 9.110367774963379, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": 6.380338191986084, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": 5.280115127563477, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": 7.194417476654053, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": 10.446166038513184, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": 8.619575500488281, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": 9.810938835144043, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": 9.904622077941895, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": 10.59847354888916, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": 11.621076583862305, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": 12.982672691345215, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": 14.102602005004883, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": 13.441460609436035, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": 15.85467529296875, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": 15.422769546508789, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": 15.77392578125, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": 15.383973121643066, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": 18.606969833374023, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": 17.781076431274414, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": 17.820886611938477, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": 13.083016395568848, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": 13.844712257385254, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": 14.806283950805664, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": 14.06712532043457, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": 13.402239799499512, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": 12.640549659729004, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": 12.082905769348145, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": 11.5925874710083, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": 12.883514404296875, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": 11.941774368286133, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": 10.322896957397461, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": 10.873269081115723, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": 12.407357215881348, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": 12.63485336303711, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": 11.636147499084473, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": 13.40455150604248, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": 10.326606750488281, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": 9.812091827392578, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": 9.487981796264648, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": 11.621597290039062, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": 11.010762214660645, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": 11.404937744140625, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": 11.937431335449219, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": 11.410445213317871, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": 13.643637657165527, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": 11.815434455871582, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": 11.92147159576416, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": 9.964231491088867, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": 11.924184799194336, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": 11.86936092376709, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": 9.854744911193848, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": 7.732048034667969, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": 7.9994916915893555, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": 7.381368160247803, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": 7.5318474769592285, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": 7.220534801483154, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": 11.192496299743652, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": 11.84804916381836, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": 11.509279251098633, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": 11.5039701461792, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": 9.874954223632812, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": 11.754232406616211, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": 9.139137268066406, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": 8.25823974609375, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": 6.4518537521362305, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": 6.375255584716797, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": 6.0975823402404785, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": 6.668530464172363, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": 6.109024524688721, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": 6.03978967666626, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": 8.1151762008667, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": 7.85720682144165, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": 7.901214599609375, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": 7.6189069747924805, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": 7.397176742553711, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": 8.670225143432617, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": 7.5956339836120605, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": 7.976674556732178, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": 10.898387908935547, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": 8.282123565673828, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": 11.045380592346191, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": 10.857589721679688, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": 11.104416847229004, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": 9.970942497253418, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": 9.164610862731934, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": 9.254059791564941, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": 8.394057273864746, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": 8.112407684326172, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": 7.777646541595459, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": 7.534031391143799, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": 7.741824150085449, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": 6.601257801055908, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": 8.93957805633545, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": 9.137421607971191, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": 8.442412376403809, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": 9.477604866027832, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": 9.367471694946289, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": 9.14127254486084, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": 8.206626892089844, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": 6.184902191162109, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": 9.396224021911621, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": 11.278218269348145, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": 12.608107566833496, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": 11.816932678222656, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": 13.339637756347656, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": 11.325212478637695, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": 10.358877182006836, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": 10.035999298095703, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": 8.957974433898926, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": 11.405030250549316, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": 9.292325019836426, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": 10.418790817260742, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": 10.66446304321289, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": 10.386002540588379, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": 7.544896125793457, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": 6.855931282043457, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": 7.551339149475098, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": 10.902939796447754, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": 7.049159049987793, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": 8.699481964111328, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": 7.181623935699463, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": 9.06697940826416, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": 7.4747748374938965, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": 8.200430870056152, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": 7.04826021194458, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": 8.231524467468262, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": 7.560155868530273, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": 7.881091594696045, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": 8.025741577148438, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": 9.072128295898438, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": 8.654878616333008, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": 8.212373733520508, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": 10.377057075500488, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": 10.00160026550293, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": 10.636882781982422, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": 8.135324478149414, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": 9.208625793457031, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": 8.692391395568848, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": 6.577452182769775, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": 8.695042610168457, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": 7.942996978759766, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": 7.57709264755249, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": 8.164399147033691, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": 7.40148401260376, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": 7.849732875823975, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": 7.352765083312988, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": 7.116072177886963, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": 8.190390586853027, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": 7.477640151977539, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": 11.189453125, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": 11.328337669372559, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": 10.75123119354248, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": 8.538213729858398, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": 11.552668571472168, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": 9.632102966308594, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": 8.327067375183105, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": 8.524238586425781, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": 10.055492401123047, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": 8.081208229064941, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": 9.504231452941895, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": 8.982107162475586, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": 9.661669731140137, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": 10.600359916687012, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": 11.285079956054688, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": 11.54997730255127, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": 11.646166801452637, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": 12.056647300720215, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": 11.381178855895996, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": 11.505359649658203, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": 8.735788345336914, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": 8.054193496704102, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": 10.430400848388672, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": 10.02239990234375, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": 10.870748519897461, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": 10.617391586303711, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": 11.083741188049316, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": 12.350815773010254, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": 12.24515151977539, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": 10.642792701721191, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": 11.351046562194824, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": 12.525762557983398, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": 11.848589897155762, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": 12.368793487548828, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": 10.830001831054688, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": 11.717133522033691, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": 11.41517162322998, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": 11.477009773254395, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": 13.544875144958496, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": 13.458316802978516, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": 12.22221851348877, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": 11.334689140319824, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": 11.280905723571777, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": 11.32677936553955, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": 12.190210342407227, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": 11.429239273071289, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": 10.924306869506836, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": 12.27947998046875, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": 9.173791885375977, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": 8.417604446411133, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": 8.154123306274414, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": 8.608932495117188, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": 8.030251502990723, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": 6.329650402069092, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": 6.304080486297607, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": 7.9177327156066895, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": 9.48437213897705, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": 13.257112503051758, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": 12.452471733093262, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": 11.344724655151367, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 640, \"mu_intercept_per_group\": 12.773330688476562, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 641, \"mu_intercept_per_group\": 11.789655685424805, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 642, \"mu_intercept_per_group\": 9.907147407531738, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 643, \"mu_intercept_per_group\": 10.078775405883789, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 644, \"mu_intercept_per_group\": 11.563898086547852, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 645, \"mu_intercept_per_group\": 9.126140594482422, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 646, \"mu_intercept_per_group\": 9.734284400939941, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 647, \"mu_intercept_per_group\": 5.520310878753662, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 648, \"mu_intercept_per_group\": 6.0431742668151855, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 649, \"mu_intercept_per_group\": 6.733585357666016, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 650, \"mu_intercept_per_group\": 6.582230567932129, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 651, \"mu_intercept_per_group\": 5.539323329925537, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 652, \"mu_intercept_per_group\": 6.062948226928711, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 653, \"mu_intercept_per_group\": 9.849703788757324, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 654, \"mu_intercept_per_group\": 5.850537300109863, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 655, \"mu_intercept_per_group\": 6.039393424987793, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 656, \"mu_intercept_per_group\": 5.884930610656738, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 657, \"mu_intercept_per_group\": 8.83808422088623, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 658, \"mu_intercept_per_group\": 8.534358024597168, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 659, \"mu_intercept_per_group\": 7.593544960021973, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 660, \"mu_intercept_per_group\": 8.086081504821777, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 661, \"mu_intercept_per_group\": 6.549228668212891, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 662, \"mu_intercept_per_group\": 6.368366718292236, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 663, \"mu_intercept_per_group\": 6.4214396476745605, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 664, \"mu_intercept_per_group\": 5.772774696350098, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 665, \"mu_intercept_per_group\": 6.61445426940918, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 666, \"mu_intercept_per_group\": 10.888520240783691, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 667, \"mu_intercept_per_group\": 7.252272129058838, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 668, \"mu_intercept_per_group\": 6.834720611572266, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 669, \"mu_intercept_per_group\": 7.150309085845947, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 670, \"mu_intercept_per_group\": 7.022717475891113, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 671, \"mu_intercept_per_group\": 8.902827262878418, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 672, \"mu_intercept_per_group\": 8.762248992919922, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 673, \"mu_intercept_per_group\": 6.599742889404297, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 674, \"mu_intercept_per_group\": 7.874887466430664, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 675, \"mu_intercept_per_group\": 6.794338703155518, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 676, \"mu_intercept_per_group\": 6.872869968414307, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 677, \"mu_intercept_per_group\": 7.058830738067627, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 678, \"mu_intercept_per_group\": 7.131424903869629, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 679, \"mu_intercept_per_group\": 6.675449371337891, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 680, \"mu_intercept_per_group\": 5.541958332061768, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 681, \"mu_intercept_per_group\": 9.074125289916992, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 682, \"mu_intercept_per_group\": 8.849754333496094, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 683, \"mu_intercept_per_group\": 10.123149871826172, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 684, \"mu_intercept_per_group\": 10.600685119628906, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 685, \"mu_intercept_per_group\": 11.259135246276855, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 686, \"mu_intercept_per_group\": 11.293325424194336, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 687, \"mu_intercept_per_group\": 12.354889869689941, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 688, \"mu_intercept_per_group\": 12.941980361938477, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 689, \"mu_intercept_per_group\": 12.883407592773438, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 690, \"mu_intercept_per_group\": 13.170499801635742, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 691, \"mu_intercept_per_group\": 12.829779624938965, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 692, \"mu_intercept_per_group\": 12.832732200622559, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 693, \"mu_intercept_per_group\": 14.573281288146973, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 694, \"mu_intercept_per_group\": 14.593768119812012, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 695, \"mu_intercept_per_group\": 10.868412017822266, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 696, \"mu_intercept_per_group\": 15.243149757385254, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 697, \"mu_intercept_per_group\": 16.078378677368164, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 698, \"mu_intercept_per_group\": 16.008424758911133, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 699, \"mu_intercept_per_group\": 14.247529983520508, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 700, \"mu_intercept_per_group\": 16.168956756591797, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 701, \"mu_intercept_per_group\": 15.081872940063477, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 702, \"mu_intercept_per_group\": 16.64234733581543, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 703, \"mu_intercept_per_group\": 15.6513032913208, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 704, \"mu_intercept_per_group\": 17.209259033203125, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 705, \"mu_intercept_per_group\": 12.03798770904541, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 706, \"mu_intercept_per_group\": 10.716904640197754, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 707, \"mu_intercept_per_group\": 10.159310340881348, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 708, \"mu_intercept_per_group\": 12.619905471801758, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 709, \"mu_intercept_per_group\": 13.019041061401367, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 710, \"mu_intercept_per_group\": 11.78979206085205, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 711, \"mu_intercept_per_group\": 12.780752182006836, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 712, \"mu_intercept_per_group\": 9.44327449798584, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 713, \"mu_intercept_per_group\": 12.010271072387695, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 714, \"mu_intercept_per_group\": 8.342117309570312, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 715, \"mu_intercept_per_group\": 10.173789978027344, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 716, \"mu_intercept_per_group\": 11.149876594543457, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 717, \"mu_intercept_per_group\": 13.390517234802246, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 718, \"mu_intercept_per_group\": 12.437219619750977, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 719, \"mu_intercept_per_group\": 15.386373519897461, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 720, \"mu_intercept_per_group\": 12.232365608215332, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 721, \"mu_intercept_per_group\": 14.851457595825195, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 722, \"mu_intercept_per_group\": 12.56946849822998, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 723, \"mu_intercept_per_group\": 14.792276382446289, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 724, \"mu_intercept_per_group\": 12.876708030700684, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 725, \"mu_intercept_per_group\": 14.520129203796387, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 726, \"mu_intercept_per_group\": 14.572335243225098, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 727, \"mu_intercept_per_group\": 13.918070793151855, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 728, \"mu_intercept_per_group\": 13.997527122497559, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 729, \"mu_intercept_per_group\": 15.60755729675293, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 730, \"mu_intercept_per_group\": 13.687775611877441, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 731, \"mu_intercept_per_group\": 11.159847259521484, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 732, \"mu_intercept_per_group\": 11.377312660217285, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 733, \"mu_intercept_per_group\": 12.621520042419434, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 734, \"mu_intercept_per_group\": 10.698484420776367, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 735, \"mu_intercept_per_group\": 11.352063179016113, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 736, \"mu_intercept_per_group\": 9.287373542785645, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 737, \"mu_intercept_per_group\": 10.519289016723633, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 738, \"mu_intercept_per_group\": 9.942547798156738, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 739, \"mu_intercept_per_group\": 10.3135347366333, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 740, \"mu_intercept_per_group\": 10.564428329467773, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 741, \"mu_intercept_per_group\": 9.231167793273926, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 742, \"mu_intercept_per_group\": 9.087320327758789, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 743, \"mu_intercept_per_group\": 11.153230667114258, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 744, \"mu_intercept_per_group\": 11.03753662109375, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 745, \"mu_intercept_per_group\": 10.19254207611084, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 746, \"mu_intercept_per_group\": 9.522414207458496, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 747, \"mu_intercept_per_group\": 9.528714179992676, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 748, \"mu_intercept_per_group\": 8.349515914916992, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 749, \"mu_intercept_per_group\": 7.781357288360596, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 750, \"mu_intercept_per_group\": 8.595102310180664, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 751, \"mu_intercept_per_group\": 8.710808753967285, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 752, \"mu_intercept_per_group\": 8.910844802856445, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 753, \"mu_intercept_per_group\": 9.888984680175781, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 754, \"mu_intercept_per_group\": 9.768980026245117, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 755, \"mu_intercept_per_group\": 9.853405952453613, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 756, \"mu_intercept_per_group\": 10.633203506469727, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 757, \"mu_intercept_per_group\": 10.89544677734375, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 758, \"mu_intercept_per_group\": 11.600647926330566, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 759, \"mu_intercept_per_group\": 12.219228744506836, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 760, \"mu_intercept_per_group\": 11.795490264892578, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 5, \"draws\": 761, \"mu_intercept_per_group\": 11.131760597229004, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 5, \"draws\": 762, \"mu_intercept_per_group\": 8.7888765335083, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 5, \"draws\": 763, \"mu_intercept_per_group\": 7.706118106842041, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 5, \"draws\": 764, \"mu_intercept_per_group\": 13.550629615783691, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 5, \"draws\": 765, \"mu_intercept_per_group\": 13.34223461151123, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 5, \"draws\": 766, \"mu_intercept_per_group\": 12.125574111938477, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 5, \"draws\": 767, \"mu_intercept_per_group\": 14.484986305236816, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 5, \"draws\": 768, \"mu_intercept_per_group\": 14.353692054748535, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 5, \"draws\": 769, \"mu_intercept_per_group\": 13.084203720092773, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 5, \"draws\": 770, \"mu_intercept_per_group\": 17.027915954589844, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 5, \"draws\": 771, \"mu_intercept_per_group\": 13.705596923828125, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 5, \"draws\": 772, \"mu_intercept_per_group\": 13.81856918334961, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 5, \"draws\": 773, \"mu_intercept_per_group\": 10.22594928741455, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 5, \"draws\": 774, \"mu_intercept_per_group\": 8.62447452545166, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 5, \"draws\": 775, \"mu_intercept_per_group\": 7.989830017089844, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 5, \"draws\": 776, \"mu_intercept_per_group\": 7.869264125823975, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 5, \"draws\": 777, \"mu_intercept_per_group\": 9.706920623779297, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 5, \"draws\": 778, \"mu_intercept_per_group\": 8.49980640411377, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 5, \"draws\": 779, \"mu_intercept_per_group\": 9.481369972229004, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 5, \"draws\": 780, \"mu_intercept_per_group\": 10.95284366607666, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 5, \"draws\": 781, \"mu_intercept_per_group\": 10.679238319396973, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 5, \"draws\": 782, \"mu_intercept_per_group\": 10.90855884552002, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 5, \"draws\": 783, \"mu_intercept_per_group\": 9.51205062866211, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 5, \"draws\": 784, \"mu_intercept_per_group\": 10.198162078857422, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 5, \"draws\": 785, \"mu_intercept_per_group\": 7.931590557098389, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 5, \"draws\": 786, \"mu_intercept_per_group\": 8.880577087402344, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 5, \"draws\": 787, \"mu_intercept_per_group\": 9.017005920410156, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 5, \"draws\": 788, \"mu_intercept_per_group\": 10.701728820800781, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 5, \"draws\": 789, \"mu_intercept_per_group\": 9.930187225341797, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 5, \"draws\": 790, \"mu_intercept_per_group\": 8.565055847167969, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 5, \"draws\": 791, \"mu_intercept_per_group\": 9.071342468261719, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 5, \"draws\": 792, \"mu_intercept_per_group\": 9.5697021484375, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 5, \"draws\": 793, \"mu_intercept_per_group\": 8.10864543914795, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 5, \"draws\": 794, \"mu_intercept_per_group\": 8.20534896850586, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 5, \"draws\": 795, \"mu_intercept_per_group\": 8.020875930786133, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 5, \"draws\": 796, \"mu_intercept_per_group\": 9.49100399017334, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 5, \"draws\": 797, \"mu_intercept_per_group\": 10.017609596252441, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 5, \"draws\": 798, \"mu_intercept_per_group\": 8.887508392333984, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 5, \"draws\": 799, \"mu_intercept_per_group\": 8.787186622619629, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 18.937604904174805, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 19.664348602294922, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 20.414587020874023, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 19.778221130371094, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 20.59160614013672, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 20.38758659362793, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": 28.15546226501465, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": 27.300331115722656, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 28.252714157104492, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": 18.099130630493164, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 18.820091247558594, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 18.989990234375, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 18.861103057861328, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 19.731870651245117, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 19.15403175354004, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 19.182411193847656, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 8.909525871276855, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 8.204442977905273, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 8.152888298034668, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 8.647189140319824, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 8.568774223327637, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 8.162517547607422, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 9.028923988342285, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 13.255699157714844, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": 11.47348403930664, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": 11.860400199890137, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 12.042678833007812, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 14.922137260437012, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 13.117383003234863, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 13.014286041259766, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 10.629661560058594, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 11.397441864013672, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 12.13473892211914, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": 15.786993026733398, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 10.057943344116211, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 9.721993446350098, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 9.343534469604492, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 15.47074031829834, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 15.849945068359375, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 16.063262939453125, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 15.815269470214844, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 14.966440200805664, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 8.888345718383789, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 9.143756866455078, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 11.629989624023438, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 11.956602096557617, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 22.850032806396484, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 22.368511199951172, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 21.625492095947266, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 21.239442825317383, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 20.864513397216797, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 22.59698486328125, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 23.12487030029297, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 22.069564819335938, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 21.476030349731445, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 20.70832633972168, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 21.763166427612305, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 20.9791202545166, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 21.878456115722656, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 20.912595748901367, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 19.496734619140625, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 16.198314666748047, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 15.531993865966797, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 18.240232467651367, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 17.138290405273438, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 16.406639099121094, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 15.162186622619629, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 16.32270050048828, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 16.183073043823242, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 15.988325119018555, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 14.514741897583008, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 14.271515846252441, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 14.33584976196289, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 14.596460342407227, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 13.852265357971191, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 19.701221466064453, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 20.065214157104492, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 19.874475479125977, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 17.39888572692871, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 17.760942459106445, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 19.34257698059082, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 13.928265571594238, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 13.982674598693848, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 10.533758163452148, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 11.26522445678711, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 11.483047485351562, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 10.402337074279785, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 18.17830467224121, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 18.034364700317383, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 19.003158569335938, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 19.018815994262695, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 20.11393165588379, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 20.140031814575195, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 24.428556442260742, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 13.435372352600098, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 12.975183486938477, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 11.690057754516602, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 12.825322151184082, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 17.69639015197754, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 13.275724411010742, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 13.85627269744873, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 12.687923431396484, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 13.401216506958008, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 14.485981941223145, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 16.3284854888916, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": 18.202640533447266, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 17.4986572265625, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 17.47389793395996, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 19.82539176940918, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 19.830368041992188, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 21.441818237304688, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 20.576059341430664, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 21.519744873046875, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 19.34635353088379, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 18.221168518066406, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 19.431249618530273, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 17.780366897583008, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 16.913719177246094, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 19.39015007019043, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 18.113008499145508, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 18.716753005981445, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 18.61096954345703, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 11.509705543518066, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 12.217954635620117, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 11.33276653289795, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 11.97142505645752, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 13.897831916809082, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 12.74962329864502, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 15.848362922668457, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 15.141297340393066, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 14.266340255737305, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": 14.614713668823242, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 14.572769165039062, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 9.33471965789795, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 7.753958225250244, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 9.062274932861328, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 11.43151569366455, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 11.968130111694336, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 12.116057395935059, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 10.547157287597656, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 12.023600578308105, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 11.136281967163086, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 11.501825332641602, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 10.261323928833008, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 10.603423118591309, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 14.471277236938477, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 12.405184745788574, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 13.365852355957031, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 12.538244247436523, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 13.275877952575684, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 12.13398265838623, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 16.334697723388672, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": 16.716087341308594, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 14.766864776611328, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 15.798773765563965, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 14.680072784423828, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 12.908991813659668, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 21.545671463012695, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 20.06804084777832, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 23.108678817749023, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 12.129247665405273, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 13.120925903320312, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 13.848418235778809, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 12.468003273010254, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 13.660809516906738, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 12.066902160644531, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 13.460664749145508, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 12.785922050476074, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 15.041767120361328, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 15.881946563720703, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 14.301192283630371, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 16.988445281982422, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 16.87983512878418, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 9.232799530029297, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 9.401647567749023, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 9.123476028442383, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 9.232821464538574, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 9.261574745178223, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 9.051706314086914, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 9.15314769744873, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 9.67205810546875, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 13.155447959899902, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 14.084453582763672, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 15.781498908996582, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 15.35825252532959, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": 14.85240364074707, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 16.70491600036621, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 23.602853775024414, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 20.696762084960938, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 22.02036476135254, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 20.733753204345703, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 21.346595764160156, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 22.36793327331543, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 21.456327438354492, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": 23.88631820678711, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 21.361358642578125, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 20.701980590820312, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 21.761751174926758, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 23.65803337097168, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 21.06875991821289, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 14.229559898376465, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 14.630242347717285, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": 14.520967483520508, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 16.139066696166992, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 16.387752532958984, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 16.033395767211914, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 12.817676544189453, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 14.056300163269043, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 14.664285659790039, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 23.707496643066406, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": 23.264781951904297, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 24.06426429748535, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 15.802465438842773, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 17.50910758972168, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 17.742891311645508, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 19.64079475402832, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 19.42452621459961, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 16.253009796142578, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 15.077675819396973, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 13.626641273498535, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 13.403692245483398, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 9.582569122314453, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 8.981276512145996, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 10.793000221252441, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 11.349244117736816, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": 10.396649360656738, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 10.175344467163086, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 10.212334632873535, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": 11.13402271270752, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 14.74001693725586, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 13.911613464355469, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 14.901267051696777, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 13.706059455871582, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 14.88592529296875, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 15.087080001831055, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 11.266657829284668, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 10.947172164916992, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 12.008439064025879, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 12.723684310913086, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 12.849535942077637, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 12.273065567016602, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 10.956905364990234, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 10.858909606933594, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 18.956872940063477, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 18.945037841796875, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 17.683034896850586, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 12.45341968536377, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 14.343729972839355, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 15.299735069274902, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 13.15258502960205, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 13.337379455566406, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 18.989545822143555, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 18.263736724853516, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 22.082651138305664, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 27.62689208984375, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 27.876380920410156, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 25.12177848815918, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 27.239830017089844, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 25.76152801513672, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 24.704761505126953, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 24.45696258544922, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 23.189666748046875, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 27.707387924194336, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 23.739158630371094, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 22.658607482910156, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 22.948549270629883, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 25.224353790283203, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 24.664918899536133, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 17.886648178100586, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 19.8421573638916, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 22.83582878112793, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 23.6953125, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 18.634803771972656, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 16.279951095581055, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 16.566246032714844, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 15.387971878051758, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 16.369346618652344, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 16.064613342285156, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 16.634523391723633, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": 17.57460594177246, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 17.095458984375, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 15.820067405700684, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 15.814602851867676, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 16.242189407348633, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 20.546649932861328, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 21.795207977294922, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 19.950801849365234, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 21.078889846801758, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 18.995779037475586, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 21.381803512573242, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 20.662128448486328, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 17.19335174560547, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 16.485090255737305, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 16.58905029296875, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 12.215960502624512, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 12.763259887695312, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 9.097430229187012, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 5.838783264160156, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 6.429022789001465, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 11.649801254272461, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 8.2615385055542, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 8.931571006774902, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 8.686277389526367, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 9.926960945129395, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 11.783685684204102, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 11.485219955444336, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 13.087366104125977, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 12.06919002532959, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 11.907475471496582, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 10.447771072387695, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 11.7115478515625, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 17.394046783447266, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 18.87095832824707, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 17.169631958007812, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 17.292829513549805, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 18.829177856445312, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 16.656139373779297, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 16.216751098632812, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 13.903117179870605, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 14.993547439575195, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 13.975683212280273, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 14.64610481262207, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 16.521038055419922, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 16.796218872070312, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 16.121442794799805, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 15.695955276489258, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 18.417701721191406, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 16.647022247314453, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 16.065290451049805, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 20.8389949798584, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 20.023176193237305, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 22.66484832763672, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 20.92280387878418, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 20.422138214111328, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 13.083588600158691, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 13.94387435913086, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 13.135161399841309, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 12.274928092956543, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 12.856035232543945, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 12.870577812194824, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 8.711566925048828, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 9.366093635559082, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 6.70490837097168, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 10.875313758850098, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.525988578796387, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 11.804065704345703, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 14.094243049621582, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 14.388374328613281, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 20.121034622192383, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 19.94849395751953, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 19.257238388061523, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 25.691082000732422, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 27.115690231323242, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 29.46497917175293, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 23.924936294555664, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 25.158594131469727, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 24.12981414794922, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 21.666208267211914, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 20.88593864440918, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 21.644929885864258, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 16.09922218322754, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 15.658313751220703, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 18.843486785888672, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 19.321063995361328, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 19.41079330444336, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 21.57967758178711, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 23.020551681518555, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 24.676597595214844, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 18.027313232421875, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 17.496044158935547, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 21.34044647216797, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 19.353588104248047, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": 23.62421417236328, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": 20.93877410888672, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": 20.59860610961914, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 21.071413040161133, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 20.89080238342285, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 20.873455047607422, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 20.965662002563477, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 19.999195098876953, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 21.367401123046875, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 19.146318435668945, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 20.875497817993164, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 26.6544189453125, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 25.057981491088867, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 22.26319122314453, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": 27.610002517700195, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": 27.81405258178711, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 23.050817489624023, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 23.459165573120117, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 20.334213256835938, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 21.272768020629883, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 19.920063018798828, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 19.045793533325195, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 18.3698673248291, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 20.33272933959961, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": 18.557558059692383, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": 18.466754913330078, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": 17.634628295898438, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 14.706835746765137, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 21.348529815673828, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 21.198450088500977, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 17.340999603271484, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 17.589134216308594, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 21.508182525634766, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 21.504655838012695, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 18.898488998413086, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 18.584392547607422, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 19.918514251708984, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 18.522171020507812, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 17.659894943237305, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 17.39243507385254, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 17.59307098388672, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 17.24727439880371, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 17.009387969970703, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 16.029918670654297, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 17.380014419555664, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 14.48680305480957, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 17.413328170776367, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 17.471712112426758, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 19.95968246459961, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 19.535139083862305, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 18.88329315185547, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 20.74589729309082, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 20.180116653442383, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 19.024221420288086, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 17.73184585571289, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 17.614240646362305, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 17.54598617553711, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 15.790271759033203, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 15.790714263916016, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 15.073684692382812, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 11.385496139526367, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 10.606128692626953, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 12.854652404785156, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 17.038381576538086, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 14.482909202575684, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 16.10269546508789, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 15.718443870544434, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 16.859071731567383, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 18.936033248901367, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 22.074493408203125, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 22.233734130859375, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 23.093971252441406, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 24.502790451049805, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 26.87642478942871, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 25.23527717590332, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 28.068958282470703, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 28.296653747558594, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 29.936538696289062, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 31.536041259765625, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 22.25765609741211, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 23.99789047241211, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 23.6294002532959, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 23.702146530151367, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 21.86338996887207, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 22.569982528686523, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 18.436126708984375, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 20.539113998413086, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 20.385263442993164, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 21.285539627075195, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 17.14751625061035, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 18.0678768157959, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 19.9985408782959, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 20.819210052490234, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 20.44673728942871, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 22.97222328186035, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 15.761966705322266, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 16.62696647644043, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 17.588346481323242, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 17.642019271850586, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 18.563995361328125, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 19.619338989257812, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 20.62061309814453, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 17.330867767333984, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 19.42095375061035, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 17.992523193359375, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 20.957082748413086, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 19.15003776550293, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 19.737632751464844, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 19.66057586669922, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 15.156773567199707, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 11.912764549255371, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 14.332159042358398, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 13.218092918395996, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 12.396828651428223, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 12.605866432189941, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 18.809560775756836, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 18.041149139404297, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 18.079626083374023, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 17.938709259033203, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 17.36231803894043, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 18.72540855407715, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 15.750983238220215, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 15.269285202026367, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 9.946122169494629, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 9.466215133666992, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 10.830352783203125, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 10.983832359313965, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 9.796112060546875, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 9.858768463134766, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 12.551560401916504, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 13.150074005126953, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 12.631783485412598, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 12.587259292602539, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 13.223931312561035, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 14.077281951904297, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 13.226137161254883, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 13.335345268249512, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 17.3710880279541, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 15.311388969421387, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 17.35862922668457, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 17.361454010009766, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 18.683589935302734, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 15.918396949768066, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": 14.696080207824707, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 14.478073120117188, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 13.537064552307129, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 13.493009567260742, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 13.869086265563965, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 12.564895629882812, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 12.25295639038086, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": 11.292055130004883, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 14.706817626953125, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 15.667325973510742, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 14.485298156738281, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 16.243736267089844, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 15.640156745910645, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 15.584613800048828, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 12.784460067749023, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 11.009686470031738, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 15.064576148986816, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 18.913455963134766, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 19.354726791381836, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 19.49165916442871, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 21.495378494262695, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 18.144603729248047, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 15.257075309753418, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 17.458879470825195, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 16.56070899963379, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 19.991771697998047, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 17.91043472290039, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": 15.68265438079834, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 16.933767318725586, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 18.23729133605957, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 11.916205406188965, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 11.366460800170898, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 12.095577239990234, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 17.231075286865234, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 12.29189395904541, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 14.033822059631348, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 12.779338836669922, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 13.449596405029297, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 12.057092666625977, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 12.704080581665039, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 12.604995727539062, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 13.014062881469727, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 12.994406700134277, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 14.214735984802246, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 14.08224868774414, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 14.567066192626953, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 14.994406700134277, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 15.216352462768555, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 15.341737747192383, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 15.145146369934082, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 17.89491081237793, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 13.725109100341797, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 14.787832260131836, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 14.757427215576172, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 11.23617935180664, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 13.720928192138672, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 13.432788848876953, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 12.78497314453125, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 12.501047134399414, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 12.423500061035156, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 12.045026779174805, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 12.52320384979248, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 12.959207534790039, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 13.040419578552246, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 12.401437759399414, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 18.835718154907227, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 17.757190704345703, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 18.66309928894043, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 16.446178436279297, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 17.380373001098633, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 17.55062484741211, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 14.181119918823242, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 13.987855911254883, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 15.297444343566895, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 13.665599822998047, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 15.690376281738281, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 15.541190147399902, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 15.206360816955566, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 16.45104217529297, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 18.874073028564453, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 18.943706512451172, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 19.519847869873047, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 19.226282119750977, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 17.772178649902344, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 19.35355567932129, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 15.194503784179688, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 14.93582820892334, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 16.955713272094727, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 15.97462272644043, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 17.433116912841797, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 16.59766960144043, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 18.028867721557617, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 20.736722946166992, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 20.811786651611328, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 18.2913875579834, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 19.184722900390625, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 19.371532440185547, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 21.21445655822754, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 19.219547271728516, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 20.13524627685547, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 18.667821884155273, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 21.358272552490234, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 22.217988967895508, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 20.26032257080078, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 22.00338363647461, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 20.761173248291016, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 18.596651077270508, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 18.625951766967773, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 19.23904037475586, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": 17.236841201782227, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": 16.023202896118164, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 20.317909240722656, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 17.9202938079834, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 15.324775695800781, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 13.29107666015625, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 12.58755111694336, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 12.972870826721191, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 12.811959266662598, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 9.467981338500977, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 9.415968894958496, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 12.65714168548584, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 15.853363037109375, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 20.099979400634766, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 21.05261993408203, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 19.20013999938965, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 640, \"mu_intercept_per_group\": 20.1112003326416, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 641, \"mu_intercept_per_group\": 19.962223052978516, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 642, \"mu_intercept_per_group\": 16.162006378173828, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 643, \"mu_intercept_per_group\": 16.553180694580078, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 644, \"mu_intercept_per_group\": 18.10539436340332, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 645, \"mu_intercept_per_group\": 16.501760482788086, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 646, \"mu_intercept_per_group\": 15.765002250671387, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 647, \"mu_intercept_per_group\": 9.56507682800293, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 648, \"mu_intercept_per_group\": 9.408673286437988, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 649, \"mu_intercept_per_group\": 11.449236869812012, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 650, \"mu_intercept_per_group\": 9.6470365524292, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 651, \"mu_intercept_per_group\": 9.555069923400879, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 652, \"mu_intercept_per_group\": 9.320928573608398, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 653, \"mu_intercept_per_group\": 16.6997013092041, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 654, \"mu_intercept_per_group\": 9.823287963867188, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 655, \"mu_intercept_per_group\": 9.501263618469238, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 656, \"mu_intercept_per_group\": 9.47612476348877, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 657, \"mu_intercept_per_group\": 14.203490257263184, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 658, \"mu_intercept_per_group\": 12.98378849029541, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 659, \"mu_intercept_per_group\": 13.023357391357422, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 660, \"mu_intercept_per_group\": 12.868600845336914, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 661, \"mu_intercept_per_group\": 10.838421821594238, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 662, \"mu_intercept_per_group\": 10.38577651977539, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 663, \"mu_intercept_per_group\": 10.50092601776123, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 664, \"mu_intercept_per_group\": 9.804004669189453, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 665, \"mu_intercept_per_group\": 10.714414596557617, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 666, \"mu_intercept_per_group\": 18.336143493652344, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 667, \"mu_intercept_per_group\": 12.234333992004395, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 668, \"mu_intercept_per_group\": 11.337474822998047, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 669, \"mu_intercept_per_group\": 10.925562858581543, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 670, \"mu_intercept_per_group\": 10.578272819519043, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 671, \"mu_intercept_per_group\": 13.628772735595703, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 672, \"mu_intercept_per_group\": 14.656571388244629, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 673, \"mu_intercept_per_group\": 10.744807243347168, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 674, \"mu_intercept_per_group\": 11.78188419342041, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 675, \"mu_intercept_per_group\": 12.59411907196045, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 676, \"mu_intercept_per_group\": 11.196702003479004, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 677, \"mu_intercept_per_group\": 10.501055717468262, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 678, \"mu_intercept_per_group\": 12.18205451965332, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 679, \"mu_intercept_per_group\": 11.329413414001465, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 680, \"mu_intercept_per_group\": 9.262927055358887, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 681, \"mu_intercept_per_group\": 14.990884780883789, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 682, \"mu_intercept_per_group\": 14.788623809814453, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 683, \"mu_intercept_per_group\": 15.956804275512695, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 684, \"mu_intercept_per_group\": 16.634479522705078, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 685, \"mu_intercept_per_group\": 18.473268508911133, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 686, \"mu_intercept_per_group\": 19.421646118164062, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 687, \"mu_intercept_per_group\": 20.762598037719727, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 688, \"mu_intercept_per_group\": 21.764589309692383, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 689, \"mu_intercept_per_group\": 21.46291732788086, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 690, \"mu_intercept_per_group\": 21.928190231323242, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 691, \"mu_intercept_per_group\": 21.30898666381836, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 692, \"mu_intercept_per_group\": 22.41980743408203, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 693, \"mu_intercept_per_group\": 25.00678062438965, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 694, \"mu_intercept_per_group\": 24.194923400878906, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 695, \"mu_intercept_per_group\": 17.71616554260254, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 696, \"mu_intercept_per_group\": 25.859317779541016, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 697, \"mu_intercept_per_group\": 25.691654205322266, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 698, \"mu_intercept_per_group\": 25.727685928344727, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 699, \"mu_intercept_per_group\": 23.446819305419922, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 700, \"mu_intercept_per_group\": 26.540300369262695, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 701, \"mu_intercept_per_group\": 24.613306045532227, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 702, \"mu_intercept_per_group\": 27.287063598632812, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 703, \"mu_intercept_per_group\": 27.016910552978516, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 704, \"mu_intercept_per_group\": 26.659194946289062, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 705, \"mu_intercept_per_group\": 20.02311134338379, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 706, \"mu_intercept_per_group\": 18.476160049438477, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 707, \"mu_intercept_per_group\": 17.942651748657227, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 708, \"mu_intercept_per_group\": 21.476900100708008, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 709, \"mu_intercept_per_group\": 19.973979949951172, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 710, \"mu_intercept_per_group\": 19.567602157592773, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 711, \"mu_intercept_per_group\": 21.13597297668457, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 712, \"mu_intercept_per_group\": 16.391551971435547, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 713, \"mu_intercept_per_group\": 17.388446807861328, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 714, \"mu_intercept_per_group\": 14.3932466506958, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 715, \"mu_intercept_per_group\": 18.004438400268555, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 716, \"mu_intercept_per_group\": 18.827558517456055, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 717, \"mu_intercept_per_group\": 21.19615936279297, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 718, \"mu_intercept_per_group\": 21.120250701904297, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 719, \"mu_intercept_per_group\": 24.960832595825195, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 720, \"mu_intercept_per_group\": 22.817626953125, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 721, \"mu_intercept_per_group\": 21.799253463745117, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 722, \"mu_intercept_per_group\": 23.451419830322266, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 723, \"mu_intercept_per_group\": 21.47041130065918, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 724, \"mu_intercept_per_group\": 22.777536392211914, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 725, \"mu_intercept_per_group\": 23.16026496887207, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 726, \"mu_intercept_per_group\": 23.215917587280273, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 727, \"mu_intercept_per_group\": 24.711515426635742, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 728, \"mu_intercept_per_group\": 23.857608795166016, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 729, \"mu_intercept_per_group\": 24.113969802856445, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 730, \"mu_intercept_per_group\": 23.48415756225586, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 731, \"mu_intercept_per_group\": 18.372364044189453, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 732, \"mu_intercept_per_group\": 19.940834045410156, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 733, \"mu_intercept_per_group\": 20.063858032226562, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 734, \"mu_intercept_per_group\": 17.275754928588867, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 735, \"mu_intercept_per_group\": 17.682313919067383, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 736, \"mu_intercept_per_group\": 15.696589469909668, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 737, \"mu_intercept_per_group\": 15.850454330444336, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 738, \"mu_intercept_per_group\": 16.292739868164062, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 739, \"mu_intercept_per_group\": 16.25723648071289, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 740, \"mu_intercept_per_group\": 16.846708297729492, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 741, \"mu_intercept_per_group\": 15.353650093078613, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 742, \"mu_intercept_per_group\": 15.837409019470215, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 743, \"mu_intercept_per_group\": 17.999433517456055, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 744, \"mu_intercept_per_group\": 18.03529930114746, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 745, \"mu_intercept_per_group\": 18.524900436401367, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 746, \"mu_intercept_per_group\": 17.292085647583008, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 747, \"mu_intercept_per_group\": 17.072174072265625, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 748, \"mu_intercept_per_group\": 13.606905937194824, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 749, \"mu_intercept_per_group\": 13.185881614685059, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 750, \"mu_intercept_per_group\": 15.477256774902344, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 751, \"mu_intercept_per_group\": 15.169647216796875, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 752, \"mu_intercept_per_group\": 16.23084831237793, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 753, \"mu_intercept_per_group\": 16.918729782104492, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 754, \"mu_intercept_per_group\": 16.234167098999023, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 755, \"mu_intercept_per_group\": 16.00002670288086, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 756, \"mu_intercept_per_group\": 17.566740036010742, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 757, \"mu_intercept_per_group\": 18.00018310546875, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 758, \"mu_intercept_per_group\": 19.784618377685547, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 759, \"mu_intercept_per_group\": 20.37797737121582, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 760, \"mu_intercept_per_group\": 19.358999252319336, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 6, \"draws\": 761, \"mu_intercept_per_group\": 18.609737396240234, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 6, \"draws\": 762, \"mu_intercept_per_group\": 13.447147369384766, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 6, \"draws\": 763, \"mu_intercept_per_group\": 14.84967041015625, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 6, \"draws\": 764, \"mu_intercept_per_group\": 22.17626953125, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 6, \"draws\": 765, \"mu_intercept_per_group\": 21.689170837402344, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 6, \"draws\": 766, \"mu_intercept_per_group\": 21.15968132019043, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 6, \"draws\": 767, \"mu_intercept_per_group\": 22.61962890625, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 6, \"draws\": 768, \"mu_intercept_per_group\": 22.34902000427246, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 6, \"draws\": 769, \"mu_intercept_per_group\": 21.836023330688477, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 6, \"draws\": 770, \"mu_intercept_per_group\": 26.743722915649414, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 6, \"draws\": 771, \"mu_intercept_per_group\": 21.844356536865234, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 6, \"draws\": 772, \"mu_intercept_per_group\": 23.270336151123047, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 6, \"draws\": 773, \"mu_intercept_per_group\": 15.944229125976562, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 6, \"draws\": 774, \"mu_intercept_per_group\": 14.368600845336914, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 6, \"draws\": 775, \"mu_intercept_per_group\": 13.671834945678711, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 6, \"draws\": 776, \"mu_intercept_per_group\": 14.023852348327637, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 6, \"draws\": 777, \"mu_intercept_per_group\": 15.021628379821777, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 6, \"draws\": 778, \"mu_intercept_per_group\": 15.724934577941895, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 6, \"draws\": 779, \"mu_intercept_per_group\": 14.209985733032227, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 6, \"draws\": 780, \"mu_intercept_per_group\": 17.099092483520508, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 6, \"draws\": 781, \"mu_intercept_per_group\": 15.412032127380371, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 6, \"draws\": 782, \"mu_intercept_per_group\": 19.215728759765625, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 6, \"draws\": 783, \"mu_intercept_per_group\": 16.829179763793945, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 6, \"draws\": 784, \"mu_intercept_per_group\": 15.302300453186035, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 6, \"draws\": 785, \"mu_intercept_per_group\": 14.884604454040527, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 6, \"draws\": 786, \"mu_intercept_per_group\": 13.46036434173584, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 6, \"draws\": 787, \"mu_intercept_per_group\": 16.239215850830078, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 6, \"draws\": 788, \"mu_intercept_per_group\": 15.939936637878418, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 6, \"draws\": 789, \"mu_intercept_per_group\": 16.395124435424805, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 6, \"draws\": 790, \"mu_intercept_per_group\": 14.832764625549316, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 6, \"draws\": 791, \"mu_intercept_per_group\": 16.423147201538086, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 6, \"draws\": 792, \"mu_intercept_per_group\": 15.788386344909668, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 6, \"draws\": 793, \"mu_intercept_per_group\": 13.088505744934082, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 6, \"draws\": 794, \"mu_intercept_per_group\": 13.656217575073242, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 6, \"draws\": 795, \"mu_intercept_per_group\": 12.712646484375, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 6, \"draws\": 796, \"mu_intercept_per_group\": 16.858530044555664, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 6, \"draws\": 797, \"mu_intercept_per_group\": 16.255611419677734, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 6, \"draws\": 798, \"mu_intercept_per_group\": 14.31478214263916, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 6, \"draws\": 799, \"mu_intercept_per_group\": 15.11365795135498, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 10.0435209274292, \"sigma_intercept_per_group\": 29.992013931274414, \"sigma_obs\": 149.51699829101562, \"slope\": -53.0309944152832, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 13.003913879394531, \"sigma_intercept_per_group\": 29.834882736206055, \"sigma_obs\": 149.67242431640625, \"slope\": -58.36262512207031, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 12.24232006072998, \"sigma_intercept_per_group\": 29.324146270751953, \"sigma_obs\": 149.84967041015625, \"slope\": -57.95899963378906, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 12.13481616973877, \"sigma_intercept_per_group\": 28.65837287902832, \"sigma_obs\": 149.26161193847656, \"slope\": -48.89718246459961, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 11.622476577758789, \"sigma_intercept_per_group\": 28.85279655456543, \"sigma_obs\": 149.43252563476562, \"slope\": -42.630279541015625, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 13.81946086883545, \"sigma_intercept_per_group\": 27.782840728759766, \"sigma_obs\": 149.24539184570312, \"slope\": -49.70182418823242, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 16.52869987487793, \"sigma_intercept_per_group\": 20.308063507080078, \"sigma_obs\": 150.0518798828125, \"slope\": -61.90262985229492, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 17.012611389160156, \"sigma_intercept_per_group\": 21.67207908630371, \"sigma_obs\": 149.90269470214844, \"slope\": -61.41543197631836, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 17.680654525756836, \"sigma_intercept_per_group\": 20.860034942626953, \"sigma_obs\": 149.10789489746094, \"slope\": -59.73502731323242, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 11.780206680297852, \"sigma_intercept_per_group\": 31.91815757751465, \"sigma_obs\": 149.5522918701172, \"slope\": -54.14534378051758, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 10.891923904418945, \"sigma_intercept_per_group\": 31.08805274963379, \"sigma_obs\": 150.6352081298828, \"slope\": -46.71100997924805, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 13.013839721679688, \"sigma_intercept_per_group\": 28.760128021240234, \"sigma_obs\": 148.57261657714844, \"slope\": -37.15999221801758, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 12.736510276794434, \"sigma_intercept_per_group\": 29.441486358642578, \"sigma_obs\": 148.83106994628906, \"slope\": -34.787601470947266, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 10.882925033569336, \"sigma_intercept_per_group\": 30.322948455810547, \"sigma_obs\": 148.7506866455078, \"slope\": -35.033634185791016, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 11.66528034210205, \"sigma_intercept_per_group\": 32.44574737548828, \"sigma_obs\": 149.2281036376953, \"slope\": -36.64241409301758, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 11.473368644714355, \"sigma_intercept_per_group\": 29.680713653564453, \"sigma_obs\": 149.2036895751953, \"slope\": -38.43317413330078, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 5.449887752532959, \"sigma_intercept_per_group\": 69.15745544433594, \"sigma_obs\": 149.34939575195312, \"slope\": -71.49980926513672, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 5.197403907775879, \"sigma_intercept_per_group\": 68.07624053955078, \"sigma_obs\": 149.4242706298828, \"slope\": -70.82833862304688, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 5.206885814666748, \"sigma_intercept_per_group\": 68.10065460205078, \"sigma_obs\": 149.4138641357422, \"slope\": -71.23052215576172, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 5.4471755027771, \"sigma_intercept_per_group\": 68.76171112060547, \"sigma_obs\": 149.07931518554688, \"slope\": -80.03704833984375, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 4.664447784423828, \"sigma_intercept_per_group\": 72.40339660644531, \"sigma_obs\": 149.7560272216797, \"slope\": -40.8574333190918, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 5.232434272766113, \"sigma_intercept_per_group\": 70.87094116210938, \"sigma_obs\": 149.6305389404297, \"slope\": -34.777061462402344, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 5.827211380004883, \"sigma_intercept_per_group\": 63.020992279052734, \"sigma_obs\": 150.08636474609375, \"slope\": -41.19651412963867, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 7.865777492523193, \"sigma_intercept_per_group\": 47.176536560058594, \"sigma_obs\": 148.93365478515625, \"slope\": -88.02324676513672, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 6.909968852996826, \"sigma_intercept_per_group\": 50.886474609375, \"sigma_obs\": 149.3558807373047, \"slope\": -69.41546630859375, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 7.094212532043457, \"sigma_intercept_per_group\": 48.3944091796875, \"sigma_obs\": 149.8260955810547, \"slope\": -42.43610763549805, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 7.629965782165527, \"sigma_intercept_per_group\": 49.74172592163086, \"sigma_obs\": 150.08837890625, \"slope\": -55.930908203125, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 8.630657196044922, \"sigma_intercept_per_group\": 41.10176467895508, \"sigma_obs\": 148.70571899414062, \"slope\": -52.14641571044922, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 8.581001281738281, \"sigma_intercept_per_group\": 45.19416046142578, \"sigma_obs\": 149.1440887451172, \"slope\": -51.183563232421875, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 8.791802406311035, \"sigma_intercept_per_group\": 42.82604217529297, \"sigma_obs\": 149.15924072265625, \"slope\": -48.46913528442383, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 6.650266647338867, \"sigma_intercept_per_group\": 52.495426177978516, \"sigma_obs\": 150.09274291992188, \"slope\": -52.703285217285156, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 6.787519931793213, \"sigma_intercept_per_group\": 54.28266906738281, \"sigma_obs\": 150.0127410888672, \"slope\": -53.138797760009766, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 7.134615421295166, \"sigma_intercept_per_group\": 51.50969696044922, \"sigma_obs\": 150.41041564941406, \"slope\": -52.05210876464844, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 9.78707218170166, \"sigma_intercept_per_group\": 35.370628356933594, \"sigma_obs\": 148.96958923339844, \"slope\": -65.7079086303711, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 6.061673641204834, \"sigma_intercept_per_group\": 60.724952697753906, \"sigma_obs\": 150.23114013671875, \"slope\": -66.05095672607422, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 5.7703447341918945, \"sigma_intercept_per_group\": 62.24485397338867, \"sigma_obs\": 150.50576782226562, \"slope\": -50.29402542114258, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 5.808041572570801, \"sigma_intercept_per_group\": 62.393463134765625, \"sigma_obs\": 150.87416076660156, \"slope\": -48.0222282409668, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 10.091727256774902, \"sigma_intercept_per_group\": 38.00029754638672, \"sigma_obs\": 151.0096893310547, \"slope\": -50.73441696166992, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 8.93934154510498, \"sigma_intercept_per_group\": 37.57072067260742, \"sigma_obs\": 150.69757080078125, \"slope\": -53.74131393432617, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 10.079118728637695, \"sigma_intercept_per_group\": 37.219993591308594, \"sigma_obs\": 150.1290283203125, \"slope\": -39.65065002441406, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 9.885072708129883, \"sigma_intercept_per_group\": 37.44202423095703, \"sigma_obs\": 150.0353546142578, \"slope\": -57.93046188354492, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 8.936127662658691, \"sigma_intercept_per_group\": 39.030860900878906, \"sigma_obs\": 149.9508819580078, \"slope\": -66.12995910644531, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 5.62835693359375, \"sigma_intercept_per_group\": 65.51499938964844, \"sigma_obs\": 149.2870330810547, \"slope\": -39.354209899902344, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 5.658347129821777, \"sigma_intercept_per_group\": 64.33783721923828, \"sigma_obs\": 149.32974243164062, \"slope\": -41.26865005493164, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 6.939907073974609, \"sigma_intercept_per_group\": 50.68098068237305, \"sigma_obs\": 150.25027465820312, \"slope\": -61.59043502807617, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 7.110286235809326, \"sigma_intercept_per_group\": 49.906654357910156, \"sigma_obs\": 150.4973602294922, \"slope\": -69.43373107910156, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 15.250388145446777, \"sigma_intercept_per_group\": 25.4967041015625, \"sigma_obs\": 150.37477111816406, \"slope\": -49.27677917480469, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 12.667940139770508, \"sigma_intercept_per_group\": 27.20892333984375, \"sigma_obs\": 149.2605438232422, \"slope\": -55.40483474731445, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 12.649925231933594, \"sigma_intercept_per_group\": 27.525835037231445, \"sigma_obs\": 148.84107971191406, \"slope\": -59.29759979248047, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 12.560123443603516, \"sigma_intercept_per_group\": 26.804567337036133, \"sigma_obs\": 149.08934020996094, \"slope\": -61.152626037597656, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 13.237394332885742, \"sigma_intercept_per_group\": 27.543657302856445, \"sigma_obs\": 149.12417602539062, \"slope\": -50.705284118652344, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 13.346288681030273, \"sigma_intercept_per_group\": 26.144977569580078, \"sigma_obs\": 149.9871368408203, \"slope\": -51.46207809448242, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 14.342869758605957, \"sigma_intercept_per_group\": 26.416654586791992, \"sigma_obs\": 149.0999298095703, \"slope\": -79.15438842773438, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 12.963568687438965, \"sigma_intercept_per_group\": 26.847169876098633, \"sigma_obs\": 149.68663024902344, \"slope\": -48.2201042175293, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 13.456622123718262, \"sigma_intercept_per_group\": 28.261184692382812, \"sigma_obs\": 149.62710571289062, \"slope\": -46.005977630615234, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 12.981213569641113, \"sigma_intercept_per_group\": 26.216604232788086, \"sigma_obs\": 149.674072265625, \"slope\": -45.70415115356445, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 12.283825874328613, \"sigma_intercept_per_group\": 27.681346893310547, \"sigma_obs\": 149.19288635253906, \"slope\": -51.5345458984375, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 13.915050506591797, \"sigma_intercept_per_group\": 26.859905242919922, \"sigma_obs\": 149.68441772460938, \"slope\": -43.47213363647461, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 12.427580833435059, \"sigma_intercept_per_group\": 27.929622650146484, \"sigma_obs\": 150.41278076171875, \"slope\": -40.2572135925293, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 12.552755355834961, \"sigma_intercept_per_group\": 27.008005142211914, \"sigma_obs\": 150.14663696289062, \"slope\": -48.08512878417969, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 11.990281105041504, \"sigma_intercept_per_group\": 31.03257179260254, \"sigma_obs\": 149.35694885253906, \"slope\": -61.037174224853516, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 9.972738265991211, \"sigma_intercept_per_group\": 36.87860107421875, \"sigma_obs\": 149.2298126220703, \"slope\": -70.48233795166016, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 10.753958702087402, \"sigma_intercept_per_group\": 36.412689208984375, \"sigma_obs\": 149.05877685546875, \"slope\": -70.27105712890625, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 11.39665412902832, \"sigma_intercept_per_group\": 31.42559051513672, \"sigma_obs\": 149.7039031982422, \"slope\": -33.08928680419922, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 9.204086303710938, \"sigma_intercept_per_group\": 36.39390563964844, \"sigma_obs\": 149.76687622070312, \"slope\": -37.903846740722656, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 9.286764144897461, \"sigma_intercept_per_group\": 35.19857406616211, \"sigma_obs\": 149.72996520996094, \"slope\": -39.36241912841797, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 9.254095077514648, \"sigma_intercept_per_group\": 37.78334426879883, \"sigma_obs\": 149.66307067871094, \"slope\": -29.771520614624023, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 9.742668151855469, \"sigma_intercept_per_group\": 35.508785247802734, \"sigma_obs\": 149.83595275878906, \"slope\": -31.90477180480957, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 9.746724128723145, \"sigma_intercept_per_group\": 35.62479782104492, \"sigma_obs\": 149.83059692382812, \"slope\": -31.48130226135254, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 10.052496910095215, \"sigma_intercept_per_group\": 35.81074523925781, \"sigma_obs\": 149.6710662841797, \"slope\": -58.702049255371094, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 8.310437202453613, \"sigma_intercept_per_group\": 39.251121520996094, \"sigma_obs\": 149.90756225585938, \"slope\": -53.598960876464844, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 8.83492374420166, \"sigma_intercept_per_group\": 40.12062072753906, \"sigma_obs\": 149.99435424804688, \"slope\": -54.09773254394531, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 9.288222312927246, \"sigma_intercept_per_group\": 41.37584686279297, \"sigma_obs\": 149.0125732421875, \"slope\": -50.60586929321289, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 8.356138229370117, \"sigma_intercept_per_group\": 40.34029006958008, \"sigma_obs\": 149.04824829101562, \"slope\": -53.74540328979492, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 8.877214431762695, \"sigma_intercept_per_group\": 40.79104995727539, \"sigma_obs\": 149.53773498535156, \"slope\": -49.99536895751953, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 11.897615432739258, \"sigma_intercept_per_group\": 30.123414993286133, \"sigma_obs\": 149.64608764648438, \"slope\": -34.54511642456055, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 12.006486892700195, \"sigma_intercept_per_group\": 29.41142463684082, \"sigma_obs\": 149.61163330078125, \"slope\": -35.725791931152344, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 11.455902099609375, \"sigma_intercept_per_group\": 28.31003761291504, \"sigma_obs\": 149.5510711669922, \"slope\": -42.453468322753906, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 10.305874824523926, \"sigma_intercept_per_group\": 32.28583908081055, \"sigma_obs\": 149.8246612548828, \"slope\": -37.079593658447266, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 11.305742263793945, \"sigma_intercept_per_group\": 33.187652587890625, \"sigma_obs\": 149.13470458984375, \"slope\": -55.9332275390625, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 11.717558860778809, \"sigma_intercept_per_group\": 29.88359832763672, \"sigma_obs\": 149.5350341796875, \"slope\": -36.01868438720703, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 8.373473167419434, \"sigma_intercept_per_group\": 43.26848602294922, \"sigma_obs\": 149.30447387695312, \"slope\": -59.533260345458984, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 8.872159004211426, \"sigma_intercept_per_group\": 42.48272705078125, \"sigma_obs\": 149.69483947753906, \"slope\": -59.29927062988281, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 6.427504539489746, \"sigma_intercept_per_group\": 54.371822357177734, \"sigma_obs\": 149.46595764160156, \"slope\": -57.105506896972656, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 7.09501838684082, \"sigma_intercept_per_group\": 53.4381103515625, \"sigma_obs\": 149.68191528320312, \"slope\": -58.56203842163086, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 6.050449371337891, \"sigma_intercept_per_group\": 52.16038513183594, \"sigma_obs\": 149.50352478027344, \"slope\": -58.309410095214844, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 7.549395561218262, \"sigma_intercept_per_group\": 52.578948974609375, \"sigma_obs\": 149.60507202148438, \"slope\": -57.11822509765625, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 10.353625297546387, \"sigma_intercept_per_group\": 32.25145721435547, \"sigma_obs\": 149.60728454589844, \"slope\": -40.861480712890625, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": 11.656938552856445, \"sigma_intercept_per_group\": 32.600154876708984, \"sigma_obs\": 149.88661193847656, \"slope\": -41.56602478027344, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 10.78028392791748, \"sigma_intercept_per_group\": 31.878549575805664, \"sigma_obs\": 149.59950256347656, \"slope\": -49.68770980834961, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 12.076475143432617, \"sigma_intercept_per_group\": 30.7208194732666, \"sigma_obs\": 149.13555908203125, \"slope\": -55.67075729370117, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 11.9874906539917, \"sigma_intercept_per_group\": 28.57813262939453, \"sigma_obs\": 149.7364501953125, \"slope\": -48.91842269897461, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 12.105104446411133, \"sigma_intercept_per_group\": 28.962146759033203, \"sigma_obs\": 149.22027587890625, \"slope\": -33.286582946777344, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 13.660985946655273, \"sigma_intercept_per_group\": 24.177291870117188, \"sigma_obs\": 149.77052307128906, \"slope\": -55.30226516723633, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 8.040143966674805, \"sigma_intercept_per_group\": 46.42974090576172, \"sigma_obs\": 149.43809509277344, \"slope\": -49.28314208984375, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 6.862365245819092, \"sigma_intercept_per_group\": 46.19129180908203, \"sigma_obs\": 149.3498992919922, \"slope\": -42.27696228027344, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 7.85923957824707, \"sigma_intercept_per_group\": 49.22921371459961, \"sigma_obs\": 149.8193817138672, \"slope\": -45.40687561035156, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 7.052608489990234, \"sigma_intercept_per_group\": 47.47309875488281, \"sigma_obs\": 149.6923370361328, \"slope\": -42.286190032958984, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 10.384084701538086, \"sigma_intercept_per_group\": 35.1531867980957, \"sigma_obs\": 149.56027221679688, \"slope\": -71.4789810180664, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 8.616475105285645, \"sigma_intercept_per_group\": 40.542030334472656, \"sigma_obs\": 149.41514587402344, \"slope\": -35.08841323852539, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 8.117835998535156, \"sigma_intercept_per_group\": 45.63587951660156, \"sigma_obs\": 149.37411499023438, \"slope\": -40.13053894042969, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 7.371649265289307, \"sigma_intercept_per_group\": 45.0046272277832, \"sigma_obs\": 149.26318359375, \"slope\": -40.82155990600586, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 7.890815258026123, \"sigma_intercept_per_group\": 44.022972106933594, \"sigma_obs\": 149.40951538085938, \"slope\": -46.7662353515625, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 8.931546211242676, \"sigma_intercept_per_group\": 39.90015411376953, \"sigma_obs\": 149.27699279785156, \"slope\": -59.49796676635742, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 9.960502624511719, \"sigma_intercept_per_group\": 34.789337158203125, \"sigma_obs\": 149.17218017578125, \"slope\": -41.57195281982422, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 10.891331672668457, \"sigma_intercept_per_group\": 31.951126098632812, \"sigma_obs\": 148.97840881347656, \"slope\": -52.18392562866211, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 11.24672794342041, \"sigma_intercept_per_group\": 33.59646224975586, \"sigma_obs\": 148.99240112304688, \"slope\": -51.76518249511719, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 9.643665313720703, \"sigma_intercept_per_group\": 33.63627243041992, \"sigma_obs\": 149.4224853515625, \"slope\": -29.955846786499023, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 12.248235702514648, \"sigma_intercept_per_group\": 30.533296585083008, \"sigma_obs\": 149.33721923828125, \"slope\": -37.87009811401367, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 11.82535171508789, \"sigma_intercept_per_group\": 28.57244300842285, \"sigma_obs\": 149.59059143066406, \"slope\": -34.7667236328125, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 12.271160125732422, \"sigma_intercept_per_group\": 28.062549591064453, \"sigma_obs\": 149.53089904785156, \"slope\": -59.592830657958984, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 12.408388137817383, \"sigma_intercept_per_group\": 29.456146240234375, \"sigma_obs\": 150.11585998535156, \"slope\": -66.43437194824219, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 12.669180870056152, \"sigma_intercept_per_group\": 27.451141357421875, \"sigma_obs\": 149.3893585205078, \"slope\": -57.295814514160156, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 10.513036727905273, \"sigma_intercept_per_group\": 30.940763473510742, \"sigma_obs\": 149.57424926757812, \"slope\": -61.6981201171875, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 11.659893989562988, \"sigma_intercept_per_group\": 31.600597381591797, \"sigma_obs\": 149.4156494140625, \"slope\": -56.19284439086914, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 11.993412971496582, \"sigma_intercept_per_group\": 30.851102828979492, \"sigma_obs\": 149.522705078125, \"slope\": -54.24045944213867, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 10.533583641052246, \"sigma_intercept_per_group\": 34.23581314086914, \"sigma_obs\": 149.75994873046875, \"slope\": -41.990047454833984, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 10.498993873596191, \"sigma_intercept_per_group\": 33.36187744140625, \"sigma_obs\": 149.4795684814453, \"slope\": -45.538307189941406, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 11.532083511352539, \"sigma_intercept_per_group\": 31.802879333496094, \"sigma_obs\": 148.86578369140625, \"slope\": -54.028202056884766, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 11.993027687072754, \"sigma_intercept_per_group\": 31.343355178833008, \"sigma_obs\": 148.94927978515625, \"slope\": -60.319210052490234, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 12.139593124389648, \"sigma_intercept_per_group\": 31.3190860748291, \"sigma_obs\": 148.87351989746094, \"slope\": -59.07102584838867, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 11.782509803771973, \"sigma_intercept_per_group\": 33.164329528808594, \"sigma_obs\": 149.8475341796875, \"slope\": -79.20236206054688, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 7.193693161010742, \"sigma_intercept_per_group\": 49.62897491455078, \"sigma_obs\": 149.35238647460938, \"slope\": -42.9088249206543, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 7.096402168273926, \"sigma_intercept_per_group\": 48.3784294128418, \"sigma_obs\": 149.516357421875, \"slope\": -45.57040023803711, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 6.803463459014893, \"sigma_intercept_per_group\": 51.779884338378906, \"sigma_obs\": 148.8705291748047, \"slope\": -81.84781646728516, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 7.563178062438965, \"sigma_intercept_per_group\": 53.18100357055664, \"sigma_obs\": 149.49461364746094, \"slope\": -91.90613555908203, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 8.169090270996094, \"sigma_intercept_per_group\": 46.20973205566406, \"sigma_obs\": 150.36695861816406, \"slope\": -68.3107681274414, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 7.856063365936279, \"sigma_intercept_per_group\": 46.00948715209961, \"sigma_obs\": 149.86868286132812, \"slope\": -54.62176513671875, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 9.518887519836426, \"sigma_intercept_per_group\": 37.666561126708984, \"sigma_obs\": 148.9615020751953, \"slope\": -49.74371337890625, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 8.74270248413086, \"sigma_intercept_per_group\": 38.42090606689453, \"sigma_obs\": 148.84193420410156, \"slope\": -52.39888000488281, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 9.53834056854248, \"sigma_intercept_per_group\": 42.514076232910156, \"sigma_obs\": 148.9730682373047, \"slope\": -49.043487548828125, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 7.88215970993042, \"sigma_intercept_per_group\": 41.58879852294922, \"sigma_obs\": 148.6448974609375, \"slope\": -49.140506744384766, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 9.735876083374023, \"sigma_intercept_per_group\": 40.1783447265625, \"sigma_obs\": 148.63037109375, \"slope\": -40.97654342651367, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 5.3800859451293945, \"sigma_intercept_per_group\": 66.2188720703125, \"sigma_obs\": 150.12466430664062, \"slope\": -68.48500061035156, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 4.349761962890625, \"sigma_intercept_per_group\": 74.6090316772461, \"sigma_obs\": 150.13525390625, \"slope\": -28.690629959106445, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 5.261830806732178, \"sigma_intercept_per_group\": 64.78313446044922, \"sigma_obs\": 149.63475036621094, \"slope\": -32.560882568359375, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 7.013137340545654, \"sigma_intercept_per_group\": 52.060123443603516, \"sigma_obs\": 149.16555786132812, \"slope\": -73.52751922607422, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 7.4315643310546875, \"sigma_intercept_per_group\": 50.11958312988281, \"sigma_obs\": 149.42091369628906, \"slope\": -68.20726776123047, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 7.551698684692383, \"sigma_intercept_per_group\": 51.009132385253906, \"sigma_obs\": 149.3773956298828, \"slope\": -66.86866760253906, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 6.2962822914123535, \"sigma_intercept_per_group\": 58.07676696777344, \"sigma_obs\": 149.27627563476562, \"slope\": -67.61532592773438, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 7.372936248779297, \"sigma_intercept_per_group\": 50.4527702331543, \"sigma_obs\": 148.92825317382812, \"slope\": -59.76478576660156, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 6.966646194458008, \"sigma_intercept_per_group\": 52.08620834350586, \"sigma_obs\": 150.17434692382812, \"slope\": -30.357282638549805, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 6.238609790802002, \"sigma_intercept_per_group\": 51.66173553466797, \"sigma_obs\": 150.10598754882812, \"slope\": -32.56822967529297, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 6.293945789337158, \"sigma_intercept_per_group\": 55.545623779296875, \"sigma_obs\": 148.6278839111328, \"slope\": -32.506439208984375, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 6.786289215087891, \"sigma_intercept_per_group\": 57.97259521484375, \"sigma_obs\": 149.2147979736328, \"slope\": -54.751487731933594, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 8.055414199829102, \"sigma_intercept_per_group\": 40.13186264038086, \"sigma_obs\": 149.38729858398438, \"slope\": -49.17842102050781, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 7.533913612365723, \"sigma_intercept_per_group\": 46.888084411621094, \"sigma_obs\": 150.17198181152344, \"slope\": -74.94562530517578, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 7.471127986907959, \"sigma_intercept_per_group\": 44.88867950439453, \"sigma_obs\": 149.00042724609375, \"slope\": -55.18149948120117, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 8.200170516967773, \"sigma_intercept_per_group\": 45.107181549072266, \"sigma_obs\": 148.85179138183594, \"slope\": -54.42918395996094, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 7.1432905197143555, \"sigma_intercept_per_group\": 45.785247802734375, \"sigma_obs\": 148.7313995361328, \"slope\": -57.69482421875, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 7.900973320007324, \"sigma_intercept_per_group\": 47.32032012939453, \"sigma_obs\": 149.7028350830078, \"slope\": -48.9265022277832, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 10.87585735321045, \"sigma_intercept_per_group\": 34.43137741088867, \"sigma_obs\": 149.735107421875, \"slope\": -64.4511947631836, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 9.839495658874512, \"sigma_intercept_per_group\": 35.84980392456055, \"sigma_obs\": 149.5125732421875, \"slope\": -66.69151306152344, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 9.801215171813965, \"sigma_intercept_per_group\": 36.794795989990234, \"sigma_obs\": 149.8853302001953, \"slope\": -57.45372772216797, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 10.587679862976074, \"sigma_intercept_per_group\": 36.61735534667969, \"sigma_obs\": 148.76812744140625, \"slope\": -70.0621109008789, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 7.323224067687988, \"sigma_intercept_per_group\": 41.075279235839844, \"sigma_obs\": 150.31448364257812, \"slope\": -43.83427810668945, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 9.29265308380127, \"sigma_intercept_per_group\": 42.99530792236328, \"sigma_obs\": 150.0042266845703, \"slope\": -44.85643768310547, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 13.76766586303711, \"sigma_intercept_per_group\": 28.749645233154297, \"sigma_obs\": 149.75267028808594, \"slope\": -65.34007263183594, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 11.151589393615723, \"sigma_intercept_per_group\": 27.59615707397461, \"sigma_obs\": 149.41372680664062, \"slope\": -33.41246795654297, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 14.24173355102539, \"sigma_intercept_per_group\": 27.165170669555664, \"sigma_obs\": 149.87318420410156, \"slope\": -42.90122985839844, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 6.439108848571777, \"sigma_intercept_per_group\": 50.099403381347656, \"sigma_obs\": 150.2717742919922, \"slope\": -64.86260223388672, \"chain\": 0, \"draw\": 160}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 8.15864086151123, \"sigma_intercept_per_group\": 45.218284606933594, \"sigma_obs\": 150.11363220214844, \"slope\": -54.817054748535156, \"chain\": 0, \"draw\": 161}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 8.005393028259277, \"sigma_intercept_per_group\": 45.117164611816406, \"sigma_obs\": 149.8870391845703, \"slope\": -56.269691467285156, \"chain\": 0, \"draw\": 162}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 7.8812689781188965, \"sigma_intercept_per_group\": 45.65479278564453, \"sigma_obs\": 149.932861328125, \"slope\": -55.49066925048828, \"chain\": 0, \"draw\": 163}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 8.233536720275879, \"sigma_intercept_per_group\": 44.712852478027344, \"sigma_obs\": 149.67813110351562, \"slope\": -63.663421630859375, \"chain\": 0, \"draw\": 164}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 7.471640110015869, \"sigma_intercept_per_group\": 47.54026412963867, \"sigma_obs\": 149.82058715820312, \"slope\": -62.580711364746094, \"chain\": 0, \"draw\": 165}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 8.057626724243164, \"sigma_intercept_per_group\": 43.94322204589844, \"sigma_obs\": 149.86753845214844, \"slope\": -58.12971878051758, \"chain\": 0, \"draw\": 166}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 7.906357765197754, \"sigma_intercept_per_group\": 47.69151306152344, \"sigma_obs\": 149.9446563720703, \"slope\": -57.99553680419922, \"chain\": 0, \"draw\": 167}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 8.706341743469238, \"sigma_intercept_per_group\": 38.725257873535156, \"sigma_obs\": 149.80572509765625, \"slope\": -55.34803771972656, \"chain\": 0, \"draw\": 168}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 9.36500358581543, \"sigma_intercept_per_group\": 36.45734786987305, \"sigma_obs\": 149.51071166992188, \"slope\": -32.363258361816406, \"chain\": 0, \"draw\": 169}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 9.028122901916504, \"sigma_intercept_per_group\": 38.85295104980469, \"sigma_obs\": 149.52505493164062, \"slope\": -32.3813362121582, \"chain\": 0, \"draw\": 170}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 10.73561954498291, \"sigma_intercept_per_group\": 33.64015197753906, \"sigma_obs\": 149.38473510742188, \"slope\": -37.36843490600586, \"chain\": 0, \"draw\": 171}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 9.464592933654785, \"sigma_intercept_per_group\": 36.10041046142578, \"sigma_obs\": 149.6343231201172, \"slope\": -46.03499221801758, \"chain\": 0, \"draw\": 172}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 5.096001148223877, \"sigma_intercept_per_group\": 64.5937728881836, \"sigma_obs\": 149.4208526611328, \"slope\": -33.42097854614258, \"chain\": 0, \"draw\": 173}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 5.7688984870910645, \"sigma_intercept_per_group\": 62.87046813964844, \"sigma_obs\": 149.48719787597656, \"slope\": -56.185325622558594, \"chain\": 0, \"draw\": 174}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 5.486934185028076, \"sigma_intercept_per_group\": 63.304649353027344, \"sigma_obs\": 150.09474182128906, \"slope\": -57.75685119628906, \"chain\": 0, \"draw\": 175}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 5.552762031555176, \"sigma_intercept_per_group\": 65.13715362548828, \"sigma_obs\": 149.83609008789062, \"slope\": -56.2039680480957, \"chain\": 0, \"draw\": 176}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 5.504631996154785, \"sigma_intercept_per_group\": 63.139686584472656, \"sigma_obs\": 149.86988830566406, \"slope\": -48.87291717529297, \"chain\": 0, \"draw\": 177}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 5.285942554473877, \"sigma_intercept_per_group\": 66.59159088134766, \"sigma_obs\": 150.16360473632812, \"slope\": -55.536983489990234, \"chain\": 0, \"draw\": 178}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 5.4931769371032715, \"sigma_intercept_per_group\": 62.3517951965332, \"sigma_obs\": 149.93115234375, \"slope\": -42.33003616333008, \"chain\": 0, \"draw\": 179}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 5.6766743659973145, \"sigma_intercept_per_group\": 63.203636169433594, \"sigma_obs\": 149.2006378173828, \"slope\": -50.70250701904297, \"chain\": 0, \"draw\": 180}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 9.085188865661621, \"sigma_intercept_per_group\": 42.74665832519531, \"sigma_obs\": 149.94351196289062, \"slope\": -65.12686157226562, \"chain\": 0, \"draw\": 181}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 8.871294975280762, \"sigma_intercept_per_group\": 41.042442321777344, \"sigma_obs\": 149.3362274169922, \"slope\": -50.37986373901367, \"chain\": 0, \"draw\": 182}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 8.933309555053711, \"sigma_intercept_per_group\": 37.4361572265625, \"sigma_obs\": 149.01612854003906, \"slope\": -50.3925666809082, \"chain\": 0, \"draw\": 183}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 9.268926620483398, \"sigma_intercept_per_group\": 40.81249237060547, \"sigma_obs\": 148.9007110595703, \"slope\": -49.58821105957031, \"chain\": 0, \"draw\": 184}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 8.762442588806152, \"sigma_intercept_per_group\": 40.9211311340332, \"sigma_obs\": 149.351318359375, \"slope\": -50.700340270996094, \"chain\": 0, \"draw\": 185}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 9.671292304992676, \"sigma_intercept_per_group\": 34.788604736328125, \"sigma_obs\": 150.41307067871094, \"slope\": -28.647804260253906, \"chain\": 0, \"draw\": 186}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 14.634625434875488, \"sigma_intercept_per_group\": 25.910720825195312, \"sigma_obs\": 150.07620239257812, \"slope\": -79.41743469238281, \"chain\": 0, \"draw\": 187}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 12.884990692138672, \"sigma_intercept_per_group\": 27.15949821472168, \"sigma_obs\": 149.837158203125, \"slope\": -65.78192901611328, \"chain\": 0, \"draw\": 188}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 12.497568130493164, \"sigma_intercept_per_group\": 27.810428619384766, \"sigma_obs\": 149.93344116210938, \"slope\": -62.376949310302734, \"chain\": 0, \"draw\": 189}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 13.480728149414062, \"sigma_intercept_per_group\": 28.806339263916016, \"sigma_obs\": 149.615478515625, \"slope\": -79.90865325927734, \"chain\": 0, \"draw\": 190}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 12.697213172912598, \"sigma_intercept_per_group\": 28.787334442138672, \"sigma_obs\": 149.71453857421875, \"slope\": -80.26519775390625, \"chain\": 0, \"draw\": 191}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 13.812814712524414, \"sigma_intercept_per_group\": 27.372421264648438, \"sigma_obs\": 150.10240173339844, \"slope\": -77.63921356201172, \"chain\": 0, \"draw\": 192}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 13.67388916015625, \"sigma_intercept_per_group\": 28.878280639648438, \"sigma_obs\": 149.50051879882812, \"slope\": -68.97371673583984, \"chain\": 0, \"draw\": 193}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 13.413585662841797, \"sigma_intercept_per_group\": 24.630205154418945, \"sigma_obs\": 148.90887451171875, \"slope\": -59.44440460205078, \"chain\": 0, \"draw\": 194}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 12.821245193481445, \"sigma_intercept_per_group\": 27.711029052734375, \"sigma_obs\": 149.78115844726562, \"slope\": -67.86597442626953, \"chain\": 0, \"draw\": 195}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 12.790650367736816, \"sigma_intercept_per_group\": 30.612354278564453, \"sigma_obs\": 149.83694458007812, \"slope\": -67.6420669555664, \"chain\": 0, \"draw\": 196}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 12.594766616821289, \"sigma_intercept_per_group\": 25.09090805053711, \"sigma_obs\": 149.63568115234375, \"slope\": -44.23572540283203, \"chain\": 0, \"draw\": 197}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 14.351057052612305, \"sigma_intercept_per_group\": 25.45458984375, \"sigma_obs\": 149.60720825195312, \"slope\": -42.64217758178711, \"chain\": 0, \"draw\": 198}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 13.107738494873047, \"sigma_intercept_per_group\": 26.828800201416016, \"sigma_obs\": 149.59165954589844, \"slope\": -46.285736083984375, \"chain\": 0, \"draw\": 199}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 8.420618057250977, \"sigma_intercept_per_group\": 42.31307601928711, \"sigma_obs\": 149.30239868164062, \"slope\": -54.67703628540039, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 8.971139907836914, \"sigma_intercept_per_group\": 41.46722412109375, \"sigma_obs\": 149.9925079345703, \"slope\": -68.48248291015625, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 8.685914993286133, \"sigma_intercept_per_group\": 38.120731353759766, \"sigma_obs\": 150.47705078125, \"slope\": -62.28839111328125, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 10.171027183532715, \"sigma_intercept_per_group\": 39.180633544921875, \"sigma_obs\": 149.9187774658203, \"slope\": -73.39976501464844, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 10.127123832702637, \"sigma_intercept_per_group\": 37.465721130371094, \"sigma_obs\": 149.66085815429688, \"slope\": -62.81023406982422, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 9.950536727905273, \"sigma_intercept_per_group\": 36.46297073364258, \"sigma_obs\": 149.63853454589844, \"slope\": -62.11786651611328, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 7.950291156768799, \"sigma_intercept_per_group\": 44.05678176879883, \"sigma_obs\": 149.94308471679688, \"slope\": -52.851497650146484, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 8.139278411865234, \"sigma_intercept_per_group\": 44.28252029418945, \"sigma_obs\": 150.15243530273438, \"slope\": -58.984371185302734, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 9.961637496948242, \"sigma_intercept_per_group\": 38.420074462890625, \"sigma_obs\": 150.63809204101562, \"slope\": -50.93675231933594, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 15.121737480163574, \"sigma_intercept_per_group\": 24.083498001098633, \"sigma_obs\": 149.1063995361328, \"slope\": -59.28237533569336, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 15.275071144104004, \"sigma_intercept_per_group\": 24.88448143005371, \"sigma_obs\": 149.24069213867188, \"slope\": -55.29788589477539, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 14.834430694580078, \"sigma_intercept_per_group\": 24.66098403930664, \"sigma_obs\": 149.0184783935547, \"slope\": -59.927093505859375, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 9.948328971862793, \"sigma_intercept_per_group\": 36.72753143310547, \"sigma_obs\": 150.16783142089844, \"slope\": -50.78712463378906, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 11.351251602172852, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.9833526611328, \"slope\": -70.14786529541016, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 11.717802047729492, \"sigma_intercept_per_group\": 31.994033813476562, \"sigma_obs\": 150.16661071777344, \"slope\": -73.63648986816406, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 12.344597816467285, \"sigma_intercept_per_group\": 30.556840896606445, \"sigma_obs\": 148.7860107421875, \"slope\": -48.6257209777832, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 11.10846996307373, \"sigma_intercept_per_group\": 30.893875122070312, \"sigma_obs\": 149.42584228515625, \"slope\": -68.47007751464844, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 8.814095497131348, \"sigma_intercept_per_group\": 36.45805358886719, \"sigma_obs\": 149.5413055419922, \"slope\": -43.14373779296875, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 9.257158279418945, \"sigma_intercept_per_group\": 39.75490951538086, \"sigma_obs\": 149.2314453125, \"slope\": -39.9219970703125, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 8.73965072631836, \"sigma_intercept_per_group\": 43.51689529418945, \"sigma_obs\": 150.06832885742188, \"slope\": -51.35866928100586, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 7.8213348388671875, \"sigma_intercept_per_group\": 43.38471984863281, \"sigma_obs\": 150.0648956298828, \"slope\": -58.998291015625, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 6.376073837280273, \"sigma_intercept_per_group\": 61.560203552246094, \"sigma_obs\": 149.9400177001953, \"slope\": -49.18618392944336, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 5.052074432373047, \"sigma_intercept_per_group\": 66.68444061279297, \"sigma_obs\": 149.92214965820312, \"slope\": -53.27687454223633, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 7.089932918548584, \"sigma_intercept_per_group\": 54.026763916015625, \"sigma_obs\": 149.17979431152344, \"slope\": -77.23040008544922, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 6.610743999481201, \"sigma_intercept_per_group\": 52.37803268432617, \"sigma_obs\": 149.1511993408203, \"slope\": -78.84164428710938, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 6.190406322479248, \"sigma_intercept_per_group\": 57.252349853515625, \"sigma_obs\": 149.8621063232422, \"slope\": -25.992528915405273, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 7.034337520599365, \"sigma_intercept_per_group\": 59.57826232910156, \"sigma_obs\": 149.0181121826172, \"slope\": -90.41265869140625, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 5.688724517822266, \"sigma_intercept_per_group\": 57.08804702758789, \"sigma_obs\": 149.01869201660156, \"slope\": -85.62890625, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 7.332720756530762, \"sigma_intercept_per_group\": 55.907752990722656, \"sigma_obs\": 149.89947509765625, \"slope\": -98.08885192871094, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 9.828225135803223, \"sigma_intercept_per_group\": 39.54765701293945, \"sigma_obs\": 149.05557250976562, \"slope\": -62.98877716064453, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 8.599159240722656, \"sigma_intercept_per_group\": 42.33460235595703, \"sigma_obs\": 149.32618713378906, \"slope\": -55.74855041503906, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 8.645319938659668, \"sigma_intercept_per_group\": 41.484893798828125, \"sigma_obs\": 149.2851104736328, \"slope\": -61.19160079956055, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 8.672574996948242, \"sigma_intercept_per_group\": 43.96246337890625, \"sigma_obs\": 149.91171264648438, \"slope\": -64.50808715820312, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 8.578628540039062, \"sigma_intercept_per_group\": 39.77725601196289, \"sigma_obs\": 149.9269256591797, \"slope\": -59.34741973876953, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 9.09077262878418, \"sigma_intercept_per_group\": 39.816497802734375, \"sigma_obs\": 149.71168518066406, \"slope\": -68.85893249511719, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 6.7690253257751465, \"sigma_intercept_per_group\": 51.388343811035156, \"sigma_obs\": 149.5433807373047, \"slope\": -44.77457046508789, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 6.735915184020996, \"sigma_intercept_per_group\": 52.139556884765625, \"sigma_obs\": 149.53311157226562, \"slope\": -54.54106521606445, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 7.5583109855651855, \"sigma_intercept_per_group\": 49.599510192871094, \"sigma_obs\": 149.33609008789062, \"slope\": -54.20711135864258, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 8.029606819152832, \"sigma_intercept_per_group\": 44.31786346435547, \"sigma_obs\": 149.9833526611328, \"slope\": -53.878997802734375, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 6.9023847579956055, \"sigma_intercept_per_group\": 49.03131103515625, \"sigma_obs\": 150.11936950683594, \"slope\": -62.75360107421875, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 6.525547981262207, \"sigma_intercept_per_group\": 51.113075256347656, \"sigma_obs\": 150.1123504638672, \"slope\": -53.36281967163086, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.863955020904541, \"sigma_intercept_per_group\": 53.53353500366211, \"sigma_obs\": 150.3126220703125, \"slope\": -54.758243560791016, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 6.855710983276367, \"sigma_intercept_per_group\": 53.07986831665039, \"sigma_obs\": 149.94601440429688, \"slope\": -64.94681549072266, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 11.146918296813965, \"sigma_intercept_per_group\": 31.86237335205078, \"sigma_obs\": 149.44415283203125, \"slope\": -71.49414825439453, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 10.947186470031738, \"sigma_intercept_per_group\": 32.34297180175781, \"sigma_obs\": 149.91299438476562, \"slope\": -58.17951583862305, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 11.222031593322754, \"sigma_intercept_per_group\": 32.606327056884766, \"sigma_obs\": 148.92477416992188, \"slope\": -53.90595626831055, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 7.778254985809326, \"sigma_intercept_per_group\": 45.37640380859375, \"sigma_obs\": 149.9329376220703, \"slope\": -42.65547180175781, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 8.323031425476074, \"sigma_intercept_per_group\": 42.32612228393555, \"sigma_obs\": 149.6610107421875, \"slope\": -52.428340911865234, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 8.466851234436035, \"sigma_intercept_per_group\": 40.14007568359375, \"sigma_obs\": 149.12417602539062, \"slope\": -51.56126403808594, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 8.561859130859375, \"sigma_intercept_per_group\": 43.26526641845703, \"sigma_obs\": 149.1283721923828, \"slope\": -48.626426696777344, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 8.43768310546875, \"sigma_intercept_per_group\": 43.62908172607422, \"sigma_obs\": 149.40972900390625, \"slope\": -45.59284210205078, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 10.829582214355469, \"sigma_intercept_per_group\": 32.380348205566406, \"sigma_obs\": 149.94973754882812, \"slope\": -65.75581359863281, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 11.373749732971191, \"sigma_intercept_per_group\": 30.864471435546875, \"sigma_obs\": 149.83895874023438, \"slope\": -67.6273422241211, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 14.558820724487305, \"sigma_intercept_per_group\": 25.529380798339844, \"sigma_obs\": 149.490478515625, \"slope\": -59.27496337890625, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 17.870105743408203, \"sigma_intercept_per_group\": 21.43952751159668, \"sigma_obs\": 149.48912048339844, \"slope\": -47.43830871582031, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 16.95926856994629, \"sigma_intercept_per_group\": 21.85824203491211, \"sigma_obs\": 149.75765991210938, \"slope\": -46.211856842041016, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 16.60460090637207, \"sigma_intercept_per_group\": 23.227127075195312, \"sigma_obs\": 150.13088989257812, \"slope\": -47.84712219238281, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 17.038955688476562, \"sigma_intercept_per_group\": 20.619056701660156, \"sigma_obs\": 149.78802490234375, \"slope\": -51.6127815246582, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 15.529139518737793, \"sigma_intercept_per_group\": 21.824871063232422, \"sigma_obs\": 149.9332275390625, \"slope\": -50.54451370239258, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 16.803274154663086, \"sigma_intercept_per_group\": 24.485742568969727, \"sigma_obs\": 149.05755615234375, \"slope\": -61.81319808959961, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 14.945558547973633, \"sigma_intercept_per_group\": 24.542015075683594, \"sigma_obs\": 149.35032653808594, \"slope\": -54.36296081542969, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 13.885786056518555, \"sigma_intercept_per_group\": 23.991641998291016, \"sigma_obs\": 149.39334106445312, \"slope\": -54.32212448120117, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 17.276653289794922, \"sigma_intercept_per_group\": 20.26078987121582, \"sigma_obs\": 149.6973419189453, \"slope\": -37.5472526550293, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 14.01372241973877, \"sigma_intercept_per_group\": 24.290050506591797, \"sigma_obs\": 149.41835021972656, \"slope\": -74.60778045654297, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 14.927916526794434, \"sigma_intercept_per_group\": 26.077592849731445, \"sigma_obs\": 149.65701293945312, \"slope\": -76.2125244140625, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 12.1337890625, \"sigma_intercept_per_group\": 26.969968795776367, \"sigma_obs\": 149.29571533203125, \"slope\": -64.85987854003906, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 16.481807708740234, \"sigma_intercept_per_group\": 24.205564498901367, \"sigma_obs\": 149.5638427734375, \"slope\": -86.2822265625, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 14.907218933105469, \"sigma_intercept_per_group\": 24.462303161621094, \"sigma_obs\": 150.109130859375, \"slope\": -65.63301849365234, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 11.622800827026367, \"sigma_intercept_per_group\": 31.483793258666992, \"sigma_obs\": 149.01904296875, \"slope\": -40.860198974609375, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 12.814809799194336, \"sigma_intercept_per_group\": 28.33328628540039, \"sigma_obs\": 149.36044311523438, \"slope\": -42.31155014038086, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 14.230781555175781, \"sigma_intercept_per_group\": 24.86953353881836, \"sigma_obs\": 149.9453125, \"slope\": -35.73918533325195, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 14.671174049377441, \"sigma_intercept_per_group\": 24.518287658691406, \"sigma_obs\": 149.6931915283203, \"slope\": -37.81827926635742, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 11.445858001708984, \"sigma_intercept_per_group\": 31.95962905883789, \"sigma_obs\": 149.04583740234375, \"slope\": -55.447269439697266, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": 10.110857963562012, \"sigma_intercept_per_group\": 35.13798522949219, \"sigma_obs\": 148.8062286376953, \"slope\": -50.204010009765625, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 10.522405624389648, \"sigma_intercept_per_group\": 35.85902786254883, \"sigma_obs\": 148.84689331054688, \"slope\": -60.48188781738281, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 9.090240478515625, \"sigma_intercept_per_group\": 37.654701232910156, \"sigma_obs\": 148.5792694091797, \"slope\": -60.28794860839844, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 9.795626640319824, \"sigma_intercept_per_group\": 37.30908966064453, \"sigma_obs\": 148.8356170654297, \"slope\": -63.99615478515625, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 9.524917602539062, \"sigma_intercept_per_group\": 37.830421447753906, \"sigma_obs\": 148.59068298339844, \"slope\": -63.575008392333984, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 11.071205139160156, \"sigma_intercept_per_group\": 34.398075103759766, \"sigma_obs\": 149.41629028320312, \"slope\": -64.11125183105469, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 9.467848777770996, \"sigma_intercept_per_group\": 35.90825271606445, \"sigma_obs\": 149.93565368652344, \"slope\": -60.36227035522461, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 9.39892578125, \"sigma_intercept_per_group\": 34.99135208129883, \"sigma_obs\": 149.68212890625, \"slope\": -63.14372253417969, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 10.60328483581543, \"sigma_intercept_per_group\": 37.42443084716797, \"sigma_obs\": 149.9944305419922, \"slope\": -59.761802673339844, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 8.725231170654297, \"sigma_intercept_per_group\": 36.738441467285156, \"sigma_obs\": 149.80894470214844, \"slope\": -53.29452896118164, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 10.591944694519043, \"sigma_intercept_per_group\": 37.733543395996094, \"sigma_obs\": 149.4751434326172, \"slope\": -67.04308319091797, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 12.913798332214355, \"sigma_intercept_per_group\": 29.968990325927734, \"sigma_obs\": 149.3283233642578, \"slope\": -59.70196533203125, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 12.056467056274414, \"sigma_intercept_per_group\": 29.02197265625, \"sigma_obs\": 149.46310424804688, \"slope\": -68.9309310913086, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 13.043288230895996, \"sigma_intercept_per_group\": 29.524002075195312, \"sigma_obs\": 149.73367309570312, \"slope\": -67.92891693115234, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 12.092246055603027, \"sigma_intercept_per_group\": 29.513151168823242, \"sigma_obs\": 149.7408905029297, \"slope\": -67.42471313476562, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 12.41557788848877, \"sigma_intercept_per_group\": 30.643146514892578, \"sigma_obs\": 149.45091247558594, \"slope\": -67.58707427978516, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 12.405966758728027, \"sigma_intercept_per_group\": 27.43653678894043, \"sigma_obs\": 149.84730529785156, \"slope\": -35.410133361816406, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 13.602458000183105, \"sigma_intercept_per_group\": 27.233495712280273, \"sigma_obs\": 149.64830017089844, \"slope\": -47.02678680419922, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 9.65005111694336, \"sigma_intercept_per_group\": 36.132415771484375, \"sigma_obs\": 149.2853240966797, \"slope\": -59.23286437988281, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 9.65271282196045, \"sigma_intercept_per_group\": 36.48398208618164, \"sigma_obs\": 148.93699645996094, \"slope\": -68.81861877441406, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 10.105796813964844, \"sigma_intercept_per_group\": 37.43098068237305, \"sigma_obs\": 149.0055389404297, \"slope\": -69.05757141113281, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 7.732029438018799, \"sigma_intercept_per_group\": 47.03521728515625, \"sigma_obs\": 150.39134216308594, \"slope\": -40.58855438232422, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 7.440708637237549, \"sigma_intercept_per_group\": 45.9240608215332, \"sigma_obs\": 149.9883575439453, \"slope\": -50.99708938598633, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 5.1983466148376465, \"sigma_intercept_per_group\": 64.72755432128906, \"sigma_obs\": 149.32247924804688, \"slope\": -51.4216423034668, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 3.4839205741882324, \"sigma_intercept_per_group\": 101.42420959472656, \"sigma_obs\": 149.64744567871094, \"slope\": -31.416831970214844, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 3.659660816192627, \"sigma_intercept_per_group\": 89.19828796386719, \"sigma_obs\": 149.61070251464844, \"slope\": -30.012760162353516, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 6.986855506896973, \"sigma_intercept_per_group\": 53.28636932373047, \"sigma_obs\": 149.34228515625, \"slope\": -64.93147277832031, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 5.109130382537842, \"sigma_intercept_per_group\": 69.26675415039062, \"sigma_obs\": 149.8392333984375, \"slope\": -62.635398864746094, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 5.208404064178467, \"sigma_intercept_per_group\": 67.00617980957031, \"sigma_obs\": 150.3441619873047, \"slope\": -39.46193313598633, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 5.332141399383545, \"sigma_intercept_per_group\": 66.49954223632812, \"sigma_obs\": 150.46859741210938, \"slope\": -39.58296203613281, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 5.9935102462768555, \"sigma_intercept_per_group\": 60.30059051513672, \"sigma_obs\": 149.01187133789062, \"slope\": -49.039894104003906, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 7.633599281311035, \"sigma_intercept_per_group\": 49.390769958496094, \"sigma_obs\": 149.4241180419922, \"slope\": -40.1952018737793, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 6.986281394958496, \"sigma_intercept_per_group\": 50.21342468261719, \"sigma_obs\": 149.60507202148438, \"slope\": -41.97958755493164, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 7.919068336486816, \"sigma_intercept_per_group\": 45.626129150390625, \"sigma_obs\": 149.68905639648438, \"slope\": -50.1706657409668, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 7.50275182723999, \"sigma_intercept_per_group\": 48.5141716003418, \"sigma_obs\": 149.79029846191406, \"slope\": -52.201087951660156, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 6.507081031799316, \"sigma_intercept_per_group\": 50.4769287109375, \"sigma_obs\": 148.1484375, \"slope\": -46.960975646972656, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 6.8708672523498535, \"sigma_intercept_per_group\": 54.349517822265625, \"sigma_obs\": 148.3300323486328, \"slope\": -49.33734893798828, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 6.613604545593262, \"sigma_intercept_per_group\": 50.161624908447266, \"sigma_obs\": 148.54342651367188, \"slope\": -52.829776763916016, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.81042766571045, \"sigma_intercept_per_group\": 34.227195739746094, \"sigma_obs\": 150.6180419921875, \"slope\": -51.91100311279297, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 11.643370628356934, \"sigma_intercept_per_group\": 31.34308624267578, \"sigma_obs\": 150.86740112304688, \"slope\": -47.11669158935547, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 9.835589408874512, \"sigma_intercept_per_group\": 33.952667236328125, \"sigma_obs\": 150.99880981445312, \"slope\": -47.38988494873047, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 9.969562530517578, \"sigma_intercept_per_group\": 33.26029968261719, \"sigma_obs\": 150.9950714111328, \"slope\": -46.75352096557617, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 10.506319999694824, \"sigma_intercept_per_group\": 32.50272750854492, \"sigma_obs\": 150.86480712890625, \"slope\": -50.951568603515625, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 10.022452354431152, \"sigma_intercept_per_group\": 36.72361755371094, \"sigma_obs\": 148.0379180908203, \"slope\": -52.28779602050781, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 9.905436515808105, \"sigma_intercept_per_group\": 36.863277435302734, \"sigma_obs\": 148.17889404296875, \"slope\": -52.170013427734375, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 8.634441375732422, \"sigma_intercept_per_group\": 41.108341217041016, \"sigma_obs\": 148.49386596679688, \"slope\": -55.59366226196289, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 9.444035530090332, \"sigma_intercept_per_group\": 39.08082962036133, \"sigma_obs\": 148.44903564453125, \"slope\": -55.971256256103516, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 9.212336540222168, \"sigma_intercept_per_group\": 42.092159271240234, \"sigma_obs\": 148.89993286132812, \"slope\": -59.410789489746094, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 8.394930839538574, \"sigma_intercept_per_group\": 39.844295501708984, \"sigma_obs\": 148.71600341796875, \"slope\": -51.24010467529297, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 10.128040313720703, \"sigma_intercept_per_group\": 37.14492416381836, \"sigma_obs\": 149.87303161621094, \"slope\": -59.51080322265625, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 10.070469856262207, \"sigma_intercept_per_group\": 35.039730072021484, \"sigma_obs\": 149.83802795410156, \"slope\": -61.9698371887207, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 10.015460014343262, \"sigma_intercept_per_group\": 35.76618194580078, \"sigma_obs\": 150.08407592773438, \"slope\": -69.7225570678711, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 9.483497619628906, \"sigma_intercept_per_group\": 39.69683837890625, \"sigma_obs\": 150.1272430419922, \"slope\": -67.75897979736328, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 10.836668014526367, \"sigma_intercept_per_group\": 31.311784744262695, \"sigma_obs\": 148.89715576171875, \"slope\": -52.21194076538086, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 10.374436378479004, \"sigma_intercept_per_group\": 34.02876281738281, \"sigma_obs\": 150.11671447753906, \"slope\": -55.26838302612305, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 9.194436073303223, \"sigma_intercept_per_group\": 37.096805572509766, \"sigma_obs\": 150.3585662841797, \"slope\": -60.55963897705078, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 12.004249572753906, \"sigma_intercept_per_group\": 28.65755844116211, \"sigma_obs\": 148.98919677734375, \"slope\": -36.8075065612793, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 11.856539726257324, \"sigma_intercept_per_group\": 28.985149383544922, \"sigma_obs\": 150.0128173828125, \"slope\": -32.42474365234375, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 13.240726470947266, \"sigma_intercept_per_group\": 26.781641006469727, \"sigma_obs\": 149.50787353515625, \"slope\": -33.20916748046875, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 12.213074684143066, \"sigma_intercept_per_group\": 30.639860153198242, \"sigma_obs\": 150.08128356933594, \"slope\": -63.578399658203125, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 11.838593482971191, \"sigma_intercept_per_group\": 28.432117462158203, \"sigma_obs\": 150.04493713378906, \"slope\": -64.42937469482422, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": 8.768279075622559, \"sigma_intercept_per_group\": 42.46661376953125, \"sigma_obs\": 150.14227294921875, \"slope\": -45.679168701171875, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 7.964690685272217, \"sigma_intercept_per_group\": 41.51305389404297, \"sigma_obs\": 150.16519165039062, \"slope\": -45.710567474365234, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 8.423237800598145, \"sigma_intercept_per_group\": 43.285255432128906, \"sigma_obs\": 150.1427764892578, \"slope\": -44.979209899902344, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 6.896530628204346, \"sigma_intercept_per_group\": 47.69465255737305, \"sigma_obs\": 149.75523376464844, \"slope\": -65.4950180053711, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 7.916696548461914, \"sigma_intercept_per_group\": 45.571250915527344, \"sigma_obs\": 149.09303283691406, \"slope\": -69.1910400390625, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 7.931607723236084, \"sigma_intercept_per_group\": 45.59056091308594, \"sigma_obs\": 149.37881469726562, \"slope\": -70.30494689941406, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 5.146280765533447, \"sigma_intercept_per_group\": 65.63616943359375, \"sigma_obs\": 149.8767547607422, \"slope\": -37.455196380615234, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 5.879347801208496, \"sigma_intercept_per_group\": 62.614402770996094, \"sigma_obs\": 149.72232055664062, \"slope\": -44.023406982421875, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 4.232803821563721, \"sigma_intercept_per_group\": 87.1924057006836, \"sigma_obs\": 150.0166778564453, \"slope\": -73.06346130371094, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 6.215141773223877, \"sigma_intercept_per_group\": 52.633140563964844, \"sigma_obs\": 148.836181640625, \"slope\": -31.6420841217041, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 7.29689884185791, \"sigma_intercept_per_group\": 50.66543197631836, \"sigma_obs\": 150.0127410888672, \"slope\": -59.13755798339844, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 7.498323440551758, \"sigma_intercept_per_group\": 49.88369369506836, \"sigma_obs\": 150.07691955566406, \"slope\": -62.74351501464844, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 8.783544540405273, \"sigma_intercept_per_group\": 40.71681594848633, \"sigma_obs\": 149.0445556640625, \"slope\": -42.311676025390625, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 8.273082733154297, \"sigma_intercept_per_group\": 41.04567337036133, \"sigma_obs\": 148.92747497558594, \"slope\": -45.16836166381836, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 12.084381103515625, \"sigma_intercept_per_group\": 30.004886627197266, \"sigma_obs\": 150.43666076660156, \"slope\": -40.739723205566406, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 12.499151229858398, \"sigma_intercept_per_group\": 29.876075744628906, \"sigma_obs\": 150.46937561035156, \"slope\": -35.70029067993164, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 9.665633201599121, \"sigma_intercept_per_group\": 30.820350646972656, \"sigma_obs\": 149.493896484375, \"slope\": -32.52292251586914, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 15.903630256652832, \"sigma_intercept_per_group\": 23.749744415283203, \"sigma_obs\": 150.1533660888672, \"slope\": -75.24552917480469, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 17.741451263427734, \"sigma_intercept_per_group\": 21.71770477294922, \"sigma_obs\": 149.1768798828125, \"slope\": -57.495758056640625, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 17.281814575195312, \"sigma_intercept_per_group\": 20.124818801879883, \"sigma_obs\": 150.0441436767578, \"slope\": -66.4367446899414, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 15.085576057434082, \"sigma_intercept_per_group\": 23.96558952331543, \"sigma_obs\": 149.38722229003906, \"slope\": -42.78986740112305, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 15.588571548461914, \"sigma_intercept_per_group\": 23.790781021118164, \"sigma_obs\": 149.64166259765625, \"slope\": -67.12482452392578, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 14.792545318603516, \"sigma_intercept_per_group\": 25.116554260253906, \"sigma_obs\": 149.09033203125, \"slope\": -60.92854690551758, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 12.649588584899902, \"sigma_intercept_per_group\": 27.297025680541992, \"sigma_obs\": 149.39028930664062, \"slope\": -62.50963592529297, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 13.244379043579102, \"sigma_intercept_per_group\": 27.81063461303711, \"sigma_obs\": 151.0994415283203, \"slope\": -67.48622131347656, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 12.661734580993652, \"sigma_intercept_per_group\": 27.307205200195312, \"sigma_obs\": 150.3972930908203, \"slope\": -63.5327033996582, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 9.839728355407715, \"sigma_intercept_per_group\": 36.04438781738281, \"sigma_obs\": 148.93357849121094, \"slope\": -58.0826530456543, \"chain\": 1, \"draw\": 160}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 9.202154159545898, \"sigma_intercept_per_group\": 36.98814392089844, \"sigma_obs\": 149.03538513183594, \"slope\": -61.29700469970703, \"chain\": 1, \"draw\": 161}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 11.697294235229492, \"sigma_intercept_per_group\": 32.66135787963867, \"sigma_obs\": 149.78451538085938, \"slope\": -67.38556671142578, \"chain\": 1, \"draw\": 162}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 11.570273399353027, \"sigma_intercept_per_group\": 32.419273376464844, \"sigma_obs\": 150.1197967529297, \"slope\": -68.51101684570312, \"chain\": 1, \"draw\": 163}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 11.511030197143555, \"sigma_intercept_per_group\": 31.6068058013916, \"sigma_obs\": 149.9264373779297, \"slope\": -61.37117385864258, \"chain\": 1, \"draw\": 164}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 13.337885856628418, \"sigma_intercept_per_group\": 26.60269546508789, \"sigma_obs\": 150.3516845703125, \"slope\": -52.483272552490234, \"chain\": 1, \"draw\": 165}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 14.808865547180176, \"sigma_intercept_per_group\": 24.023826599121094, \"sigma_obs\": 150.40274047851562, \"slope\": -51.818359375, \"chain\": 1, \"draw\": 166}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 14.396162986755371, \"sigma_intercept_per_group\": 25.50411033630371, \"sigma_obs\": 150.14620971679688, \"slope\": -49.69293212890625, \"chain\": 1, \"draw\": 167}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": 12.2857666015625, \"sigma_intercept_per_group\": 32.122833251953125, \"sigma_obs\": 150.10240173339844, \"slope\": -58.86885452270508, \"chain\": 1, \"draw\": 168}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 9.982282638549805, \"sigma_intercept_per_group\": 34.06332778930664, \"sigma_obs\": 149.25714111328125, \"slope\": -45.50519943237305, \"chain\": 1, \"draw\": 169}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 13.41805648803711, \"sigma_intercept_per_group\": 28.075538635253906, \"sigma_obs\": 149.7816619873047, \"slope\": -66.23719024658203, \"chain\": 1, \"draw\": 170}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 13.008684158325195, \"sigma_intercept_per_group\": 28.32697105407715, \"sigma_obs\": 149.73867797851562, \"slope\": -36.97660446166992, \"chain\": 1, \"draw\": 171}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 13.635787963867188, \"sigma_intercept_per_group\": 24.407245635986328, \"sigma_obs\": 150.06646728515625, \"slope\": -54.94904708862305, \"chain\": 1, \"draw\": 172}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 11.46671199798584, \"sigma_intercept_per_group\": 27.518112182617188, \"sigma_obs\": 148.8021240234375, \"slope\": -44.23331069946289, \"chain\": 1, \"draw\": 173}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 12.645809173583984, \"sigma_intercept_per_group\": 27.474149703979492, \"sigma_obs\": 149.79930114746094, \"slope\": -44.90391540527344, \"chain\": 1, \"draw\": 174}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 12.608129501342773, \"sigma_intercept_per_group\": 28.825368881225586, \"sigma_obs\": 149.80287170410156, \"slope\": -45.56399917602539, \"chain\": 1, \"draw\": 175}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 12.465412139892578, \"sigma_intercept_per_group\": 27.34790802001953, \"sigma_obs\": 148.8358917236328, \"slope\": -51.72528839111328, \"chain\": 1, \"draw\": 176}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 13.002494812011719, \"sigma_intercept_per_group\": 28.748390197753906, \"sigma_obs\": 148.77296447753906, \"slope\": -49.88285446166992, \"chain\": 1, \"draw\": 177}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 12.937217712402344, \"sigma_intercept_per_group\": 29.098234176635742, \"sigma_obs\": 148.74302673339844, \"slope\": -59.46125030517578, \"chain\": 1, \"draw\": 178}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 13.236355781555176, \"sigma_intercept_per_group\": 30.353761672973633, \"sigma_obs\": 149.7738037109375, \"slope\": -61.754573822021484, \"chain\": 1, \"draw\": 179}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 13.11501407623291, \"sigma_intercept_per_group\": 29.097816467285156, \"sigma_obs\": 149.68692016601562, \"slope\": -52.007144927978516, \"chain\": 1, \"draw\": 180}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 11.81007194519043, \"sigma_intercept_per_group\": 29.543508529663086, \"sigma_obs\": 149.46617126464844, \"slope\": -56.1817512512207, \"chain\": 1, \"draw\": 181}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 13.065034866333008, \"sigma_intercept_per_group\": 28.900066375732422, \"sigma_obs\": 149.2987060546875, \"slope\": -55.31761169433594, \"chain\": 1, \"draw\": 182}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 16.985517501831055, \"sigma_intercept_per_group\": 22.38743782043457, \"sigma_obs\": 150.52658081054688, \"slope\": -68.2265396118164, \"chain\": 1, \"draw\": 183}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 15.375848770141602, \"sigma_intercept_per_group\": 24.104511260986328, \"sigma_obs\": 149.84344482421875, \"slope\": -86.08905792236328, \"chain\": 1, \"draw\": 184}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 13.828131675720215, \"sigma_intercept_per_group\": 26.333133697509766, \"sigma_obs\": 149.30760192871094, \"slope\": -55.230770111083984, \"chain\": 1, \"draw\": 185}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 15.868697166442871, \"sigma_intercept_per_group\": 22.826034545898438, \"sigma_obs\": 150.18287658691406, \"slope\": -82.40233612060547, \"chain\": 1, \"draw\": 186}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 15.019938468933105, \"sigma_intercept_per_group\": 22.207096099853516, \"sigma_obs\": 149.5958709716797, \"slope\": -75.5795669555664, \"chain\": 1, \"draw\": 187}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 12.690558433532715, \"sigma_intercept_per_group\": 25.121395111083984, \"sigma_obs\": 149.4355926513672, \"slope\": -39.00226974487305, \"chain\": 1, \"draw\": 188}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 14.89028549194336, \"sigma_intercept_per_group\": 26.977558135986328, \"sigma_obs\": 150.30609130859375, \"slope\": -56.39103698730469, \"chain\": 1, \"draw\": 189}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 13.719621658325195, \"sigma_intercept_per_group\": 26.860071182250977, \"sigma_obs\": 149.58016967773438, \"slope\": -48.01296615600586, \"chain\": 1, \"draw\": 190}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 12.491247177124023, \"sigma_intercept_per_group\": 28.18824577331543, \"sigma_obs\": 149.35809326171875, \"slope\": -58.38300323486328, \"chain\": 1, \"draw\": 191}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 12.152777671813965, \"sigma_intercept_per_group\": 28.776649475097656, \"sigma_obs\": 149.47999572753906, \"slope\": -51.96708679199219, \"chain\": 1, \"draw\": 192}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 11.741598129272461, \"sigma_intercept_per_group\": 31.425649642944336, \"sigma_obs\": 150.41514587402344, \"slope\": -59.200984954833984, \"chain\": 1, \"draw\": 193}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 10.79664421081543, \"sigma_intercept_per_group\": 32.35205841064453, \"sigma_obs\": 150.2484130859375, \"slope\": -56.13885498046875, \"chain\": 1, \"draw\": 194}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 12.394901275634766, \"sigma_intercept_per_group\": 29.591867446899414, \"sigma_obs\": 149.11209106445312, \"slope\": -70.52861022949219, \"chain\": 1, \"draw\": 195}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 11.637584686279297, \"sigma_intercept_per_group\": 30.178529739379883, \"sigma_obs\": 149.239990234375, \"slope\": -63.856842041015625, \"chain\": 1, \"draw\": 196}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 11.846349716186523, \"sigma_intercept_per_group\": 30.82855224609375, \"sigma_obs\": 149.18490600585938, \"slope\": -64.31880950927734, \"chain\": 1, \"draw\": 197}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 10.43397045135498, \"sigma_intercept_per_group\": 33.25497817993164, \"sigma_obs\": 150.0243377685547, \"slope\": -35.98551940917969, \"chain\": 1, \"draw\": 198}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 8.884814262390137, \"sigma_intercept_per_group\": 40.67255401611328, \"sigma_obs\": 148.97434997558594, \"slope\": -78.41593170166016, \"chain\": 1, \"draw\": 199}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 12.932821273803711, \"sigma_intercept_per_group\": 28.2408504486084, \"sigma_obs\": 149.9814910888672, \"slope\": -56.92304229736328, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 12.607513427734375, \"sigma_intercept_per_group\": 27.781124114990234, \"sigma_obs\": 149.89161682128906, \"slope\": -41.6776008605957, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 10.421667098999023, \"sigma_intercept_per_group\": 33.807804107666016, \"sigma_obs\": 149.28468322753906, \"slope\": -67.65138244628906, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 10.95294189453125, \"sigma_intercept_per_group\": 34.86964416503906, \"sigma_obs\": 149.30909729003906, \"slope\": -70.27485656738281, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 12.624173164367676, \"sigma_intercept_per_group\": 26.826215744018555, \"sigma_obs\": 149.81402587890625, \"slope\": -48.31196212768555, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 13.376911163330078, \"sigma_intercept_per_group\": 28.079769134521484, \"sigma_obs\": 150.04930114746094, \"slope\": -45.28303909301758, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 12.461965560913086, \"sigma_intercept_per_group\": 31.659305572509766, \"sigma_obs\": 149.86532592773438, \"slope\": -75.92716217041016, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 11.559656143188477, \"sigma_intercept_per_group\": 29.643211364746094, \"sigma_obs\": 150.0939483642578, \"slope\": -64.24701690673828, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 11.81203556060791, \"sigma_intercept_per_group\": 30.159719467163086, \"sigma_obs\": 149.84552001953125, \"slope\": -59.47110366821289, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 10.943984031677246, \"sigma_intercept_per_group\": 31.72667694091797, \"sigma_obs\": 150.23831176757812, \"slope\": -46.09202194213867, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 10.623899459838867, \"sigma_intercept_per_group\": 34.75639724731445, \"sigma_obs\": 149.8902587890625, \"slope\": -47.632957458496094, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 11.526450157165527, \"sigma_intercept_per_group\": 32.47600173950195, \"sigma_obs\": 148.71450805664062, \"slope\": -72.0738754272461, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 11.293119430541992, \"sigma_intercept_per_group\": 34.9443473815918, \"sigma_obs\": 148.5020751953125, \"slope\": -71.7523193359375, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 11.764432907104492, \"sigma_intercept_per_group\": 33.915199279785156, \"sigma_obs\": 148.30421447753906, \"slope\": -72.58786010742188, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 12.159270286560059, \"sigma_intercept_per_group\": 35.19479751586914, \"sigma_obs\": 148.35365295410156, \"slope\": -70.2803726196289, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 10.424593925476074, \"sigma_intercept_per_group\": 35.532894134521484, \"sigma_obs\": 149.5848846435547, \"slope\": -62.70464324951172, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 10.879096031188965, \"sigma_intercept_per_group\": 34.47879409790039, \"sigma_obs\": 149.6619415283203, \"slope\": -61.90192794799805, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 9.587295532226562, \"sigma_intercept_per_group\": 39.829830169677734, \"sigma_obs\": 149.6644287109375, \"slope\": -51.165138244628906, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 11.128852844238281, \"sigma_intercept_per_group\": 33.274654388427734, \"sigma_obs\": 149.89862060546875, \"slope\": -62.6220703125, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 10.015878677368164, \"sigma_intercept_per_group\": 35.07706832885742, \"sigma_obs\": 149.65643310546875, \"slope\": -60.06675338745117, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.889513969421387, \"sigma_intercept_per_group\": 31.088186264038086, \"sigma_obs\": 149.4634552001953, \"slope\": -61.591583251953125, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 11.57266616821289, \"sigma_intercept_per_group\": 29.66481590270996, \"sigma_obs\": 149.36563110351562, \"slope\": -65.0810546875, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 11.266541481018066, \"sigma_intercept_per_group\": 31.907894134521484, \"sigma_obs\": 148.82347106933594, \"slope\": -59.8874397277832, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 13.283332824707031, \"sigma_intercept_per_group\": 28.40877342224121, \"sigma_obs\": 149.5603485107422, \"slope\": -54.76527786254883, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 12.089662551879883, \"sigma_intercept_per_group\": 28.857887268066406, \"sigma_obs\": 149.614990234375, \"slope\": -69.69937133789062, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 11.80008602142334, \"sigma_intercept_per_group\": 30.559921264648438, \"sigma_obs\": 149.8219451904297, \"slope\": -57.356563568115234, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 11.547124862670898, \"sigma_intercept_per_group\": 31.61546516418457, \"sigma_obs\": 149.41065979003906, \"slope\": -72.67996215820312, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 11.262802124023438, \"sigma_intercept_per_group\": 33.800018310546875, \"sigma_obs\": 150.13796997070312, \"slope\": -36.31727600097656, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 11.392831802368164, \"sigma_intercept_per_group\": 32.23628234863281, \"sigma_obs\": 150.1767120361328, \"slope\": -35.6829719543457, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 9.416399955749512, \"sigma_intercept_per_group\": 36.51845932006836, \"sigma_obs\": 150.43113708496094, \"slope\": -42.38167953491211, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 9.824956893920898, \"sigma_intercept_per_group\": 36.43455505371094, \"sigma_obs\": 150.35133361816406, \"slope\": -48.20625686645508, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 8.808104515075684, \"sigma_intercept_per_group\": 38.59626007080078, \"sigma_obs\": 150.1597442626953, \"slope\": -49.45503234863281, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 6.864311695098877, \"sigma_intercept_per_group\": 54.29547119140625, \"sigma_obs\": 149.08506774902344, \"slope\": -73.12244415283203, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 6.235584735870361, \"sigma_intercept_per_group\": 59.12739181518555, \"sigma_obs\": 148.51588439941406, \"slope\": -56.62800979614258, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 6.569436550140381, \"sigma_intercept_per_group\": 46.530296325683594, \"sigma_obs\": 150.011962890625, \"slope\": -28.936084747314453, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 9.820472717285156, \"sigma_intercept_per_group\": 36.408382415771484, \"sigma_obs\": 149.86253356933594, \"slope\": -84.28812408447266, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 9.580020904541016, \"sigma_intercept_per_group\": 40.732398986816406, \"sigma_obs\": 149.71461486816406, \"slope\": -76.31169128417969, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 10.087870597839355, \"sigma_intercept_per_group\": 37.61369323730469, \"sigma_obs\": 149.36178588867188, \"slope\": -65.61651611328125, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 9.59917163848877, \"sigma_intercept_per_group\": 37.161277770996094, \"sigma_obs\": 149.9823455810547, \"slope\": -65.5815200805664, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 10.267611503601074, \"sigma_intercept_per_group\": 35.01966094970703, \"sigma_obs\": 150.20114135742188, \"slope\": -55.28022384643555, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 10.788188934326172, \"sigma_intercept_per_group\": 31.26617431640625, \"sigma_obs\": 149.5244140625, \"slope\": -54.89482879638672, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 13.865323066711426, \"sigma_intercept_per_group\": 26.73248291015625, \"sigma_obs\": 149.90133666992188, \"slope\": -49.187320709228516, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 13.629632949829102, \"sigma_intercept_per_group\": 27.289112091064453, \"sigma_obs\": 149.9352264404297, \"slope\": -59.0245246887207, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 14.243756294250488, \"sigma_intercept_per_group\": 25.994468688964844, \"sigma_obs\": 149.98748779296875, \"slope\": -52.93175506591797, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 15.120848655700684, \"sigma_intercept_per_group\": 23.407888412475586, \"sigma_obs\": 150.28302001953125, \"slope\": -43.492645263671875, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 17.53875732421875, \"sigma_intercept_per_group\": 22.06814193725586, \"sigma_obs\": 150.26295471191406, \"slope\": -51.47919464111328, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 16.835603713989258, \"sigma_intercept_per_group\": 23.102096557617188, \"sigma_obs\": 150.37649536132812, \"slope\": -54.51995086669922, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 16.96844482421875, \"sigma_intercept_per_group\": 21.493118286132812, \"sigma_obs\": 148.73748779296875, \"slope\": -50.716407775878906, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 17.548742294311523, \"sigma_intercept_per_group\": 19.999122619628906, \"sigma_obs\": 149.1716766357422, \"slope\": -35.87165069580078, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 18.080137252807617, \"sigma_intercept_per_group\": 19.057825088500977, \"sigma_obs\": 149.1669921875, \"slope\": -35.516014099121094, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 17.206348419189453, \"sigma_intercept_per_group\": 19.87080192565918, \"sigma_obs\": 149.69091796875, \"slope\": -68.3768081665039, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 12.454523086547852, \"sigma_intercept_per_group\": 25.822303771972656, \"sigma_obs\": 149.04490661621094, \"slope\": -37.85193634033203, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 15.519237518310547, \"sigma_intercept_per_group\": 24.07105827331543, \"sigma_obs\": 148.8043212890625, \"slope\": -37.953609466552734, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 13.454845428466797, \"sigma_intercept_per_group\": 24.239973068237305, \"sigma_obs\": 148.86477661132812, \"slope\": -38.406494140625, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 15.189955711364746, \"sigma_intercept_per_group\": 25.291492462158203, \"sigma_obs\": 149.8899688720703, \"slope\": -48.03862380981445, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 12.916178703308105, \"sigma_intercept_per_group\": 26.21569061279297, \"sigma_obs\": 150.01760864257812, \"slope\": -16.066499710083008, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 11.914666175842285, \"sigma_intercept_per_group\": 26.798248291015625, \"sigma_obs\": 150.04071044921875, \"slope\": -23.575756072998047, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 12.527092933654785, \"sigma_intercept_per_group\": 28.78832244873047, \"sigma_obs\": 149.64736938476562, \"slope\": -26.52445411682129, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 11.626688957214355, \"sigma_intercept_per_group\": 31.729633331298828, \"sigma_obs\": 149.4030303955078, \"slope\": -71.27552795410156, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 13.66341781616211, \"sigma_intercept_per_group\": 27.515159606933594, \"sigma_obs\": 149.30020141601562, \"slope\": -49.8277587890625, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 12.946368217468262, \"sigma_intercept_per_group\": 28.09011459350586, \"sigma_obs\": 149.5474395751953, \"slope\": -51.756797790527344, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 11.41550350189209, \"sigma_intercept_per_group\": 34.56875228881836, \"sigma_obs\": 149.57675170898438, \"slope\": -85.49920654296875, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 11.189044952392578, \"sigma_intercept_per_group\": 32.80913162231445, \"sigma_obs\": 149.59779357910156, \"slope\": -86.74429321289062, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 12.60996150970459, \"sigma_intercept_per_group\": 29.19448471069336, \"sigma_obs\": 149.07852172851562, \"slope\": -51.90673065185547, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 11.935111045837402, \"sigma_intercept_per_group\": 28.25433349609375, \"sigma_obs\": 150.00515747070312, \"slope\": -45.43831253051758, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 12.763641357421875, \"sigma_intercept_per_group\": 28.81355857849121, \"sigma_obs\": 150.41241455078125, \"slope\": -45.20682907104492, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 13.991302490234375, \"sigma_intercept_per_group\": 25.752073287963867, \"sigma_obs\": 150.48574829101562, \"slope\": -56.24309539794922, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 8.757843017578125, \"sigma_intercept_per_group\": 36.40184020996094, \"sigma_obs\": 148.74594116210938, \"slope\": -49.3320198059082, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 11.68653392791748, \"sigma_intercept_per_group\": 34.758270263671875, \"sigma_obs\": 148.58551025390625, \"slope\": -58.15275192260742, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 11.633562088012695, \"sigma_intercept_per_group\": 33.856868743896484, \"sigma_obs\": 148.6245574951172, \"slope\": -57.456966400146484, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 10.195740699768066, \"sigma_intercept_per_group\": 32.85891342163086, \"sigma_obs\": 149.2512969970703, \"slope\": -45.89016342163086, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 10.863065719604492, \"sigma_intercept_per_group\": 32.303009033203125, \"sigma_obs\": 149.31016540527344, \"slope\": -43.516910552978516, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 10.420695304870605, \"sigma_intercept_per_group\": 31.700862884521484, \"sigma_obs\": 148.94686889648438, \"slope\": -62.360782623291016, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 11.636606216430664, \"sigma_intercept_per_group\": 29.66411590576172, \"sigma_obs\": 150.6221466064453, \"slope\": -57.1563606262207, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 11.344648361206055, \"sigma_intercept_per_group\": 32.10137939453125, \"sigma_obs\": 150.2381591796875, \"slope\": -54.68900680541992, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 12.271449089050293, \"sigma_intercept_per_group\": 30.007640838623047, \"sigma_obs\": 149.5091552734375, \"slope\": -60.59846115112305, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 13.190057754516602, \"sigma_intercept_per_group\": 29.220605850219727, \"sigma_obs\": 149.27798461914062, \"slope\": -47.2110710144043, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 11.592764854431152, \"sigma_intercept_per_group\": 29.372804641723633, \"sigma_obs\": 149.29534912109375, \"slope\": -60.7282829284668, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 10.92121696472168, \"sigma_intercept_per_group\": 32.52154541015625, \"sigma_obs\": 149.87403869628906, \"slope\": -45.71375274658203, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 10.597929954528809, \"sigma_intercept_per_group\": 31.247596740722656, \"sigma_obs\": 150.009033203125, \"slope\": -52.05729675292969, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 10.940069198608398, \"sigma_intercept_per_group\": 31.272443771362305, \"sigma_obs\": 150.03048706054688, \"slope\": -51.83207702636719, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 9.302616119384766, \"sigma_intercept_per_group\": 39.966304779052734, \"sigma_obs\": 149.11380004882812, \"slope\": -63.8470344543457, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 7.24957799911499, \"sigma_intercept_per_group\": 46.77680206298828, \"sigma_obs\": 149.41806030273438, \"slope\": -46.22017288208008, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 8.486992835998535, \"sigma_intercept_per_group\": 41.27655792236328, \"sigma_obs\": 149.4540557861328, \"slope\": -52.888938903808594, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 7.76864767074585, \"sigma_intercept_per_group\": 46.734397888183594, \"sigma_obs\": 149.38516235351562, \"slope\": -57.53165817260742, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 6.521977424621582, \"sigma_intercept_per_group\": 50.24983215332031, \"sigma_obs\": 148.872314453125, \"slope\": -63.319679260253906, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 6.53973913192749, \"sigma_intercept_per_group\": 48.124168395996094, \"sigma_obs\": 149.39242553710938, \"slope\": -50.62717819213867, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 11.21953010559082, \"sigma_intercept_per_group\": 31.09370994567871, \"sigma_obs\": 149.55691528320312, \"slope\": -53.63612747192383, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 10.783488273620605, \"sigma_intercept_per_group\": 32.073890686035156, \"sigma_obs\": 149.46054077148438, \"slope\": -50.91706085205078, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 10.761430740356445, \"sigma_intercept_per_group\": 32.53390884399414, \"sigma_obs\": 149.59693908691406, \"slope\": -51.0548095703125, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 11.20490837097168, \"sigma_intercept_per_group\": 32.65534973144531, \"sigma_obs\": 149.60400390625, \"slope\": -49.21818923950195, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 10.894855499267578, \"sigma_intercept_per_group\": 33.3702392578125, \"sigma_obs\": 149.8357391357422, \"slope\": -49.782257080078125, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 10.727254867553711, \"sigma_intercept_per_group\": 31.7624454498291, \"sigma_obs\": 149.86846923828125, \"slope\": -39.334407806396484, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 9.682307243347168, \"sigma_intercept_per_group\": 37.91794204711914, \"sigma_obs\": 149.70176696777344, \"slope\": -67.4252700805664, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 8.983375549316406, \"sigma_intercept_per_group\": 39.39912033081055, \"sigma_obs\": 150.17442321777344, \"slope\": -52.065887451171875, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 6.760251522064209, \"sigma_intercept_per_group\": 56.984371185302734, \"sigma_obs\": 149.66964721679688, \"slope\": -34.41216278076172, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 5.753769874572754, \"sigma_intercept_per_group\": 59.71404266357422, \"sigma_obs\": 149.35104370117188, \"slope\": -49.32047653198242, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 7.297539710998535, \"sigma_intercept_per_group\": 55.441131591796875, \"sigma_obs\": 149.60379028320312, \"slope\": -58.88754653930664, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 6.4815497398376465, \"sigma_intercept_per_group\": 53.83161163330078, \"sigma_obs\": 149.4407958984375, \"slope\": -55.71691131591797, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 6.1811747550964355, \"sigma_intercept_per_group\": 59.76620101928711, \"sigma_obs\": 149.19515991210938, \"slope\": -64.42808532714844, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 6.085032939910889, \"sigma_intercept_per_group\": 60.49293899536133, \"sigma_obs\": 149.60977172851562, \"slope\": -74.01913452148438, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 8.246581077575684, \"sigma_intercept_per_group\": 47.694732666015625, \"sigma_obs\": 149.36741638183594, \"slope\": -81.68744659423828, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 7.5505595207214355, \"sigma_intercept_per_group\": 46.29090118408203, \"sigma_obs\": 149.5612030029297, \"slope\": -82.34151458740234, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 8.574755668640137, \"sigma_intercept_per_group\": 49.60881805419922, \"sigma_obs\": 149.36669921875, \"slope\": -82.04602813720703, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": 6.6650590896606445, \"sigma_intercept_per_group\": 46.708377838134766, \"sigma_obs\": 149.81051635742188, \"slope\": -32.22996520996094, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": 8.052938461303711, \"sigma_intercept_per_group\": 44.577022552490234, \"sigma_obs\": 149.97898864746094, \"slope\": -41.168792724609375, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 8.645190238952637, \"sigma_intercept_per_group\": 42.48161315917969, \"sigma_obs\": 149.3756866455078, \"slope\": -72.06976318359375, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 7.877379894256592, \"sigma_intercept_per_group\": 45.48069381713867, \"sigma_obs\": 149.4085235595703, \"slope\": -73.31832122802734, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 8.357924461364746, \"sigma_intercept_per_group\": 46.37391662597656, \"sigma_obs\": 149.4789276123047, \"slope\": -62.46219253540039, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 10.473993301391602, \"sigma_intercept_per_group\": 32.8843994140625, \"sigma_obs\": 149.609130859375, \"slope\": -31.132892608642578, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 9.921985626220703, \"sigma_intercept_per_group\": 36.812522888183594, \"sigma_obs\": 149.12026977539062, \"slope\": -35.56773376464844, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 10.857259750366211, \"sigma_intercept_per_group\": 32.1336784362793, \"sigma_obs\": 149.03794860839844, \"slope\": -36.67203140258789, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 11.199874877929688, \"sigma_intercept_per_group\": 34.15412139892578, \"sigma_obs\": 148.96511840820312, \"slope\": -36.631526947021484, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 10.470536231994629, \"sigma_intercept_per_group\": 30.29210090637207, \"sigma_obs\": 150.07635498046875, \"slope\": -30.335512161254883, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 9.953486442565918, \"sigma_intercept_per_group\": 37.2745361328125, \"sigma_obs\": 149.7386016845703, \"slope\": -58.30036544799805, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 9.365028381347656, \"sigma_intercept_per_group\": 42.0003662109375, \"sigma_obs\": 150.1438446044922, \"slope\": -63.024986267089844, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 9.274791717529297, \"sigma_intercept_per_group\": 39.70135498046875, \"sigma_obs\": 150.28546142578125, \"slope\": -62.300498962402344, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 8.221920013427734, \"sigma_intercept_per_group\": 43.062400817871094, \"sigma_obs\": 150.52032470703125, \"slope\": -63.93791580200195, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 8.331295013427734, \"sigma_intercept_per_group\": 45.87865447998047, \"sigma_obs\": 149.60906982421875, \"slope\": -64.95704650878906, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 8.151941299438477, \"sigma_intercept_per_group\": 43.3839225769043, \"sigma_obs\": 149.59950256347656, \"slope\": -65.95553588867188, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 7.254655838012695, \"sigma_intercept_per_group\": 49.81130599975586, \"sigma_obs\": 149.8284454345703, \"slope\": -57.404075622558594, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 6.80889892578125, \"sigma_intercept_per_group\": 50.832733154296875, \"sigma_obs\": 149.40652465820312, \"slope\": -62.44459915161133, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 7.091213226318359, \"sigma_intercept_per_group\": 55.96579360961914, \"sigma_obs\": 148.67303466796875, \"slope\": -66.38162994384766, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 8.853593826293945, \"sigma_intercept_per_group\": 38.692955017089844, \"sigma_obs\": 149.66793823242188, \"slope\": -34.45853042602539, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 9.376175880432129, \"sigma_intercept_per_group\": 38.98112487792969, \"sigma_obs\": 149.28411865234375, \"slope\": -35.13855743408203, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 8.683531761169434, \"sigma_intercept_per_group\": 40.465728759765625, \"sigma_obs\": 150.07620239257812, \"slope\": -43.18672561645508, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 9.401918411254883, \"sigma_intercept_per_group\": 37.06919479370117, \"sigma_obs\": 149.75938415527344, \"slope\": -35.872188568115234, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 8.96379280090332, \"sigma_intercept_per_group\": 39.460697174072266, \"sigma_obs\": 149.75360107421875, \"slope\": -33.96523666381836, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 9.288330078125, \"sigma_intercept_per_group\": 38.750579833984375, \"sigma_obs\": 149.61741638183594, \"slope\": -28.334762573242188, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": 8.240191459655762, \"sigma_intercept_per_group\": 44.876522064208984, \"sigma_obs\": 149.71018981933594, \"slope\": -16.529457092285156, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 6.318216800689697, \"sigma_intercept_per_group\": 52.25089645385742, \"sigma_obs\": 149.643310546875, \"slope\": -30.731773376464844, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 9.654708862304688, \"sigma_intercept_per_group\": 38.041831970214844, \"sigma_obs\": 149.48426818847656, \"slope\": -58.87641525268555, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 10.856789588928223, \"sigma_intercept_per_group\": 30.92159080505371, \"sigma_obs\": 150.17514038085938, \"slope\": -38.00929260253906, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 11.89115047454834, \"sigma_intercept_per_group\": 30.450899124145508, \"sigma_obs\": 149.27001953125, \"slope\": -75.10746765136719, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 12.261566162109375, \"sigma_intercept_per_group\": 31.28819465637207, \"sigma_obs\": 149.90426635742188, \"slope\": -78.18477630615234, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 13.030388832092285, \"sigma_intercept_per_group\": 28.058128356933594, \"sigma_obs\": 149.80279541015625, \"slope\": -73.10515594482422, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 10.87699031829834, \"sigma_intercept_per_group\": 32.47443771362305, \"sigma_obs\": 149.6870574951172, \"slope\": -59.64079666137695, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 10.48548412322998, \"sigma_intercept_per_group\": 38.081207275390625, \"sigma_obs\": 149.52005004882812, \"slope\": -61.562171936035156, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 10.031451225280762, \"sigma_intercept_per_group\": 36.34879684448242, \"sigma_obs\": 149.18789672851562, \"slope\": -67.23326873779297, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 8.95887565612793, \"sigma_intercept_per_group\": 37.41767883300781, \"sigma_obs\": 150.50741577148438, \"slope\": -67.79561614990234, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 12.007109642028809, \"sigma_intercept_per_group\": 31.52255630493164, \"sigma_obs\": 150.24761962890625, \"slope\": -64.32698059082031, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 9.310606002807617, \"sigma_intercept_per_group\": 34.575904846191406, \"sigma_obs\": 149.744384765625, \"slope\": -77.19860076904297, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 10.697399139404297, \"sigma_intercept_per_group\": 35.68790817260742, \"sigma_obs\": 148.93138122558594, \"slope\": -59.93794250488281, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 10.60852336883545, \"sigma_intercept_per_group\": 35.32102584838867, \"sigma_obs\": 149.60121154785156, \"slope\": -51.87514877319336, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 10.665848731994629, \"sigma_intercept_per_group\": 33.15134811401367, \"sigma_obs\": 150.06991577148438, \"slope\": -46.369537353515625, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 7.212688446044922, \"sigma_intercept_per_group\": 52.04518127441406, \"sigma_obs\": 148.74082946777344, \"slope\": -74.90487670898438, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 7.647363662719727, \"sigma_intercept_per_group\": 50.04373550415039, \"sigma_obs\": 150.227783203125, \"slope\": -46.854915618896484, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 6.4139885902404785, \"sigma_intercept_per_group\": 49.22843933105469, \"sigma_obs\": 150.20457458496094, \"slope\": -47.40263366699219, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 9.757902145385742, \"sigma_intercept_per_group\": 34.78876495361328, \"sigma_obs\": 148.9015655517578, \"slope\": -65.02546691894531, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 6.979348182678223, \"sigma_intercept_per_group\": 49.198543548583984, \"sigma_obs\": 149.46945190429688, \"slope\": -57.91337966918945, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 8.604216575622559, \"sigma_intercept_per_group\": 42.780433654785156, \"sigma_obs\": 149.88418579101562, \"slope\": -52.80186080932617, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 8.179105758666992, \"sigma_intercept_per_group\": 46.31017303466797, \"sigma_obs\": 148.8301544189453, \"slope\": -43.76424026489258, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 8.085428237915039, \"sigma_intercept_per_group\": 43.28837966918945, \"sigma_obs\": 148.8981475830078, \"slope\": -49.19413757324219, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 6.785043716430664, \"sigma_intercept_per_group\": 46.727088928222656, \"sigma_obs\": 149.18128967285156, \"slope\": -44.5637092590332, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 7.878840923309326, \"sigma_intercept_per_group\": 47.182586669921875, \"sigma_obs\": 149.15296936035156, \"slope\": -67.25364685058594, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 7.88079833984375, \"sigma_intercept_per_group\": 47.218902587890625, \"sigma_obs\": 148.95901489257812, \"slope\": -66.8662109375, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 7.451599597930908, \"sigma_intercept_per_group\": 47.03003692626953, \"sigma_obs\": 148.8092803955078, \"slope\": -69.009521484375, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 8.367899894714355, \"sigma_intercept_per_group\": 44.79789733886719, \"sigma_obs\": 148.67098999023438, \"slope\": -70.05595397949219, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 9.06887435913086, \"sigma_intercept_per_group\": 44.284908294677734, \"sigma_obs\": 149.30282592773438, \"slope\": -59.96355056762695, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 9.042526245117188, \"sigma_intercept_per_group\": 43.028564453125, \"sigma_obs\": 149.2986297607422, \"slope\": -59.94430923461914, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 8.206840515136719, \"sigma_intercept_per_group\": 40.92930603027344, \"sigma_obs\": 149.002197265625, \"slope\": -56.88553237915039, \"chain\": 2, \"draw\": 160}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 9.838640213012695, \"sigma_intercept_per_group\": 38.0201530456543, \"sigma_obs\": 149.55264282226562, \"slope\": -56.813194274902344, \"chain\": 2, \"draw\": 161}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 9.362780570983887, \"sigma_intercept_per_group\": 39.54132080078125, \"sigma_obs\": 149.487548828125, \"slope\": -81.16752624511719, \"chain\": 2, \"draw\": 162}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 9.256501197814941, \"sigma_intercept_per_group\": 39.15386199951172, \"sigma_obs\": 149.4251251220703, \"slope\": -82.12211608886719, \"chain\": 2, \"draw\": 163}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.814387321472168, \"sigma_intercept_per_group\": 38.4681396484375, \"sigma_obs\": 150.2681121826172, \"slope\": -43.18540573120117, \"chain\": 2, \"draw\": 164}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 10.306273460388184, \"sigma_intercept_per_group\": 32.395713806152344, \"sigma_obs\": 148.89552307128906, \"slope\": -52.784942626953125, \"chain\": 2, \"draw\": 165}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 8.963644027709961, \"sigma_intercept_per_group\": 43.306663513183594, \"sigma_obs\": 150.27513122558594, \"slope\": -45.972503662109375, \"chain\": 2, \"draw\": 166}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 8.34640884399414, \"sigma_intercept_per_group\": 41.02183151245117, \"sigma_obs\": 149.795654296875, \"slope\": -53.975337982177734, \"chain\": 2, \"draw\": 167}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 9.06482982635498, \"sigma_intercept_per_group\": 39.00727081298828, \"sigma_obs\": 149.52554321289062, \"slope\": -34.91872024536133, \"chain\": 2, \"draw\": 168}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 6.262929439544678, \"sigma_intercept_per_group\": 50.600929260253906, \"sigma_obs\": 149.9842071533203, \"slope\": -39.19443893432617, \"chain\": 2, \"draw\": 169}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 8.518619537353516, \"sigma_intercept_per_group\": 43.741493225097656, \"sigma_obs\": 149.91893005371094, \"slope\": -62.90880584716797, \"chain\": 2, \"draw\": 170}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 7.825648307800293, \"sigma_intercept_per_group\": 44.1774787902832, \"sigma_obs\": 149.80694580078125, \"slope\": -48.382530212402344, \"chain\": 2, \"draw\": 171}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 7.310818672180176, \"sigma_intercept_per_group\": 46.34214782714844, \"sigma_obs\": 149.9977264404297, \"slope\": -47.954593658447266, \"chain\": 2, \"draw\": 172}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 7.030733585357666, \"sigma_intercept_per_group\": 44.61217498779297, \"sigma_obs\": 150.18923950195312, \"slope\": -44.07026290893555, \"chain\": 2, \"draw\": 173}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 8.276421546936035, \"sigma_intercept_per_group\": 46.25059127807617, \"sigma_obs\": 150.34408569335938, \"slope\": -46.74321365356445, \"chain\": 2, \"draw\": 174}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 7.402637004852295, \"sigma_intercept_per_group\": 49.03145217895508, \"sigma_obs\": 150.56591796875, \"slope\": -44.79983901977539, \"chain\": 2, \"draw\": 175}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 7.828991889953613, \"sigma_intercept_per_group\": 45.41879653930664, \"sigma_obs\": 150.38775634765625, \"slope\": -41.409950256347656, \"chain\": 2, \"draw\": 176}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 8.534147262573242, \"sigma_intercept_per_group\": 45.55944061279297, \"sigma_obs\": 150.41551208496094, \"slope\": -41.06117630004883, \"chain\": 2, \"draw\": 177}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 7.840980529785156, \"sigma_intercept_per_group\": 44.93928527832031, \"sigma_obs\": 150.11521911621094, \"slope\": -45.35396194458008, \"chain\": 2, \"draw\": 178}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 7.074116230010986, \"sigma_intercept_per_group\": 47.95979309082031, \"sigma_obs\": 149.3961944580078, \"slope\": -42.48301315307617, \"chain\": 2, \"draw\": 179}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 11.9286470413208, \"sigma_intercept_per_group\": 32.119754791259766, \"sigma_obs\": 150.0704803466797, \"slope\": -65.87995147705078, \"chain\": 2, \"draw\": 180}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 11.981047630310059, \"sigma_intercept_per_group\": 31.989824295043945, \"sigma_obs\": 150.01760864257812, \"slope\": -55.16585922241211, \"chain\": 2, \"draw\": 181}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 10.483858108520508, \"sigma_intercept_per_group\": 33.10736846923828, \"sigma_obs\": 149.64288330078125, \"slope\": -59.64963150024414, \"chain\": 2, \"draw\": 182}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 10.778717041015625, \"sigma_intercept_per_group\": 36.52464294433594, \"sigma_obs\": 149.66836547851562, \"slope\": -57.7021369934082, \"chain\": 2, \"draw\": 183}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 9.50455379486084, \"sigma_intercept_per_group\": 33.23161315917969, \"sigma_obs\": 149.18917846679688, \"slope\": -66.4971694946289, \"chain\": 2, \"draw\": 184}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 11.63215446472168, \"sigma_intercept_per_group\": 34.571876525878906, \"sigma_obs\": 149.23593139648438, \"slope\": -60.549598693847656, \"chain\": 2, \"draw\": 185}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 10.06318473815918, \"sigma_intercept_per_group\": 41.26976776123047, \"sigma_obs\": 149.62710571289062, \"slope\": -46.77846908569336, \"chain\": 2, \"draw\": 186}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 8.875434875488281, \"sigma_intercept_per_group\": 40.24291229248047, \"sigma_obs\": 149.17979431152344, \"slope\": -43.999813079833984, \"chain\": 2, \"draw\": 187}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 9.624136924743652, \"sigma_intercept_per_group\": 38.5634651184082, \"sigma_obs\": 148.95339965820312, \"slope\": -50.683834075927734, \"chain\": 2, \"draw\": 188}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 8.524888038635254, \"sigma_intercept_per_group\": 42.34941864013672, \"sigma_obs\": 148.94679260253906, \"slope\": -65.25275421142578, \"chain\": 2, \"draw\": 189}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 10.187176704406738, \"sigma_intercept_per_group\": 37.36117172241211, \"sigma_obs\": 149.5097198486328, \"slope\": -72.3075942993164, \"chain\": 2, \"draw\": 190}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 10.125185012817383, \"sigma_intercept_per_group\": 38.970458984375, \"sigma_obs\": 149.43972778320312, \"slope\": -72.5997314453125, \"chain\": 2, \"draw\": 191}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 8.977848052978516, \"sigma_intercept_per_group\": 38.39219284057617, \"sigma_obs\": 149.4427947998047, \"slope\": -57.45625305175781, \"chain\": 2, \"draw\": 192}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 9.907881736755371, \"sigma_intercept_per_group\": 36.13473129272461, \"sigma_obs\": 150.13296508789062, \"slope\": -58.720069885253906, \"chain\": 2, \"draw\": 193}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 10.20732593536377, \"sigma_intercept_per_group\": 30.77359390258789, \"sigma_obs\": 148.8423614501953, \"slope\": -47.73109817504883, \"chain\": 2, \"draw\": 194}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 10.21557903289795, \"sigma_intercept_per_group\": 32.101715087890625, \"sigma_obs\": 148.87210083007812, \"slope\": -46.51782989501953, \"chain\": 2, \"draw\": 195}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 11.907957077026367, \"sigma_intercept_per_group\": 30.03348731994629, \"sigma_obs\": 150.17120361328125, \"slope\": -56.167205810546875, \"chain\": 2, \"draw\": 196}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 11.86826229095459, \"sigma_intercept_per_group\": 31.37647819519043, \"sigma_obs\": 150.21395874023438, \"slope\": -48.37398147583008, \"chain\": 2, \"draw\": 197}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 11.396306991577148, \"sigma_intercept_per_group\": 32.41941833496094, \"sigma_obs\": 150.57229614257812, \"slope\": -38.6264533996582, \"chain\": 2, \"draw\": 198}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 10.323060035705566, \"sigma_intercept_per_group\": 30.552228927612305, \"sigma_obs\": 150.8916473388672, \"slope\": -39.349876403808594, \"chain\": 2, \"draw\": 199}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 8.969614028930664, \"sigma_intercept_per_group\": 39.797828674316406, \"sigma_obs\": 149.24851989746094, \"slope\": -53.703128814697266, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 9.141499519348145, \"sigma_intercept_per_group\": 40.40498352050781, \"sigma_obs\": 149.31301879882812, \"slope\": -54.27500915527344, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 9.982765197753906, \"sigma_intercept_per_group\": 34.40089416503906, \"sigma_obs\": 150.03184509277344, \"slope\": -55.67878341674805, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 10.419866561889648, \"sigma_intercept_per_group\": 34.18991470336914, \"sigma_obs\": 150.26832580566406, \"slope\": -56.66985321044922, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 10.425129890441895, \"sigma_intercept_per_group\": 35.50615310668945, \"sigma_obs\": 149.75115966796875, \"slope\": -54.74111557006836, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 10.953563690185547, \"sigma_intercept_per_group\": 33.91717529296875, \"sigma_obs\": 149.7740936279297, \"slope\": -66.04747009277344, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 11.06769847869873, \"sigma_intercept_per_group\": 34.90497970581055, \"sigma_obs\": 149.774658203125, \"slope\": -66.41301727294922, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 12.587502479553223, \"sigma_intercept_per_group\": 27.829404830932617, \"sigma_obs\": 149.85060119628906, \"slope\": -67.72528076171875, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 12.212563514709473, \"sigma_intercept_per_group\": 29.81825065612793, \"sigma_obs\": 149.2893829345703, \"slope\": -53.03959274291992, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 10.688494682312012, \"sigma_intercept_per_group\": 33.72574996948242, \"sigma_obs\": 149.7021942138672, \"slope\": -56.12704086303711, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 11.053979873657227, \"sigma_intercept_per_group\": 31.787817001342773, \"sigma_obs\": 149.35296630859375, \"slope\": -54.60025405883789, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 13.011966705322266, \"sigma_intercept_per_group\": 29.189876556396484, \"sigma_obs\": 149.53509521484375, \"slope\": -47.485748291015625, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 11.241118431091309, \"sigma_intercept_per_group\": 28.83407211303711, \"sigma_obs\": 149.79537963867188, \"slope\": -48.65481948852539, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 11.923799514770508, \"sigma_intercept_per_group\": 29.654916763305664, \"sigma_obs\": 149.7822265625, \"slope\": -53.56775665283203, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 12.994828224182129, \"sigma_intercept_per_group\": 29.78944969177246, \"sigma_obs\": 149.47943115234375, \"slope\": -54.28810119628906, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 13.866838455200195, \"sigma_intercept_per_group\": 30.311708450317383, \"sigma_obs\": 149.4055938720703, \"slope\": -54.669612884521484, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 11.325870513916016, \"sigma_intercept_per_group\": 29.430644989013672, \"sigma_obs\": 149.56597900390625, \"slope\": -56.46135711669922, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 12.705991744995117, \"sigma_intercept_per_group\": 28.80392074584961, \"sigma_obs\": 149.60549926757812, \"slope\": -66.86804962158203, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 14.772555351257324, \"sigma_intercept_per_group\": 27.64714241027832, \"sigma_obs\": 149.00440979003906, \"slope\": -53.094573974609375, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 14.087296485900879, \"sigma_intercept_per_group\": 27.909578323364258, \"sigma_obs\": 149.05792236328125, \"slope\": -53.39004898071289, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 12.047786712646484, \"sigma_intercept_per_group\": 28.381471633911133, \"sigma_obs\": 149.32647705078125, \"slope\": -36.650794982910156, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 11.06732177734375, \"sigma_intercept_per_group\": 32.2325553894043, \"sigma_obs\": 149.03936767578125, \"slope\": -61.0895881652832, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 10.991538047790527, \"sigma_intercept_per_group\": 29.195661544799805, \"sigma_obs\": 150.15673828125, \"slope\": -40.379276275634766, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 11.437387466430664, \"sigma_intercept_per_group\": 30.275928497314453, \"sigma_obs\": 149.73167419433594, \"slope\": -45.13876724243164, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 11.094756126403809, \"sigma_intercept_per_group\": 32.32337951660156, \"sigma_obs\": 149.7843017578125, \"slope\": -45.67937469482422, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 11.44845962524414, \"sigma_intercept_per_group\": 35.05482864379883, \"sigma_obs\": 148.93927001953125, \"slope\": -65.18575286865234, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 12.710989952087402, \"sigma_intercept_per_group\": 29.573789596557617, \"sigma_obs\": 150.0838623046875, \"slope\": -62.39550018310547, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 10.933051109313965, \"sigma_intercept_per_group\": 32.79873275756836, \"sigma_obs\": 150.14112854003906, \"slope\": -61.762306213378906, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 10.480586051940918, \"sigma_intercept_per_group\": 39.18811798095703, \"sigma_obs\": 149.58973693847656, \"slope\": -76.41439819335938, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 8.490199089050293, \"sigma_intercept_per_group\": 45.569786071777344, \"sigma_obs\": 149.51820373535156, \"slope\": -65.33365631103516, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 7.998578071594238, \"sigma_intercept_per_group\": 44.86735534667969, \"sigma_obs\": 149.44151306152344, \"slope\": -59.12660598754883, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 8.154507637023926, \"sigma_intercept_per_group\": 46.50042724609375, \"sigma_obs\": 149.2767791748047, \"slope\": -60.637908935546875, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 7.650768756866455, \"sigma_intercept_per_group\": 46.57422637939453, \"sigma_obs\": 149.2268829345703, \"slope\": -58.12887191772461, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 5.871665954589844, \"sigma_intercept_per_group\": 59.030174255371094, \"sigma_obs\": 149.1829833984375, \"slope\": -57.16595458984375, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 5.9364142417907715, \"sigma_intercept_per_group\": 58.73155212402344, \"sigma_obs\": 149.18618774414062, \"slope\": -57.386512756347656, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 8.128868103027344, \"sigma_intercept_per_group\": 42.023292541503906, \"sigma_obs\": 148.90028381347656, \"slope\": -53.270843505859375, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 9.288825988769531, \"sigma_intercept_per_group\": 39.22404098510742, \"sigma_obs\": 149.48106384277344, \"slope\": -44.97898483276367, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 13.365771293640137, \"sigma_intercept_per_group\": 27.941070556640625, \"sigma_obs\": 149.9925079345703, \"slope\": -67.28974151611328, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 13.376826286315918, \"sigma_intercept_per_group\": 27.931034088134766, \"sigma_obs\": 149.80209350585938, \"slope\": -65.996337890625, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 11.627250671386719, \"sigma_intercept_per_group\": 29.03453254699707, \"sigma_obs\": 149.1083221435547, \"slope\": -39.77928161621094, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 640, \"mu_intercept_per_group\": 12.577581405639648, \"sigma_intercept_per_group\": 28.593732833862305, \"sigma_obs\": 149.49560546875, \"slope\": -51.79585266113281, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 641, \"mu_intercept_per_group\": 12.399062156677246, \"sigma_intercept_per_group\": 30.749404907226562, \"sigma_obs\": 149.4436492919922, \"slope\": -61.07163619995117, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 642, \"mu_intercept_per_group\": 10.423301696777344, \"sigma_intercept_per_group\": 35.61671829223633, \"sigma_obs\": 150.29779052734375, \"slope\": -51.15089797973633, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 643, \"mu_intercept_per_group\": 9.70880126953125, \"sigma_intercept_per_group\": 35.055992126464844, \"sigma_obs\": 150.32545471191406, \"slope\": -56.707157135009766, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 644, \"mu_intercept_per_group\": 10.70035457611084, \"sigma_intercept_per_group\": 32.81318664550781, \"sigma_obs\": 149.62747192382812, \"slope\": -61.992000579833984, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 645, \"mu_intercept_per_group\": 9.493640899658203, \"sigma_intercept_per_group\": 36.58837127685547, \"sigma_obs\": 150.04000854492188, \"slope\": -47.70600891113281, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 646, \"mu_intercept_per_group\": 9.488411903381348, \"sigma_intercept_per_group\": 35.98486328125, \"sigma_obs\": 149.94158935546875, \"slope\": -41.473018646240234, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 647, \"mu_intercept_per_group\": 6.064734935760498, \"sigma_intercept_per_group\": 62.10935974121094, \"sigma_obs\": 149.19692993164062, \"slope\": -52.86369705200195, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 648, \"mu_intercept_per_group\": 5.556668281555176, \"sigma_intercept_per_group\": 62.33975601196289, \"sigma_obs\": 149.30987548828125, \"slope\": -51.033260345458984, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 649, \"mu_intercept_per_group\": 6.462488651275635, \"sigma_intercept_per_group\": 55.630577087402344, \"sigma_obs\": 150.09803771972656, \"slope\": -66.313232421875, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 650, \"mu_intercept_per_group\": 6.522670745849609, \"sigma_intercept_per_group\": 56.568233489990234, \"sigma_obs\": 149.7403106689453, \"slope\": -67.07889556884766, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 651, \"mu_intercept_per_group\": 5.859230995178223, \"sigma_intercept_per_group\": 67.22803497314453, \"sigma_obs\": 149.8679656982422, \"slope\": -78.67586517333984, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 652, \"mu_intercept_per_group\": 5.801149845123291, \"sigma_intercept_per_group\": 65.14498138427734, \"sigma_obs\": 149.9058380126953, \"slope\": -76.61106872558594, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 653, \"mu_intercept_per_group\": 10.166823387145996, \"sigma_intercept_per_group\": 34.54305648803711, \"sigma_obs\": 149.3522491455078, \"slope\": -42.3956413269043, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 654, \"mu_intercept_per_group\": 5.568660259246826, \"sigma_intercept_per_group\": 64.30777740478516, \"sigma_obs\": 149.00262451171875, \"slope\": -70.73319244384766, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 655, \"mu_intercept_per_group\": 5.539837837219238, \"sigma_intercept_per_group\": 62.894935607910156, \"sigma_obs\": 149.00299072265625, \"slope\": -70.35411834716797, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 656, \"mu_intercept_per_group\": 6.05386209487915, \"sigma_intercept_per_group\": 62.70930099487305, \"sigma_obs\": 149.201416015625, \"slope\": -67.4554672241211, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 657, \"mu_intercept_per_group\": 9.050978660583496, \"sigma_intercept_per_group\": 40.33037567138672, \"sigma_obs\": 149.94009399414062, \"slope\": -65.42355346679688, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 658, \"mu_intercept_per_group\": 7.740325450897217, \"sigma_intercept_per_group\": 46.51158142089844, \"sigma_obs\": 149.6935577392578, \"slope\": -59.2196044921875, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 659, \"mu_intercept_per_group\": 8.174643516540527, \"sigma_intercept_per_group\": 44.23012161254883, \"sigma_obs\": 149.63160705566406, \"slope\": -57.749534606933594, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 660, \"mu_intercept_per_group\": 7.984317302703857, \"sigma_intercept_per_group\": 46.73834228515625, \"sigma_obs\": 149.41514587402344, \"slope\": -54.56046676635742, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 661, \"mu_intercept_per_group\": 6.413971900939941, \"sigma_intercept_per_group\": 53.565338134765625, \"sigma_obs\": 150.5032501220703, \"slope\": -51.723052978515625, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 662, \"mu_intercept_per_group\": 6.422076225280762, \"sigma_intercept_per_group\": 57.46141052246094, \"sigma_obs\": 150.2155303955078, \"slope\": -56.76536560058594, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 663, \"mu_intercept_per_group\": 6.309511661529541, \"sigma_intercept_per_group\": 54.868431091308594, \"sigma_obs\": 150.299072265625, \"slope\": -55.823936462402344, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 664, \"mu_intercept_per_group\": 6.148965358734131, \"sigma_intercept_per_group\": 57.937137603759766, \"sigma_obs\": 150.18724060058594, \"slope\": -58.817481994628906, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 665, \"mu_intercept_per_group\": 6.584911346435547, \"sigma_intercept_per_group\": 56.12306594848633, \"sigma_obs\": 150.02841186523438, \"slope\": -58.20888900756836, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 666, \"mu_intercept_per_group\": 11.50439453125, \"sigma_intercept_per_group\": 32.94123458862305, \"sigma_obs\": 149.58053588867188, \"slope\": -55.11065673828125, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 667, \"mu_intercept_per_group\": 7.644707202911377, \"sigma_intercept_per_group\": 47.298439025878906, \"sigma_obs\": 149.60891723632812, \"slope\": -43.51453399658203, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 668, \"mu_intercept_per_group\": 7.234286785125732, \"sigma_intercept_per_group\": 51.25526428222656, \"sigma_obs\": 149.34754943847656, \"slope\": -60.69580841064453, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 669, \"mu_intercept_per_group\": 6.7870283126831055, \"sigma_intercept_per_group\": 53.49867630004883, \"sigma_obs\": 149.9662628173828, \"slope\": -55.000343322753906, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 670, \"mu_intercept_per_group\": 6.3094964027404785, \"sigma_intercept_per_group\": 55.82698440551758, \"sigma_obs\": 149.94236755371094, \"slope\": -55.019371032714844, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 671, \"mu_intercept_per_group\": 8.360604286193848, \"sigma_intercept_per_group\": 43.43305969238281, \"sigma_obs\": 149.82186889648438, \"slope\": -39.1512336730957, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 672, \"mu_intercept_per_group\": 9.435396194458008, \"sigma_intercept_per_group\": 41.0853157043457, \"sigma_obs\": 149.36770629882812, \"slope\": -82.77497100830078, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 673, \"mu_intercept_per_group\": 6.11918306350708, \"sigma_intercept_per_group\": 56.53587341308594, \"sigma_obs\": 149.74624633789062, \"slope\": -62.22017288208008, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 674, \"mu_intercept_per_group\": 6.907912731170654, \"sigma_intercept_per_group\": 49.32791519165039, \"sigma_obs\": 149.71197509765625, \"slope\": -49.907527923583984, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 675, \"mu_intercept_per_group\": 7.3350653648376465, \"sigma_intercept_per_group\": 49.74290084838867, \"sigma_obs\": 149.719970703125, \"slope\": -48.420013427734375, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 676, \"mu_intercept_per_group\": 7.076115131378174, \"sigma_intercept_per_group\": 53.591766357421875, \"sigma_obs\": 149.7735137939453, \"slope\": -52.86709213256836, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 677, \"mu_intercept_per_group\": 7.270553112030029, \"sigma_intercept_per_group\": 50.86212921142578, \"sigma_obs\": 149.75616455078125, \"slope\": -54.45124053955078, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 678, \"mu_intercept_per_group\": 6.76141357421875, \"sigma_intercept_per_group\": 47.871429443359375, \"sigma_obs\": 149.6562957763672, \"slope\": -47.729522705078125, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 679, \"mu_intercept_per_group\": 6.434093475341797, \"sigma_intercept_per_group\": 51.97257995605469, \"sigma_obs\": 150.09259033203125, \"slope\": -48.05812454223633, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 680, \"mu_intercept_per_group\": 5.753491401672363, \"sigma_intercept_per_group\": 61.295997619628906, \"sigma_obs\": 150.76312255859375, \"slope\": -44.124229431152344, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 681, \"mu_intercept_per_group\": 8.621536254882812, \"sigma_intercept_per_group\": 41.036415100097656, \"sigma_obs\": 148.7876434326172, \"slope\": -59.210472106933594, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 682, \"mu_intercept_per_group\": 9.453145980834961, \"sigma_intercept_per_group\": 40.09690856933594, \"sigma_obs\": 149.1243896484375, \"slope\": -57.500244140625, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 683, \"mu_intercept_per_group\": 9.36215877532959, \"sigma_intercept_per_group\": 37.609222412109375, \"sigma_obs\": 149.11834716796875, \"slope\": -61.06543731689453, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 684, \"mu_intercept_per_group\": 10.48302936553955, \"sigma_intercept_per_group\": 33.4036865234375, \"sigma_obs\": 150.10812377929688, \"slope\": -33.909027099609375, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 685, \"mu_intercept_per_group\": 11.381909370422363, \"sigma_intercept_per_group\": 29.93646812438965, \"sigma_obs\": 148.6487274169922, \"slope\": -36.96488571166992, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 686, \"mu_intercept_per_group\": 10.924843788146973, \"sigma_intercept_per_group\": 28.499774932861328, \"sigma_obs\": 150.1331787109375, \"slope\": -35.88608932495117, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 687, \"mu_intercept_per_group\": 12.983100891113281, \"sigma_intercept_per_group\": 27.134754180908203, \"sigma_obs\": 149.8111572265625, \"slope\": -24.39476203918457, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 688, \"mu_intercept_per_group\": 12.291954040527344, \"sigma_intercept_per_group\": 27.33142852783203, \"sigma_obs\": 149.49374389648438, \"slope\": -26.08132553100586, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 689, \"mu_intercept_per_group\": 13.537484169006348, \"sigma_intercept_per_group\": 27.120512008666992, \"sigma_obs\": 149.13868713378906, \"slope\": -25.486984252929688, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 690, \"mu_intercept_per_group\": 13.727743148803711, \"sigma_intercept_per_group\": 27.96885108947754, \"sigma_obs\": 149.82473754882812, \"slope\": -79.81719970703125, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 691, \"mu_intercept_per_group\": 13.13376235961914, \"sigma_intercept_per_group\": 27.11872100830078, \"sigma_obs\": 149.25051879882812, \"slope\": -36.43144226074219, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 692, \"mu_intercept_per_group\": 14.459563255310059, \"sigma_intercept_per_group\": 26.06061363220215, \"sigma_obs\": 149.50921630859375, \"slope\": -44.736427307128906, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 693, \"mu_intercept_per_group\": 16.907421112060547, \"sigma_intercept_per_group\": 23.724334716796875, \"sigma_obs\": 148.6039276123047, \"slope\": -55.17925262451172, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 694, \"mu_intercept_per_group\": 14.481817245483398, \"sigma_intercept_per_group\": 23.878549575805664, \"sigma_obs\": 148.56773376464844, \"slope\": -52.108882904052734, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 695, \"mu_intercept_per_group\": 10.812710762023926, \"sigma_intercept_per_group\": 31.942533493041992, \"sigma_obs\": 149.759521484375, \"slope\": -56.3205680847168, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 696, \"mu_intercept_per_group\": 15.356611251831055, \"sigma_intercept_per_group\": 23.416706085205078, \"sigma_obs\": 149.5321807861328, \"slope\": -51.4175910949707, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 697, \"mu_intercept_per_group\": 15.90696907043457, \"sigma_intercept_per_group\": 23.030887603759766, \"sigma_obs\": 149.44757080078125, \"slope\": -40.9432258605957, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 698, \"mu_intercept_per_group\": 15.8771333694458, \"sigma_intercept_per_group\": 22.88582420349121, \"sigma_obs\": 149.44671630859375, \"slope\": -41.146488189697266, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 699, \"mu_intercept_per_group\": 14.420198440551758, \"sigma_intercept_per_group\": 24.67955207824707, \"sigma_obs\": 149.61427307128906, \"slope\": -48.084381103515625, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 700, \"mu_intercept_per_group\": 16.374752044677734, \"sigma_intercept_per_group\": 22.46479034423828, \"sigma_obs\": 150.1994171142578, \"slope\": -61.769264221191406, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 701, \"mu_intercept_per_group\": 13.953788757324219, \"sigma_intercept_per_group\": 24.448688507080078, \"sigma_obs\": 148.9864959716797, \"slope\": -66.78024291992188, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 702, \"mu_intercept_per_group\": 17.24220085144043, \"sigma_intercept_per_group\": 21.068540573120117, \"sigma_obs\": 149.51007080078125, \"slope\": -56.11101531982422, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 703, \"mu_intercept_per_group\": 16.52190399169922, \"sigma_intercept_per_group\": 22.886184692382812, \"sigma_obs\": 148.64865112304688, \"slope\": -54.227294921875, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 704, \"mu_intercept_per_group\": 17.08745765686035, \"sigma_intercept_per_group\": 22.076557159423828, \"sigma_obs\": 150.04666137695312, \"slope\": -56.702919006347656, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 705, \"mu_intercept_per_group\": 12.268174171447754, \"sigma_intercept_per_group\": 30.72484016418457, \"sigma_obs\": 149.1226043701172, \"slope\": -72.10225677490234, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 706, \"mu_intercept_per_group\": 11.446138381958008, \"sigma_intercept_per_group\": 31.09046173095703, \"sigma_obs\": 149.6746368408203, \"slope\": -36.53008270263672, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 707, \"mu_intercept_per_group\": 11.34583854675293, \"sigma_intercept_per_group\": 31.831180572509766, \"sigma_obs\": 150.28982543945312, \"slope\": -29.71929359436035, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 708, \"mu_intercept_per_group\": 13.217501640319824, \"sigma_intercept_per_group\": 27.224140167236328, \"sigma_obs\": 150.2145233154297, \"slope\": -45.06717300415039, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 709, \"mu_intercept_per_group\": 12.231100082397461, \"sigma_intercept_per_group\": 28.628671646118164, \"sigma_obs\": 150.65589904785156, \"slope\": -32.624942779541016, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 710, \"mu_intercept_per_group\": 13.578710556030273, \"sigma_intercept_per_group\": 28.337501525878906, \"sigma_obs\": 149.74974060058594, \"slope\": -48.55332565307617, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 711, \"mu_intercept_per_group\": 11.45312786102295, \"sigma_intercept_per_group\": 29.02643585205078, \"sigma_obs\": 150.1046142578125, \"slope\": -49.835514068603516, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 712, \"mu_intercept_per_group\": 10.782361030578613, \"sigma_intercept_per_group\": 34.744384765625, \"sigma_obs\": 149.6984100341797, \"slope\": -55.124271392822266, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 713, \"mu_intercept_per_group\": 11.290562629699707, \"sigma_intercept_per_group\": 32.60394287109375, \"sigma_obs\": 149.14309692382812, \"slope\": -57.56433868408203, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 714, \"mu_intercept_per_group\": 9.040813446044922, \"sigma_intercept_per_group\": 39.787166595458984, \"sigma_obs\": 149.50502014160156, \"slope\": -48.159446716308594, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 715, \"mu_intercept_per_group\": 10.823014259338379, \"sigma_intercept_per_group\": 32.505680084228516, \"sigma_obs\": 148.84136962890625, \"slope\": -38.97305679321289, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 716, \"mu_intercept_per_group\": 11.821381568908691, \"sigma_intercept_per_group\": 31.84182357788086, \"sigma_obs\": 149.28326416015625, \"slope\": -53.69269561767578, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 717, \"mu_intercept_per_group\": 13.111496925354004, \"sigma_intercept_per_group\": 26.91877555847168, \"sigma_obs\": 149.73974609375, \"slope\": -52.75967025756836, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 718, \"mu_intercept_per_group\": 12.824597358703613, \"sigma_intercept_per_group\": 28.6251163482666, \"sigma_obs\": 149.8776092529297, \"slope\": -70.38489532470703, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 719, \"mu_intercept_per_group\": 16.722797393798828, \"sigma_intercept_per_group\": 23.572980880737305, \"sigma_obs\": 149.99607849121094, \"slope\": -79.48884582519531, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 720, \"mu_intercept_per_group\": 14.527649879455566, \"sigma_intercept_per_group\": 27.130569458007812, \"sigma_obs\": 148.85903930664062, \"slope\": -87.77865600585938, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 721, \"mu_intercept_per_group\": 12.803001403808594, \"sigma_intercept_per_group\": 27.050691604614258, \"sigma_obs\": 148.59451293945312, \"slope\": -74.28412628173828, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 722, \"mu_intercept_per_group\": 14.66860294342041, \"sigma_intercept_per_group\": 25.906667709350586, \"sigma_obs\": 148.01519775390625, \"slope\": -59.88166809082031, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 723, \"mu_intercept_per_group\": 12.620409965515137, \"sigma_intercept_per_group\": 27.2808895111084, \"sigma_obs\": 149.67884826660156, \"slope\": -55.23183822631836, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 724, \"mu_intercept_per_group\": 15.2241849899292, \"sigma_intercept_per_group\": 26.398515701293945, \"sigma_obs\": 149.59835815429688, \"slope\": -48.060176849365234, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 725, \"mu_intercept_per_group\": 13.068041801452637, \"sigma_intercept_per_group\": 25.778322219848633, \"sigma_obs\": 149.6505126953125, \"slope\": -56.51639175415039, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 726, \"mu_intercept_per_group\": 14.194169998168945, \"sigma_intercept_per_group\": 25.219951629638672, \"sigma_obs\": 149.78016662597656, \"slope\": -62.52903366088867, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 727, \"mu_intercept_per_group\": 14.705320358276367, \"sigma_intercept_per_group\": 24.22286605834961, \"sigma_obs\": 149.0962371826172, \"slope\": -47.563438415527344, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 728, \"mu_intercept_per_group\": 14.779685974121094, \"sigma_intercept_per_group\": 24.936656951904297, \"sigma_obs\": 149.5214080810547, \"slope\": -52.80880355834961, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 729, \"mu_intercept_per_group\": 13.8563814163208, \"sigma_intercept_per_group\": 23.974361419677734, \"sigma_obs\": 149.76930236816406, \"slope\": -39.1859245300293, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 730, \"mu_intercept_per_group\": 14.801727294921875, \"sigma_intercept_per_group\": 25.800155639648438, \"sigma_obs\": 149.3464813232422, \"slope\": -60.07048034667969, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 731, \"mu_intercept_per_group\": 12.03048038482666, \"sigma_intercept_per_group\": 30.590065002441406, \"sigma_obs\": 149.63389587402344, \"slope\": -54.88322830200195, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 732, \"mu_intercept_per_group\": 13.4150972366333, \"sigma_intercept_per_group\": 29.368471145629883, \"sigma_obs\": 149.45718383789062, \"slope\": -53.061256408691406, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 733, \"mu_intercept_per_group\": 11.103283882141113, \"sigma_intercept_per_group\": 28.875349044799805, \"sigma_obs\": 148.67083740234375, \"slope\": -45.04933166503906, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 734, \"mu_intercept_per_group\": 11.041401863098145, \"sigma_intercept_per_group\": 33.95161437988281, \"sigma_obs\": 150.71804809570312, \"slope\": -68.46733093261719, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 735, \"mu_intercept_per_group\": 11.38629150390625, \"sigma_intercept_per_group\": 33.98228454589844, \"sigma_obs\": 150.93252563476562, \"slope\": -66.04681396484375, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 736, \"mu_intercept_per_group\": 8.990859985351562, \"sigma_intercept_per_group\": 38.88502502441406, \"sigma_obs\": 149.00454711914062, \"slope\": -47.97492218017578, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 737, \"mu_intercept_per_group\": 10.913572311401367, \"sigma_intercept_per_group\": 35.34335708618164, \"sigma_obs\": 148.64837646484375, \"slope\": -52.5514030456543, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 738, \"mu_intercept_per_group\": 9.540661811828613, \"sigma_intercept_per_group\": 36.74904251098633, \"sigma_obs\": 149.07447814941406, \"slope\": -58.66435241699219, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 739, \"mu_intercept_per_group\": 9.885551452636719, \"sigma_intercept_per_group\": 36.49473571777344, \"sigma_obs\": 149.10064697265625, \"slope\": -58.94429016113281, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 740, \"mu_intercept_per_group\": 10.77833366394043, \"sigma_intercept_per_group\": 35.050575256347656, \"sigma_obs\": 149.56398010253906, \"slope\": -52.545291900634766, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 741, \"mu_intercept_per_group\": 8.997485160827637, \"sigma_intercept_per_group\": 37.71259689331055, \"sigma_obs\": 149.44479370117188, \"slope\": -46.57403564453125, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 742, \"mu_intercept_per_group\": 9.02265453338623, \"sigma_intercept_per_group\": 36.89469528198242, \"sigma_obs\": 149.51393127441406, \"slope\": -46.64009475708008, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 743, \"mu_intercept_per_group\": 11.057331085205078, \"sigma_intercept_per_group\": 31.931842803955078, \"sigma_obs\": 149.36143493652344, \"slope\": -38.613487243652344, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 744, \"mu_intercept_per_group\": 11.222312927246094, \"sigma_intercept_per_group\": 33.661590576171875, \"sigma_obs\": 149.577392578125, \"slope\": -56.920650482177734, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 745, \"mu_intercept_per_group\": 11.828192710876465, \"sigma_intercept_per_group\": 30.852346420288086, \"sigma_obs\": 150.09024047851562, \"slope\": -47.38932418823242, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 746, \"mu_intercept_per_group\": 10.97363567352295, \"sigma_intercept_per_group\": 34.221073150634766, \"sigma_obs\": 149.0024871826172, \"slope\": -58.96162033081055, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 747, \"mu_intercept_per_group\": 10.912248611450195, \"sigma_intercept_per_group\": 34.33283233642578, \"sigma_obs\": 149.0070343017578, \"slope\": -59.03157043457031, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 748, \"mu_intercept_per_group\": 7.5930304527282715, \"sigma_intercept_per_group\": 44.109375, \"sigma_obs\": 150.45367431640625, \"slope\": -55.11520767211914, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 749, \"mu_intercept_per_group\": 8.870293617248535, \"sigma_intercept_per_group\": 44.07700729370117, \"sigma_obs\": 150.43975830078125, \"slope\": -57.1993522644043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 750, \"mu_intercept_per_group\": 9.5540132522583, \"sigma_intercept_per_group\": 39.44708251953125, \"sigma_obs\": 148.55532836914062, \"slope\": -73.34575653076172, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 751, \"mu_intercept_per_group\": 9.929974555969238, \"sigma_intercept_per_group\": 38.9285888671875, \"sigma_obs\": 148.93670654296875, \"slope\": -36.72061538696289, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 752, \"mu_intercept_per_group\": 10.174285888671875, \"sigma_intercept_per_group\": 36.94684982299805, \"sigma_obs\": 150.2220458984375, \"slope\": -41.723785400390625, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 753, \"mu_intercept_per_group\": 9.962597846984863, \"sigma_intercept_per_group\": 34.1566162109375, \"sigma_obs\": 148.49874877929688, \"slope\": -40.50437927246094, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 754, \"mu_intercept_per_group\": 9.713443756103516, \"sigma_intercept_per_group\": 36.26573944091797, \"sigma_obs\": 148.63766479492188, \"slope\": -43.8365592956543, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 755, \"mu_intercept_per_group\": 9.642979621887207, \"sigma_intercept_per_group\": 36.090518951416016, \"sigma_obs\": 148.63681030273438, \"slope\": -43.89973831176758, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 756, \"mu_intercept_per_group\": 11.070981979370117, \"sigma_intercept_per_group\": 32.805450439453125, \"sigma_obs\": 148.5435791015625, \"slope\": -38.69224166870117, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 757, \"mu_intercept_per_group\": 10.907362937927246, \"sigma_intercept_per_group\": 31.4542236328125, \"sigma_obs\": 148.64894104003906, \"slope\": -32.875770568847656, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 758, \"mu_intercept_per_group\": 12.741983413696289, \"sigma_intercept_per_group\": 30.254215240478516, \"sigma_obs\": 149.21536254882812, \"slope\": -26.972253799438477, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 759, \"mu_intercept_per_group\": 12.710384368896484, \"sigma_intercept_per_group\": 29.434194564819336, \"sigma_obs\": 148.6268310546875, \"slope\": -36.92820739746094, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 760, \"mu_intercept_per_group\": 11.312230110168457, \"sigma_intercept_per_group\": 29.467378616333008, \"sigma_obs\": 149.26475524902344, \"slope\": -32.738731384277344, \"chain\": 3, \"draw\": 160}, {\"mouse\": 7, \"draws\": 761, \"mu_intercept_per_group\": 11.447319984436035, \"sigma_intercept_per_group\": 31.26399040222168, \"sigma_obs\": 148.90135192871094, \"slope\": -53.47361373901367, \"chain\": 3, \"draw\": 161}, {\"mouse\": 7, \"draws\": 762, \"mu_intercept_per_group\": 7.736050605773926, \"sigma_intercept_per_group\": 41.3063850402832, \"sigma_obs\": 150.04844665527344, \"slope\": -38.76655197143555, \"chain\": 3, \"draw\": 162}, {\"mouse\": 7, \"draws\": 763, \"mu_intercept_per_group\": 8.94742202758789, \"sigma_intercept_per_group\": 40.1536750793457, \"sigma_obs\": 150.27206420898438, \"slope\": -35.04038619995117, \"chain\": 3, \"draw\": 163}, {\"mouse\": 7, \"draws\": 764, \"mu_intercept_per_group\": 12.446178436279297, \"sigma_intercept_per_group\": 27.59532928466797, \"sigma_obs\": 149.6392364501953, \"slope\": -64.56290435791016, \"chain\": 3, \"draw\": 164}, {\"mouse\": 7, \"draws\": 765, \"mu_intercept_per_group\": 12.682336807250977, \"sigma_intercept_per_group\": 27.504528045654297, \"sigma_obs\": 148.51275634765625, \"slope\": -69.7296142578125, \"chain\": 3, \"draw\": 165}, {\"mouse\": 7, \"draws\": 766, \"mu_intercept_per_group\": 12.854276657104492, \"sigma_intercept_per_group\": 28.35382843017578, \"sigma_obs\": 149.31072998046875, \"slope\": -70.59873962402344, \"chain\": 3, \"draw\": 166}, {\"mouse\": 7, \"draws\": 767, \"mu_intercept_per_group\": 13.73818302154541, \"sigma_intercept_per_group\": 26.685537338256836, \"sigma_obs\": 149.47250366210938, \"slope\": -69.87269592285156, \"chain\": 3, \"draw\": 167}, {\"mouse\": 7, \"draws\": 768, \"mu_intercept_per_group\": 14.5586519241333, \"sigma_intercept_per_group\": 26.602333068847656, \"sigma_obs\": 149.21713256835938, \"slope\": -63.52388381958008, \"chain\": 3, \"draw\": 168}, {\"mouse\": 7, \"draws\": 769, \"mu_intercept_per_group\": 11.894071578979492, \"sigma_intercept_per_group\": 26.6981258392334, \"sigma_obs\": 149.17381286621094, \"slope\": -61.07274627685547, \"chain\": 3, \"draw\": 169}, {\"mouse\": 7, \"draws\": 770, \"mu_intercept_per_group\": 16.49319839477539, \"sigma_intercept_per_group\": 22.789676666259766, \"sigma_obs\": 149.39427185058594, \"slope\": -49.03448486328125, \"chain\": 3, \"draw\": 170}, {\"mouse\": 7, \"draws\": 771, \"mu_intercept_per_group\": 13.835418701171875, \"sigma_intercept_per_group\": 26.23227310180664, \"sigma_obs\": 148.9504852294922, \"slope\": -55.793643951416016, \"chain\": 3, \"draw\": 171}, {\"mouse\": 7, \"draws\": 772, \"mu_intercept_per_group\": 13.674811363220215, \"sigma_intercept_per_group\": 25.141586303710938, \"sigma_obs\": 148.9178924560547, \"slope\": -48.72225570678711, \"chain\": 3, \"draw\": 172}, {\"mouse\": 7, \"draws\": 773, \"mu_intercept_per_group\": 9.741236686706543, \"sigma_intercept_per_group\": 38.17262649536133, \"sigma_obs\": 150.2451934814453, \"slope\": -61.209449768066406, \"chain\": 3, \"draw\": 173}, {\"mouse\": 7, \"draws\": 774, \"mu_intercept_per_group\": 8.639215469360352, \"sigma_intercept_per_group\": 41.64714431762695, \"sigma_obs\": 149.7413787841797, \"slope\": -50.613243103027344, \"chain\": 3, \"draw\": 174}, {\"mouse\": 7, \"draws\": 775, \"mu_intercept_per_group\": 9.533571243286133, \"sigma_intercept_per_group\": 40.84455490112305, \"sigma_obs\": 149.74288940429688, \"slope\": -53.26091003417969, \"chain\": 3, \"draw\": 175}, {\"mouse\": 7, \"draws\": 776, \"mu_intercept_per_group\": 9.376082420349121, \"sigma_intercept_per_group\": 42.00336837768555, \"sigma_obs\": 149.79151916503906, \"slope\": -51.604957580566406, \"chain\": 3, \"draw\": 176}, {\"mouse\": 7, \"draws\": 777, \"mu_intercept_per_group\": 8.340288162231445, \"sigma_intercept_per_group\": 38.514739990234375, \"sigma_obs\": 149.65480041503906, \"slope\": -54.72943115234375, \"chain\": 3, \"draw\": 177}, {\"mouse\": 7, \"draws\": 778, \"mu_intercept_per_group\": 9.965736389160156, \"sigma_intercept_per_group\": 38.98981857299805, \"sigma_obs\": 149.48056030273438, \"slope\": -58.06358337402344, \"chain\": 3, \"draw\": 178}, {\"mouse\": 7, \"draws\": 779, \"mu_intercept_per_group\": 8.816882133483887, \"sigma_intercept_per_group\": 40.96273422241211, \"sigma_obs\": 149.32760620117188, \"slope\": -59.85368728637695, \"chain\": 3, \"draw\": 179}, {\"mouse\": 7, \"draws\": 780, \"mu_intercept_per_group\": 11.696566581726074, \"sigma_intercept_per_group\": 32.24744415283203, \"sigma_obs\": 149.12452697753906, \"slope\": -65.30731964111328, \"chain\": 3, \"draw\": 180}, {\"mouse\": 7, \"draws\": 781, \"mu_intercept_per_group\": 10.112627029418945, \"sigma_intercept_per_group\": 36.58480453491211, \"sigma_obs\": 149.23870849609375, \"slope\": -69.21104431152344, \"chain\": 3, \"draw\": 181}, {\"mouse\": 7, \"draws\": 782, \"mu_intercept_per_group\": 10.309979438781738, \"sigma_intercept_per_group\": 32.348609924316406, \"sigma_obs\": 149.05209350585938, \"slope\": -58.47964096069336, \"chain\": 3, \"draw\": 182}, {\"mouse\": 7, \"draws\": 783, \"mu_intercept_per_group\": 8.78647518157959, \"sigma_intercept_per_group\": 36.98827362060547, \"sigma_obs\": 148.58041381835938, \"slope\": -59.232025146484375, \"chain\": 3, \"draw\": 183}, {\"mouse\": 7, \"draws\": 784, \"mu_intercept_per_group\": 10.587617874145508, \"sigma_intercept_per_group\": 37.5113410949707, \"sigma_obs\": 148.6498565673828, \"slope\": -60.99367141723633, \"chain\": 3, \"draw\": 184}, {\"mouse\": 7, \"draws\": 785, \"mu_intercept_per_group\": 7.710811614990234, \"sigma_intercept_per_group\": 39.550777435302734, \"sigma_obs\": 149.89675903320312, \"slope\": -43.223819732666016, \"chain\": 3, \"draw\": 185}, {\"mouse\": 7, \"draws\": 786, \"mu_intercept_per_group\": 8.484600067138672, \"sigma_intercept_per_group\": 42.45391082763672, \"sigma_obs\": 149.99600219726562, \"slope\": -45.79113006591797, \"chain\": 3, \"draw\": 186}, {\"mouse\": 7, \"draws\": 787, \"mu_intercept_per_group\": 9.504579544067383, \"sigma_intercept_per_group\": 38.36369705200195, \"sigma_obs\": 149.77609252929688, \"slope\": -49.984230041503906, \"chain\": 3, \"draw\": 187}, {\"mouse\": 7, \"draws\": 788, \"mu_intercept_per_group\": 10.628092765808105, \"sigma_intercept_per_group\": 35.563812255859375, \"sigma_obs\": 150.57122802734375, \"slope\": -40.6912841796875, \"chain\": 3, \"draw\": 188}, {\"mouse\": 7, \"draws\": 789, \"mu_intercept_per_group\": 10.031142234802246, \"sigma_intercept_per_group\": 36.961483001708984, \"sigma_obs\": 149.1175537109375, \"slope\": -64.6260986328125, \"chain\": 3, \"draw\": 189}, {\"mouse\": 7, \"draws\": 790, \"mu_intercept_per_group\": 8.798791885375977, \"sigma_intercept_per_group\": 39.681678771972656, \"sigma_obs\": 148.78231811523438, \"slope\": -44.92689895629883, \"chain\": 3, \"draw\": 190}, {\"mouse\": 7, \"draws\": 791, \"mu_intercept_per_group\": 9.424964904785156, \"sigma_intercept_per_group\": 37.9449462890625, \"sigma_obs\": 149.4321746826172, \"slope\": -45.83393859863281, \"chain\": 3, \"draw\": 191}, {\"mouse\": 7, \"draws\": 792, \"mu_intercept_per_group\": 9.21310806274414, \"sigma_intercept_per_group\": 36.04187774658203, \"sigma_obs\": 149.56304931640625, \"slope\": -44.81796646118164, \"chain\": 3, \"draw\": 192}, {\"mouse\": 7, \"draws\": 793, \"mu_intercept_per_group\": 8.659992218017578, \"sigma_intercept_per_group\": 45.8780517578125, \"sigma_obs\": 149.60470581054688, \"slope\": -55.9234733581543, \"chain\": 3, \"draw\": 193}, {\"mouse\": 7, \"draws\": 794, \"mu_intercept_per_group\": 7.878162860870361, \"sigma_intercept_per_group\": 46.316978454589844, \"sigma_obs\": 149.77001953125, \"slope\": -61.34113311767578, \"chain\": 3, \"draw\": 194}, {\"mouse\": 7, \"draws\": 795, \"mu_intercept_per_group\": 8.283644676208496, \"sigma_intercept_per_group\": 46.45271301269531, \"sigma_obs\": 149.71424865722656, \"slope\": -57.08464050292969, \"chain\": 3, \"draw\": 195}, {\"mouse\": 7, \"draws\": 796, \"mu_intercept_per_group\": 10.037446022033691, \"sigma_intercept_per_group\": 35.25872802734375, \"sigma_obs\": 149.87246704101562, \"slope\": -49.91300964355469, \"chain\": 3, \"draw\": 196}, {\"mouse\": 7, \"draws\": 797, \"mu_intercept_per_group\": 9.99404239654541, \"sigma_intercept_per_group\": 36.3427848815918, \"sigma_obs\": 149.86546325683594, \"slope\": -52.58259582519531, \"chain\": 3, \"draw\": 197}, {\"mouse\": 7, \"draws\": 798, \"mu_intercept_per_group\": 8.93742847442627, \"sigma_intercept_per_group\": 39.849327087402344, \"sigma_obs\": 149.35366821289062, \"slope\": -39.019874572753906, \"chain\": 3, \"draw\": 198}, {\"mouse\": 7, \"draws\": 799, \"mu_intercept_per_group\": 8.428977012634277, \"sigma_intercept_per_group\": 39.894046783447266, \"sigma_obs\": 149.19607543945312, \"slope\": -39.305233001708984, \"chain\": 3, \"draw\": 199}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 22,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Initialize:\n",
    "df_null, df_monster_null, _, _ = generate_fake_lfp(mouse_response_slope=0, n_trials=30)\n",
    "window = BayesRegression(df=df_null, y='Power', treatment='stim', group='mouse')\n",
    "# Fit:\n",
    "window.fit(model=models.model_hierarchical, add_group_intercept=True,\n",
    "           add_group_slope=False, robust_slopes=False,\n",
    "           do_make_change='subtract', dist_y='normal')\n",
    "\n",
    "# Plot:\n",
    "chart_power_difference = window.plot(independent_axes=False,\n",
    "                                     ).properties(title='Posterior')\n",
    "\n",
    "chart_power_difference"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "This does not happen if we estimate group slopes.\n",
    "\n",
    "GLM is more robust to no differences in the case of no effect:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-9c204e53bd804db3a37a3b9c24554728\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-9c204e53bd804db3a37a3b9c24554728\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-9c204e53bd804db3a37a3b9c24554728\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-40a0e4a1cef0800b3ab6268ee9edce5e\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-0.18724535405635834, 0.09555035084486008], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-40a0e4a1cef0800b3ab6268ee9edce5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-0.18724535405635834, 0.09555035084486008], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-40a0e4a1cef0800b3ab6268ee9edce5e\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-0.18724535405635834, 0.09555035084486008], \"zero\": true}}}}, {\"data\": {\"name\": \"data-b52e4943f07fbb194a01c5d9c92a4c03\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [-0.18724535405635834, 0.09555035084486008], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [-0.18724535405635834, 0.09555035084486008], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-40a0e4a1cef0800b3ab6268ee9edce5e\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-490.50158019438845, 262.66033766992655], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-40a0e4a1cef0800b3ab6268ee9edce5e\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-490.50158019438845, 262.66033766992655], \"zero\": false}}}}, {\"data\": {\"name\": \"data-40a0e4a1cef0800b3ab6268ee9edce5e\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-490.50158019438845, 262.66033766992655], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\", \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-40a0e4a1cef0800b3ab6268ee9edce5e\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 373.1024771699109, \"mu_intercept_per_group higher interval\": -0.12385888397693634, \"mu_intercept_per_group lower interval\": -17.632741928100586, \"mu_intercept_per_group center interval\": -6.200740337371826, \"mu_intercept_per_group higher interval75\": -2.577758312225342, \"mu_intercept_per_group lower interval75\": -13.07994270324707, \"sigma_intercept_per_group higher interval\": 0.04357578977942467, \"sigma_intercept_per_group lower interval\": 0.011250090785324574, \"sigma_intercept_per_group center interval\": 0.026297304779291153, \"sigma_obs higher interval\": 0.004357711877673864, \"sigma_obs lower interval\": 0.0033383516129106283, \"sigma_obs center interval\": 0.003855894785374403, \"higher interval\": 0.09555035084486008, \"lower interval\": -0.18724535405635834, \"center interval\": -0.05068191513419151, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 6.461420296542826, \"mu_intercept_per_group higher interval\": -1.4003232717514038, \"mu_intercept_per_group lower interval\": -19.43457794189453, \"mu_intercept_per_group center interval\": -7.977890968322754, \"mu_intercept_per_group higher interval75\": -4.483433723449707, \"mu_intercept_per_group lower interval75\": -14.774507522583008, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": -4.794562915542059, \"mu_intercept_per_group higher interval\": 3.6694140434265137, \"mu_intercept_per_group lower interval\": -13.337035179138184, \"mu_intercept_per_group center interval\": -4.974222183227539, \"mu_intercept_per_group higher interval75\": 0.0273563414812088, \"mu_intercept_per_group lower interval75\": -8.805277824401855, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": -25.16081796364446, \"mu_intercept_per_group higher interval\": 5.863987922668457, \"mu_intercept_per_group lower interval\": -11.548116683959961, \"mu_intercept_per_group center interval\": -1.8225511312484741, \"mu_intercept_per_group higher interval75\": 2.71802020072937, \"mu_intercept_per_group lower interval75\": -7.08134651184082, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 57.553507169956106, \"mu_intercept_per_group higher interval\": 7.717593193054199, \"mu_intercept_per_group lower interval\": -9.57455825805664, \"mu_intercept_per_group center interval\": 0.3305230140686035, \"mu_intercept_per_group higher interval75\": 5.496521472930908, \"mu_intercept_per_group lower interval75\": -4.522876739501953, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -66.20482985488388, \"mu_intercept_per_group higher interval\": 15.108519554138184, \"mu_intercept_per_group lower interval\": -3.968463897705078, \"mu_intercept_per_group center interval\": 6.495595932006836, \"mu_intercept_per_group higher interval75\": 11.175139427185059, \"mu_intercept_per_group lower interval75\": 0.4292086362838745, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -693.6727465366484, \"mu_intercept_per_group higher interval\": 17.32099151611328, \"mu_intercept_per_group lower interval\": 0.4689110815525055, \"mu_intercept_per_group center interval\": 7.4138264656066895, \"mu_intercept_per_group higher interval75\": 13.270885467529297, \"mu_intercept_per_group lower interval75\": 3.4133732318878174, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": -113.18369984447719, \"mu_intercept_per_group higher interval\": 25.326744079589844, \"mu_intercept_per_group lower interval\": 5.215124130249023, \"mu_intercept_per_group center interval\": 12.897375106811523, \"mu_intercept_per_group higher interval75\": 19.976173400878906, \"mu_intercept_per_group lower interval75\": 8.132830619812012, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-b52e4943f07fbb194a01c5d9c92a4c03\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -5.360697269439697, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -6.113516807556152, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -13.243094444274902, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -11.044171333312988, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -7.59847354888916, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -16.35530662536621, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -10.57153606414795, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -15.325989723205566, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -10.551904678344727, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -8.202742576599121, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -3.9095561504364014, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -5.881542205810547, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -7.339447021484375, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -8.545356750488281, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -9.00646686553955, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.125738143920898, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -9.93112564086914, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -9.62222957611084, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -10.084239959716797, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -3.2041070461273193, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -6.654911041259766, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -3.9514527320861816, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -14.52961540222168, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -7.688597679138184, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -13.689024925231934, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -15.478493690490723, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -12.05264663696289, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -4.035715579986572, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -12.06708812713623, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -7.003600120544434, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -5.134799480438232, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -4.944941997528076, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -4.659669399261475, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -11.346683502197266, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -5.586073398590088, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -3.368584394454956, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -11.303518295288086, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -7.276511192321777, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -8.270418167114258, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -9.047924041748047, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -10.515215873718262, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -11.695355415344238, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -1.9765613079071045, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -4.009708881378174, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -3.6506619453430176, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -2.517570972442627, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -15.845433235168457, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -0.4016449749469757, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -1.450397253036499, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -6.94807243347168, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": 0.3586457371711731, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -2.2626419067382812, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -4.7445549964904785, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -8.174196243286133, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -1.5617207288742065, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -7.292285919189453, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -4.993925094604492, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -12.978638648986816, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -7.2211384773254395, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -15.768158912658691, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -3.863198757171631, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -15.59113883972168, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -6.210816860198975, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -3.1989710330963135, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -23.599544525146484, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -26.15598487854004, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -8.08046817779541, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -9.614583969116211, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -8.74190616607666, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -10.099483489990234, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -10.960065841674805, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -14.29343032836914, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -7.74554967880249, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -12.72173023223877, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": 0.6517786383628845, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -0.635370135307312, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -4.485712051391602, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -17.203351974487305, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -5.238399982452393, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -4.6794023513793945, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -6.393994331359863, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -7.923083782196045, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -7.408852577209473, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -9.101765632629395, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -11.931848526000977, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -12.336999893188477, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -14.96207046508789, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": -2.5026164054870605, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -9.314985275268555, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -8.184121131896973, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -9.899998664855957, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -4.538906097412109, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -13.679439544677734, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -8.307722091674805, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -15.020071983337402, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -14.275291442871094, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -4.582866668701172, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -12.001626014709473, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -14.01615047454834, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -12.734010696411133, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -1.2608752250671387, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -1.2228057384490967, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -4.7201828956604, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -5.077175140380859, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -1.114240288734436, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -4.483077526092529, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -5.357980728149414, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -3.4787850379943848, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -10.782973289489746, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -10.227107048034668, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -5.716595649719238, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -5.1708502769470215, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -2.2493927478790283, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -2.9931604862213135, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -5.337422847747803, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -3.9518673419952393, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -9.758589744567871, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -7.03887414932251, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -4.577511787414551, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -11.117094039916992, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -3.9408962726593018, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -6.84578275680542, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -6.506763458251953, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -5.085968017578125, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -5.244931697845459, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -4.245874881744385, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -11.167210578918457, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -8.648662567138672, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -10.12059497833252, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -17.372623443603516, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -4.773813724517822, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -12.82419204711914, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -9.149223327636719, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -3.5981922149658203, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -2.7257351875305176, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -6.239372730255127, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -19.53461456298828, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -10.694526672363281, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -9.535296440124512, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -13.712453842163086, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -15.938152313232422, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -14.253772735595703, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -17.54982566833496, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -9.058645248413086, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -19.619586944580078, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -1.710917353630066, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -5.966087341308594, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -4.37146520614624, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -10.61314582824707, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -4.952693462371826, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -10.38408088684082, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -3.3677561283111572, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -8.447193145751953, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -8.818157196044922, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -6.943643569946289, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -6.381852626800537, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -5.8749260902404785, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -8.739461898803711, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -4.892273902893066, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -4.866211414337158, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -7.214631080627441, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -0.748675525188446, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -9.983851432800293, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -5.957518577575684, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -14.14577865600586, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -2.843184471130371, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -10.181252479553223, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -10.975688934326172, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -16.573930740356445, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -5.388379096984863, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -10.906859397888184, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -10.393954277038574, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -10.626559257507324, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": -7.888521671295166, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -9.417363166809082, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -0.7610281109809875, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -6.459048271179199, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -7.975074291229248, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -2.2685647010803223, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -7.29087495803833, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -2.7884480953216553, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -10.600831031799316, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -6.619733810424805, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -12.679549217224121, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -12.57571029663086, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -13.112909317016602, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -18.595149993896484, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -17.060970306396484, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -17.746000289916992, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -5.825954437255859, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -10.028719902038574, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -9.027544975280762, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -7.597222328186035, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -6.7957987785339355, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -8.924874305725098, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.914536476135254, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -10.329346656799316, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -3.087447166442871, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -3.2053961753845215, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -5.952932357788086, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -7.622361660003662, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -11.351142883300781, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -8.518974304199219, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -6.904703140258789, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -15.798457145690918, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -15.958581924438477, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -8.430635452270508, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -7.08709716796875, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -6.906693458557129, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -9.32590389251709, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -11.160439491271973, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -6.12939977645874, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -5.941909313201904, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -13.873905181884766, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -13.791787147521973, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -2.346881628036499, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -11.694937705993652, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -6.192392826080322, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -3.4954051971435547, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -3.988839626312256, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -10.549930572509766, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -5.171855926513672, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -4.722924709320068, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -13.50557804107666, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -12.726235389709473, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -12.884763717651367, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.617238521575928, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -5.911417007446289, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -13.723782539367676, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -8.017559051513672, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -5.881659507751465, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -9.559125900268555, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -4.138284206390381, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -4.847749710083008, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -5.9170403480529785, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -8.886092185974121, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -4.7214813232421875, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -4.111277103424072, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -2.8240201473236084, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -3.2245235443115234, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -12.928251266479492, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -16.094083786010742, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -8.200810432434082, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -4.685267448425293, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -6.019376277923584, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -7.684789657592773, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -7.939826965332031, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -14.929689407348633, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -15.876842498779297, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": 0.4492742121219635, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -7.8419647216796875, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -8.328108787536621, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -7.367325782775879, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -8.45392894744873, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -5.496407985687256, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -11.34249496459961, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -1.018405795097351, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -1.7220269441604614, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -7.446821212768555, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -2.577758312225342, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -7.7144575119018555, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -10.339506149291992, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -6.856272220611572, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -4.4789509773254395, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -15.39782428741455, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -7.359472751617432, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": -1.6976778507232666, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -7.380312919616699, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -3.0444414615631104, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -8.843992233276367, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -8.868606567382812, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -10.9906587600708, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -16.11487579345703, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.527894020080566, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -3.2793946266174316, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -14.130839347839355, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -14.27795696258545, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -9.486902236938477, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -9.261590003967285, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -3.708972215652466, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -10.184734344482422, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -12.190354347229004, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -5.552417755126953, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -6.742118835449219, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -4.952000141143799, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -12.451754570007324, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -2.1268768310546875, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -9.68196964263916, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -6.845007419586182, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -7.979539394378662, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -6.85430908203125, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -6.293148517608643, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -7.724856853485107, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -8.387807846069336, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -8.720739364624023, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -5.4526448249816895, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -7.786330223083496, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -7.65914249420166, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -5.969279766082764, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -4.932415008544922, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -8.864917755126953, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -6.312615871429443, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -6.256636619567871, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -12.748576164245605, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -5.325443267822266, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -2.8911447525024414, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.397550582885742, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -7.2846479415893555, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -3.2305643558502197, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -4.504624843597412, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -10.44770336151123, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -3.3536460399627686, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -9.893096923828125, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -8.22957706451416, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -6.27789306640625, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -6.108059883117676, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -5.770761489868164, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -7.998083591461182, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -10.926939010620117, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -8.083629608154297, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -8.210094451904297, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -13.3590087890625, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -16.63786506652832, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -14.322495460510254, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -11.243119239807129, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -13.317095756530762, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": -2.6109678745269775, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -6.627811908721924, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -7.974698543548584, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -9.186285018920898, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -11.140576362609863, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -6.242288589477539, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -5.69441556930542, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -3.715712547302246, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -11.185103416442871, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -14.764699935913086, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -16.247364044189453, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -22.966960906982422, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -8.428997993469238, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -9.805685997009277, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -4.445455074310303, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -3.166464328765869, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -3.2480733394622803, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -3.3834664821624756, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -7.056716442108154, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -2.4381473064422607, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -9.934440612792969, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -15.403428077697754, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -4.260374546051025, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -5.460249423980713, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -11.600586891174316, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -7.431332588195801, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -7.697688102722168, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": -3.024352550506592, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.405233383178711, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -9.721979141235352, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -15.637262344360352, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -10.052909851074219, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -3.7268259525299072, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -10.382439613342285, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -8.721609115600586, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -14.146400451660156, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -3.203115940093994, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -7.521787643432617, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -7.796635150909424, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -4.497536659240723, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -5.019337177276611, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -9.498448371887207, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -14.745986938476562, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -9.00545883178711, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -17.48749351501465, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -4.580405235290527, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -9.910500526428223, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -8.214644432067871, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -4.987922668457031, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -7.878864765167236, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -10.573073387145996, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -4.423040390014648, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -0.12385888397693634, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -0.1788640022277832, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -13.899658203125, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -2.37420392036438, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -6.5084991455078125, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": -0.9640220999717712, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -21.848304748535156, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -20.415958404541016, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -3.650846481323242, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -0.8680586218833923, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -0.2829506993293762, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": 0.4215431809425354, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -15.487957000732422, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -4.671380043029785, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -14.32739543914795, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -7.584131240844727, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -2.688498020172119, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -14.809906959533691, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -3.085721492767334, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -17.632741928100586, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -14.003795623779297, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -11.092477798461914, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -3.5328357219696045, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -12.876002311706543, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -8.927543640136719, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -9.15611743927002, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -5.9984660148620605, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -13.0184907913208, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -11.055575370788574, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -4.355703830718994, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -13.523791313171387, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -8.365167617797852, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -10.320601463317871, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -2.462073802947998, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -5.366098880767822, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -0.3552404046058655, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -9.790170669555664, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -6.924896717071533, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -5.777102470397949, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -10.61330509185791, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -3.9605910778045654, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -3.143146276473999, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -15.039719581604004, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -6.518373489379883, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -10.04587173461914, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -5.762923717498779, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -4.712020397186279, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -6.682355880737305, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -9.092719078063965, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -16.36296844482422, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -16.596494674682617, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -4.589853286743164, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -8.930246353149414, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -6.99222469329834, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -6.680440425872803, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -17.249887466430664, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -17.965490341186523, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -5.508443832397461, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -7.827744007110596, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -8.850516319274902, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -8.377970695495605, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -5.755041599273682, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -4.486813068389893, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -6.541646957397461, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -3.3219642639160156, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -5.15454626083374, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -2.847475051879883, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -6.791231155395508, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -4.466159820556641, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -10.509112358093262, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -13.0526704788208, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -7.985391616821289, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -14.228196144104004, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -16.01700782775879, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -12.26891040802002, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -12.695513725280762, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -14.69420337677002, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -4.424271583557129, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -15.974157333374023, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -15.031198501586914, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -14.805672645568848, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -4.566394805908203, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -13.051093101501465, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -9.505301475524902, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -9.654291152954102, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -4.057024002075195, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -12.342055320739746, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -11.679831504821777, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -15.013482093811035, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -16.046863555908203, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -14.32643985748291, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -17.05356216430664, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -0.5166111588478088, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -7.504343509674072, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -10.507493019104004, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -11.887663841247559, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -2.6746835708618164, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -11.214261054992676, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -14.143415451049805, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -3.429741382598877, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -5.418373107910156, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -5.218635082244873, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -10.902812004089355, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -6.09084415435791, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -6.842221260070801, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -6.710031509399414, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -1.8642785549163818, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -19.4240665435791, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -0.27420923113822937, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -6.729586124420166, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": -1.2837973833084106, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": -7.036014080047607, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -9.537561416625977, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -13.046269416809082, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -4.373612880706787, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -17.198101043701172, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -1.6642590761184692, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -10.911462783813477, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -8.981364250183105, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -12.247897148132324, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -3.2269575595855713, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -2.4862101078033447, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -8.780314445495605, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -15.192741394042969, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -4.602137088775635, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -9.47437858581543, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -7.919343948364258, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -6.8672709465026855, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -6.887680530548096, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -9.645870208740234, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -2.5832390785217285, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -19.27419662475586, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -8.883374214172363, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -4.074501991271973, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -4.088937759399414, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -7.760058879852295, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": -9.069245338439941, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -8.414226531982422, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -9.33604907989502, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -6.37553596496582, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -13.828621864318848, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -11.404452323913574, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -10.930147171020508, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -20.4794864654541, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -4.532627582550049, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -5.4520721435546875, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -18.37757110595703, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -17.50928497314453, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -19.622547149658203, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -16.450416564941406, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -12.83405590057373, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -14.545180320739746, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -12.92983341217041, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -6.660207748413086, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -12.697665214538574, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -9.044236183166504, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -8.221637725830078, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -7.8049163818359375, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -6.1136603355407715, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -9.030399322509766, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -4.3380961418151855, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -10.154470443725586, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -1.2810033559799194, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -13.283863067626953, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -8.546095848083496, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -6.870307922363281, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -11.458736419677734, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": -3.729041337966919, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -5.8087663650512695, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -5.194253921508789, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -9.197148323059082, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -14.846721649169922, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -5.315441131591797, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -11.889819145202637, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -6.3352861404418945, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -15.935991287231445, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -3.1216399669647217, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -19.416484832763672, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -6.745564937591553, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -10.599084854125977, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -4.19182014465332, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -3.7205283641815186, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": 0.25181451439857483, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -23.073719024658203, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -0.15227262675762177, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -10.839534759521484, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -7.097766876220703, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -11.753616333007812, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -5.698916912078857, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -6.482027530670166, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -3.9200057983398438, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -7.674986362457275, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -7.698893070220947, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -8.364340782165527, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -10.876829147338867, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -6.063680648803711, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -3.857851505279541, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -8.75809097290039, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -5.755526065826416, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": -1.7941203117370605, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -17.83573341369629, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -5.578787326812744, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -12.096527099609375, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -2.9685449600219727, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -9.38240909576416, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -8.91124439239502, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -6.511636257171631, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -7.81205940246582, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -12.067265510559082, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -8.061563491821289, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -9.059870719909668, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -12.667549133300781, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -3.1025047302246094, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -5.260878086090088, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -9.36058521270752, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -6.555973529815674, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -4.816176891326904, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -13.07994270324707, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -10.510225296020508, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -17.802385330200195, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -13.122442245483398, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -14.418883323669434, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -5.853867053985596, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": -2.872022867202759, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -9.858663558959961, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -21.761104583740234, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": -5.278674602508545, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -14.642322540283203, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -13.732705116271973, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": 0.08808491379022598, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -1.890895962715149, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": 0.7708138227462769, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": 3.077449321746826, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -14.452537536621094, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -12.9911527633667, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -6.462948799133301, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -6.682945251464844, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -6.335513114929199, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -13.409822463989258, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -9.721748352050781, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -4.261620998382568, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -8.87337875366211, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -9.222296714782715, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -5.942927837371826, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -9.34276008605957, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -11.538904190063477, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -5.5409321784973145, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -4.117276191711426, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": -5.426909923553467, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": -6.505112648010254, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -10.84605598449707, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": -9.82054328918457, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -5.749186992645264, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -9.952767372131348, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -12.576080322265625, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -7.79628324508667, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -8.37496566772461, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -14.704010009765625, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -22.01612091064453, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -7.8907036781311035, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -6.129847526550293, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -11.0386381149292, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 640, \"mu_intercept_per_group\": -2.998535394668579, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 641, \"mu_intercept_per_group\": -12.669179916381836, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 642, \"mu_intercept_per_group\": -11.204878807067871, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 643, \"mu_intercept_per_group\": -13.024813652038574, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 644, \"mu_intercept_per_group\": -11.396958351135254, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 645, \"mu_intercept_per_group\": -6.538820743560791, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 646, \"mu_intercept_per_group\": -12.094749450683594, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 647, \"mu_intercept_per_group\": -14.201250076293945, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 648, \"mu_intercept_per_group\": -15.481759071350098, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 649, \"mu_intercept_per_group\": 1.3178160190582275, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 650, \"mu_intercept_per_group\": -0.2899433970451355, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 651, \"mu_intercept_per_group\": -18.66486358642578, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 652, \"mu_intercept_per_group\": -4.065168380737305, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 653, \"mu_intercept_per_group\": -7.633037090301514, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 654, \"mu_intercept_per_group\": -10.386906623840332, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 655, \"mu_intercept_per_group\": -1.4597159624099731, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 656, \"mu_intercept_per_group\": -10.509278297424316, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 657, \"mu_intercept_per_group\": -11.69708251953125, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 658, \"mu_intercept_per_group\": -8.885601043701172, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 659, \"mu_intercept_per_group\": -9.189509391784668, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 660, \"mu_intercept_per_group\": -4.78420352935791, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 661, \"mu_intercept_per_group\": -2.3507370948791504, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 662, \"mu_intercept_per_group\": -2.946296215057373, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 663, \"mu_intercept_per_group\": -4.177427768707275, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 664, \"mu_intercept_per_group\": -3.026254653930664, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 665, \"mu_intercept_per_group\": -3.935508966445923, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 666, \"mu_intercept_per_group\": -2.5809237957000732, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 667, \"mu_intercept_per_group\": -2.45147442817688, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 668, \"mu_intercept_per_group\": -6.449415683746338, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 669, \"mu_intercept_per_group\": -4.70999002456665, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 670, \"mu_intercept_per_group\": -5.777318000793457, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 671, \"mu_intercept_per_group\": -3.446908712387085, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 672, \"mu_intercept_per_group\": -7.674118518829346, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 673, \"mu_intercept_per_group\": -4.48499059677124, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 674, \"mu_intercept_per_group\": -12.57374382019043, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 675, \"mu_intercept_per_group\": -8.305331230163574, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 676, \"mu_intercept_per_group\": -5.289124488830566, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 677, \"mu_intercept_per_group\": -14.358983993530273, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 678, \"mu_intercept_per_group\": -6.254711151123047, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 679, \"mu_intercept_per_group\": -12.657055854797363, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 680, \"mu_intercept_per_group\": -15.36733341217041, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 681, \"mu_intercept_per_group\": -20.56238555908203, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 682, \"mu_intercept_per_group\": -4.856252193450928, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 683, \"mu_intercept_per_group\": -14.843124389648438, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 684, \"mu_intercept_per_group\": -19.20552635192871, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 685, \"mu_intercept_per_group\": -5.010932922363281, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 686, \"mu_intercept_per_group\": -6.19329833984375, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 687, \"mu_intercept_per_group\": -11.703832626342773, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 688, \"mu_intercept_per_group\": -13.812983512878418, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 689, \"mu_intercept_per_group\": -6.899607181549072, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 690, \"mu_intercept_per_group\": -4.626230239868164, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 691, \"mu_intercept_per_group\": -6.012710094451904, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 692, \"mu_intercept_per_group\": -2.5977730751037598, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 693, \"mu_intercept_per_group\": 2.7754077911376953, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 694, \"mu_intercept_per_group\": -14.55564022064209, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 695, \"mu_intercept_per_group\": -14.98638916015625, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 696, \"mu_intercept_per_group\": -2.412247657775879, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 697, \"mu_intercept_per_group\": -1.5655232667922974, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 698, \"mu_intercept_per_group\": -5.632409572601318, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 699, \"mu_intercept_per_group\": -7.862301349639893, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 700, \"mu_intercept_per_group\": -9.80797004699707, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 701, \"mu_intercept_per_group\": -10.466011047363281, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 702, \"mu_intercept_per_group\": -6.450698375701904, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 703, \"mu_intercept_per_group\": -4.476806163787842, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 704, \"mu_intercept_per_group\": 2.8624837398529053, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 705, \"mu_intercept_per_group\": -9.48000717163086, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 706, \"mu_intercept_per_group\": -2.1327950954437256, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 707, \"mu_intercept_per_group\": -1.5486096143722534, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 708, \"mu_intercept_per_group\": -11.525429725646973, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 709, \"mu_intercept_per_group\": -2.6163692474365234, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 710, \"mu_intercept_per_group\": -5.026086807250977, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 711, \"mu_intercept_per_group\": -19.156755447387695, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 712, \"mu_intercept_per_group\": -4.26860237121582, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 713, \"mu_intercept_per_group\": -0.8883744478225708, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 714, \"mu_intercept_per_group\": -6.586152076721191, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 715, \"mu_intercept_per_group\": -8.983536720275879, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 716, \"mu_intercept_per_group\": -9.587594985961914, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 717, \"mu_intercept_per_group\": -2.579329252243042, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 718, \"mu_intercept_per_group\": -10.21817398071289, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 719, \"mu_intercept_per_group\": -4.458429336547852, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 720, \"mu_intercept_per_group\": -9.76286506652832, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 721, \"mu_intercept_per_group\": -2.606229305267334, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 722, \"mu_intercept_per_group\": -6.713465690612793, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 723, \"mu_intercept_per_group\": -2.6730289459228516, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 724, \"mu_intercept_per_group\": -3.600998640060425, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 725, \"mu_intercept_per_group\": -4.240785121917725, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 726, \"mu_intercept_per_group\": -5.220587253570557, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 727, \"mu_intercept_per_group\": -4.551281929016113, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 728, \"mu_intercept_per_group\": -11.664947509765625, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 729, \"mu_intercept_per_group\": -7.570199489593506, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 730, \"mu_intercept_per_group\": -7.433091163635254, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 731, \"mu_intercept_per_group\": -11.609864234924316, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 732, \"mu_intercept_per_group\": -9.167573928833008, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 733, \"mu_intercept_per_group\": -14.073145866394043, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 734, \"mu_intercept_per_group\": -6.4778618812561035, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 735, \"mu_intercept_per_group\": -4.545477390289307, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 736, \"mu_intercept_per_group\": -2.2437167167663574, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 737, \"mu_intercept_per_group\": -10.917572021484375, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 738, \"mu_intercept_per_group\": -8.458740234375, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 739, \"mu_intercept_per_group\": -2.2262017726898193, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 740, \"mu_intercept_per_group\": -9.100317001342773, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 741, \"mu_intercept_per_group\": -8.415115356445312, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 742, \"mu_intercept_per_group\": -8.09626579284668, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 743, \"mu_intercept_per_group\": -4.527872562408447, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 744, \"mu_intercept_per_group\": -10.812729835510254, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 745, \"mu_intercept_per_group\": -5.406728267669678, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 746, \"mu_intercept_per_group\": -10.183183670043945, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 747, \"mu_intercept_per_group\": -3.5167105197906494, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 748, \"mu_intercept_per_group\": -10.849933624267578, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 749, \"mu_intercept_per_group\": -8.40908145904541, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 750, \"mu_intercept_per_group\": -17.604116439819336, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 751, \"mu_intercept_per_group\": -8.167295455932617, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 752, \"mu_intercept_per_group\": -14.474555969238281, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 753, \"mu_intercept_per_group\": -11.392937660217285, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 754, \"mu_intercept_per_group\": -7.307062149047852, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 755, \"mu_intercept_per_group\": -6.131682395935059, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 756, \"mu_intercept_per_group\": -11.419718742370605, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 757, \"mu_intercept_per_group\": -11.1609468460083, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 758, \"mu_intercept_per_group\": -10.35185432434082, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 759, \"mu_intercept_per_group\": -8.662569999694824, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 0, \"draws\": 760, \"mu_intercept_per_group\": -12.86898136138916, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 0, \"draws\": 761, \"mu_intercept_per_group\": -2.910890579223633, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 0, \"draws\": 762, \"mu_intercept_per_group\": -1.9281493425369263, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 0, \"draws\": 763, \"mu_intercept_per_group\": -16.095022201538086, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 0, \"draws\": 764, \"mu_intercept_per_group\": -8.849691390991211, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 0, \"draws\": 765, \"mu_intercept_per_group\": -4.2350335121154785, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 0, \"draws\": 766, \"mu_intercept_per_group\": -15.163063049316406, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 0, \"draws\": 767, \"mu_intercept_per_group\": -17.450435638427734, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 0, \"draws\": 768, \"mu_intercept_per_group\": -15.24328899383545, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 0, \"draws\": 769, \"mu_intercept_per_group\": -12.16889762878418, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 0, \"draws\": 770, \"mu_intercept_per_group\": -3.9116921424865723, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 0, \"draws\": 771, \"mu_intercept_per_group\": -8.440031051635742, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 0, \"draws\": 772, \"mu_intercept_per_group\": -8.02475643157959, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 0, \"draws\": 773, \"mu_intercept_per_group\": -11.578217506408691, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 0, \"draws\": 774, \"mu_intercept_per_group\": -6.101170063018799, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 0, \"draws\": 775, \"mu_intercept_per_group\": -12.16646957397461, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 0, \"draws\": 776, \"mu_intercept_per_group\": -16.680055618286133, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 0, \"draws\": 777, \"mu_intercept_per_group\": -12.457479476928711, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 0, \"draws\": 778, \"mu_intercept_per_group\": -13.378334045410156, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 0, \"draws\": 779, \"mu_intercept_per_group\": -11.978010177612305, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 0, \"draws\": 780, \"mu_intercept_per_group\": -5.338235378265381, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 0, \"draws\": 781, \"mu_intercept_per_group\": -2.2112278938293457, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 0, \"draws\": 782, \"mu_intercept_per_group\": -9.558947563171387, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 0, \"draws\": 783, \"mu_intercept_per_group\": -11.126148223876953, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 0, \"draws\": 784, \"mu_intercept_per_group\": -9.955938339233398, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 0, \"draws\": 785, \"mu_intercept_per_group\": -4.125387191772461, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 0, \"draws\": 786, \"mu_intercept_per_group\": 0.5203419327735901, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 0, \"draws\": 787, \"mu_intercept_per_group\": -20.905502319335938, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 0, \"draws\": 788, \"mu_intercept_per_group\": -9.684865951538086, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 0, \"draws\": 789, \"mu_intercept_per_group\": -14.770892143249512, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 0, \"draws\": 790, \"mu_intercept_per_group\": -2.8905184268951416, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 0, \"draws\": 791, \"mu_intercept_per_group\": -4.462109565734863, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 0, \"draws\": 792, \"mu_intercept_per_group\": -8.431899070739746, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 0, \"draws\": 793, \"mu_intercept_per_group\": -6.9501237869262695, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 0, \"draws\": 794, \"mu_intercept_per_group\": -5.615489959716797, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 0, \"draws\": 795, \"mu_intercept_per_group\": -8.923439025878906, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 0, \"draws\": 796, \"mu_intercept_per_group\": -8.707955360412598, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 0, \"draws\": 797, \"mu_intercept_per_group\": -11.329267501831055, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 0, \"draws\": 798, \"mu_intercept_per_group\": 1.1675227880477905, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 0, \"draws\": 799, \"mu_intercept_per_group\": -12.73240852355957, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -20.452598571777344, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -4.622435092926025, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -16.164270401000977, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -13.02291202545166, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -7.308695316314697, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -14.939637184143066, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -12.561445236206055, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -14.695652961730957, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -5.208195686340332, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -15.150546073913574, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -6.785571098327637, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -10.406298637390137, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -5.565413475036621, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -11.425450325012207, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -11.886573791503906, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -13.911625862121582, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -12.356555938720703, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -6.280803203582764, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -6.843579292297363, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -7.605058193206787, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -4.91711950302124, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -5.746920585632324, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -13.761781692504883, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -9.48132038116455, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": -8.234940528869629, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": -16.842321395874023, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": -1.4027824401855469, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -19.86370849609375, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -2.45121693611145, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -5.17197847366333, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -6.730312347412109, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -3.4943366050720215, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -7.033088684082031, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -9.575098991394043, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -13.205946922302246, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -15.220187187194824, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -9.010519981384277, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -14.430901527404785, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -6.980576515197754, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -7.459941864013672, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": -0.9444191455841064, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -1.0319955348968506, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -3.74064564704895, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -5.227249622344971, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -4.825946807861328, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -6.3675994873046875, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": -4.536842346191406, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": -7.648080348968506, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -7.4859185218811035, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -8.653756141662598, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -1.6667752265930176, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -4.761752605438232, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -3.7655341625213623, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -5.927766799926758, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -5.8489990234375, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -7.4424052238464355, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -10.45536994934082, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -9.39373779296875, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -12.382237434387207, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -17.911361694335938, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": -2.0129287242889404, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -19.32696533203125, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -8.663415908813477, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -13.833440780639648, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -9.749438285827637, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -14.922026634216309, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -27.591835021972656, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": -1.5912740230560303, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": -1.905063271522522, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -11.487154960632324, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -9.529964447021484, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -7.756184101104736, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -18.008935928344727, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -13.248647689819336, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -9.428730010986328, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -11.814101219177246, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -10.561366081237793, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -13.690457344055176, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -12.482769966125488, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": -9.770532608032227, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -10.555245399475098, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -4.170563220977783, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -18.225168228149414, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -18.75402069091797, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -6.31278133392334, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -5.289710998535156, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -6.547335624694824, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": -4.667680740356445, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": -8.5082368850708, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.106111526489258, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -7.7334513664245605, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -9.428868293762207, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -14.559629440307617, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": -4.985876560211182, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -13.7260103225708, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -14.832880973815918, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -5.12388277053833, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -10.065382957458496, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -14.621960639953613, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -7.497123718261719, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -5.031879901885986, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -3.4456186294555664, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -5.598202705383301, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -1.4003232717514038, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -4.6361870765686035, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -4.078645706176758, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -8.117972373962402, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -8.680863380432129, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -3.9800920486450195, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -4.099391460418701, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -4.360194206237793, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -5.343170166015625, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -6.9762797355651855, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -9.877483367919922, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -3.0768754482269287, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -3.413475275039673, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -14.968912124633789, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -2.6713807582855225, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -8.996379852294922, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -3.1082003116607666, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -2.877800703048706, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -2.9326205253601074, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -6.5980048179626465, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -8.178972244262695, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -9.005332946777344, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -7.9087233543396, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -8.493863105773926, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -5.029394626617432, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -14.669321060180664, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -9.863310813903809, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -13.664475440979004, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -11.003500938415527, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -6.054823875427246, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -6.3397297859191895, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -5.92275857925415, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -7.132695198059082, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -0.07600659877061844, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -2.0847740173339844, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -19.186555862426758, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -8.776782035827637, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -6.771552562713623, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -21.942398071289062, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -14.759942054748535, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -11.86044979095459, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -14.902119636535645, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": -2.2097954750061035, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -6.980043411254883, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": -2.4538772106170654, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -9.068045616149902, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -6.26188325881958, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -12.918173789978027, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": -0.4600535035133362, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -14.334693908691406, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -11.515241622924805, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -4.194006443023682, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -8.671757698059082, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -5.967463970184326, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -5.207616806030273, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -6.675032615661621, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -8.998008728027344, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -4.483433723449707, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -4.738607406616211, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -10.083643913269043, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -7.109315872192383, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": -5.813457489013672, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -7.204838275909424, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -7.532041072845459, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -13.74515151977539, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -16.450294494628906, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": -3.428896903991699, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -13.772018432617188, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -5.768528938293457, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -6.711949825286865, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": -5.313790321350098, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -8.004415512084961, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -4.869723320007324, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": -2.092036724090576, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -7.058260917663574, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -8.108158111572266, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -4.651468753814697, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -9.614063262939453, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -3.0662992000579834, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -21.132766723632812, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -12.410422325134277, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -12.432549476623535, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": -0.8834739327430725, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": -3.49446964263916, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": -11.626216888427734, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -13.604320526123047, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -9.280716896057129, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -10.298563957214355, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -8.550606727600098, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -9.811959266662598, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -13.12436294555664, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -11.575562477111816, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -12.011157035827637, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -13.545019149780273, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -2.4477100372314453, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -4.126707077026367, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -3.7334892749786377, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -5.496851444244385, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -14.217740058898926, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -15.245438575744629, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -15.413924217224121, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -13.414012908935547, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -8.601343154907227, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -13.874324798583984, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -4.142345428466797, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -3.844379186630249, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -9.206022262573242, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -6.74979829788208, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -11.141764640808105, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -9.506479263305664, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -10.063288688659668, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -12.849353790283203, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -5.035654067993164, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -8.478560447692871, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -11.061935424804688, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": -2.855389356613159, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -4.5210371017456055, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -17.072254180908203, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -17.434133529663086, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -8.904716491699219, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -10.085999488830566, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -9.504600524902344, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -12.286649703979492, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -24.146326065063477, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -14.074440002441406, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -22.78874397277832, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": -4.022039890289307, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": -6.782666206359863, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -7.141948223114014, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -5.509437561035156, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -2.9042599201202393, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -4.934211254119873, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -4.068200588226318, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -8.185028076171875, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -6.395401954650879, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -3.417839527130127, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -3.410301446914673, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -14.475518226623535, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -13.105003356933594, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -10.016613960266113, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -7.10314416885376, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -6.244558334350586, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -10.648999214172363, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -6.525013446807861, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -12.404440879821777, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -11.36009693145752, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -4.560536861419678, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -8.344531059265137, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -7.168642520904541, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -6.466464996337891, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -4.583006858825684, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": -2.789203405380249, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -2.4416894912719727, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -14.56029224395752, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -7.8495869636535645, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": -13.66977310180664, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -1.422890543937683, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -2.6098523139953613, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -4.945626258850098, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -5.352181911468506, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -7.603225231170654, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -8.211015701293945, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -10.945683479309082, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": -1.6298085451126099, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -8.353074073791504, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -4.882934093475342, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -8.911416053771973, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -9.367339134216309, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -7.923511028289795, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -6.203583240509033, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -7.996985912322998, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -9.196725845336914, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -6.691488742828369, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": -2.9140307903289795, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -6.318240165710449, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -7.966722011566162, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -14.541147232055664, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -6.577362060546875, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -7.508410453796387, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -10.457060813903809, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -6.656027317047119, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -9.990056991577148, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -11.249074935913086, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -4.928837299346924, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -5.199375629425049, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -4.195580959320068, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -7.421377658843994, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -4.660099983215332, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -12.515266418457031, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -3.8847310543060303, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -4.743808746337891, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -10.142111778259277, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -10.552530288696289, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -11.815277099609375, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": 6.0378265380859375, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": -2.12213134765625, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -9.743425369262695, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -7.668150424957275, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -7.435042858123779, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -5.036427974700928, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -9.363218307495117, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -9.089692115783691, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -14.362852096557617, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -15.616983413696289, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -18.010425567626953, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": 0.08032844215631485, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -13.581934928894043, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": -1.9613277912139893, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -8.02820873260498, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -4.773665904998779, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -15.422889709472656, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -6.714000701904297, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -6.9391326904296875, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -10.244235038757324, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -8.117058753967285, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -8.575765609741211, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -12.367496490478516, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -5.928946495056152, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -5.970050811767578, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -16.632577896118164, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -14.62865161895752, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -12.483254432678223, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -10.94054126739502, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -6.302626132965088, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -7.38372278213501, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -16.972110748291016, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -15.106231689453125, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -4.398885250091553, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -2.9245402812957764, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -11.990592956542969, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -9.247725486755371, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -14.050139427185059, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -11.812926292419434, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -10.1124906539917, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -9.499771118164062, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -20.46501350402832, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -10.764481544494629, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -5.573411464691162, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -9.101179122924805, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -2.8512024879455566, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -2.3570194244384766, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -5.936738014221191, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -4.27443790435791, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -7.073056697845459, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -9.329116821289062, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -6.57049036026001, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -11.548808097839355, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -9.76722240447998, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.522422790527344, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -8.354975700378418, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -6.274951934814453, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -12.061635971069336, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -11.545170783996582, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -9.894837379455566, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -12.595378875732422, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -2.8065507411956787, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -12.267524719238281, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -7.1900224685668945, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -8.08620548248291, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -6.462759017944336, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -4.956143379211426, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -6.001622200012207, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": -9.739566802978516, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -3.350433111190796, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -14.774507522583008, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -15.160456657409668, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -10.00748062133789, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -8.721370697021484, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -11.021175384521484, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -6.08528470993042, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -7.0882134437561035, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -5.212774276733398, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -8.840865135192871, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -5.027707099914551, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -6.463276386260986, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -10.612326622009277, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -9.503524780273438, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -8.80634593963623, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -8.375341415405273, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -13.97473430633545, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": 1.7209928035736084, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -23.3988037109375, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -11.893548965454102, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -7.973784923553467, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -5.341891765594482, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -8.559233665466309, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": -8.984153747558594, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -7.635012149810791, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -11.158234596252441, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -13.67641544342041, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -11.923284530639648, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -6.039179801940918, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.761236190795898, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -8.743346214294434, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -8.610560417175293, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -10.533015251159668, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -10.962503433227539, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -4.558284759521484, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -7.043536186218262, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -8.70256519317627, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -9.447488784790039, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -7.752495765686035, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -6.7924885749816895, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -7.496687412261963, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -7.28485107421875, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": -15.327766418457031, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -9.91905689239502, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": -8.342644691467285, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -6.79480504989624, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -11.906003952026367, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -14.875411033630371, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -10.455700874328613, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -14.603590965270996, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -5.67373514175415, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -6.863907337188721, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -14.549626350402832, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -19.223052978515625, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -13.625238418579102, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.145027160644531, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -5.613734722137451, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -13.048483848571777, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -6.269863605499268, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -13.65236759185791, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -3.712156057357788, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -14.275237083435059, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -7.921351909637451, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -12.525330543518066, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -9.790629386901855, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -6.5096564292907715, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -7.907253742218018, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -9.091761589050293, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -15.168041229248047, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -9.057477951049805, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -11.422950744628906, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -10.443620681762695, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -11.193025588989258, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -12.811644554138184, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -3.8079512119293213, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -4.9880547523498535, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -4.331655502319336, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -4.402731418609619, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -5.310861110687256, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -4.1407341957092285, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -8.77803897857666, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -7.587051868438721, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -7.972409248352051, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -14.539591789245605, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -15.369531631469727, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -6.584939956665039, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -8.155258178710938, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -14.6618013381958, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -22.069320678710938, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -15.864250183105469, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -18.530073165893555, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -12.510644912719727, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -9.281136512756348, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -10.115605354309082, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -4.9272332191467285, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -5.2998175621032715, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -6.050412178039551, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -1.496659278869629, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": -1.1820403337478638, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -4.513702392578125, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -11.443387031555176, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -10.010522842407227, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -30.668298721313477, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -7.333108425140381, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -11.993755340576172, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.890336990356445, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -7.132999897003174, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -8.2675199508667, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -6.533572196960449, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -6.955770969390869, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -14.49740219116211, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -4.196443557739258, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -10.959526062011719, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -9.95236587524414, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -7.01733922958374, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -12.327916145324707, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -3.813764810562134, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -6.960392475128174, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -3.5415167808532715, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -18.588045120239258, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": -4.304055690765381, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": -3.302586078643799, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -8.008030891418457, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -14.214324951171875, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -10.56972599029541, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -9.967157363891602, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -8.749573707580566, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -2.660352945327759, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -16.97930145263672, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -7.214580059051514, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -9.639130592346191, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -19.953773498535156, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -13.69430160522461, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -6.1650519371032715, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -8.925531387329102, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -10.999090194702148, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -9.259786605834961, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -6.045423984527588, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -6.6728386878967285, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -8.013190269470215, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -8.886422157287598, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -11.344398498535156, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -10.906515121459961, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -10.972814559936523, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -17.332469940185547, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -1.0118160247802734, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -8.999534606933594, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -14.686075210571289, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -5.635523796081543, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": -5.844944000244141, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -7.8421759605407715, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -5.998310089111328, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -16.599599838256836, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -13.188767433166504, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -12.717182159423828, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -15.566573143005371, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -9.681355476379395, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -11.111454010009766, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -10.200071334838867, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -27.759675979614258, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -26.758760452270508, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -21.623214721679688, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -17.914134979248047, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -12.398392677307129, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -17.404035568237305, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -15.492921829223633, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -15.78579330444336, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -7.682719707489014, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -9.293804168701172, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -11.127945899963379, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -9.557998657226562, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -8.64327621459961, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -5.3052449226379395, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -13.725578308105469, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -8.558537483215332, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -5.62636661529541, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -13.34357738494873, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -11.63655948638916, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -9.631924629211426, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -8.091353416442871, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -6.346938133239746, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": -10.845120429992676, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -1.435651183128357, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -13.849334716796875, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -3.6097042560577393, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -16.424772262573242, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -14.815325736999512, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -10.223373413085938, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -10.537750244140625, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -10.321033477783203, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -15.128082275390625, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -7.4391279220581055, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -7.1816182136535645, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -8.129958152770996, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -7.7725300788879395, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -12.770190238952637, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -8.388420104980469, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -5.043483734130859, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -16.465444564819336, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -6.804876804351807, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -6.225788593292236, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -4.681602478027344, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -5.5569329261779785, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -5.321174144744873, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -7.4906792640686035, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -8.919342041015625, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -5.3758320808410645, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -10.021666526794434, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -7.080060005187988, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -12.732233047485352, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -11.979473114013672, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -12.436845779418945, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -11.493189811706543, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -17.856571197509766, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -0.3436718285083771, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -14.580161094665527, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -14.28050708770752, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -9.027009963989258, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -12.88689136505127, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -6.121161460876465, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -10.273687362670898, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -9.937995910644531, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -9.592591285705566, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -6.611219882965088, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -12.83009147644043, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -16.360069274902344, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -5.09151029586792, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -11.338907241821289, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -9.68795108795166, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -10.94223403930664, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -9.032402992248535, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -13.802629470825195, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -18.83034896850586, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -19.142549514770508, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": -5.560223579406738, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -12.499194145202637, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -10.228904724121094, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -12.012703895568848, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -13.949188232421875, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -13.52773666381836, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -9.667695999145508, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -5.7874650955200195, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -9.394314765930176, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -5.783945083618164, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": 1.1830062866210938, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -8.377022743225098, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -11.821539878845215, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -6.516091823577881, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -8.108173370361328, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -7.084167003631592, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -13.91552448272705, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -9.02151870727539, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -14.221385955810547, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -13.936368942260742, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -9.335872650146484, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -11.13001823425293, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": -2.9576609134674072, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": -5.729398727416992, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -15.051931381225586, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -15.164011001586914, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -13.571453094482422, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -10.037331581115723, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -8.865962982177734, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -5.984600067138672, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -10.81895637512207, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -11.48855209350586, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -4.972982883453369, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -16.91759490966797, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -16.976593017578125, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -17.279830932617188, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -18.187755584716797, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": -2.0245070457458496, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": -3.494657278060913, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": -2.7144243717193604, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 640, \"mu_intercept_per_group\": -7.944818496704102, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 641, \"mu_intercept_per_group\": -11.874332427978516, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 642, \"mu_intercept_per_group\": -14.115923881530762, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 643, \"mu_intercept_per_group\": -15.80151081085205, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 644, \"mu_intercept_per_group\": -19.834897994995117, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 645, \"mu_intercept_per_group\": -16.23308563232422, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 646, \"mu_intercept_per_group\": -13.146952629089355, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 647, \"mu_intercept_per_group\": -14.272028923034668, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 648, \"mu_intercept_per_group\": -10.032909393310547, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 649, \"mu_intercept_per_group\": -5.592789173126221, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 650, \"mu_intercept_per_group\": -6.15735387802124, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 651, \"mu_intercept_per_group\": -14.154386520385742, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 652, \"mu_intercept_per_group\": -11.901698112487793, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 653, \"mu_intercept_per_group\": -12.540374755859375, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 654, \"mu_intercept_per_group\": -7.1065874099731445, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 655, \"mu_intercept_per_group\": -9.670320510864258, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 656, \"mu_intercept_per_group\": -9.968283653259277, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 657, \"mu_intercept_per_group\": -10.926596641540527, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 658, \"mu_intercept_per_group\": -9.55213451385498, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 659, \"mu_intercept_per_group\": -6.647780418395996, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 660, \"mu_intercept_per_group\": -8.045455932617188, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 661, \"mu_intercept_per_group\": -8.587028503417969, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 662, \"mu_intercept_per_group\": -8.236431121826172, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 663, \"mu_intercept_per_group\": -7.736665725708008, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 664, \"mu_intercept_per_group\": -0.8849182724952698, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 665, \"mu_intercept_per_group\": -2.018559455871582, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 666, \"mu_intercept_per_group\": -4.6470770835876465, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 667, \"mu_intercept_per_group\": -3.224071979522705, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 668, \"mu_intercept_per_group\": -5.812364101409912, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 669, \"mu_intercept_per_group\": -6.163301944732666, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 670, \"mu_intercept_per_group\": -6.302254676818848, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 671, \"mu_intercept_per_group\": -5.327621936798096, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 672, \"mu_intercept_per_group\": -7.198653697967529, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 673, \"mu_intercept_per_group\": -6.162899494171143, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 674, \"mu_intercept_per_group\": -11.093828201293945, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 675, \"mu_intercept_per_group\": -7.5639824867248535, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 676, \"mu_intercept_per_group\": -13.359631538391113, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 677, \"mu_intercept_per_group\": -5.183041095733643, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 678, \"mu_intercept_per_group\": -8.040637969970703, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 679, \"mu_intercept_per_group\": -13.229632377624512, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 680, \"mu_intercept_per_group\": -14.041478157043457, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 681, \"mu_intercept_per_group\": -2.772676706314087, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 682, \"mu_intercept_per_group\": -15.320996284484863, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 683, \"mu_intercept_per_group\": -8.526836395263672, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 684, \"mu_intercept_per_group\": -20.217445373535156, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 685, \"mu_intercept_per_group\": -4.790424823760986, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 686, \"mu_intercept_per_group\": -8.398781776428223, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 687, \"mu_intercept_per_group\": -19.418764114379883, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 688, \"mu_intercept_per_group\": -14.425796508789062, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 689, \"mu_intercept_per_group\": -3.9589684009552, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 690, \"mu_intercept_per_group\": -8.761381149291992, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 691, \"mu_intercept_per_group\": -5.3585968017578125, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 692, \"mu_intercept_per_group\": -2.9213805198669434, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 693, \"mu_intercept_per_group\": -8.775766372680664, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 694, \"mu_intercept_per_group\": -14.134422302246094, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 695, \"mu_intercept_per_group\": -14.084216117858887, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 696, \"mu_intercept_per_group\": -5.090535640716553, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 697, \"mu_intercept_per_group\": -5.661681652069092, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 698, \"mu_intercept_per_group\": -11.459495544433594, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 699, \"mu_intercept_per_group\": -9.609298706054688, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 700, \"mu_intercept_per_group\": -11.357207298278809, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 701, \"mu_intercept_per_group\": -4.720399856567383, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 702, \"mu_intercept_per_group\": -11.919123649597168, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 703, \"mu_intercept_per_group\": -6.409720420837402, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 704, \"mu_intercept_per_group\": -9.755796432495117, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 705, \"mu_intercept_per_group\": -0.8173140287399292, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 706, \"mu_intercept_per_group\": -10.678360939025879, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 707, \"mu_intercept_per_group\": -12.990707397460938, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 708, \"mu_intercept_per_group\": -2.8840866088867188, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 709, \"mu_intercept_per_group\": -12.710577964782715, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 710, \"mu_intercept_per_group\": -16.470008850097656, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 711, \"mu_intercept_per_group\": -4.841241836547852, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 712, \"mu_intercept_per_group\": -18.235002517700195, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 713, \"mu_intercept_per_group\": -13.643118858337402, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 714, \"mu_intercept_per_group\": -14.582253456115723, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 715, \"mu_intercept_per_group\": -8.067436218261719, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 716, \"mu_intercept_per_group\": -7.805572032928467, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 717, \"mu_intercept_per_group\": -8.41103744506836, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 718, \"mu_intercept_per_group\": -12.655707359313965, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 719, \"mu_intercept_per_group\": 2.011129140853882, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 720, \"mu_intercept_per_group\": -20.41252899169922, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 721, \"mu_intercept_per_group\": 1.0789917707443237, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 722, \"mu_intercept_per_group\": -12.393584251403809, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 723, \"mu_intercept_per_group\": -6.822595596313477, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 724, \"mu_intercept_per_group\": -5.939946174621582, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 725, \"mu_intercept_per_group\": -6.578561782836914, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 726, \"mu_intercept_per_group\": -8.683465003967285, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 727, \"mu_intercept_per_group\": -7.167017459869385, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 728, \"mu_intercept_per_group\": -12.464510917663574, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 729, \"mu_intercept_per_group\": -1.7137892246246338, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 730, \"mu_intercept_per_group\": -16.36293601989746, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 731, \"mu_intercept_per_group\": -13.56166934967041, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 732, \"mu_intercept_per_group\": -8.803915023803711, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 733, \"mu_intercept_per_group\": -6.779425621032715, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 734, \"mu_intercept_per_group\": -7.53000020980835, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 735, \"mu_intercept_per_group\": -6.594666481018066, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 736, \"mu_intercept_per_group\": -4.500934600830078, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 737, \"mu_intercept_per_group\": -10.249200820922852, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 738, \"mu_intercept_per_group\": -10.336034774780273, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 739, \"mu_intercept_per_group\": -11.450291633605957, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 740, \"mu_intercept_per_group\": -3.3571784496307373, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 741, \"mu_intercept_per_group\": -9.93986701965332, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 742, \"mu_intercept_per_group\": -13.217033386230469, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 743, \"mu_intercept_per_group\": -13.954264640808105, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 744, \"mu_intercept_per_group\": -5.818735599517822, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 745, \"mu_intercept_per_group\": -12.747861862182617, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 746, \"mu_intercept_per_group\": -3.6532974243164062, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 747, \"mu_intercept_per_group\": -9.306291580200195, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 748, \"mu_intercept_per_group\": -11.045859336853027, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 749, \"mu_intercept_per_group\": -9.738914489746094, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 750, \"mu_intercept_per_group\": -19.331872940063477, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 751, \"mu_intercept_per_group\": -22.14756202697754, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 752, \"mu_intercept_per_group\": -17.000083923339844, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 753, \"mu_intercept_per_group\": -2.030193328857422, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 754, \"mu_intercept_per_group\": -12.67818832397461, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 755, \"mu_intercept_per_group\": -5.199551105499268, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 756, \"mu_intercept_per_group\": -20.728857040405273, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 757, \"mu_intercept_per_group\": -14.527103424072266, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 758, \"mu_intercept_per_group\": -11.20872688293457, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 759, \"mu_intercept_per_group\": -8.615543365478516, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 760, \"mu_intercept_per_group\": -10.805074691772461, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 1, \"draws\": 761, \"mu_intercept_per_group\": -6.678704738616943, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 1, \"draws\": 762, \"mu_intercept_per_group\": -8.350821495056152, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 1, \"draws\": 763, \"mu_intercept_per_group\": -9.321687698364258, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 1, \"draws\": 764, \"mu_intercept_per_group\": -19.43457794189453, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 1, \"draws\": 765, \"mu_intercept_per_group\": -4.360244274139404, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 1, \"draws\": 766, \"mu_intercept_per_group\": -10.634013175964355, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 1, \"draws\": 767, \"mu_intercept_per_group\": -21.05377769470215, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 1, \"draws\": 768, \"mu_intercept_per_group\": -18.893056869506836, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 1, \"draws\": 769, \"mu_intercept_per_group\": -12.64026927947998, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 1, \"draws\": 770, \"mu_intercept_per_group\": -8.365190505981445, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 1, \"draws\": 771, \"mu_intercept_per_group\": -10.321532249450684, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 1, \"draws\": 772, \"mu_intercept_per_group\": -8.258161544799805, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 1, \"draws\": 773, \"mu_intercept_per_group\": -20.027929306030273, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 1, \"draws\": 774, \"mu_intercept_per_group\": -11.992382049560547, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 1, \"draws\": 775, \"mu_intercept_per_group\": -11.650823593139648, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 1, \"draws\": 776, \"mu_intercept_per_group\": -15.979503631591797, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 1, \"draws\": 777, \"mu_intercept_per_group\": -12.374348640441895, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 1, \"draws\": 778, \"mu_intercept_per_group\": -13.631390571594238, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 1, \"draws\": 779, \"mu_intercept_per_group\": -10.949263572692871, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 1, \"draws\": 780, \"mu_intercept_per_group\": -11.824105262756348, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 1, \"draws\": 781, \"mu_intercept_per_group\": -2.283813714981079, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 1, \"draws\": 782, \"mu_intercept_per_group\": -6.206733226776123, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 1, \"draws\": 783, \"mu_intercept_per_group\": -9.632731437683105, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 1, \"draws\": 784, \"mu_intercept_per_group\": -8.363502502441406, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 1, \"draws\": 785, \"mu_intercept_per_group\": -2.981694459915161, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 1, \"draws\": 786, \"mu_intercept_per_group\": -7.420117378234863, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 1, \"draws\": 787, \"mu_intercept_per_group\": -10.374552726745605, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 1, \"draws\": 788, \"mu_intercept_per_group\": -20.218183517456055, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 1, \"draws\": 789, \"mu_intercept_per_group\": -7.405616760253906, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 1, \"draws\": 790, \"mu_intercept_per_group\": -10.873927116394043, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 1, \"draws\": 791, \"mu_intercept_per_group\": -6.5653581619262695, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 1, \"draws\": 792, \"mu_intercept_per_group\": -8.059200286865234, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 1, \"draws\": 793, \"mu_intercept_per_group\": -6.340863227844238, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 1, \"draws\": 794, \"mu_intercept_per_group\": -12.398531913757324, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 1, \"draws\": 795, \"mu_intercept_per_group\": -3.92246675491333, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 1, \"draws\": 796, \"mu_intercept_per_group\": -8.120468139648438, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 1, \"draws\": 797, \"mu_intercept_per_group\": -7.824810981750488, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 1, \"draws\": 798, \"mu_intercept_per_group\": -4.0611572265625, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 1, \"draws\": 799, \"mu_intercept_per_group\": -9.410531997680664, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": -8.453125953674316, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -10.454785346984863, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -0.5505073666572571, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -6.564847469329834, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": 0.8672871589660645, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -7.163012504577637, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": -9.541592597961426, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -12.771615982055664, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -4.679462432861328, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -6.701568603515625, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -1.150195837020874, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -0.9085290431976318, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -4.121076583862305, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -9.063036918640137, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -7.382567882537842, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -3.789546489715576, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": -0.42006048560142517, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -1.7509183883666992, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -2.2105374336242676, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -3.8419957160949707, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -3.469275951385498, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": -6.478386402130127, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -3.709590196609497, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -6.551856517791748, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -4.2170000076293945, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -4.170506477355957, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": -0.5221824645996094, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -8.780101776123047, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -0.5072362422943115, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -1.3847856521606445, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -2.157677412033081, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -5.302281856536865, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -4.424627780914307, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -5.123846054077148, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -3.757948875427246, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -3.109968900680542, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": 0.6271545886993408, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -1.434674620628357, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -7.391280174255371, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -1.2723774909973145, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": 0.4044848382472992, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -1.612626314163208, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": 3.9046475887298584, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": 3.2945616245269775, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -3.2762014865875244, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": 0.3004353642463684, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -4.9485321044921875, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": 3.6694140434265137, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": 3.8674802780151367, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": 2.7233972549438477, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -7.615335941314697, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -3.7901790142059326, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -0.5081406831741333, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -0.23227158188819885, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -5.226064205169678, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -4.687062740325928, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -3.7698962688446045, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -0.5077437162399292, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -16.11695098876953, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -11.669119834899902, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -11.635869026184082, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -3.33479905128479, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -4.915732383728027, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -6.077853679656982, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -29.28828239440918, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -22.517559051513672, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -11.097686767578125, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -4.802347660064697, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -5.086028575897217, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -4.861690998077393, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -5.986260414123535, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -10.99962043762207, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -4.103909015655518, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -2.822763681411743, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -1.6142919063568115, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -1.5072990655899048, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -2.677438259124756, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -12.38514232635498, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": -1.9107877016067505, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -2.8579375743865967, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -6.766031742095947, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -0.05175594240427017, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -0.9026862382888794, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -10.98798656463623, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -0.9480888247489929, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -6.160677909851074, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -8.901968955993652, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -0.6219491362571716, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -6.173497676849365, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -6.142988681793213, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -1.5900465250015259, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -1.3871883153915405, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -11.650614738464355, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.630257606506348, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -3.005791425704956, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -5.9110941886901855, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -7.455978870391846, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -17.364866256713867, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -7.090042591094971, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -4.335328578948975, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -5.632610321044922, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -6.387805938720703, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -2.5746514797210693, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -5.175774097442627, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": 2.0594780445098877, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -4.7335710525512695, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -4.150950908660889, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -3.0110960006713867, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -4.969646453857422, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -4.996833801269531, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -5.0785627365112305, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -5.132578372955322, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -4.305849552154541, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -3.651965856552124, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -0.667121946811676, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -0.35074523091316223, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -10.069809913635254, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -1.906997799873352, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -1.2788348197937012, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -3.333012580871582, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -0.9113098978996277, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -1.8378926515579224, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -4.325409412384033, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -5.921744346618652, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -3.658174753189087, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -4.463387489318848, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -8.470341682434082, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -8.611347198486328, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -7.236758232116699, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -9.623326301574707, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -0.10595664381980896, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -7.919762134552002, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -2.352844476699829, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": 1.2967678308486938, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": 1.9503440856933594, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -4.104397296905518, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -5.999149322509766, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -7.1501078605651855, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -6.465514183044434, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -10.277183532714844, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -9.86198902130127, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -9.039198875427246, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -4.135949611663818, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -11.288759231567383, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -7.483941078186035, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -5.342532634735107, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -3.4966657161712646, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.024428367614746, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -4.928310871124268, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -4.315949440002441, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -5.275633335113525, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": 0.6347512006759644, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -5.4332380294799805, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -3.17635440826416, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -7.883580207824707, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -2.016864776611328, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -1.801456093788147, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -5.977039337158203, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -2.0070674419403076, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -4.068023204803467, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -2.5232372283935547, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -2.5492372512817383, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -6.679758071899414, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -1.6997337341308594, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -4.745677947998047, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -3.2065393924713135, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -6.934398174285889, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -7.58858060836792, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -8.503161430358887, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -5.624189376831055, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -1.7077863216400146, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -5.470183849334717, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -0.20052671432495117, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -0.08538419008255005, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": 5.233631134033203, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -1.9312161207199097, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -6.259824275970459, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -8.387072563171387, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -5.28582239151001, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -1.9335938692092896, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -1.7255843877792358, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -7.588410377502441, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -2.3853447437286377, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -5.978462219238281, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -4.816373348236084, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -15.877439498901367, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -11.644328117370605, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -6.948698043823242, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -6.082642078399658, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -9.684722900390625, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -10.770740509033203, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -8.317103385925293, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -14.813054084777832, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -15.567910194396973, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -15.720407485961914, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -15.438539505004883, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -5.205615043640137, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -3.519782304763794, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -7.340847492218018, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -1.7186076641082764, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -0.9701380729675293, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -13.017924308776855, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -16.555200576782227, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.501222610473633, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -6.423163890838623, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -4.721338272094727, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -1.1996175050735474, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -7.355599880218506, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -5.348257064819336, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -3.2512874603271484, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -6.711539268493652, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -4.400938034057617, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -5.053346633911133, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -11.414849281311035, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -10.030593872070312, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -0.6767314076423645, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -5.6731061935424805, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -1.8070660829544067, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -0.18882009387016296, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -1.671953797340393, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -7.657625198364258, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -3.8510775566101074, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -3.5175352096557617, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -7.231562614440918, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -14.423741340637207, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -10.211858749389648, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -9.30064582824707, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -10.30962085723877, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -9.250638008117676, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -4.8359055519104, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": 1.5824508666992188, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -6.637001037597656, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": 2.8989572525024414, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": 0.26806265115737915, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -2.352775812149048, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -3.139439821243286, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -7.532801628112793, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -8.170465469360352, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -6.382599353790283, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -5.564872741699219, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": 0.4020656645298004, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": 4.214279651641846, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -2.8299331665039062, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -4.460197448730469, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -4.250995635986328, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -9.653432846069336, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": 3.3134336471557617, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -4.718210220336914, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -5.876277446746826, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -1.3321104049682617, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -4.8700079917907715, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -4.721019268035889, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": 1.5029376745224, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -6.2899909019470215, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -0.3540162444114685, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -4.634821891784668, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -2.609189748764038, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -8.340095520019531, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -1.6315644979476929, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -5.749641418457031, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -3.073047161102295, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -4.340782642364502, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -12.886957168579102, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -2.4892735481262207, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -3.2659637928009033, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -7.198091506958008, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -2.7761597633361816, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -0.9186689257621765, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -1.6793535947799683, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -3.430885076522827, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": -4.28679895401001, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -4.77161979675293, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -10.664891242980957, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -8.668783187866211, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -0.19895479083061218, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -10.670884132385254, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -9.25484561920166, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": 0.35978129506111145, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": 2.8519983291625977, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -19.243160247802734, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -17.75119400024414, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -18.864299774169922, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -12.527027130126953, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": 3.5940279960632324, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -6.848689079284668, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -5.111294746398926, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -1.2918663024902344, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -5.768561363220215, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -2.809800863265991, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": 1.4851064682006836, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": 0.75862056016922, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -9.66215991973877, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": 1.955972671508789, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": 1.383881688117981, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -2.8283851146698, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -1.9161655902862549, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -1.3106476068496704, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -0.6097164750099182, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -1.0603739023208618, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -2.3881139755249023, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -4.0595197677612305, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -4.250674247741699, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -4.009250164031982, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -14.249719619750977, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -0.48197460174560547, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -7.4479169845581055, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -8.748726844787598, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -6.366126537322998, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": 0.26196980476379395, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -6.667550086975098, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": -0.09104166179895401, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -6.868774890899658, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -6.696242809295654, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -3.944584369659424, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -7.267531394958496, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -1.0260199308395386, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -8.036567687988281, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -3.156015396118164, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -8.42514419555664, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -2.510563373565674, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -7.722168445587158, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -8.805277824401855, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -7.805069923400879, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -8.090011596679688, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -10.139873504638672, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -2.7916290760040283, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -3.0873262882232666, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -5.21682596206665, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -6.856114864349365, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -12.456212997436523, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": 3.4319334030151367, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -2.371907949447632, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -4.286661148071289, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": -1.4425303936004639, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -6.8982157707214355, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -12.645343780517578, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -12.42700481414795, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -11.09960651397705, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -2.2446255683898926, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -0.5219089984893799, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -5.103990077972412, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -4.256702899932861, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -1.1358908414840698, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -4.807381629943848, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -0.2560058832168579, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -3.7104880809783936, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -3.0007166862487793, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -4.8855133056640625, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": 0.7540574073791504, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -5.319677352905273, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -12.390704154968262, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": -0.07967319339513779, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -3.9410643577575684, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -1.670464277267456, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -6.111070156097412, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -5.779119968414307, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -10.095335006713867, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -2.3953938484191895, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -4.105098724365234, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -3.5638413429260254, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -3.662493944168091, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -1.1616007089614868, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": -0.5817890167236328, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -2.089905261993408, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -3.0901293754577637, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": -1.829884648323059, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -0.7214406132698059, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -6.503670692443848, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -8.34061050415039, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -8.095166206359863, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -9.47652816772461, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -5.344085693359375, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -6.08355712890625, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.631709098815918, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -7.5422282218933105, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -0.06087679788470268, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -8.256967544555664, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -5.789309501647949, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -7.131173610687256, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -8.485200881958008, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -1.7980055809020996, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -8.056114196777344, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -5.604140281677246, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -2.0057570934295654, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -5.581324100494385, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -12.970598220825195, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": 0.28525492548942566, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -6.7851243019104, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -5.191228866577148, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": -3.0349085330963135, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -5.023478031158447, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": -1.7572894096374512, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -11.728983879089355, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": 1.8728306293487549, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -8.12926197052002, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": -5.414556503295898, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -2.094726324081421, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": -0.6505733728408813, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": -2.9459853172302246, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -5.372722148895264, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -1.9393633604049683, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -5.307972431182861, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": -9.700248718261719, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -10.340350151062012, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -3.0507190227508545, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -8.700528144836426, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -6.07609224319458, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -2.890040159225464, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -7.600711345672607, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -8.199468612670898, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -0.8590995669364929, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -6.672173500061035, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -5.50967264175415, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -4.948030948638916, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": 0.0273563414812088, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -0.669363260269165, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -2.7497332096099854, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -6.003470420837402, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -5.690000534057617, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -7.705903053283691, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -0.24828939139842987, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -6.862492084503174, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -4.032130718231201, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -5.167738437652588, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -5.559901714324951, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -1.9490350484848022, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -5.989488124847412, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": 0.4320143461227417, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -2.475433826446533, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -9.280078887939453, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -8.12259292602539, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -7.638378620147705, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -7.909689426422119, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -4.665563106536865, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -5.372437477111816, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -11.127668380737305, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -7.056180000305176, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -10.807973861694336, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -6.728318691253662, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -2.08168888092041, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -2.921133279800415, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -3.643737554550171, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -1.329910397529602, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -1.9500442743301392, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -2.266308546066284, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -2.6808791160583496, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -6.323187828063965, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": -0.6127552390098572, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -1.9407082796096802, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -10.675975799560547, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -11.266485214233398, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -7.3424835205078125, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -7.469003200531006, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -5.310315132141113, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -7.115092754364014, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -8.87636947631836, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -5.20542049407959, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -10.1183500289917, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -6.391887664794922, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -0.47317588329315186, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -6.341428279876709, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -4.998658657073975, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -5.836798191070557, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -6.192933559417725, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -9.435730934143066, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": 1.8440918922424316, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -3.71109676361084, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -7.063124656677246, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -9.657201766967773, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -3.200937032699585, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -9.118134498596191, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -10.137907028198242, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": 1.0037981271743774, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -1.6931324005126953, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -7.2846479415893555, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -9.86028003692627, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": -7.3883137702941895, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -5.730720043182373, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -2.8395588397979736, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -3.197953224182129, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -1.28974449634552, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -10.003436088562012, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": 0.0059593189507722855, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -4.576898097991943, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -5.979147434234619, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -4.217459678649902, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -8.447060585021973, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -5.614293098449707, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -6.384840965270996, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -11.528701782226562, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -10.831080436706543, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -7.283724308013916, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -1.2648134231567383, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -4.663161754608154, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -8.607006072998047, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": 7.597047805786133, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -13.414286613464355, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -0.6964192986488342, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -5.7473225593566895, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -4.190615653991699, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -8.289958000183105, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -2.2554075717926025, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -7.317960739135742, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -0.25004759430885315, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -9.169034004211426, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -9.18163013458252, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -7.759466648101807, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -4.849884033203125, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -4.6597819328308105, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -8.841999053955078, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -8.950467109680176, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": 0.10978802293539047, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -0.8785604238510132, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -6.991869926452637, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -1.89983332157135, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -3.3178553581237793, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -3.2074649333953857, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -1.379225254058838, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -16.153060913085938, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -11.66618537902832, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -6.773317813873291, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -9.907257080078125, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -5.3084588050842285, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -5.830621242523193, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -7.904778480529785, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -11.271245956420898, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -13.594831466674805, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -15.96960735321045, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": -4.060739517211914, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -16.92107582092285, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -2.7040789127349854, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -21.02044677734375, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -5.8860673904418945, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -5.536397457122803, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -12.797099113464355, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -6.2600884437561035, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -6.179899215698242, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": 6.048455715179443, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -1.7278237342834473, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -4.28956413269043, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -6.405912399291992, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -0.6326455473899841, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -6.665114402770996, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": 1.2943753004074097, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -5.092678070068359, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -2.9390463829040527, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -3.5115854740142822, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -5.090423107147217, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -1.2055041790008545, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -6.127264022827148, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": 0.025185557082295418, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -12.61019515991211, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -6.464621067047119, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -10.178231239318848, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": -0.44302886724472046, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -12.457958221435547, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -7.127999782562256, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -4.73904275894165, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -5.6314473152160645, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -6.205964088439941, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -3.1862611770629883, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -8.916603088378906, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -2.73327374458313, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -4.414101600646973, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -7.720731258392334, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -4.471842288970947, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -1.1441774368286133, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -4.252739429473877, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -4.482448101043701, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -5.428653240203857, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -2.3844733238220215, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -4.370785236358643, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -3.032787322998047, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -9.395673751831055, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -0.01531130913645029, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -4.559273719787598, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -12.942113876342773, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -9.54560375213623, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -4.654560089111328, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -13.062165260314941, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": 2.288564920425415, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -8.676717758178711, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -3.1114933490753174, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -6.211437702178955, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": 0.8193585276603699, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -2.225738048553467, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -4.839567184448242, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -7.384401798248291, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -7.056671142578125, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -11.094812393188477, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": 0.6813381910324097, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": 0.8489454984664917, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -7.996780872344971, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -6.5492167472839355, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -8.00389289855957, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -10.875518798828125, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -6.520978927612305, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -4.6304426193237305, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -4.169956684112549, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -6.345893383026123, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -3.110091209411621, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -2.2480971813201904, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -1.7081506252288818, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -5.653355598449707, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -12.9144287109375, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -9.673559188842773, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -1.1884607076644897, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -5.271449565887451, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -2.985360622406006, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -4.849937438964844, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -3.001817464828491, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -6.34254789352417, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -5.089544296264648, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -4.38462495803833, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -1.2118898630142212, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -4.024364471435547, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -4.277993679046631, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": -2.7671990394592285, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -1.7377537488937378, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -3.474607229232788, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": 4.644804000854492, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -13.337035179138184, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": 3.073399305343628, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -2.0178298950195312, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -6.4879913330078125, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -9.121392250061035, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -3.026379346847534, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -6.875876426696777, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -4.604304790496826, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -0.2533967196941376, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -7.316065311431885, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -5.441899299621582, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -7.809372425079346, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -10.49714469909668, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -11.07302188873291, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -12.653373718261719, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -5.171016693115234, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -4.221711158752441, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -4.94983434677124, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -4.062536716461182, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 640, \"mu_intercept_per_group\": -4.78094482421875, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 641, \"mu_intercept_per_group\": -8.326581954956055, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 642, \"mu_intercept_per_group\": -0.9433061480522156, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 643, \"mu_intercept_per_group\": -9.143431663513184, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 644, \"mu_intercept_per_group\": -8.621070861816406, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 645, \"mu_intercept_per_group\": -10.671802520751953, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 646, \"mu_intercept_per_group\": -12.110109329223633, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 647, \"mu_intercept_per_group\": -5.912927150726318, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 648, \"mu_intercept_per_group\": -6.339178562164307, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 649, \"mu_intercept_per_group\": -1.0634801387786865, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 650, \"mu_intercept_per_group\": 1.2771570682525635, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 651, \"mu_intercept_per_group\": -7.94574499130249, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 652, \"mu_intercept_per_group\": -7.432999134063721, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 653, \"mu_intercept_per_group\": -10.55966854095459, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 654, \"mu_intercept_per_group\": -7.909594535827637, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 655, \"mu_intercept_per_group\": -5.151159286499023, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 656, \"mu_intercept_per_group\": -2.4740467071533203, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 657, \"mu_intercept_per_group\": -13.560009002685547, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 658, \"mu_intercept_per_group\": -4.534151554107666, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 659, \"mu_intercept_per_group\": -4.915889739990234, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 660, \"mu_intercept_per_group\": -4.171502590179443, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 661, \"mu_intercept_per_group\": -4.037130832672119, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 662, \"mu_intercept_per_group\": -4.199772834777832, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 663, \"mu_intercept_per_group\": -1.952060580253601, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 664, \"mu_intercept_per_group\": -1.6556602716445923, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 665, \"mu_intercept_per_group\": -3.0260207653045654, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 666, \"mu_intercept_per_group\": -0.9088966250419617, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 667, \"mu_intercept_per_group\": -1.5713183879852295, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 668, \"mu_intercept_per_group\": -2.899477005004883, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 669, \"mu_intercept_per_group\": -2.765488386154175, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 670, \"mu_intercept_per_group\": -3.612396001815796, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 671, \"mu_intercept_per_group\": -3.295034408569336, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 672, \"mu_intercept_per_group\": -4.110628128051758, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 673, \"mu_intercept_per_group\": -4.816243648529053, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 674, \"mu_intercept_per_group\": -9.099227905273438, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 675, \"mu_intercept_per_group\": -1.9325809478759766, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 676, \"mu_intercept_per_group\": -3.777186870574951, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 677, \"mu_intercept_per_group\": -5.401274681091309, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 678, \"mu_intercept_per_group\": 2.4905381202697754, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 679, \"mu_intercept_per_group\": -15.060787200927734, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 680, \"mu_intercept_per_group\": -4.376192569732666, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 681, \"mu_intercept_per_group\": 3.65761661529541, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 682, \"mu_intercept_per_group\": -11.129131317138672, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 683, \"mu_intercept_per_group\": -10.983657836914062, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 684, \"mu_intercept_per_group\": -7.954740047454834, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 685, \"mu_intercept_per_group\": -5.865729331970215, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 686, \"mu_intercept_per_group\": -0.0514724962413311, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 687, \"mu_intercept_per_group\": -4.268936634063721, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 688, \"mu_intercept_per_group\": -13.284570693969727, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 689, \"mu_intercept_per_group\": -1.407471776008606, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 690, \"mu_intercept_per_group\": 4.341193675994873, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 691, \"mu_intercept_per_group\": -6.009574890136719, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 692, \"mu_intercept_per_group\": 1.866850733757019, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 693, \"mu_intercept_per_group\": 2.5612308979034424, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 694, \"mu_intercept_per_group\": -7.0316948890686035, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 695, \"mu_intercept_per_group\": -8.39795207977295, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 696, \"mu_intercept_per_group\": -2.683875560760498, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 697, \"mu_intercept_per_group\": 3.5652413368225098, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 698, \"mu_intercept_per_group\": -8.173748016357422, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 699, \"mu_intercept_per_group\": -7.141757965087891, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 700, \"mu_intercept_per_group\": -9.768097877502441, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 701, \"mu_intercept_per_group\": -4.290656089782715, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 702, \"mu_intercept_per_group\": -4.767599105834961, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 703, \"mu_intercept_per_group\": -3.2423946857452393, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 704, \"mu_intercept_per_group\": -7.482798099517822, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 705, \"mu_intercept_per_group\": 4.886491298675537, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 706, \"mu_intercept_per_group\": -6.537560939788818, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 707, \"mu_intercept_per_group\": -5.107451438903809, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 708, \"mu_intercept_per_group\": 2.508481025695801, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 709, \"mu_intercept_per_group\": -16.134008407592773, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 710, \"mu_intercept_per_group\": -2.547455310821533, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 711, \"mu_intercept_per_group\": -13.410199165344238, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 712, \"mu_intercept_per_group\": -5.650603294372559, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 713, \"mu_intercept_per_group\": -11.507898330688477, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 714, \"mu_intercept_per_group\": -7.443871974945068, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 715, \"mu_intercept_per_group\": -5.753130912780762, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 716, \"mu_intercept_per_group\": -6.921490669250488, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 717, \"mu_intercept_per_group\": -1.9417837858200073, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 718, \"mu_intercept_per_group\": -7.832800388336182, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 719, \"mu_intercept_per_group\": 0.750263512134552, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 720, \"mu_intercept_per_group\": -8.855888366699219, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 721, \"mu_intercept_per_group\": -0.4709112048149109, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 722, \"mu_intercept_per_group\": 1.2887591123580933, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 723, \"mu_intercept_per_group\": -0.13016286492347717, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 724, \"mu_intercept_per_group\": -1.6860158443450928, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 725, \"mu_intercept_per_group\": -3.2535979747772217, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 726, \"mu_intercept_per_group\": -4.857997894287109, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 727, \"mu_intercept_per_group\": -8.31367015838623, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 728, \"mu_intercept_per_group\": -0.7162702083587646, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 729, \"mu_intercept_per_group\": -2.5196568965911865, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 730, \"mu_intercept_per_group\": -5.254389762878418, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 731, \"mu_intercept_per_group\": -17.384309768676758, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 732, \"mu_intercept_per_group\": -0.8647406697273254, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 733, \"mu_intercept_per_group\": -1.685760259628296, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 734, \"mu_intercept_per_group\": -5.449748992919922, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 735, \"mu_intercept_per_group\": -6.005951881408691, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 736, \"mu_intercept_per_group\": -5.716185092926025, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 737, \"mu_intercept_per_group\": 0.8603424429893494, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 738, \"mu_intercept_per_group\": -0.8683345317840576, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 739, \"mu_intercept_per_group\": -3.643982410430908, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 740, \"mu_intercept_per_group\": -4.798969268798828, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 741, \"mu_intercept_per_group\": -6.326286315917969, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 742, \"mu_intercept_per_group\": -6.354798316955566, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 743, \"mu_intercept_per_group\": -4.974249839782715, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 744, \"mu_intercept_per_group\": -6.460498332977295, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 745, \"mu_intercept_per_group\": 0.3396229147911072, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 746, \"mu_intercept_per_group\": -2.9916727542877197, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 747, \"mu_intercept_per_group\": -2.754013776779175, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 748, \"mu_intercept_per_group\": -13.237261772155762, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 749, \"mu_intercept_per_group\": -10.941370964050293, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 750, \"mu_intercept_per_group\": -3.332930088043213, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 751, \"mu_intercept_per_group\": -3.5670809745788574, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 752, \"mu_intercept_per_group\": -0.8857442736625671, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 753, \"mu_intercept_per_group\": -7.333043575286865, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 754, \"mu_intercept_per_group\": -3.2679567337036133, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 755, \"mu_intercept_per_group\": -7.245314121246338, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 756, \"mu_intercept_per_group\": -4.130021572113037, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 757, \"mu_intercept_per_group\": -6.025651931762695, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 758, \"mu_intercept_per_group\": -3.15502667427063, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 759, \"mu_intercept_per_group\": -9.009719848632812, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 760, \"mu_intercept_per_group\": -3.2100205421447754, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 2, \"draws\": 761, \"mu_intercept_per_group\": -3.19205379486084, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 2, \"draws\": 762, \"mu_intercept_per_group\": -6.732545852661133, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 2, \"draws\": 763, \"mu_intercept_per_group\": -8.011567115783691, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 2, \"draws\": 764, \"mu_intercept_per_group\": -0.8993993997573853, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 2, \"draws\": 765, \"mu_intercept_per_group\": -2.306169271469116, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 2, \"draws\": 766, \"mu_intercept_per_group\": -12.434998512268066, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 2, \"draws\": 767, \"mu_intercept_per_group\": -4.773910999298096, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 2, \"draws\": 768, \"mu_intercept_per_group\": -5.946661472320557, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 2, \"draws\": 769, \"mu_intercept_per_group\": -7.873775005340576, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 2, \"draws\": 770, \"mu_intercept_per_group\": -6.791451454162598, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 2, \"draws\": 771, \"mu_intercept_per_group\": -4.2936577796936035, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 2, \"draws\": 772, \"mu_intercept_per_group\": -5.142871856689453, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 2, \"draws\": 773, \"mu_intercept_per_group\": -14.31627368927002, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 2, \"draws\": 774, \"mu_intercept_per_group\": -12.36171817779541, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 2, \"draws\": 775, \"mu_intercept_per_group\": -6.712922096252441, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 2, \"draws\": 776, \"mu_intercept_per_group\": -9.651631355285645, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 2, \"draws\": 777, \"mu_intercept_per_group\": -14.539401054382324, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 2, \"draws\": 778, \"mu_intercept_per_group\": -15.18818473815918, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 2, \"draws\": 779, \"mu_intercept_per_group\": -2.6369786262512207, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 2, \"draws\": 780, \"mu_intercept_per_group\": -2.933114767074585, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 2, \"draws\": 781, \"mu_intercept_per_group\": -1.4494256973266602, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 2, \"draws\": 782, \"mu_intercept_per_group\": -1.3931396007537842, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 2, \"draws\": 783, \"mu_intercept_per_group\": -4.595110893249512, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 2, \"draws\": 784, \"mu_intercept_per_group\": -6.4242401123046875, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 2, \"draws\": 785, \"mu_intercept_per_group\": -2.5185546875, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 2, \"draws\": 786, \"mu_intercept_per_group\": 3.1089842319488525, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 2, \"draws\": 787, \"mu_intercept_per_group\": -11.959139823913574, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 2, \"draws\": 788, \"mu_intercept_per_group\": -2.921675682067871, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 2, \"draws\": 789, \"mu_intercept_per_group\": -10.664714813232422, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 2, \"draws\": 790, \"mu_intercept_per_group\": 0.5719683766365051, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 2, \"draws\": 791, \"mu_intercept_per_group\": -7.505753040313721, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 2, \"draws\": 792, \"mu_intercept_per_group\": -3.3922877311706543, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 2, \"draws\": 793, \"mu_intercept_per_group\": -10.66794490814209, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 2, \"draws\": 794, \"mu_intercept_per_group\": -6.48715877532959, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 2, \"draws\": 795, \"mu_intercept_per_group\": -6.622535705566406, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 2, \"draws\": 796, \"mu_intercept_per_group\": -4.584940433502197, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 2, \"draws\": 797, \"mu_intercept_per_group\": -8.618965148925781, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 2, \"draws\": 798, \"mu_intercept_per_group\": 4.649777889251709, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 2, \"draws\": 799, \"mu_intercept_per_group\": -4.510105133056641, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": 0.7729978561401367, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": 2.5576159954071045, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -15.630372047424316, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -7.6771016120910645, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -5.916408061981201, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -7.897109031677246, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": 1.4757341146469116, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -4.903013229370117, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": 0.0008504570578224957, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -6.191142559051514, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": -1.231655240058899, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": 0.07658789306879044, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -0.5222709774971008, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": 2.488961696624756, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": 4.562325477600098, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": 4.297399520874023, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -2.1755757331848145, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -3.3988754749298096, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -2.7023894786834717, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": -0.8932782411575317, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -0.6970798373222351, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": 1.1319938898086548, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -8.907038688659668, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": -2.1540539264678955, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": 1.8095935583114624, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": 1.9386407136917114, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -7.984805583953857, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": 1.022409200668335, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -7.996187686920166, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": -0.0855005532503128, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -0.8716172575950623, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": 0.2112625688314438, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -1.348555564880371, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -5.858479976654053, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -2.790870428085327, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -1.8255144357681274, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -1.0595612525939941, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -7.927624702453613, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -6.20832633972168, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -2.1399383544921875, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -1.5381795167922974, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -1.5545978546142578, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": 0.215438112616539, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -1.5891093015670776, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": 1.7711843252182007, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -1.2604111433029175, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": 8.4384183883667, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": -5.633958339691162, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": -3.992328405380249, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": -3.331123113632202, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": 2.71802020072937, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.240558624267578, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": 1.6682199239730835, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": 4.460513591766357, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -3.732459306716919, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -6.447565078735352, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -1.6070784330368042, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -4.977980136871338, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -2.6622726917266846, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -4.670049667358398, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.63996958732605, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -6.944875240325928, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -11.007387161254883, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -3.0327038764953613, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": -3.62882924079895, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": -1.3610283136367798, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": 13.914705276489258, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -3.2970852851867676, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -2.6963889598846436, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -2.5653228759765625, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -4.373826503753662, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -1.1720118522644043, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": -8.70683479309082, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -2.438925266265869, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.2935564517974854, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -3.090775489807129, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -1.5278346538543701, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -8.215974807739258, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -7.3276448249816895, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -4.790713310241699, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": -5.492677688598633, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": 3.9661335945129395, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": 0.8954457640647888, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.4581475257873535, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -1.0431321859359741, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -4.430739879608154, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": -0.8749560117721558, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": 1.1966431140899658, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": -0.8651579022407532, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": 1.9903035163879395, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": 0.7818329930305481, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": 1.8585156202316284, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": -5.520743370056152, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -1.9033398628234863, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": -1.2173367738723755, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": -2.310163736343384, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -4.370276927947998, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": -0.6061571836471558, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": 3.919738531112671, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.537262439727783, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": 1.3796738386154175, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": -2.4834635257720947, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -1.9795879125595093, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -1.5032273530960083, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": 0.35730239748954773, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": 1.548250436782837, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -4.235903739929199, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": -4.03542423248291, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -4.609384536743164, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -4.904811859130859, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -1.986157774925232, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -3.238687038421631, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": 0.2477487176656723, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": 1.249472737312317, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": -2.1174490451812744, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -2.047882556915283, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -4.010584831237793, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -3.4212327003479004, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -2.3824496269226074, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": 0.8859773278236389, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": 1.573637843132019, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": 1.6629940271377563, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -2.046961784362793, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -1.7331576347351074, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -2.832564353942871, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -7.121358394622803, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -0.40063801407814026, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": 1.7901945114135742, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -3.779466152191162, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -5.856951713562012, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -12.53681468963623, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": -4.802778244018555, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -4.689883708953857, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -1.8355873823165894, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": -2.376208543777466, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -1.5421327352523804, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": -7.0563859939575195, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -3.3421196937561035, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -5.937716007232666, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -5.722917556762695, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -4.670416355133057, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": -9.58543586730957, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": -12.17514419555664, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -5.196476459503174, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -3.1978840827941895, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": -4.271164417266846, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -1.2053731679916382, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -3.0357038974761963, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": 0.8285552859306335, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -7.2529826164245605, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": 2.855712890625, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -5.281179904937744, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": 0.11891759932041168, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -1.3204766511917114, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -6.861410140991211, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": 0.3529870808124542, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -3.6149821281433105, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": -1.7037326097488403, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -0.17777523398399353, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": 1.172585368156433, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": -0.6606081128120422, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -3.2972850799560547, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": 5.426305770874023, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": -11.137568473815918, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": 4.0911054611206055, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": -4.546718120574951, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": 2.3315799236297607, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -4.638082504272461, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -15.599499702453613, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": 5.009268760681152, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -10.581379890441895, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": -7.08134651184082, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -7.74715518951416, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": -2.5135130882263184, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": -1.133852243423462, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -0.026793822646141052, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -3.6288652420043945, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": 1.496415376663208, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -0.664207398891449, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -2.265352249145508, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -1.784432053565979, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -2.5753791332244873, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -3.403897523880005, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -6.488370418548584, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -4.2030110359191895, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -4.461339950561523, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": -2.5829524993896484, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -9.537115097045898, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -10.74303150177002, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": 4.412139892578125, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -0.9835578203201294, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": -10.080460548400879, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -9.055121421813965, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -8.233230590820312, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": -11.831539154052734, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -12.184955596923828, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -8.283927917480469, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": 2.154409885406494, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -1.7304502725601196, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": -0.45911160111427307, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -0.4810064136981964, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -9.619840621948242, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -12.92672348022461, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -8.507692337036133, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -6.64900541305542, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -8.096454620361328, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": 3.8468217849731445, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -9.48820686340332, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -8.874402046203613, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -0.06898639351129532, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": 4.08890438079834, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -8.726569175720215, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -9.27495002746582, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": 0.6376737356185913, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -7.221817493438721, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": -0.34191495180130005, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -0.948788583278656, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": 7.580447196960449, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -2.6769556999206543, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -1.0453697443008423, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": 1.4647083282470703, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -8.465591430664062, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -1.4972397089004517, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -4.581372261047363, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -2.190138816833496, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -6.100614070892334, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -7.044806003570557, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": 1.149350881576538, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": 1.2659876346588135, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -5.195645332336426, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -2.498837947845459, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -3.2305495738983154, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": 3.7393500804901123, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -1.3136063814163208, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -1.826981544494629, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -1.1596156358718872, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -0.41364046931266785, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": 1.9637316465377808, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -1.4677605628967285, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": 0.7056909203529358, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -3.780853033065796, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -8.136689186096191, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -5.551948070526123, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": 3.4272098541259766, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -2.075362205505371, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -1.72201669216156, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": 1.449154257774353, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -1.3620833158493042, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": -0.5075043439865112, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": -1.1450228691101074, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -0.36527732014656067, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": 0.09547734260559082, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -1.6158649921417236, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": -0.09719149023294449, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -3.8173511028289795, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -2.326616048812866, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": -0.8784146308898926, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": -4.131935119628906, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": 0.5276712775230408, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -4.933258056640625, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -5.23471212387085, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": -3.7781925201416016, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -4.5595221519470215, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": 5.08206844329834, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -5.339930534362793, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": -0.24307216703891754, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": 2.6928279399871826, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": -2.0223493576049805, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": 1.790094017982483, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -1.841404676437378, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": -2.427300453186035, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": 0.1738460659980774, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -2.6124939918518066, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -2.045912981033325, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": -1.9370566606521606, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -5.966158390045166, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -1.821732759475708, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -3.5022640228271484, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": 3.303950548171997, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -8.234082221984863, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -8.883081436157227, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -3.943300724029541, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -2.544323205947876, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -1.3240317106246948, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": 5.333137035369873, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -3.036935567855835, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -1.676323413848877, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -4.030872821807861, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -3.548109531402588, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -6.717248439788818, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -6.717763900756836, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": 2.4115774631500244, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -2.2747128009796143, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -1.1647106409072876, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": 1.268754243850708, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": 2.5047833919525146, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": 4.70051383972168, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": 2.0318031311035156, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -0.15804092586040497, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": 2.0572078227996826, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -3.2935431003570557, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -5.0384745597839355, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -6.0845208168029785, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -2.363816738128662, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -2.602214813232422, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -6.9825873374938965, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": 1.8069485425949097, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -1.612187385559082, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": 5.84406042098999, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -1.0108296871185303, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -4.586216449737549, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": 1.1758159399032593, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -0.19554448127746582, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": -5.441779613494873, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -3.635439395904541, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -0.6617841720581055, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -3.8006112575531006, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -1.4100514650344849, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": 2.193551540374756, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -11.548116683959961, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": 0.10682724416255951, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -1.633874535560608, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -6.431010723114014, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -5.747864723205566, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": -6.607283592224121, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -3.562821388244629, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": -0.5321371555328369, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": -5.833706855773926, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -4.0697174072265625, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": -0.23639695346355438, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -7.8773016929626465, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": -13.07494068145752, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": 10.130295753479004, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": -1.5055333375930786, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -5.5272321701049805, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -5.98327112197876, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -8.0422945022583, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -10.151165008544922, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -1.4218918085098267, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -4.701929092407227, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": 1.2102677822113037, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": 2.306626796722412, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": 2.1971404552459717, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -1.0194830894470215, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": -0.48005592823028564, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -0.030725030228495598, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": 0.20156224071979523, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": 2.5576300621032715, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -6.270695686340332, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -0.5279982686042786, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": -4.689144611358643, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -2.899472951889038, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": -2.457252264022827, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": 4.523967742919922, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -3.708181619644165, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -2.7483341693878174, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -8.117924690246582, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -5.606544494628906, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": 2.3204281330108643, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": -4.051812648773193, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -6.777442932128906, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -8.581803321838379, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": 11.323477745056152, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -9.7399263381958, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": -7.909341812133789, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": 8.820597648620605, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": 5.280309677124023, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -8.454923629760742, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": -2.2238190174102783, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -9.336411476135254, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -8.493613243103027, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -4.491842269897461, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -5.194399356842041, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -5.652657985687256, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.4333231449127197, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.122965335845947, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -4.90877103805542, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -3.871978998184204, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -2.4101455211639404, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": -0.28004997968673706, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": -5.658375263214111, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": 0.04556048661470413, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -6.822695732116699, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": 6.333250522613525, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -13.376962661743164, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -1.8158949613571167, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -1.875123143196106, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -8.012168884277344, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -3.842062473297119, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": -9.849735260009766, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": 3.1212399005889893, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -10.854839324951172, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -3.9350996017456055, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -2.8015007972717285, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -4.797412872314453, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -1.7533438205718994, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.222460746765137, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": -0.5228568911552429, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -1.6841996908187866, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": -0.3925299048423767, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": 0.014026306569576263, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": -4.972944259643555, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": -5.890504360198975, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -6.4565348625183105, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -6.078294277191162, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.885735034942627, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": 0.7769301533699036, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -2.837780475616455, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -3.609874963760376, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": 2.4180572032928467, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -2.526620388031006, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -3.6871256828308105, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -4.6655073165893555, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -3.7391233444213867, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": 1.6963337659835815, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": -2.7879111766815186, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": 2.0171875953674316, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -0.6188649535179138, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": 2.3816747665405273, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -3.80289363861084, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -4.134194850921631, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": -2.6655044555664062, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -4.337265968322754, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -0.2965644896030426, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": 4.272500514984131, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": 5.858344554901123, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -6.253540515899658, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -4.033501625061035, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -2.78776478767395, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": 1.641811728477478, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -0.5487359166145325, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": -0.46142950654029846, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": 0.18609517812728882, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -5.003287315368652, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -10.343600273132324, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": 1.8699016571044922, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": 7.5756425857543945, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": 5.318737030029297, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": 2.686436891555786, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -3.681781530380249, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -2.257204532623291, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -0.9874634742736816, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": -2.299757719039917, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -0.7148319482803345, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": -1.4990540742874146, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -0.3842703700065613, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": 0.4930330216884613, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -3.0846705436706543, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -2.4280905723571777, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -1.011371374130249, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": 1.2819397449493408, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": 0.7718411684036255, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -2.2469098567962646, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -2.8420774936676025, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -9.168822288513184, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -14.82772159576416, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -6.330742359161377, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": 5.863987922668457, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": 2.63208270072937, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": 1.0274628400802612, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -4.197484016418457, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -8.098832130432129, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -6.701765537261963, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -5.983802795410156, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -6.69032621383667, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -5.8324503898620605, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -8.549087524414062, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -11.50606918334961, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": -2.604837656021118, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -4.569591522216797, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -1.8013606071472168, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": 2.694913864135742, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": 2.3314974308013916, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -0.27117180824279785, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": -5.818562984466553, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": 3.9881751537323, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -9.01700496673584, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -0.8230257034301758, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -1.5750385522842407, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": -2.746061086654663, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": -9.366789817810059, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": 1.9630008935928345, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -5.180045127868652, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -3.5839788913726807, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -5.943552017211914, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": 1.1581122875213623, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -10.871915817260742, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -3.272449016571045, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": 11.12423038482666, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -12.285792350769043, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -11.452980041503906, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -5.362009525299072, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": 1.3363844156265259, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": -10.614635467529297, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": 1.0960532426834106, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": -4.455873489379883, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": 4.793271541595459, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -4.298285007476807, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -2.690425395965576, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": -9.418298721313477, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": 4.813493728637695, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -10.082383155822754, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -8.733139991760254, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": 2.550971746444702, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": 0.656514585018158, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": 1.0267070531845093, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -1.8246073722839355, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -3.421159267425537, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": -3.457228183746338, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -6.311945915222168, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -2.027968406677246, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -6.089402675628662, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": 2.45943546295166, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -6.669027805328369, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -3.6838507652282715, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": -3.2083654403686523, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": 1.7677066326141357, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -7.518925189971924, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -4.401648998260498, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -8.496939659118652, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -7.235056400299072, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": 3.750149726867676, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -12.567476272583008, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -8.686779022216797, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -4.5600128173828125, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": 2.7737088203430176, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": 3.838435649871826, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": -0.7197181582450867, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": -3.3963325023651123, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -8.164698600769043, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -8.012284278869629, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -10.554362297058105, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -6.095640182495117, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": -1.4059772491455078, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -2.1465418338775635, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -5.407135009765625, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -2.7066566944122314, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.606553316116333, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": -1.0590019226074219, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -6.312851428985596, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -1.7632514238357544, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -1.8353770971298218, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": 1.415894865989685, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": -1.2546262741088867, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -5.481130599975586, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": -0.06600435823202133, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": -1.3231734037399292, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": -4.929859638214111, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": 4.536769866943359, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -10.353217124938965, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": -3.2245419025421143, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -6.709771156311035, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": -6.806426525115967, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -4.43497371673584, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": 0.4083751142024994, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -8.372294425964355, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -9.751710891723633, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": 2.280830144882202, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -10.626394271850586, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": -8.325470924377441, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": -7.338185787200928, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -0.6945818662643433, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -8.861900329589844, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -4.5486345291137695, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": -8.140633583068848, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -2.749159097671509, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": -1.3354222774505615, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": -8.896646499633789, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -9.403252601623535, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": -5.306309223175049, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": -5.318828582763672, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": 2.706613779067993, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -9.88220500946045, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -11.386905670166016, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -7.873952865600586, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": -9.037904739379883, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -2.038160562515259, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -1.7292916774749756, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -7.190836429595947, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -0.6901519894599915, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": -7.476047515869141, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": 1.7148542404174805, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -1.2695749998092651, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -0.3088337182998657, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": 2.3561103343963623, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": 2.75426983833313, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -1.9799730777740479, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": 2.597970485687256, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": 0.1949249804019928, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -0.6100018620491028, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -4.782199382781982, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -5.7646026611328125, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -2.782027244567871, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -2.860196828842163, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -3.512709856033325, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": -8.340370178222656, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -8.80096435546875, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -7.172421932220459, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -6.54105281829834, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -8.092638969421387, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": 0.4316912889480591, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -11.016030311584473, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": 0.28955012559890747, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": 0.6889787912368774, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -3.608013868331909, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -7.062358856201172, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -4.489008903503418, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": 2.3111960887908936, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": 4.235152244567871, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": 5.506235599517822, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": 6.664157390594482, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -0.7491138577461243, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -8.907501220703125, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": 0.0628831684589386, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": 0.855061411857605, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -2.395770788192749, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": -3.098580837249756, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -1.356034755706787, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": 2.2811648845672607, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -2.004554510116577, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -5.292853832244873, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": -1.8861891031265259, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": -0.28457367420196533, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": -0.60145503282547, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": -0.27850279211997986, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -2.043290376663208, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -6.528043746948242, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": -1.0598158836364746, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -5.7285284996032715, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": 1.7178311347961426, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -7.2815423011779785, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -5.883734226226807, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": -1.0119725465774536, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -10.619335174560547, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -10.962689399719238, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -13.847087860107422, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -7.4948930740356445, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -3.658454179763794, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": -2.1661136150360107, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -2.5975892543792725, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 640, \"mu_intercept_per_group\": -2.2468814849853516, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 641, \"mu_intercept_per_group\": -1.0284518003463745, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 642, \"mu_intercept_per_group\": 4.391664981842041, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 643, \"mu_intercept_per_group\": 2.9000000953674316, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 644, \"mu_intercept_per_group\": -11.056596755981445, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 645, \"mu_intercept_per_group\": -17.745315551757812, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 646, \"mu_intercept_per_group\": -15.67020320892334, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 647, \"mu_intercept_per_group\": 2.660463571548462, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 648, \"mu_intercept_per_group\": -4.771359443664551, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 649, \"mu_intercept_per_group\": 2.9194276332855225, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 650, \"mu_intercept_per_group\": 1.7498847246170044, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 651, \"mu_intercept_per_group\": -5.505434036254883, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 652, \"mu_intercept_per_group\": -0.09222177416086197, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 653, \"mu_intercept_per_group\": -4.62263822555542, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 654, \"mu_intercept_per_group\": -0.9472702145576477, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 655, \"mu_intercept_per_group\": -7.935478210449219, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 656, \"mu_intercept_per_group\": -8.632340431213379, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 657, \"mu_intercept_per_group\": 0.7324752807617188, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 658, \"mu_intercept_per_group\": -3.0321476459503174, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 659, \"mu_intercept_per_group\": -2.35292911529541, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 660, \"mu_intercept_per_group\": -2.1271626949310303, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 661, \"mu_intercept_per_group\": 0.4639717638492584, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 662, \"mu_intercept_per_group\": 0.5958596467971802, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 663, \"mu_intercept_per_group\": 3.297173261642456, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 664, \"mu_intercept_per_group\": -3.706890106201172, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 665, \"mu_intercept_per_group\": -2.5453717708587646, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 666, \"mu_intercept_per_group\": -0.37216678261756897, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 667, \"mu_intercept_per_group\": -0.2469213604927063, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 668, \"mu_intercept_per_group\": -1.3232388496398926, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 669, \"mu_intercept_per_group\": -2.906867742538452, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 670, \"mu_intercept_per_group\": -1.5115824937820435, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 671, \"mu_intercept_per_group\": 0.2185535728931427, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 672, \"mu_intercept_per_group\": -4.99647855758667, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 673, \"mu_intercept_per_group\": -1.2066024541854858, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 674, \"mu_intercept_per_group\": -5.39521598815918, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 675, \"mu_intercept_per_group\": -1.5990757942199707, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 676, \"mu_intercept_per_group\": -2.224437952041626, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 677, \"mu_intercept_per_group\": -4.856782913208008, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 678, \"mu_intercept_per_group\": -7.974399089813232, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 679, \"mu_intercept_per_group\": -1.920876383781433, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 680, \"mu_intercept_per_group\": 3.7750213146209717, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 681, \"mu_intercept_per_group\": -1.5201829671859741, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 682, \"mu_intercept_per_group\": -9.091574668884277, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 683, \"mu_intercept_per_group\": -6.95822811126709, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 684, \"mu_intercept_per_group\": -8.126626968383789, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 685, \"mu_intercept_per_group\": -2.389530658721924, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 686, \"mu_intercept_per_group\": -8.640242576599121, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 687, \"mu_intercept_per_group\": -1.5745396614074707, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 688, \"mu_intercept_per_group\": -1.2525497674942017, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 689, \"mu_intercept_per_group\": 0.058085858821868896, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 690, \"mu_intercept_per_group\": -1.4349377155303955, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 691, \"mu_intercept_per_group\": 2.4706037044525146, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 692, \"mu_intercept_per_group\": -2.186415910720825, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 693, \"mu_intercept_per_group\": -4.482550621032715, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 694, \"mu_intercept_per_group\": -0.01432141661643982, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 695, \"mu_intercept_per_group\": -2.2793478965759277, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 696, \"mu_intercept_per_group\": -0.22418785095214844, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 697, \"mu_intercept_per_group\": -1.3972597122192383, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 698, \"mu_intercept_per_group\": -7.197316646575928, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 699, \"mu_intercept_per_group\": -13.507685661315918, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 700, \"mu_intercept_per_group\": -9.526333808898926, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 701, \"mu_intercept_per_group\": -5.483582973480225, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 702, \"mu_intercept_per_group\": -0.47711125016212463, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 703, \"mu_intercept_per_group\": 5.863067150115967, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 704, \"mu_intercept_per_group\": 1.2611258029937744, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 705, \"mu_intercept_per_group\": -0.12948386371135712, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 706, \"mu_intercept_per_group\": -6.933868885040283, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 707, \"mu_intercept_per_group\": -8.220573425292969, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 708, \"mu_intercept_per_group\": 6.276364803314209, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 709, \"mu_intercept_per_group\": -6.4308695793151855, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 710, \"mu_intercept_per_group\": -15.684427261352539, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 711, \"mu_intercept_per_group\": -10.95212459564209, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 712, \"mu_intercept_per_group\": 3.8075761795043945, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 713, \"mu_intercept_per_group\": 2.326347589492798, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 714, \"mu_intercept_per_group\": -5.305049419403076, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 715, \"mu_intercept_per_group\": -6.809045791625977, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 716, \"mu_intercept_per_group\": -0.669330358505249, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 717, \"mu_intercept_per_group\": 3.2990448474884033, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 718, \"mu_intercept_per_group\": -4.465162754058838, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 719, \"mu_intercept_per_group\": 4.1154398918151855, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 720, \"mu_intercept_per_group\": -5.626036643981934, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 721, \"mu_intercept_per_group\": 1.2012723684310913, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 722, \"mu_intercept_per_group\": 2.5984013080596924, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 723, \"mu_intercept_per_group\": 2.4577410221099854, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 724, \"mu_intercept_per_group\": 2.2246668338775635, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 725, \"mu_intercept_per_group\": -0.8230442404747009, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 726, \"mu_intercept_per_group\": -2.5841143131256104, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 727, \"mu_intercept_per_group\": -0.34180882573127747, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 728, \"mu_intercept_per_group\": -4.037069797515869, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 729, \"mu_intercept_per_group\": -1.3687015771865845, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 730, \"mu_intercept_per_group\": -5.178031921386719, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 731, \"mu_intercept_per_group\": 0.8855155110359192, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 732, \"mu_intercept_per_group\": -3.3502166271209717, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 733, \"mu_intercept_per_group\": 0.5392231345176697, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 734, \"mu_intercept_per_group\": 0.8368700742721558, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 735, \"mu_intercept_per_group\": -3.9336323738098145, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 736, \"mu_intercept_per_group\": -2.002354145050049, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 737, \"mu_intercept_per_group\": -1.345548391342163, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 738, \"mu_intercept_per_group\": -4.621778964996338, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 739, \"mu_intercept_per_group\": 1.33220374584198, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 740, \"mu_intercept_per_group\": -4.420913219451904, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 741, \"mu_intercept_per_group\": -6.314290523529053, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 742, \"mu_intercept_per_group\": -5.879936218261719, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 743, \"mu_intercept_per_group\": -7.114010334014893, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 744, \"mu_intercept_per_group\": -4.744460105895996, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 745, \"mu_intercept_per_group\": -2.8933112621307373, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 746, \"mu_intercept_per_group\": -4.239678859710693, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 747, \"mu_intercept_per_group\": -6.10495662689209, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 748, \"mu_intercept_per_group\": -13.223487854003906, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 749, \"mu_intercept_per_group\": -8.596107482910156, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 750, \"mu_intercept_per_group\": -6.459287166595459, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 751, \"mu_intercept_per_group\": 1.7112090587615967, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 752, \"mu_intercept_per_group\": -4.056285858154297, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 753, \"mu_intercept_per_group\": -6.1363139152526855, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 754, \"mu_intercept_per_group\": -0.9960377812385559, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 755, \"mu_intercept_per_group\": -6.486042499542236, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 756, \"mu_intercept_per_group\": 2.436647653579712, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 757, \"mu_intercept_per_group\": 3.4043526649475098, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 758, \"mu_intercept_per_group\": 2.267836332321167, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 759, \"mu_intercept_per_group\": -9.767388343811035, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 760, \"mu_intercept_per_group\": -4.393158912658691, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 3, \"draws\": 761, \"mu_intercept_per_group\": -0.344616174697876, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 3, \"draws\": 762, \"mu_intercept_per_group\": -3.5106453895568848, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 3, \"draws\": 763, \"mu_intercept_per_group\": -6.434812545776367, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 3, \"draws\": 764, \"mu_intercept_per_group\": 3.038347005844116, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 3, \"draws\": 765, \"mu_intercept_per_group\": -13.914017677307129, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 3, \"draws\": 766, \"mu_intercept_per_group\": -10.240656852722168, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 3, \"draws\": 767, \"mu_intercept_per_group\": 0.7463173270225525, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 3, \"draws\": 768, \"mu_intercept_per_group\": -1.241904616355896, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 3, \"draws\": 769, \"mu_intercept_per_group\": -2.298616886138916, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 3, \"draws\": 770, \"mu_intercept_per_group\": 7.241799354553223, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 3, \"draws\": 771, \"mu_intercept_per_group\": 7.60746955871582, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 3, \"draws\": 772, \"mu_intercept_per_group\": -13.528547286987305, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 3, \"draws\": 773, \"mu_intercept_per_group\": -8.452853202819824, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 3, \"draws\": 774, \"mu_intercept_per_group\": -13.1639986038208, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 3, \"draws\": 775, \"mu_intercept_per_group\": 0.5599178075790405, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 3, \"draws\": 776, \"mu_intercept_per_group\": -13.727354049682617, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 3, \"draws\": 777, \"mu_intercept_per_group\": 0.6607734560966492, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 3, \"draws\": 778, \"mu_intercept_per_group\": 0.19224005937576294, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 3, \"draws\": 779, \"mu_intercept_per_group\": -12.990958213806152, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 3, \"draws\": 780, \"mu_intercept_per_group\": 6.182288646697998, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 3, \"draws\": 781, \"mu_intercept_per_group\": -7.878615856170654, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 3, \"draws\": 782, \"mu_intercept_per_group\": -3.175875663757324, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 3, \"draws\": 783, \"mu_intercept_per_group\": -2.2130630016326904, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 3, \"draws\": 784, \"mu_intercept_per_group\": -5.337174892425537, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 3, \"draws\": 785, \"mu_intercept_per_group\": 1.0695079565048218, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 3, \"draws\": 786, \"mu_intercept_per_group\": -1.4714792966842651, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 3, \"draws\": 787, \"mu_intercept_per_group\": 1.0740083456039429, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 3, \"draws\": 788, \"mu_intercept_per_group\": -14.667440414428711, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 3, \"draws\": 789, \"mu_intercept_per_group\": -1.7504222393035889, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 3, \"draws\": 790, \"mu_intercept_per_group\": -2.0282371044158936, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 3, \"draws\": 791, \"mu_intercept_per_group\": -4.471524715423584, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 3, \"draws\": 792, \"mu_intercept_per_group\": -2.085010051727295, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 3, \"draws\": 793, \"mu_intercept_per_group\": 3.712113380432129, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 3, \"draws\": 794, \"mu_intercept_per_group\": -6.207667350769043, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 3, \"draws\": 795, \"mu_intercept_per_group\": -2.813821315765381, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 3, \"draws\": 796, \"mu_intercept_per_group\": -6.484835624694824, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 3, \"draws\": 797, \"mu_intercept_per_group\": 5.695314407348633, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 3, \"draws\": 798, \"mu_intercept_per_group\": -6.322709560394287, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 3, \"draws\": 799, \"mu_intercept_per_group\": 6.0068182945251465, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": 5.1156182289123535, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": -4.454998970031738, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -1.5051785707473755, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -1.185460090637207, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": 1.1279643774032593, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -0.01661406271159649, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -9.024558067321777, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -6.064688205718994, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": 7.812157154083252, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -8.287120819091797, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": 0.9461223483085632, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": 2.499837875366211, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -1.4895927906036377, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": 0.8405243158340454, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": 2.2790915966033936, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -1.1009260416030884, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": 7.067309856414795, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": 4.822682857513428, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": 4.769409656524658, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -2.440972328186035, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": 4.536755561828613, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": 4.707822799682617, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -11.092272758483887, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": -0.38059452176094055, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": -0.043926846235990524, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": 5.188973903656006, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": 0.5604416728019714, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": 0.08138760179281235, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -7.736147403717041, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": 2.3661515712738037, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": 0.1777845025062561, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": 2.116401195526123, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -1.0413906574249268, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -2.7406296730041504, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -0.7095293998718262, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -0.9425797462463379, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -0.9080623388290405, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -4.971570014953613, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -6.3113274574279785, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": 5.496521472930908, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": 1.5471538305282593, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": 1.0321208238601685, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": 6.250414848327637, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": 4.455760955810547, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": 10.998411178588867, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": 7.656618595123291, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -6.308050155639648, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": 5.955265522003174, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": 6.392009258270264, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": 6.299585342407227, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": 3.271092414855957, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -3.306713819503784, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -2.7466158866882324, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": 0.046207111328840256, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": 0.9303532838821411, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": 4.3676018714904785, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": -6.299905776977539, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": 3.6722986698150635, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -3.982924222946167, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": 0.9599448442459106, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -6.197045803070068, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -0.49448004364967346, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -3.13375186920166, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": -3.489988327026367, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -5.552624225616455, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -7.182042598724365, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": 1.3740073442459106, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": 0.073964424431324, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": 0.2331823855638504, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -1.857471227645874, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": -2.065788507461548, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -3.793858051300049, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -1.993916630744934, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -1.365516185760498, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": 1.1463963985443115, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": 4.0993194580078125, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": 3.58670973777771, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": -6.066768169403076, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -2.9240665435791016, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -3.593717098236084, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": -0.7204934358596802, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": 3.88370418548584, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -3.1109251976013184, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -8.71292495727539, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": 4.540823936462402, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": 5.355626583099365, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": 5.413890361785889, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -1.489777684211731, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": 9.033890724182129, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": 7.911537170410156, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": 5.918521881103516, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": 1.0959123373031616, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": 2.71136474609375, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -3.1173033714294434, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": 2.977689027786255, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": 2.363872528076172, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -3.4640889167785645, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -2.517052412033081, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": 2.653062582015991, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": 5.337561130523682, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": -0.12902295589447021, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -2.637746810913086, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": -2.796678304672241, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": 1.2792474031448364, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": -1.1054576635360718, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": 2.5731217861175537, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -3.424839735031128, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": -3.9740097522735596, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": 0.07212571799755096, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": 0.9078658819198608, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": 0.6375399231910706, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": 1.130536675453186, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": 2.234689950942993, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": 0.9038075804710388, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": -0.14674583077430725, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": -1.322433352470398, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -1.300746202468872, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -1.639060139656067, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": 1.0665463209152222, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": 1.8708109855651855, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": 0.7643848061561584, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": 0.23025207221508026, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -1.2912242412567139, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -0.16707724332809448, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -0.11516336351633072, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -0.06627526879310608, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -1.958249807357788, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": 2.380553722381592, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": 4.320312976837158, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": 3.837256669998169, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -10.381379127502441, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -12.692630767822266, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": 2.1929595470428467, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": 0.22386576235294342, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": 0.671087920665741, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": -3.3307485580444336, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -1.9795032739639282, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": -3.8851311206817627, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": 0.9909618496894836, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": -7.157304763793945, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -4.510440826416016, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -4.948209285736084, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": -8.648031234741211, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": 6.050476551055908, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -6.443554401397705, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -0.18920476734638214, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": 2.8943231105804443, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": 2.4175033569335938, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -2.9097907543182373, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": -0.17369654774665833, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -1.7149232625961304, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": 2.2616615295410156, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": 0.9123438596725464, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -1.8769060373306274, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": 1.1230369806289673, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -0.7268622517585754, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": 3.427778720855713, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": 3.910863161087036, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": 0.19274945557117462, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": 0.5586625933647156, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": 1.2778606414794922, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": -3.1659204959869385, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": 3.9557487964630127, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -4.612392425537109, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": 3.4417834281921387, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -1.0370126962661743, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": 1.387492299079895, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": 3.925194025039673, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -0.040185216814279556, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -2.550446033477783, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": 3.1018552780151367, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -3.5315237045288086, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": -1.5151947736740112, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": 6.189752578735352, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": 3.15032958984375, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": 1.6915638446807861, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": 1.9852125644683838, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -0.08062414824962616, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": 4.070410251617432, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -1.1406450271606445, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": 0.8294100165367126, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -2.598912477493286, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -1.8153165578842163, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": 2.9695959091186523, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": 3.272545337677002, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": -2.756528854370117, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -6.767012596130371, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -7.425303936004639, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -3.6160619258880615, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": 1.0935500860214233, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -2.8697564601898193, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -6.3965325355529785, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -3.898015022277832, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -5.358492851257324, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -5.745563983917236, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -8.839985847473145, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -9.053955078125, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": 5.213561534881592, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": 2.186666488647461, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": 0.6481235027313232, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -4.149691581726074, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": 0.9985529184341431, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -9.480239868164062, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -7.1371893882751465, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -7.652785778045654, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -8.251346588134766, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -7.25816011428833, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": 0.9636154770851135, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": 1.1379661560058594, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -4.040475845336914, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -7.405605316162109, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": 3.6622250080108643, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": 3.1288020610809326, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -6.999793529510498, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -3.447509765625, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -0.6488972902297974, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": 3.9828567504882812, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": 0.14852721989154816, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": 3.2866926193237305, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": 3.499316453933716, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": 6.293667793273926, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -4.865436553955078, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": 1.3368916511535645, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -3.9205126762390137, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -10.36670970916748, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": 4.208789825439453, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -17.408466339111328, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -16.569992065429688, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -14.022186279296875, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": 6.123493194580078, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": 6.506656169891357, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": -2.0291967391967773, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": 8.543365478515625, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": 5.528222560882568, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": 0.8516635894775391, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": 2.862783193588257, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -5.143924713134766, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -3.552511692047119, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": 0.1463955044746399, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": 0.9817221164703369, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -1.2799988985061646, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -7.7230658531188965, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -5.621201515197754, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": 4.316369533538818, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": 7.494516849517822, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -2.7024941444396973, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": 0.9052087068557739, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": 2.658675193786621, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": 3.2702419757843018, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -0.7365882396697998, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": 0.755963146686554, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": 1.7811744213104248, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": 2.306004524230957, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -3.2073476314544678, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -0.5964193940162659, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": 1.4479120969772339, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -3.6060497760772705, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -1.1471800804138184, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": 6.39102840423584, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -5.639570236206055, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -5.851770401000977, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": -0.5399554371833801, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": 3.558488368988037, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -2.5179646015167236, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -4.261041641235352, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -0.6464850306510925, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -1.4964582920074463, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": 2.594697952270508, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": 1.941373586654663, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": 3.2580394744873047, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": 2.6590750217437744, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": 0.8888639211654663, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": 2.6215219497680664, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": 2.873098850250244, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": -0.7541326284408569, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": 5.82467794418335, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -2.1690402030944824, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -8.49652099609375, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -9.377791404724121, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": 11.938055038452148, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": 10.923393249511719, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": 5.352827072143555, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": 4.3695454597473145, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.330234050750732, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": 5.909397125244141, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": 0.6660763621330261, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": 1.1862518787384033, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": 4.993441104888916, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": 3.56231951713562, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": 5.952818870544434, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": 7.30885648727417, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": 1.9790362119674683, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": 4.35106086730957, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": 2.838930130004883, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": 0.1515466570854187, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": 0.7289546728134155, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": 1.2931679487228394, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": 5.1645941734313965, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": 4.558197498321533, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": 1.50784432888031, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": 0.5630053877830505, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": 3.7872650623321533, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": 2.0862104892730713, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.121704339981079, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -2.5626864433288574, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": -1.3896619081497192, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": 1.3107242584228516, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": 5.2251996994018555, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": 2.213747501373291, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": 4.394522190093994, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": 5.802516460418701, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -2.010704278945923, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": 4.7920637130737305, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": -5.215092658996582, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -1.4895331859588623, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": -2.157881736755371, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -2.1257216930389404, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -1.4131895303726196, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -3.0992865562438965, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": 0.4297499656677246, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -3.596292734146118, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -1.2168598175048828, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -8.460518836975098, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -11.61655330657959, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -9.358890533447266, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -4.070477485656738, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -6.324276447296143, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": 0.24109183251857758, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -6.927430152893066, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -8.746049880981445, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": -0.8190046548843384, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": -4.425586700439453, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": 1.8997081518173218, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -2.76940655708313, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -6.073446750640869, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -0.5037386417388916, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": 3.207275629043579, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": 3.7451603412628174, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -4.140625, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": 1.8927711248397827, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": 1.4096051454544067, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": 0.7720010280609131, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": 2.5184216499328613, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": 6.52711820602417, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": 2.4345219135284424, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": 1.2938581705093384, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": 0.5517431497573853, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": 4.423878192901611, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": 3.781726598739624, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": -0.7834162712097168, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -0.5200153589248657, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": -0.4646046757698059, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": 1.7943854331970215, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": 0.7419343590736389, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": 1.0249954462051392, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": 3.0881824493408203, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": 3.5427167415618896, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -6.475241661071777, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": 5.707470893859863, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -5.4284281730651855, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": 0.6762484908103943, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": 0.7786275744438171, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -1.178585171699524, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": 3.8063833713531494, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": 4.719347953796387, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": 1.8661952018737793, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": 0.6960034966468811, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": -0.9852910041809082, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -5.086926460266113, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": 0.16287079453468323, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -0.07759910821914673, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -5.748922824859619, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -1.5322669744491577, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -1.5763181447982788, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -5.181453227996826, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -1.5166802406311035, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -3.473252534866333, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -1.7522926330566406, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": -9.57455825805664, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": -9.500923156738281, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": 2.7734110355377197, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -2.2194018363952637, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": 4.017869472503662, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": 3.2357687950134277, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": 8.515029907226562, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -28.49359130859375, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": 7.804621696472168, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": 4.290979862213135, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": 3.503208637237549, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": -5.604499340057373, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": 4.161564350128174, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -8.833394050598145, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": 6.380134582519531, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": -3.9561710357666016, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": -4.171249866485596, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": 1.2682405710220337, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -4.846833229064941, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -4.086613655090332, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -1.8126219511032104, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -1.1940587759017944, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": 1.1123946905136108, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": -1.5103994607925415, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": 1.5340478420257568, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": 0.5641594529151917, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -0.6305243372917175, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -1.314523696899414, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -0.5945066809654236, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": -4.088489055633545, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": 2.990294933319092, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": -4.175098896026611, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": 4.935359954833984, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": -4.146798133850098, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -10.262266159057617, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": -3.0410730838775635, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": 4.259956359863281, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": 5.477126121520996, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": 0.7660236954689026, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": 0.3942500054836273, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": 3.453885316848755, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -1.8462340831756592, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": 9.678252220153809, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -6.957736968994141, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -0.21919581294059753, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": 0.7943508625030518, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": 2.5815250873565674, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -4.093629360198975, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -0.45101794600486755, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": 4.5402655601501465, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": 0.9066123962402344, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -2.4247312545776367, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -0.9603496193885803, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -0.4179445505142212, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -1.624733567237854, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -6.608171463012695, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -0.9353424906730652, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -5.395445823669434, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": 3.0551722049713135, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": 0.5784128308296204, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -0.15208840370178223, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": 3.4902162551879883, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": -2.330967426300049, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -4.00036096572876, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": -1.6337424516677856, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -1.6092987060546875, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": 1.2708073854446411, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -1.0523977279663086, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": 1.8445743322372437, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -0.6053265929222107, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -0.7073754072189331, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.8983163833618164, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -3.9579453468322754, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -3.7737741470336914, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": -1.3790104389190674, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": 1.5067272186279297, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": 6.122858047485352, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -1.2702327966690063, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": 3.5327045917510986, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": 5.7600321769714355, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -0.4827205538749695, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": 4.4486823081970215, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": -2.3248136043548584, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -1.7182880640029907, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": -1.3900026082992554, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -3.9169352054595947, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": 4.927342891693115, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -4.6164984703063965, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": 1.02855384349823, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -0.7668550610542297, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": 1.1806329488754272, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -5.090454578399658, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -1.679796814918518, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -2.2498011589050293, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -0.37454739212989807, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -1.0162047147750854, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": 1.2074226140975952, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": -0.9186279773712158, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": -5.927387714385986, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": 1.7568645477294922, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": 5.666069030761719, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": 2.58199405670166, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": -0.7491344213485718, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": -1.1063998937606812, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": 0.6110823750495911, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -4.597982883453369, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -5.786310195922852, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": -2.1541104316711426, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": 1.0593883991241455, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": 7.63137674331665, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": 1.4506062269210815, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": 3.4246718883514404, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": 5.407749652862549, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": 3.231414556503296, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -1.2655601501464844, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -2.2663509845733643, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -3.1965785026550293, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": 5.958858013153076, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": 1.073761224746704, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": 1.587100863456726, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": 4.285175800323486, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": -1.3272712230682373, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": 4.351916790008545, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -5.77946662902832, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -0.8003838062286377, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": 2.621169328689575, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": 0.308123379945755, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": 0.6977989673614502, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": 2.626063585281372, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": 2.6410982608795166, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": -4.6477437019348145, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -3.4464995861053467, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -6.458850860595703, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": 2.6982593536376953, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -0.9598680138587952, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -2.3187150955200195, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -5.339229583740234, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -5.223474979400635, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": 5.761014938354492, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": -3.5977447032928467, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -5.948357582092285, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -5.672068119049072, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -0.888302206993103, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -9.063307762145996, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": 1.3047288656234741, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": 3.4323008060455322, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -7.570306777954102, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": 0.623348593711853, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": 0.2149716317653656, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -1.8085087537765503, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -9.007619857788086, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -10.868210792541504, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": -1.1441854238510132, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": 2.8563902378082275, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": 4.104420185089111, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": 2.2168619632720947, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -4.490050315856934, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -5.702247619628906, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": 0.18450963497161865, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -4.213654041290283, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": 1.452659249305725, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -0.5966827869415283, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": 5.413449287414551, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": -3.949657678604126, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -0.3551948666572571, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -4.447479248046875, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": -3.4241158962249756, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": -3.080961227416992, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": 0.3721519410610199, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": -1.6917227506637573, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": 3.311896562576294, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -1.1525789499282837, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": 6.720943450927734, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -9.405927658081055, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": 1.290811538696289, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": -8.290696144104004, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": 8.35690975189209, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -13.049421310424805, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -2.9261579513549805, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -7.659698486328125, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -3.814462423324585, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -3.3531908988952637, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": -1.3399895429611206, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -5.486206531524658, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": 0.5891740322113037, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": 2.1455485820770264, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": 0.2747425436973572, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": 1.391318917274475, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": 0.6497126221656799, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": -2.8767967224121094, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -1.3231884241104126, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": 5.819672107696533, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": 1.056994915008545, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -2.3605923652648926, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -0.13920745253562927, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -2.440188407897949, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": 1.6565073728561401, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": -8.7618408203125, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -0.8361642956733704, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -5.416953086853027, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": 3.0249600410461426, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -4.2229437828063965, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -0.8429264426231384, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -1.2205359935760498, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": 0.4977717101573944, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": 0.6358985304832458, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": -4.4828410148620605, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": -4.083406925201416, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -1.6076968908309937, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": -3.503382921218872, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": -2.3190438747406006, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -1.5827727317810059, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": 2.495713472366333, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": 3.147111415863037, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -1.4188296794891357, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -6.383792877197266, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -4.632706165313721, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -0.5683861374855042, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -1.7034428119659424, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": 1.4365379810333252, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": -5.567563533782959, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": -6.591879844665527, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -3.206094980239868, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -1.4943337440490723, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": 8.312922477722168, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -8.825135231018066, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": 0.1084454357624054, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": 0.7664998769760132, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -0.9495618343353271, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": 4.672104835510254, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": 7.307130336761475, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": 15.758122444152832, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": 13.401596069335938, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": 1.6427394151687622, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": 5.59911584854126, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": 3.064711332321167, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": 8.4989013671875, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": -5.950882911682129, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": 4.29685115814209, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.0380048751831055, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": 1.4352627992630005, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": 3.228541851043701, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -3.446817636489868, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": 12.678860664367676, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -12.063114166259766, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -11.10678482055664, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -9.217937469482422, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -7.138777256011963, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": 2.2965540885925293, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": 1.853851318359375, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -3.726346492767334, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": 0.28147807717323303, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -2.281813859939575, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": 1.079444408416748, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -7.2649922370910645, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -0.11964879184961319, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -0.1549735963344574, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -4.8555426597595215, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": 10.473400115966797, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": 0.9686374068260193, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": 1.0502506494522095, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": 1.7587281465530396, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 640, \"mu_intercept_per_group\": 1.5894137620925903, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 641, \"mu_intercept_per_group\": -3.2049460411071777, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 642, \"mu_intercept_per_group\": -7.617331504821777, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 643, \"mu_intercept_per_group\": -15.242634773254395, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 644, \"mu_intercept_per_group\": -2.76973557472229, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 645, \"mu_intercept_per_group\": 4.667227745056152, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 646, \"mu_intercept_per_group\": 11.43069076538086, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 647, \"mu_intercept_per_group\": -17.191957473754883, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 648, \"mu_intercept_per_group\": 7.664495944976807, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 649, \"mu_intercept_per_group\": -6.51264762878418, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 650, \"mu_intercept_per_group\": -1.3505483865737915, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 651, \"mu_intercept_per_group\": 3.0304951667785645, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 652, \"mu_intercept_per_group\": -0.3208632469177246, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 653, \"mu_intercept_per_group\": 1.7947508096694946, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 654, \"mu_intercept_per_group\": 0.2114512175321579, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 655, \"mu_intercept_per_group\": -8.684758186340332, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 656, \"mu_intercept_per_group\": 3.0530917644500732, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 657, \"mu_intercept_per_group\": -9.523733139038086, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 658, \"mu_intercept_per_group\": -1.716188669204712, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 659, \"mu_intercept_per_group\": 2.8698885440826416, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 660, \"mu_intercept_per_group\": -1.9865026473999023, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 661, \"mu_intercept_per_group\": 0.274986207485199, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 662, \"mu_intercept_per_group\": -0.6059769988059998, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 663, \"mu_intercept_per_group\": -2.7117350101470947, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 664, \"mu_intercept_per_group\": 2.198659658432007, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 665, \"mu_intercept_per_group\": 2.4404869079589844, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 666, \"mu_intercept_per_group\": -1.869913101196289, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 667, \"mu_intercept_per_group\": -1.0330160856246948, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 668, \"mu_intercept_per_group\": 3.023815155029297, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 669, \"mu_intercept_per_group\": -4.255948543548584, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 670, \"mu_intercept_per_group\": -3.680028200149536, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 671, \"mu_intercept_per_group\": -3.4055354595184326, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 672, \"mu_intercept_per_group\": 0.22682558000087738, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 673, \"mu_intercept_per_group\": -2.81795597076416, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 674, \"mu_intercept_per_group\": -1.5594991445541382, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 675, \"mu_intercept_per_group\": 2.5184667110443115, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 676, \"mu_intercept_per_group\": -1.917918086051941, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 677, \"mu_intercept_per_group\": 2.3749523162841797, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 678, \"mu_intercept_per_group\": -3.6064209938049316, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 679, \"mu_intercept_per_group\": 3.452589750289917, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 680, \"mu_intercept_per_group\": 0.16559676826000214, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 681, \"mu_intercept_per_group\": -6.8579864501953125, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 682, \"mu_intercept_per_group\": -12.487968444824219, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 683, \"mu_intercept_per_group\": -5.478238582611084, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 684, \"mu_intercept_per_group\": -2.4698245525360107, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 685, \"mu_intercept_per_group\": -1.4770746231079102, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 686, \"mu_intercept_per_group\": -3.251000165939331, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 687, \"mu_intercept_per_group\": -3.0764060020446777, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 688, \"mu_intercept_per_group\": 4.954510688781738, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 689, \"mu_intercept_per_group\": -7.439533233642578, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 690, \"mu_intercept_per_group\": -3.2381179332733154, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 691, \"mu_intercept_per_group\": 4.112241268157959, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 692, \"mu_intercept_per_group\": -3.656867742538452, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 693, \"mu_intercept_per_group\": -3.718639850616455, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 694, \"mu_intercept_per_group\": -3.119849681854248, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 695, \"mu_intercept_per_group\": -6.136108875274658, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 696, \"mu_intercept_per_group\": 6.803424835205078, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 697, \"mu_intercept_per_group\": 2.6494526863098145, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 698, \"mu_intercept_per_group\": -4.898685932159424, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 699, \"mu_intercept_per_group\": -0.8052064180374146, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 700, \"mu_intercept_per_group\": -2.207000732421875, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 701, \"mu_intercept_per_group\": -1.5209002494812012, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 702, \"mu_intercept_per_group\": 0.07198591530323029, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 703, \"mu_intercept_per_group\": -0.24727550148963928, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 704, \"mu_intercept_per_group\": 2.0483734607696533, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 705, \"mu_intercept_per_group\": 4.45440149307251, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 706, \"mu_intercept_per_group\": 1.327373743057251, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 707, \"mu_intercept_per_group\": 2.4151041507720947, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 708, \"mu_intercept_per_group\": 2.6753997802734375, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 709, \"mu_intercept_per_group\": 3.4650661945343018, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 710, \"mu_intercept_per_group\": -7.924023151397705, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 711, \"mu_intercept_per_group\": -8.838018417358398, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 712, \"mu_intercept_per_group\": -6.593358516693115, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 713, \"mu_intercept_per_group\": -4.999032020568848, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 714, \"mu_intercept_per_group\": -8.575250625610352, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 715, \"mu_intercept_per_group\": 1.3385387659072876, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 716, \"mu_intercept_per_group\": 5.057435989379883, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 717, \"mu_intercept_per_group\": 6.132074356079102, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 718, \"mu_intercept_per_group\": -2.1378836631774902, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 719, \"mu_intercept_per_group\": 2.968123435974121, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 720, \"mu_intercept_per_group\": 2.489945411682129, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 721, \"mu_intercept_per_group\": -1.19246506690979, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 722, \"mu_intercept_per_group\": 5.371478080749512, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 723, \"mu_intercept_per_group\": 7.717593193054199, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 724, \"mu_intercept_per_group\": 5.880026340484619, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 725, \"mu_intercept_per_group\": 0.7461075782775879, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 726, \"mu_intercept_per_group\": 3.0187602043151855, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 727, \"mu_intercept_per_group\": 1.1118966341018677, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 728, \"mu_intercept_per_group\": -4.522876739501953, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 729, \"mu_intercept_per_group\": -5.820592880249023, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 730, \"mu_intercept_per_group\": 2.9369730949401855, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 731, \"mu_intercept_per_group\": -2.7671542167663574, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 732, \"mu_intercept_per_group\": 2.4776599407196045, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 733, \"mu_intercept_per_group\": -0.41116106510162354, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 734, \"mu_intercept_per_group\": -5.514476299285889, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 735, \"mu_intercept_per_group\": 0.21740640699863434, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 736, \"mu_intercept_per_group\": 1.4765689373016357, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 737, \"mu_intercept_per_group\": -3.7198233604431152, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 738, \"mu_intercept_per_group\": 0.06509125977754593, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 739, \"mu_intercept_per_group\": -0.3114427626132965, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 740, \"mu_intercept_per_group\": -2.6122944355010986, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 741, \"mu_intercept_per_group\": -3.8112339973449707, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 742, \"mu_intercept_per_group\": -3.3337857723236084, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 743, \"mu_intercept_per_group\": -3.996232271194458, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 744, \"mu_intercept_per_group\": -0.4326465427875519, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 745, \"mu_intercept_per_group\": 3.9897890090942383, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 746, \"mu_intercept_per_group\": -2.1457982063293457, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 747, \"mu_intercept_per_group\": -7.493503570556641, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 748, \"mu_intercept_per_group\": -10.118711471557617, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 749, \"mu_intercept_per_group\": -3.442518472671509, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 750, \"mu_intercept_per_group\": 2.3401031494140625, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 751, \"mu_intercept_per_group\": -4.871574878692627, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 752, \"mu_intercept_per_group\": -5.611466884613037, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 753, \"mu_intercept_per_group\": 1.8374919891357422, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 754, \"mu_intercept_per_group\": -2.3963918685913086, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 755, \"mu_intercept_per_group\": 1.4217143058776855, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 756, \"mu_intercept_per_group\": -6.183037281036377, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 757, \"mu_intercept_per_group\": -5.325989723205566, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 758, \"mu_intercept_per_group\": -6.265664577484131, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 759, \"mu_intercept_per_group\": 0.761108934879303, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 760, \"mu_intercept_per_group\": 3.4508779048919678, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 4, \"draws\": 761, \"mu_intercept_per_group\": -2.701709508895874, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 4, \"draws\": 762, \"mu_intercept_per_group\": -1.6342880725860596, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 4, \"draws\": 763, \"mu_intercept_per_group\": 4.958528518676758, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 4, \"draws\": 764, \"mu_intercept_per_group\": -5.844401836395264, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 4, \"draws\": 765, \"mu_intercept_per_group\": -2.0325279235839844, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 4, \"draws\": 766, \"mu_intercept_per_group\": -0.8820351958274841, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 4, \"draws\": 767, \"mu_intercept_per_group\": 2.744398593902588, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 4, \"draws\": 768, \"mu_intercept_per_group\": 2.5402657985687256, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 4, \"draws\": 769, \"mu_intercept_per_group\": -10.283926010131836, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 4, \"draws\": 770, \"mu_intercept_per_group\": 2.2966763973236084, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 4, \"draws\": 771, \"mu_intercept_per_group\": 3.2270944118499756, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 4, \"draws\": 772, \"mu_intercept_per_group\": -3.3732082843780518, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 4, \"draws\": 773, \"mu_intercept_per_group\": -7.311708927154541, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 4, \"draws\": 774, \"mu_intercept_per_group\": 3.539245843887329, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 4, \"draws\": 775, \"mu_intercept_per_group\": -9.922606468200684, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 4, \"draws\": 776, \"mu_intercept_per_group\": 7.086797714233398, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 4, \"draws\": 777, \"mu_intercept_per_group\": -3.262802839279175, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 4, \"draws\": 778, \"mu_intercept_per_group\": -2.977398157119751, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 4, \"draws\": 779, \"mu_intercept_per_group\": 2.593120813369751, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 4, \"draws\": 780, \"mu_intercept_per_group\": 1.6025114059448242, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 4, \"draws\": 781, \"mu_intercept_per_group\": -2.9202725887298584, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 4, \"draws\": 782, \"mu_intercept_per_group\": 5.650279521942139, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 4, \"draws\": 783, \"mu_intercept_per_group\": -3.086699962615967, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 4, \"draws\": 784, \"mu_intercept_per_group\": -2.3448727130889893, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 4, \"draws\": 785, \"mu_intercept_per_group\": 0.3599390685558319, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 4, \"draws\": 786, \"mu_intercept_per_group\": 5.3838791847229, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 4, \"draws\": 787, \"mu_intercept_per_group\": -6.707965850830078, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 4, \"draws\": 788, \"mu_intercept_per_group\": -3.126619338989258, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 4, \"draws\": 789, \"mu_intercept_per_group\": -3.508697748184204, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 4, \"draws\": 790, \"mu_intercept_per_group\": 4.505556106567383, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 4, \"draws\": 791, \"mu_intercept_per_group\": 1.5847944021224976, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 4, \"draws\": 792, \"mu_intercept_per_group\": 6.421355724334717, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 4, \"draws\": 793, \"mu_intercept_per_group\": -0.12431827932596207, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 4, \"draws\": 794, \"mu_intercept_per_group\": 0.5626278519630432, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 4, \"draws\": 795, \"mu_intercept_per_group\": -8.650713920593262, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 4, \"draws\": 796, \"mu_intercept_per_group\": -7.476102828979492, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 4, \"draws\": 797, \"mu_intercept_per_group\": 3.664342164993286, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 4, \"draws\": 798, \"mu_intercept_per_group\": 2.352717399597168, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 4, \"draws\": 799, \"mu_intercept_per_group\": 9.351751327514648, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": 1.634474277496338, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": 13.925888061523438, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": 3.1510980129241943, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": 2.221494436264038, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": 1.3644416332244873, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": 13.769845008850098, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -10.535638809204102, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": 8.842881202697754, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": 3.6782732009887695, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": 2.3331258296966553, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": 5.562041282653809, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": 0.646827757358551, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": -0.8604630827903748, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": 17.35409164428711, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": 12.101655006408691, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": 8.061225891113281, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": 10.08473014831543, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": 8.37710952758789, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": 7.8936333656311035, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": 4.860252380371094, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": 9.347904205322266, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": 4.553030967712402, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": 5.243752956390381, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": 1.2674322128295898, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": 11.175139427185059, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": 7.293428421020508, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": 5.238185882568359, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": 9.983145713806152, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": 0.38168391585350037, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": 5.974339008331299, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": 3.254392147064209, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": 1.7132841348648071, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": 3.7594478130340576, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": 1.135360598564148, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": 5.598453044891357, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": 6.06279182434082, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": 9.89306354522705, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": 8.891873359680176, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": 3.0578813552856445, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": 6.805270195007324, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": 9.590209007263184, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": 5.453338146209717, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": 9.206146240234375, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": 8.635096549987793, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": 8.772558212280273, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": 9.567811965942383, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": 18.176565170288086, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": 5.5393571853637695, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": 5.924402713775635, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": 8.609904289245605, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": 10.203856468200684, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -0.7724159955978394, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": 7.348630428314209, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": 8.575040817260742, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": 6.728734493255615, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": 9.255815505981445, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": -4.45028018951416, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": 14.67098617553711, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": 0.5006356239318848, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": 5.763958930969238, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": 1.4118455648422241, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": 4.289356708526611, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": 3.363105297088623, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": 2.4275574684143066, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": 9.128942489624023, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": 8.658480644226074, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": 14.133135795593262, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": 11.414372444152832, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": 10.774930000305176, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": 6.138101577758789, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": 4.295954704284668, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": 2.8673183917999268, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": 1.6195255517959595, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": 3.687943696975708, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": -0.4714019298553467, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": -3.3802149295806885, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": -0.9854703545570374, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": 12.644054412841797, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": 2.401881694793701, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": 2.883573055267334, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": 8.041131019592285, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": 12.21342945098877, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": 6.661673545837402, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": 10.361194610595703, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": 2.475858211517334, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": 2.7806010246276855, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": 7.51338529586792, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": 9.611550331115723, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": 6.974217891693115, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": 9.723236083984375, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": 12.404352188110352, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": 9.604477882385254, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": 3.286594867706299, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": 14.353299140930176, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": 3.1947474479675293, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": 2.059624433517456, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": 7.405490398406982, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": 10.838117599487305, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": 12.844878196716309, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": 5.6619086265563965, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -1.441029667854309, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": 0.9350659847259521, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": 4.2158379554748535, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": 3.724088668823242, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": 4.929691791534424, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": 7.131733417510986, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": 4.717758655548096, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": 6.138753414154053, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -1.0083812475204468, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -2.276543617248535, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": 2.185931921005249, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": 3.149054527282715, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": 2.7953546047210693, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": 7.435393333435059, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": 10.020471572875977, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": 11.890755653381348, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": 3.0206007957458496, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": 4.95441198348999, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": 3.0645432472229004, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": 5.558944225311279, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": 3.2406764030456543, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": 3.6982221603393555, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": 2.2927443981170654, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": 5.778764724731445, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": 5.541459560394287, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": -4.551441192626953, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": 9.87207317352295, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": 8.29263973236084, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": 1.8778773546218872, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": 12.897817611694336, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -7.794404983520508, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": 3.8155934810638428, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": 2.893556594848633, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": 4.988616943359375, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": 5.1261162757873535, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": 5.724350929260254, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": 6.369906425476074, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": 8.64571762084961, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": 0.686617374420166, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": 1.0886412858963013, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": 2.6429336071014404, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": 3.530019760131836, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": 7.574317932128906, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": 12.308503150939941, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": 4.583065032958984, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -0.8992596864700317, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": 10.226473808288574, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": 3.937229633331299, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": 9.493059158325195, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": 4.361320972442627, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": 8.142166137695312, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": 7.007230281829834, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": 7.366735935211182, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": 3.644712209701538, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": 5.4631195068359375, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": 2.083528518676758, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": 9.265545845031738, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": 4.214420795440674, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": 2.5876946449279785, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": 5.209510326385498, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": 6.8039469718933105, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": 7.649331092834473, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": 7.871331214904785, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": 7.882833480834961, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": 5.415031909942627, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": 6.383907794952393, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": 5.503782749176025, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": 11.414846420288086, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": 8.855015754699707, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": 2.7392656803131104, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": 8.400607109069824, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": 1.4368807077407837, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": 5.197805404663086, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": 13.260156631469727, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": 11.365567207336426, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": 5.606464385986328, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": 7.409223556518555, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": 4.030484676361084, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": 4.704768180847168, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": 4.406350135803223, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": 4.94856595993042, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": 3.3971147537231445, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": 10.591933250427246, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": 2.0168466567993164, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": 3.3118479251861572, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": 4.503365993499756, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": 6.159046649932861, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -8.467123985290527, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -0.4188801646232605, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": 11.136357307434082, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": 11.027213096618652, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": 3.1824584007263184, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -0.8157194256782532, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": 3.715172529220581, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": 1.3905638456344604, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": 8.653057098388672, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -0.2781047523021698, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": 3.9394426345825195, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": 6.602126121520996, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": 1.617281436920166, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": 6.159225940704346, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -1.063056468963623, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": 11.229581832885742, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": 0.4347456693649292, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": 14.332399368286133, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": 12.941520690917969, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": 7.06187105178833, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": 10.411670684814453, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": 13.251134872436523, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -2.805534839630127, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -2.8567087650299072, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": 9.003446578979492, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": 10.069665908813477, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": -3.5030429363250732, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -4.574103832244873, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": 12.77282428741455, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": 0.5821890830993652, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": 10.13636589050293, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": 15.634533882141113, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": 14.307356834411621, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": 13.050299644470215, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": 10.936331748962402, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": 14.31862735748291, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -2.7477493286132812, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": 0.8799887299537659, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -5.836917400360107, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": 6.135786533355713, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": 0.7209346890449524, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": 6.785480976104736, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": 7.544053077697754, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": 6.025774955749512, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": 9.476909637451172, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": 7.125578880310059, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": 7.775266647338867, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": 8.060093879699707, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": 3.8884084224700928, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": 6.605437278747559, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": 3.9285037517547607, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -1.0427340269088745, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": -0.8845116496086121, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": 7.993351459503174, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": 5.394974708557129, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": 6.193804740905762, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": 14.563714981079102, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": 4.145098686218262, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": 5.696519374847412, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": 13.69846248626709, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": 8.266799926757812, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": 7.477123737335205, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": 7.773879051208496, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": 11.134693145751953, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": 10.672698974609375, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": 1.4590885639190674, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": 1.9748129844665527, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": 3.794595241546631, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": 4.321363925933838, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": 6.515926361083984, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": 5.879268169403076, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": 7.091572284698486, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": 4.767719745635986, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": 4.32714319229126, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": 12.999946594238281, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": 13.82186222076416, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": 1.3941739797592163, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": 9.399704933166504, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": 3.417346954345703, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": 8.846954345703125, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": 5.685121059417725, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": 11.23091983795166, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": 6.584738254547119, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": 6.317869663238525, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": 8.611207008361816, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": 4.6487579345703125, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": 0.6673039793968201, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": 13.068089485168457, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": 15.909872055053711, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": 15.654929161071777, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": 8.445968627929688, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": 9.342896461486816, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": 7.8296356201171875, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": 8.979610443115234, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -1.8357248306274414, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": 2.2299065589904785, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": 4.8366923332214355, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": 7.067137718200684, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": 2.4412100315093994, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": 11.905223846435547, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": 1.2127867937088013, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": 0.42304447293281555, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": 0.1219509169459343, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": 1.1365574598312378, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": 15.779474258422852, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": 2.5391347408294678, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": 6.2010602951049805, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": 8.113673210144043, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": 4.229287147521973, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": 6.840615272521973, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": 12.576021194458008, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": 8.119244575500488, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": 9.286009788513184, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": 5.330697536468506, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": 4.486087322235107, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": 3.2381231784820557, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": 9.12254810333252, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": 8.351534843444824, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": 8.16630744934082, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": 9.32899284362793, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": 8.017127990722656, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": 15.523301124572754, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": 8.252188682556152, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": 3.994288921356201, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": 7.525878429412842, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": 2.946800947189331, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": 11.827069282531738, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": 2.01011061668396, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": 6.0098772048950195, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -3.4594814777374268, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": 4.688579559326172, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": 4.989616870880127, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": 4.117571830749512, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": 1.2365885972976685, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": 5.83210563659668, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": 5.386066913604736, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": 10.940932273864746, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": 8.64845085144043, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": 7.812448024749756, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": 7.194311618804932, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": 6.975757122039795, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": 8.775190353393555, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": 9.042176246643066, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": 15.027446746826172, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": 10.041925430297852, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": 7.086521625518799, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": 8.807974815368652, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": 4.209700107574463, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": 11.313882827758789, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": 13.38559341430664, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": 10.753484725952148, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": 13.069090843200684, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": 13.970084190368652, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": 4.465069770812988, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": 5.39229154586792, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": 6.231322765350342, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": 8.88807487487793, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": 7.8946661949157715, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": 6.011037826538086, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": 3.7683486938476562, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": 0.7300308346748352, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": 10.961939811706543, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -1.3441219329833984, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": 13.402824401855469, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -4.798981189727783, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": -2.088033676147461, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": 7.1894941329956055, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": 16.571426391601562, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": 15.29310417175293, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": 7.987903594970703, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": 4.396744728088379, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": 5.839150905609131, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": 8.786612510681152, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": 4.945742607116699, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": 7.642274379730225, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": 3.01603102684021, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": 13.588411331176758, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": 12.829752922058105, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": 9.547317504882812, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": 14.07420825958252, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": 7.307575702667236, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": 1.7579355239868164, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": 8.694326400756836, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": 2.9864842891693115, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": 5.164271354675293, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -1.7195805311203003, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -0.3212182819843292, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -0.36502906680107117, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -0.4341065585613251, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": 6.372917175292969, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": 3.3939950466156006, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": 1.422522783279419, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": 2.563795566558838, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": 9.843664169311523, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": 3.1782095432281494, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": 6.407107830047607, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": 13.033628463745117, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": 9.20993709564209, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": 8.792572975158691, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": 0.03572648763656616, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": 6.473776340484619, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": 8.099320411682129, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": 11.456045150756836, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": 3.810744285583496, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": 9.561695098876953, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": 9.128070831298828, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": 2.2054407596588135, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": -0.1779411882162094, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": 10.86819076538086, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": 5.723626136779785, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": 6.07999324798584, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": 3.520418405532837, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": 4.672008514404297, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": 9.326862335205078, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": 3.432668685913086, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": 5.922469615936279, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": 3.989567756652832, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": 2.8448657989501953, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": 8.579401969909668, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": 0.05246613547205925, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": 1.6759846210479736, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": 6.93393611907959, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": 7.421487808227539, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": 7.322384834289551, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": 4.789836406707764, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": 10.019949913024902, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": 1.7272852659225464, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": 3.5574989318847656, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": 7.475121974945068, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": 9.972122192382812, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": 7.991931915283203, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": 11.097305297851562, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": 16.70815658569336, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": 23.32840919494629, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": -1.641224980354309, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": 9.592811584472656, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": 3.692371368408203, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": -2.777116060256958, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": 5.182114601135254, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": 11.836520195007324, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": 2.321359157562256, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": 1.973084568977356, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": 9.429659843444824, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": 10.087747573852539, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": 9.78671646118164, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": 10.163559913635254, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": 10.853330612182617, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": 12.349699974060059, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": 4.711126804351807, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": 16.701416015625, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": 18.178321838378906, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": 15.863698959350586, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": 3.7454349994659424, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": 9.345475196838379, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": 1.7031193971633911, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": 8.882597923278809, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": 8.608400344848633, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": -1.1048943996429443, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": 11.42440414428711, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": 4.251701831817627, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": 13.818857192993164, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": 13.762919425964355, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": 16.290754318237305, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": 14.196593284606934, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": 0.4292086362838745, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": 1.4366631507873535, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": 0.46991753578186035, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": 5.75222110748291, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": 0.11033353954553604, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": 5.564150810241699, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": 7.228291988372803, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": 11.417553901672363, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": 4.5783867835998535, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": 9.620942115783691, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": 9.801085472106934, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": 10.795658111572266, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": 9.507046699523926, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": 3.8205807209014893, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": 1.7416491508483887, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": 3.1837916374206543, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -0.10439463704824448, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": 8.666844367980957, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -0.5342762470245361, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": 7.961543560028076, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": 6.250349521636963, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": 0.9619166254997253, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": 3.6192500591278076, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": 6.953890800476074, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -0.5847403407096863, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": 1.7651208639144897, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": 8.496652603149414, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": 6.377720832824707, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": 7.459449291229248, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": 5.409350395202637, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": 8.40640640258789, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": 4.07305383682251, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": 1.2633986473083496, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": 3.2805068492889404, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": 8.643370628356934, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": 3.634030342102051, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": 11.940666198730469, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": 3.4526071548461914, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": 18.531461715698242, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": 17.989118576049805, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": 14.519580841064453, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": 0.9776421785354614, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": 3.595067024230957, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": 4.000326633453369, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": 15.972799301147461, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": 2.3766984939575195, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": 20.49650764465332, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": 11.17349910736084, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": 11.666519165039062, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": 11.821191787719727, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": 0.280595600605011, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": 9.889345169067383, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -3.5008702278137207, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": 1.3817555904388428, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": 2.454698324203491, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": 1.6179113388061523, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": 6.918056488037109, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": 3.5094106197357178, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": 8.101579666137695, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": 3.4835526943206787, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": 8.581252098083496, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": 8.804702758789062, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": 1.9982481002807617, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": 8.99524211883545, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": 9.802752494812012, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": 5.153555393218994, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": 9.075996398925781, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": 3.613990068435669, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -0.4057876467704773, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": 6.1030097007751465, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -3.4974160194396973, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": 7.612787246704102, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": 9.858863830566406, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -4.522730827331543, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": 4.897217273712158, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": 5.641005992889404, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": 7.397843360900879, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": 5.194984436035156, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -2.6365065574645996, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": 7.600186824798584, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": 0.2195647656917572, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": 13.682950019836426, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": 13.912482261657715, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": 9.976264953613281, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": 4.240718841552734, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": 4.5809221267700195, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -1.0171968936920166, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": 0.5711917877197266, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": 5.666450500488281, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": 1.530834436416626, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": 11.235673904418945, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -0.1598006933927536, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": 1.9669408798217773, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": 3.890070915222168, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": 6.574796199798584, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": 4.151799201965332, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": 6.4445929527282715, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": 6.070124626159668, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": 6.699561595916748, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": 12.819746017456055, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -2.28364634513855, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": -3.968463897705078, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": 14.674654006958008, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": 1.292959213256836, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": 16.62885284423828, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": 7.689611911773682, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": 5.346103191375732, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": 1.7860125303268433, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": 2.8704001903533936, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": 3.1535017490386963, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": 8.760475158691406, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": -0.7896355986595154, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": 8.265732765197754, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": -0.6783075332641602, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": 2.704967498779297, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": 10.396794319152832, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": 8.185901641845703, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": 5.942236423492432, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": 5.854864120483398, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": 4.776225566864014, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": 6.667513370513916, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": 5.03252649307251, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": 10.016518592834473, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": 6.221654891967773, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": 0.6828308701515198, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": 2.4645612239837646, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -1.2125942707061768, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": 11.667766571044922, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -0.16511529684066772, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": 9.0909423828125, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": 3.8820924758911133, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": 5.049106121063232, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": 6.876501560211182, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": 7.984882354736328, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": 6.291885852813721, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": 2.0015110969543457, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": 6.6930389404296875, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": 6.593250751495361, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": 2.8912858963012695, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": 15.601383209228516, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": 10.945367813110352, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": 5.665318489074707, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": 8.460394859313965, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": 6.359673976898193, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": 0.6863711476325989, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": 1.4234929084777832, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": 3.4403774738311768, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": -1.9555072784423828, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": -3.6144492626190186, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": 1.2940253019332886, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": 4.330514430999756, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": 8.361306190490723, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": 6.846901893615723, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": 6.487677574157715, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": 13.119624137878418, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": 3.655015707015991, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": 12.503008842468262, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": 10.805795669555664, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": 8.901558876037598, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": 6.447510719299316, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": 10.550586700439453, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": 10.920633316040039, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": 8.116629600524902, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": 11.919018745422363, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": 3.275623321533203, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": 12.085850715637207, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": 3.065721273422241, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": 3.562181234359741, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": 5.285308837890625, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": 6.877431869506836, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": 8.974735260009766, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": 7.159250736236572, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": 8.141030311584473, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": 14.69585132598877, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": 5.9492082595825195, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -5.8245673179626465, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": 1.445192575454712, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": 8.581317901611328, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": 7.054030418395996, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": 6.102959156036377, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": 5.508932113647461, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": 4.139200687408447, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -0.03420865535736084, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -0.2895030081272125, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": 0.10573956370353699, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": 11.017565727233887, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": 2.3388195037841797, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": 1.5822569131851196, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": 2.969419240951538, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 640, \"mu_intercept_per_group\": -1.5094282627105713, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 641, \"mu_intercept_per_group\": 8.177345275878906, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 642, \"mu_intercept_per_group\": 1.050898551940918, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 643, \"mu_intercept_per_group\": 18.75742530822754, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 644, \"mu_intercept_per_group\": 9.766128540039062, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 645, \"mu_intercept_per_group\": 5.842657089233398, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 646, \"mu_intercept_per_group\": 5.3928728103637695, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 647, \"mu_intercept_per_group\": 4.931173324584961, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 648, \"mu_intercept_per_group\": 6.458768367767334, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 649, \"mu_intercept_per_group\": 10.876992225646973, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 650, \"mu_intercept_per_group\": 15.108519554138184, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 651, \"mu_intercept_per_group\": 8.061923027038574, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 652, \"mu_intercept_per_group\": -1.781018853187561, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 653, \"mu_intercept_per_group\": 0.835690975189209, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 654, \"mu_intercept_per_group\": 2.842926502227783, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 655, \"mu_intercept_per_group\": 7.33502721786499, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 656, \"mu_intercept_per_group\": 8.42028522491455, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 657, \"mu_intercept_per_group\": -1.8699735403060913, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 658, \"mu_intercept_per_group\": -1.8400944471359253, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 659, \"mu_intercept_per_group\": 1.0116393566131592, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 660, \"mu_intercept_per_group\": 4.551050186157227, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 661, \"mu_intercept_per_group\": 5.662790298461914, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 662, \"mu_intercept_per_group\": 5.2636260986328125, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 663, \"mu_intercept_per_group\": 6.444042682647705, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 664, \"mu_intercept_per_group\": 1.0440679788589478, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 665, \"mu_intercept_per_group\": 2.0581977367401123, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 666, \"mu_intercept_per_group\": 3.7733449935913086, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 667, \"mu_intercept_per_group\": 6.830931186676025, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 668, \"mu_intercept_per_group\": 3.791288375854492, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 669, \"mu_intercept_per_group\": 2.5136423110961914, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 670, \"mu_intercept_per_group\": 3.0558254718780518, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 671, \"mu_intercept_per_group\": 3.052903175354004, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 672, \"mu_intercept_per_group\": 0.9768362045288086, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 673, \"mu_intercept_per_group\": 2.505213737487793, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 674, \"mu_intercept_per_group\": 17.531465530395508, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 675, \"mu_intercept_per_group\": 8.423206329345703, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 676, \"mu_intercept_per_group\": 16.4642333984375, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 677, \"mu_intercept_per_group\": -3.8676891326904297, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 678, \"mu_intercept_per_group\": 2.39039945602417, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 679, \"mu_intercept_per_group\": 12.108649253845215, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 680, \"mu_intercept_per_group\": 7.166161060333252, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 681, \"mu_intercept_per_group\": 8.233209609985352, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 682, \"mu_intercept_per_group\": 6.274340629577637, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 683, \"mu_intercept_per_group\": -0.23456694185733795, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 684, \"mu_intercept_per_group\": 8.994513511657715, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 685, \"mu_intercept_per_group\": 1.1254209280014038, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 686, \"mu_intercept_per_group\": 12.446879386901855, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 687, \"mu_intercept_per_group\": 11.478215217590332, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 688, \"mu_intercept_per_group\": 7.656261920928955, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 689, \"mu_intercept_per_group\": 9.929548263549805, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 690, \"mu_intercept_per_group\": 7.251047134399414, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 691, \"mu_intercept_per_group\": 8.93316650390625, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 692, \"mu_intercept_per_group\": 11.617250442504883, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 693, \"mu_intercept_per_group\": 14.559282302856445, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 694, \"mu_intercept_per_group\": 1.4383447170257568, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 695, \"mu_intercept_per_group\": 1.6239233016967773, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 696, \"mu_intercept_per_group\": 14.07672119140625, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 697, \"mu_intercept_per_group\": 9.05691146850586, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 698, \"mu_intercept_per_group\": -2.9209513664245605, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 699, \"mu_intercept_per_group\": 7.659730911254883, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 700, \"mu_intercept_per_group\": 3.7176706790924072, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 701, \"mu_intercept_per_group\": 0.4560626149177551, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 702, \"mu_intercept_per_group\": 7.745996475219727, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 703, \"mu_intercept_per_group\": 3.651557445526123, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 704, \"mu_intercept_per_group\": 7.4930806159973145, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 705, \"mu_intercept_per_group\": 5.559814453125, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 706, \"mu_intercept_per_group\": 3.3852596282958984, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 707, \"mu_intercept_per_group\": 7.025306701660156, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 708, \"mu_intercept_per_group\": 8.39955997467041, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 709, \"mu_intercept_per_group\": 10.878217697143555, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 710, \"mu_intercept_per_group\": 3.9867701530456543, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 711, \"mu_intercept_per_group\": 7.881164073944092, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 712, \"mu_intercept_per_group\": 15.007315635681152, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 713, \"mu_intercept_per_group\": 9.699197769165039, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 714, \"mu_intercept_per_group\": 1.479518175125122, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 715, \"mu_intercept_per_group\": 8.280665397644043, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 716, \"mu_intercept_per_group\": 4.4109063148498535, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 717, \"mu_intercept_per_group\": 13.374195098876953, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 718, \"mu_intercept_per_group\": 4.3714070320129395, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 719, \"mu_intercept_per_group\": 14.028382301330566, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 720, \"mu_intercept_per_group\": 2.5582237243652344, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 721, \"mu_intercept_per_group\": 4.320334434509277, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 722, \"mu_intercept_per_group\": 5.936493873596191, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 723, \"mu_intercept_per_group\": 2.578845500946045, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 724, \"mu_intercept_per_group\": 5.718008518218994, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 725, \"mu_intercept_per_group\": 6.44868278503418, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 726, \"mu_intercept_per_group\": 5.088037014007568, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 727, \"mu_intercept_per_group\": 2.3595149517059326, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 728, \"mu_intercept_per_group\": 7.5179667472839355, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 729, \"mu_intercept_per_group\": 10.54384994506836, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 730, \"mu_intercept_per_group\": 2.3298168182373047, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 731, \"mu_intercept_per_group\": 8.229143142700195, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 732, \"mu_intercept_per_group\": 6.801103591918945, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 733, \"mu_intercept_per_group\": 4.8266801834106445, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 734, \"mu_intercept_per_group\": 2.3345701694488525, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 735, \"mu_intercept_per_group\": -0.8561691045761108, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 736, \"mu_intercept_per_group\": 1.6330338716506958, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 737, \"mu_intercept_per_group\": 7.532321929931641, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 738, \"mu_intercept_per_group\": 8.486692428588867, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 739, \"mu_intercept_per_group\": 5.112396240234375, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 740, \"mu_intercept_per_group\": 1.549146294593811, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 741, \"mu_intercept_per_group\": 2.3812522888183594, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 742, \"mu_intercept_per_group\": 0.6191903948783875, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 743, \"mu_intercept_per_group\": 4.1182475090026855, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 744, \"mu_intercept_per_group\": 0.32250455021858215, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 745, \"mu_intercept_per_group\": 4.478792190551758, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 746, \"mu_intercept_per_group\": 11.1222562789917, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 747, \"mu_intercept_per_group\": 6.203759670257568, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 748, \"mu_intercept_per_group\": 5.5947346687316895, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 749, \"mu_intercept_per_group\": -1.1939496994018555, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 750, \"mu_intercept_per_group\": 5.662972450256348, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 751, \"mu_intercept_per_group\": -6.342003345489502, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 752, \"mu_intercept_per_group\": 0.010304202325642109, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 753, \"mu_intercept_per_group\": 11.63723087310791, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 754, \"mu_intercept_per_group\": -1.3334205150604248, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 755, \"mu_intercept_per_group\": 8.060990333557129, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 756, \"mu_intercept_per_group\": 8.786029815673828, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 757, \"mu_intercept_per_group\": 8.471430778503418, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 758, \"mu_intercept_per_group\": 7.038599967956543, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 759, \"mu_intercept_per_group\": 4.17526388168335, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 760, \"mu_intercept_per_group\": 10.924713134765625, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 5, \"draws\": 761, \"mu_intercept_per_group\": 0.9558836221694946, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 5, \"draws\": 762, \"mu_intercept_per_group\": 6.486873626708984, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 5, \"draws\": 763, \"mu_intercept_per_group\": 4.37770414352417, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 5, \"draws\": 764, \"mu_intercept_per_group\": 12.972688674926758, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 5, \"draws\": 765, \"mu_intercept_per_group\": 4.541837692260742, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 5, \"draws\": 766, \"mu_intercept_per_group\": 9.329474449157715, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 5, \"draws\": 767, \"mu_intercept_per_group\": -1.6249123811721802, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 5, \"draws\": 768, \"mu_intercept_per_group\": -2.042917251586914, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 5, \"draws\": 769, \"mu_intercept_per_group\": 5.931884765625, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 5, \"draws\": 770, \"mu_intercept_per_group\": 10.919336318969727, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 5, \"draws\": 771, \"mu_intercept_per_group\": 9.839774131774902, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 5, \"draws\": 772, \"mu_intercept_per_group\": 0.7854636311531067, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 5, \"draws\": 773, \"mu_intercept_per_group\": 6.228759765625, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 5, \"draws\": 774, \"mu_intercept_per_group\": -3.565430164337158, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 5, \"draws\": 775, \"mu_intercept_per_group\": -4.155152797698975, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 5, \"draws\": 776, \"mu_intercept_per_group\": 17.156248092651367, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 5, \"draws\": 777, \"mu_intercept_per_group\": -3.9011049270629883, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 5, \"draws\": 778, \"mu_intercept_per_group\": -4.368285655975342, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 5, \"draws\": 779, \"mu_intercept_per_group\": 17.074058532714844, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 5, \"draws\": 780, \"mu_intercept_per_group\": 5.772833347320557, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 5, \"draws\": 781, \"mu_intercept_per_group\": 14.060651779174805, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 5, \"draws\": 782, \"mu_intercept_per_group\": 9.078628540039062, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 5, \"draws\": 783, \"mu_intercept_per_group\": 2.0968360900878906, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 5, \"draws\": 784, \"mu_intercept_per_group\": 0.17527295649051666, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 5, \"draws\": 785, \"mu_intercept_per_group\": 7.432702541351318, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 5, \"draws\": 786, \"mu_intercept_per_group\": 6.646369457244873, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 5, \"draws\": 787, \"mu_intercept_per_group\": 8.407577514648438, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 5, \"draws\": 788, \"mu_intercept_per_group\": -1.9863336086273193, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 5, \"draws\": 789, \"mu_intercept_per_group\": 9.283456802368164, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 5, \"draws\": 790, \"mu_intercept_per_group\": 6.373445510864258, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 5, \"draws\": 791, \"mu_intercept_per_group\": 10.431255340576172, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 5, \"draws\": 792, \"mu_intercept_per_group\": 6.448676109313965, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 5, \"draws\": 793, \"mu_intercept_per_group\": 6.747687816619873, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 5, \"draws\": 794, \"mu_intercept_per_group\": 6.8610310554504395, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 5, \"draws\": 795, \"mu_intercept_per_group\": 5.823283672332764, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 5, \"draws\": 796, \"mu_intercept_per_group\": -0.45489367842674255, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 5, \"draws\": 797, \"mu_intercept_per_group\": 4.525137901306152, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 5, \"draws\": 798, \"mu_intercept_per_group\": 13.869852066040039, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 5, \"draws\": 799, \"mu_intercept_per_group\": 12.195902824401855, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 11.632745742797852, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 11.233719825744629, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 2.0298407077789307, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 4.288939476013184, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 7.263896465301514, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 8.901853561401367, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": 2.629436731338501, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": 5.404616832733154, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 18.260936737060547, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": 5.089048862457275, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 9.717674255371094, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 11.013862609863281, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 13.397039413452148, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 8.984611511230469, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 5.688485145568848, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 6.814304828643799, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 21.13117790222168, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 15.063817977905273, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 14.488133430480957, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 3.2715091705322266, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 7.3308000564575195, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 9.43440055847168, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 3.368485927581787, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 3.0314533710479736, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": 9.063840866088867, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": 12.36256217956543, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 12.412677764892578, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 6.713487148284912, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 13.269893646240234, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 10.374320030212402, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 4.350480079650879, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 6.234470367431641, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 2.5428378582000732, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": 6.414090156555176, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 4.949948787689209, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 6.855050086975098, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 5.578754901885986, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 7.400443077087402, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 6.6804518699646, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 7.838018894195557, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 9.732063293457031, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 7.336765289306641, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 11.361775398254395, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 10.85330581665039, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 15.983418464660645, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 15.514290809631348, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 16.43450927734375, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 11.736083030700684, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 12.022178649902344, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 8.709063529968262, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 13.748573303222656, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 11.409258842468262, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 12.423006057739258, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 6.887997150421143, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 12.44063949584961, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 6.112762928009033, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 8.397367477416992, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 7.137951374053955, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 13.149940490722656, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 10.68057918548584, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 8.199775695800781, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 2.8044209480285645, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 3.9381039142608643, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 3.793003559112549, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 10.77622127532959, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 10.753153800964355, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 16.19710350036621, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 13.50414752960205, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 12.81934928894043, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 8.534982681274414, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 3.829674243927002, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 10.325078010559082, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 6.881538391113281, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 12.380773544311523, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 5.244972229003906, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 3.837373733520508, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 5.732385635375977, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 9.912847518920898, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 11.809426307678223, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 9.492090225219727, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 9.914491653442383, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 10.75780200958252, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 12.943674087524414, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 7.127316474914551, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 10.805445671081543, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 12.561098098754883, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 10.663049697875977, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 17.986679077148438, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 6.509702682495117, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 7.849224090576172, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 9.591752052307129, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 12.298008918762207, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 5.7815842628479, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 21.48198127746582, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 3.491090774536133, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 5.407175540924072, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 11.967803001403809, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 16.08183479309082, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 13.351243019104004, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 5.744067192077637, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 5.116906642913818, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 6.2866902351379395, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 2.383315324783325, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 4.2499775886535645, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 6.52124547958374, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": 7.9299635887146, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 8.182048797607422, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 7.354870319366455, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 2.89664363861084, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 2.941397190093994, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 4.778463840484619, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 4.330532550811768, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 8.603582382202148, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 5.294832706451416, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 9.5949068069458, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 9.09776782989502, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 9.445087432861328, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 4.20853853225708, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 5.9694085121154785, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 7.965192794799805, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 3.825082778930664, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 5.363434314727783, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 0.521563708782196, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 2.7544033527374268, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 5.441155910491943, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 3.1982195377349854, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 12.781709671020508, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 9.601791381835938, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 9.460763931274414, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 9.990228652954102, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 6.91964054107666, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": 1.081321358680725, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 12.057878494262695, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 7.649816513061523, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 7.247623920440674, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 15.097403526306152, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 6.897840976715088, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 5.0874857902526855, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 9.721067428588867, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": -3.0846853256225586, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": -0.30999046564102173, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 10.408760070800781, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 3.522575855255127, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 23.30436897277832, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 0.4689110815525055, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 11.509512901306152, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 6.252431392669678, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 8.064962387084961, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 10.25263786315918, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 0.5782917141914368, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 8.87739086151123, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 11.097055435180664, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": 5.724454402923584, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 5.325359344482422, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 9.326142311096191, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 10.858620643615723, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 6.551386833190918, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 6.28602933883667, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 4.984641075134277, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 5.809360980987549, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 7.815969944000244, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 5.89484977722168, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 8.477323532104492, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 8.804805755615234, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 9.822209358215332, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 6.935606956481934, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 4.801261901855469, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 6.696927070617676, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 6.194823741912842, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 13.083582878112793, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 2.789649486541748, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 10.838428497314453, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 6.146374702453613, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 17.124292373657227, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 16.602388381958008, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 8.981451034545898, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 7.0526018142700195, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 8.222333908081055, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 7.4381489753723145, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 6.346896648406982, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 7.0073089599609375, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 4.899389743804932, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 5.6826558113098145, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 17.777389526367188, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 15.245851516723633, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": -6.4431915283203125, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 10.168999671936035, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 8.044508934020996, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 13.700465202331543, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 2.666799306869507, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 5.8984503746032715, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 12.274262428283691, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 8.286943435668945, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 8.084125518798828, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": 12.093859672546387, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 10.852919578552246, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 8.248346328735352, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 12.445040702819824, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 11.636499404907227, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 3.6839964389801025, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 2.16796612739563, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 11.512070655822754, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": -1.3572708368301392, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 5.420344352722168, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 15.010819435119629, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 14.09598445892334, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 11.209918975830078, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 9.784302711486816, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 11.477121353149414, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 1.7471004724502563, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": -0.18725082278251648, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 11.056774139404297, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 10.726802825927734, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 5.54459810256958, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 6.624732494354248, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.805349826812744, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 14.515657424926758, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 15.72484016418457, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 18.805015563964844, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 18.990333557128906, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 9.496718406677246, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 4.481977939605713, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 9.363445281982422, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 9.217960357666016, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 7.33865213394165, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": -2.986319065093994, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 5.60554838180542, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 2.9867212772369385, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": -5.671130657196045, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 15.093070030212402, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 9.038530349731445, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 7.147833347320557, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 14.23138427734375, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 11.344911575317383, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.716726303100586, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 9.601812362670898, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 5.819151401519775, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.134848117828369, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 7.0128865242004395, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 5.994415760040283, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 4.6371989250183105, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 6.636090278625488, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 10.06019401550293, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 8.629623413085938, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 11.293466567993164, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 6.080497741699219, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 6.099874019622803, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 8.136085510253906, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 10.921831130981445, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 8.93692684173584, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 9.62862777709961, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 9.255105018615723, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 7.8904619216918945, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 9.359333038330078, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 10.477946281433105, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 7.185666561126709, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 7.726504325866699, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 13.199358940124512, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 9.340940475463867, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 4.039975166320801, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 7.646060466766357, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 11.954675674438477, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 13.08076000213623, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 8.610590934753418, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 6.031670093536377, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 15.340444564819336, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 10.06506633758545, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 7.145841598510742, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 13.21003532409668, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 9.884525299072266, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 9.492754936218262, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 8.544301986694336, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 9.893087387084961, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 11.467147827148438, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 7.797275543212891, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 15.313166618347168, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 13.203810691833496, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 14.525946617126465, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 15.938401222229004, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": -0.4405444860458374, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 4.358277320861816, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 8.21118450164795, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 8.973179817199707, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 3.900768995285034, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 12.674832344055176, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 13.047477722167969, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 3.3607239723205566, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 9.937864303588867, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 5.020315170288086, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 1.6319575309753418, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 2.192533493041992, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 16.066761016845703, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 7.997844219207764, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 7.022235870361328, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 9.526439666748047, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 9.768314361572266, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 14.53671646118164, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 16.151275634765625, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 13.647994041442871, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 8.281039237976074, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 6.245481967926025, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 7.84507942199707, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 5.089851379394531, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 12.393095016479492, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 3.8935933113098145, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 4.795771598815918, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 13.257675170898438, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 10.09825325012207, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 13.88893985748291, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 9.908571243286133, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 13.57817554473877, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 3.9210941791534424, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 13.535806655883789, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 5.1702094078063965, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 9.642653465270996, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 1.6558700799942017, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 4.32435941696167, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 4.398257255554199, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 5.608448505401611, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 10.881958961486816, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 0.045044541358947754, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 3.6823554039001465, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 9.244244575500488, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 12.194048881530762, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 10.561250686645508, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 10.34228229522705, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 11.823416709899902, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 7.0168561935424805, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 15.86887264251709, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 7.0203471183776855, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 15.631619453430176, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 14.829129219055176, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 5.80195951461792, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 6.6749749183654785, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 7.343850612640381, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 1.0409669876098633, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 1.478240966796875, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 1.7834888696670532, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 14.646512031555176, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 2.343787431716919, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 14.442601203918457, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 11.164793968200684, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 9.858711242675781, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 10.629820823669434, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 9.097635269165039, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 6.606456279754639, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 5.9724931716918945, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 7.516313076019287, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 7.154407501220703, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 14.600335121154785, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 7.251861572265625, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.714876174926758, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 8.23090648651123, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 12.965083122253418, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 16.249483108520508, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 15.41843318939209, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 7.000326633453369, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 9.013513565063477, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 8.828108787536621, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 6.855345726013184, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 10.53890323638916, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 11.516101837158203, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 13.256413459777832, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 8.547624588012695, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 10.283397674560547, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 18.857772827148438, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 14.054068565368652, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 10.261526107788086, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 10.192338943481445, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 4.037274360656738, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 3.3248958587646484, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 3.722395420074463, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": 2.193405866622925, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": 1.8468599319458008, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": -0.02408209629356861, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 3.1560287475585938, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 8.732633590698242, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 7.4960432052612305, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 5.442638397216797, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 4.134529113769531, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 4.945038318634033, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 13.08150577545166, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 10.632112503051758, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 13.76314640045166, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 12.85935115814209, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 4.848867416381836, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": 20.027063369750977, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": 18.45206642150879, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 19.09606170654297, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 14.257925033569336, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 6.2103071212768555, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 10.009672164916992, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 3.5548462867736816, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 5.488247871398926, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 7.150514602661133, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 3.7902677059173584, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": -0.4868389666080475, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": 6.493446350097656, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": 4.896362781524658, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 7.167704105377197, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 8.696736335754395, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 7.03252649307251, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 8.431922912597656, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 7.877817153930664, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 4.416971206665039, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 5.624139785766602, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 5.298995494842529, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 12.894747734069824, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 2.027708053588867, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 16.975675582885742, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 5.48615837097168, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 10.614027976989746, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 11.098052978515625, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 8.894858360290527, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 13.598639488220215, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 14.314702033996582, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 4.143700122833252, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 4.212463855743408, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 6.892746925354004, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 13.37410831451416, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 5.328341007232666, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 15.930116653442383, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 8.88064193725586, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 9.23046588897705, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 10.510037422180176, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 12.21329116821289, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 12.787036895751953, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 10.172673225402832, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 10.01641845703125, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 13.219475746154785, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 14.604729652404785, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 16.265424728393555, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 15.3847017288208, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 17.32099151611328, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 13.552227020263672, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 7.718541145324707, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 16.68973159790039, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 12.474905967712402, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 11.323439598083496, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 9.885552406311035, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 8.668804168701172, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 7.597942352294922, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 6.919079780578613, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 6.341151714324951, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 3.13321590423584, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 8.746448516845703, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 7.489561080932617, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 14.77580738067627, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 15.452874183654785, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 18.9110164642334, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 6.275880813598633, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 9.950307846069336, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 2.369474172592163, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 3.7109057903289795, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 8.555068016052246, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 10.615498542785645, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 14.231673240661621, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 8.110275268554688, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 10.27629280090332, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 8.212841987609863, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 9.452975273132324, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 13.88218879699707, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 13.262735366821289, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 10.122013092041016, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 8.394704818725586, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 9.783109664916992, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.419355869293213, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 4.453634738922119, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.102877140045166, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 10.605664253234863, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 5.793703556060791, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 6.499077320098877, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 0.8086158037185669, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 2.189502000808716, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 11.587628364562988, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 4.6432342529296875, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 14.192630767822266, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 2.1043341159820557, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 6.7521209716796875, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 7.247055530548096, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 8.07819938659668, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 7.5398478507995605, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 6.976463794708252, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 10.113965034484863, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 3.827695369720459, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 7.46720027923584, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 8.907787322998047, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 6.97062873840332, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 11.975459098815918, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 11.042169570922852, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 9.157285690307617, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 10.491230964660645, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 10.176403045654297, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 3.655879497528076, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 3.8081533908843994, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 16.34489631652832, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 13.833528518676758, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 1.1344290971755981, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 5.379266262054443, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 10.840170860290527, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 8.327847480773926, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 9.616548538208008, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 1.369218111038208, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 16.015907287597656, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 16.746307373046875, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 17.030427932739258, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 16.975234985351562, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 18.46536636352539, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 7.182484149932861, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 7.046080112457275, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 8.468693733215332, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 6.19887113571167, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 11.366446495056152, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 3.6902925968170166, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 11.742440223693848, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": 11.109164237976074, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 8.988150596618652, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 9.362146377563477, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 6.782577037811279, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 14.575263023376465, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 0.7414267659187317, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 14.933825492858887, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": -1.6337772607803345, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 1.0996426343917847, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 14.312433242797852, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 13.791284561157227, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 12.294355392456055, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 12.726879119873047, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 8.850038528442383, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 8.825467109680176, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 1.9888765811920166, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 9.167716026306152, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 11.958067893981934, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 16.12838363647461, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 7.074490070343018, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 6.609107971191406, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 6.389261245727539, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 12.829267501831055, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 7.207554817199707, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 5.986640453338623, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 7.933926105499268, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 8.556365013122559, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": 2.924842119216919, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 6.176980018615723, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 2.0831077098846436, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 7.613255500793457, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 3.4133732318878174, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 8.5147066116333, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 7.928164958953857, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 6.992891311645508, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 14.716009140014648, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 2.00567364692688, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": -2.1284396648406982, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 16.214872360229492, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 5.270783424377441, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 18.007091522216797, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 11.28925609588623, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 4.8742146492004395, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 10.730864524841309, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 11.673006057739258, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 9.61384391784668, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 6.338388919830322, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 5.893902778625488, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 3.3802967071533203, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 8.981549263000488, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 8.412846565246582, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 8.648835182189941, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 8.582324028015137, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 7.917031288146973, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 4.494100093841553, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 3.7067413330078125, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 4.285208225250244, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 10.598973274230957, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 11.071138381958008, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 5.9926629066467285, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.907940864562988, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 9.492807388305664, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 7.929479598999023, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 9.586721420288086, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 3.5180017948150635, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 10.573982238769531, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 5.755795478820801, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 9.006656646728516, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 3.439858913421631, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 11.4911527633667, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 8.473052978515625, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 1.589301586151123, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 4.961552619934082, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 6.269898891448975, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 7.083322525024414, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 16.322946548461914, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 14.880120277404785, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 2.4791061878204346, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 4.71028995513916, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 10.990072250366211, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 4.390254497528076, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 4.438529968261719, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 5.673379421234131, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 9.540966033935547, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 8.219474792480469, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 4.459664344787598, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 9.288054466247559, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 8.596911430358887, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 13.389898300170898, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 7.363906383514404, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 16.570518493652344, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 7.904899597167969, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 13.689584732055664, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 17.64194107055664, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 18.58974266052246, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 17.26346206665039, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 4.631406784057617, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 9.813529014587402, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 8.546311378479004, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 11.1205415725708, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 4.626804828643799, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 9.86364459991455, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 10.615093231201172, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 7.243119716644287, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 5.35297966003418, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 8.509718894958496, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 16.630126953125, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 5.114844799041748, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 2.9916648864746094, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": -4.474576473236084, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": -2.455226182937622, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 8.78261661529541, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 9.245545387268066, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 5.670923233032227, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 9.424115180969238, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 7.84380578994751, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 6.820401668548584, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 1.37026047706604, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 11.754881858825684, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 11.218875885009766, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 7.992935657501221, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 9.44516658782959, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 10.707552909851074, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 9.40965747833252, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 5.691207408905029, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 640, \"mu_intercept_per_group\": 6.325944900512695, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 641, \"mu_intercept_per_group\": 7.027575969696045, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 642, \"mu_intercept_per_group\": 10.184142112731934, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 643, \"mu_intercept_per_group\": 6.0886993408203125, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 644, \"mu_intercept_per_group\": 11.344738006591797, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 645, \"mu_intercept_per_group\": 3.5077731609344482, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 646, \"mu_intercept_per_group\": 4.902412414550781, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 647, \"mu_intercept_per_group\": 9.742884635925293, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 648, \"mu_intercept_per_group\": 11.94352912902832, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 649, \"mu_intercept_per_group\": 9.891430854797363, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 650, \"mu_intercept_per_group\": 7.78990364074707, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 651, \"mu_intercept_per_group\": 8.048843383789062, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 652, \"mu_intercept_per_group\": 9.425321578979492, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 653, \"mu_intercept_per_group\": 8.65038013458252, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 654, \"mu_intercept_per_group\": 4.3233771324157715, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 655, \"mu_intercept_per_group\": 10.785401344299316, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 656, \"mu_intercept_per_group\": 5.5934882164001465, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 657, \"mu_intercept_per_group\": 8.195670127868652, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 658, \"mu_intercept_per_group\": 2.369784355163574, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 659, \"mu_intercept_per_group\": 3.893381357192993, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 660, \"mu_intercept_per_group\": 8.177343368530273, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 661, \"mu_intercept_per_group\": 2.8923490047454834, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 662, \"mu_intercept_per_group\": 3.668105125427246, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 663, \"mu_intercept_per_group\": 6.924515724182129, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 664, \"mu_intercept_per_group\": 4.312505722045898, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 665, \"mu_intercept_per_group\": 3.5416274070739746, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 666, \"mu_intercept_per_group\": 4.141598224639893, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 667, \"mu_intercept_per_group\": 6.815834045410156, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 668, \"mu_intercept_per_group\": 5.637174129486084, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 669, \"mu_intercept_per_group\": 4.737532138824463, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 670, \"mu_intercept_per_group\": 4.440867900848389, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 671, \"mu_intercept_per_group\": 2.7720606327056885, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 672, \"mu_intercept_per_group\": 3.335063934326172, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 673, \"mu_intercept_per_group\": 2.109192371368408, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 674, \"mu_intercept_per_group\": 12.134611129760742, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 675, \"mu_intercept_per_group\": 9.859488487243652, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 676, \"mu_intercept_per_group\": 14.035245895385742, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 677, \"mu_intercept_per_group\": 13.067804336547852, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 678, \"mu_intercept_per_group\": 8.993398666381836, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 679, \"mu_intercept_per_group\": 13.516111373901367, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 680, \"mu_intercept_per_group\": 8.852582931518555, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 681, \"mu_intercept_per_group\": 5.367400169372559, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 682, \"mu_intercept_per_group\": 10.214282035827637, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 683, \"mu_intercept_per_group\": 1.3410272598266602, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 684, \"mu_intercept_per_group\": 10.619386672973633, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 685, \"mu_intercept_per_group\": 5.037410259246826, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 686, \"mu_intercept_per_group\": 7.976231098175049, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 687, \"mu_intercept_per_group\": 6.621937274932861, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 688, \"mu_intercept_per_group\": 6.746762275695801, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 689, \"mu_intercept_per_group\": 12.75241756439209, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 690, \"mu_intercept_per_group\": 8.923501014709473, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 691, \"mu_intercept_per_group\": 11.003190994262695, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 692, \"mu_intercept_per_group\": 10.207887649536133, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 693, \"mu_intercept_per_group\": 12.799129486083984, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 694, \"mu_intercept_per_group\": -0.10634159296751022, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 695, \"mu_intercept_per_group\": -1.9155504703521729, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 696, \"mu_intercept_per_group\": 21.579347610473633, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 697, \"mu_intercept_per_group\": 11.398650169372559, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 698, \"mu_intercept_per_group\": 6.093822479248047, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 699, \"mu_intercept_per_group\": 4.525607585906982, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 700, \"mu_intercept_per_group\": 4.436201572418213, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 701, \"mu_intercept_per_group\": 6.746626377105713, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 702, \"mu_intercept_per_group\": 6.319985389709473, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 703, \"mu_intercept_per_group\": 8.469095230102539, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 704, \"mu_intercept_per_group\": 13.899754524230957, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 705, \"mu_intercept_per_group\": 5.96996545791626, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 706, \"mu_intercept_per_group\": 8.649641990661621, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 707, \"mu_intercept_per_group\": 8.848359107971191, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 708, \"mu_intercept_per_group\": 15.762989044189453, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 709, \"mu_intercept_per_group\": 10.507871627807617, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 710, \"mu_intercept_per_group\": 3.822784900665283, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 711, \"mu_intercept_per_group\": 8.071508407592773, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 712, \"mu_intercept_per_group\": 17.469127655029297, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 713, \"mu_intercept_per_group\": 14.287444114685059, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 714, \"mu_intercept_per_group\": 9.839263916015625, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 715, \"mu_intercept_per_group\": 3.962115526199341, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 716, \"mu_intercept_per_group\": 7.3801751136779785, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 717, \"mu_intercept_per_group\": 6.986978054046631, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 718, \"mu_intercept_per_group\": 13.240946769714355, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 719, \"mu_intercept_per_group\": 7.259757041931152, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 720, \"mu_intercept_per_group\": 16.345478057861328, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 721, \"mu_intercept_per_group\": 9.447407722473145, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 722, \"mu_intercept_per_group\": 10.528413772583008, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 723, \"mu_intercept_per_group\": 10.267337799072266, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 724, \"mu_intercept_per_group\": 8.71937370300293, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 725, \"mu_intercept_per_group\": 10.259356498718262, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 726, \"mu_intercept_per_group\": 10.255043983459473, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 727, \"mu_intercept_per_group\": 7.053778648376465, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 728, \"mu_intercept_per_group\": 14.175482749938965, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 729, \"mu_intercept_per_group\": 5.5121002197265625, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 730, \"mu_intercept_per_group\": 10.815629959106445, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 731, \"mu_intercept_per_group\": 2.3382787704467773, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 732, \"mu_intercept_per_group\": 11.698990821838379, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 733, \"mu_intercept_per_group\": 5.557311534881592, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 734, \"mu_intercept_per_group\": 5.231598854064941, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 735, \"mu_intercept_per_group\": 3.4719719886779785, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 736, \"mu_intercept_per_group\": 4.099356174468994, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 737, \"mu_intercept_per_group\": 4.550631046295166, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 738, \"mu_intercept_per_group\": 4.567337512969971, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 739, \"mu_intercept_per_group\": 6.316329002380371, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 740, \"mu_intercept_per_group\": 4.424883842468262, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 741, \"mu_intercept_per_group\": 1.0733065605163574, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 742, \"mu_intercept_per_group\": 5.036936283111572, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 743, \"mu_intercept_per_group\": 9.092126846313477, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 744, \"mu_intercept_per_group\": 7.197318077087402, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 745, \"mu_intercept_per_group\": 12.46539306640625, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 746, \"mu_intercept_per_group\": 9.1148099899292, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 747, \"mu_intercept_per_group\": 14.574297904968262, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 748, \"mu_intercept_per_group\": 10.142965316772461, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 749, \"mu_intercept_per_group\": 16.512699127197266, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 750, \"mu_intercept_per_group\": 18.29705047607422, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 751, \"mu_intercept_per_group\": 7.268312454223633, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 752, \"mu_intercept_per_group\": 5.375317096710205, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 753, \"mu_intercept_per_group\": 5.934952259063721, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 754, \"mu_intercept_per_group\": 5.691122055053711, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 755, \"mu_intercept_per_group\": 10.215898513793945, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 756, \"mu_intercept_per_group\": 6.3493332862854, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 757, \"mu_intercept_per_group\": 6.347121238708496, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 758, \"mu_intercept_per_group\": 4.1622748374938965, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 759, \"mu_intercept_per_group\": 10.608667373657227, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 760, \"mu_intercept_per_group\": 7.410218238830566, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 6, \"draws\": 761, \"mu_intercept_per_group\": 7.1172194480896, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 6, \"draws\": 762, \"mu_intercept_per_group\": 13.844669342041016, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 6, \"draws\": 763, \"mu_intercept_per_group\": 11.981633186340332, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 6, \"draws\": 764, \"mu_intercept_per_group\": 4.440503120422363, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 6, \"draws\": 765, \"mu_intercept_per_group\": 11.173455238342285, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 6, \"draws\": 766, \"mu_intercept_per_group\": 14.612639427185059, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 6, \"draws\": 767, \"mu_intercept_per_group\": 3.149099588394165, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 6, \"draws\": 768, \"mu_intercept_per_group\": 4.445005893707275, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 6, \"draws\": 769, \"mu_intercept_per_group\": 11.085844993591309, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 6, \"draws\": 770, \"mu_intercept_per_group\": 7.202907085418701, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 6, \"draws\": 771, \"mu_intercept_per_group\": 9.665946006774902, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 6, \"draws\": 772, \"mu_intercept_per_group\": 11.513923645019531, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 6, \"draws\": 773, \"mu_intercept_per_group\": 7.3304009437561035, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 6, \"draws\": 774, \"mu_intercept_per_group\": 4.116379261016846, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 6, \"draws\": 775, \"mu_intercept_per_group\": 0.6181155443191528, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 6, \"draws\": 776, \"mu_intercept_per_group\": 17.18846893310547, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 6, \"draws\": 777, \"mu_intercept_per_group\": 4.359117031097412, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 6, \"draws\": 778, \"mu_intercept_per_group\": 4.44754695892334, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 6, \"draws\": 779, \"mu_intercept_per_group\": 21.061439514160156, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 6, \"draws\": 780, \"mu_intercept_per_group\": 13.270885467529297, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 6, \"draws\": 781, \"mu_intercept_per_group\": 14.19839096069336, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 6, \"draws\": 782, \"mu_intercept_per_group\": 14.688960075378418, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 6, \"draws\": 783, \"mu_intercept_per_group\": 2.592994213104248, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 6, \"draws\": 784, \"mu_intercept_per_group\": 6.401758670806885, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 6, \"draws\": 785, \"mu_intercept_per_group\": 10.882037162780762, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 6, \"draws\": 786, \"mu_intercept_per_group\": 4.467837810516357, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 6, \"draws\": 787, \"mu_intercept_per_group\": 16.943151473999023, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 6, \"draws\": 788, \"mu_intercept_per_group\": 8.728583335876465, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 6, \"draws\": 789, \"mu_intercept_per_group\": 7.004610061645508, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 6, \"draws\": 790, \"mu_intercept_per_group\": 13.42569637298584, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 6, \"draws\": 791, \"mu_intercept_per_group\": 6.707775115966797, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 6, \"draws\": 792, \"mu_intercept_per_group\": 10.842927932739258, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 6, \"draws\": 793, \"mu_intercept_per_group\": 18.75851058959961, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 6, \"draws\": 794, \"mu_intercept_per_group\": 4.314553260803223, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 6, \"draws\": 795, \"mu_intercept_per_group\": 8.57773494720459, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 6, \"draws\": 796, \"mu_intercept_per_group\": 6.102320194244385, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 6, \"draws\": 797, \"mu_intercept_per_group\": 6.352719783782959, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 6, \"draws\": 798, \"mu_intercept_per_group\": 16.599002838134766, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 6, \"draws\": 799, \"mu_intercept_per_group\": 12.147380828857422, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 24.181194305419922, \"sigma_intercept_per_group\": 0.019319985061883926, \"sigma_obs\": 0.0038307143840938807, \"slope\": 0.08436275273561478, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 15.255171775817871, \"sigma_intercept_per_group\": 0.029525864869356155, \"sigma_obs\": 0.003782299580052495, \"slope\": -0.11811773478984833, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 21.428943634033203, \"sigma_intercept_per_group\": 0.023254986852407455, \"sigma_obs\": 0.003643993753939867, \"slope\": 0.0007249960908666253, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 16.336637496948242, \"sigma_intercept_per_group\": 0.017252935096621513, \"sigma_obs\": 0.003907695412635803, \"slope\": -0.050033289939165115, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 19.97576332092285, \"sigma_intercept_per_group\": 0.026662087067961693, \"sigma_obs\": 0.0034698667004704475, \"slope\": -0.11519002169370651, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 13.930281639099121, \"sigma_intercept_per_group\": 0.022246239706873894, \"sigma_obs\": 0.00392912095412612, \"slope\": 0.09393657743930817, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 17.642475128173828, \"sigma_intercept_per_group\": 0.014627930708229542, \"sigma_obs\": 0.0033485470339655876, \"slope\": -0.06356866657733917, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 8.481812477111816, \"sigma_intercept_per_group\": 0.02692895382642746, \"sigma_obs\": 0.003607872175052762, \"slope\": 0.08717221766710281, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 28.620817184448242, \"sigma_intercept_per_group\": 0.02024473249912262, \"sigma_obs\": 0.0038729894440621138, \"slope\": -0.11588885635137558, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 8.759393692016602, \"sigma_intercept_per_group\": 0.021612433716654778, \"sigma_obs\": 0.003663288429379463, \"slope\": 0.06277871876955032, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 18.31708335876465, \"sigma_intercept_per_group\": 0.03456532210111618, \"sigma_obs\": 0.003890929976478219, \"slope\": -0.0832454264163971, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 12.175117492675781, \"sigma_intercept_per_group\": 0.02012905851006508, \"sigma_obs\": 0.004077587742358446, \"slope\": 0.0037287455052137375, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 16.03246307373047, \"sigma_intercept_per_group\": 0.030780568718910217, \"sigma_obs\": 0.0036289962008595467, \"slope\": -0.0971786379814148, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 19.201004028320312, \"sigma_intercept_per_group\": 0.02564358338713646, \"sigma_obs\": 0.004080600570887327, \"slope\": -0.044249121099710464, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 15.793123245239258, \"sigma_intercept_per_group\": 0.013487446121871471, \"sigma_obs\": 0.004009490367025137, \"slope\": -0.024430399760603905, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 17.331134796142578, \"sigma_intercept_per_group\": 0.02446347288787365, \"sigma_obs\": 0.004084001295268536, \"slope\": -0.01586911454796791, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 22.5208797454834, \"sigma_intercept_per_group\": 0.018991148099303246, \"sigma_obs\": 0.00395613070577383, \"slope\": -0.1444936990737915, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 20.067840576171875, \"sigma_intercept_per_group\": 0.023497916758060455, \"sigma_obs\": 0.004056012257933617, \"slope\": -0.11431069672107697, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 20.044702529907227, \"sigma_intercept_per_group\": 0.023383114486932755, \"sigma_obs\": 0.004040970001369715, \"slope\": -0.12140081077814102, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 6.548855304718018, \"sigma_intercept_per_group\": 0.059544797986745834, \"sigma_obs\": 0.003662996692582965, \"slope\": -0.055213529616594315, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 19.376964569091797, \"sigma_intercept_per_group\": 0.028702056035399437, \"sigma_obs\": 0.0038414958398789167, \"slope\": -0.18145935237407684, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 11.956223487854004, \"sigma_intercept_per_group\": 0.03583257272839546, \"sigma_obs\": 0.00393076054751873, \"slope\": -0.1716749221086502, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 12.607484817504883, \"sigma_intercept_per_group\": 0.021455245092511177, \"sigma_obs\": 0.003613188397139311, \"slope\": 0.047947924584150314, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 10.726018905639648, \"sigma_intercept_per_group\": 0.02016526274383068, \"sigma_obs\": 0.0033525123726576567, \"slope\": -0.1838483214378357, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 19.93646240234375, \"sigma_intercept_per_group\": 0.021999428048729897, \"sigma_obs\": 0.004084248561412096, \"slope\": -0.051901351660490036, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 22.67040252685547, \"sigma_intercept_per_group\": 0.016802871599793434, \"sigma_obs\": 0.0042989738285541534, \"slope\": 0.11867301166057587, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 16.314647674560547, \"sigma_intercept_per_group\": 0.03179030492901802, \"sigma_obs\": 0.003984452690929174, \"slope\": -0.09114231169223785, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 16.615211486816406, \"sigma_intercept_per_group\": 0.02450620010495186, \"sigma_obs\": 0.003623893251642585, \"slope\": -0.06677081435918808, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 14.336892127990723, \"sigma_intercept_per_group\": 0.02242415025830269, \"sigma_obs\": 0.00394173339009285, \"slope\": 0.004201550502330065, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 10.823267936706543, \"sigma_intercept_per_group\": 0.03344452381134033, \"sigma_obs\": 0.003887360217049718, \"slope\": -0.10513737797737122, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 8.007196426391602, \"sigma_intercept_per_group\": 0.04926655814051628, \"sigma_obs\": 0.0038495934568345547, \"slope\": -0.04851357266306877, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 7.597744941711426, \"sigma_intercept_per_group\": 0.0538189634680748, \"sigma_obs\": 0.0039169262163341045, \"slope\": -0.045204367488622665, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 7.410859107971191, \"sigma_intercept_per_group\": 0.04465550184249878, \"sigma_obs\": 0.003591956105083227, \"slope\": -0.07101231813430786, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 11.679069519042969, \"sigma_intercept_per_group\": 0.030774155631661415, \"sigma_obs\": 0.0035752919502556324, \"slope\": 0.0770338922739029, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 10.157262802124023, \"sigma_intercept_per_group\": 0.031782954931259155, \"sigma_obs\": 0.004062068182975054, \"slope\": 0.021193917840719223, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 11.69454288482666, \"sigma_intercept_per_group\": 0.030057409778237343, \"sigma_obs\": 0.0037870765663683414, \"slope\": -0.03669234737753868, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 11.290950775146484, \"sigma_intercept_per_group\": 0.0234619602560997, \"sigma_obs\": 0.003293053712695837, \"slope\": -0.12096664309501648, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 17.204334259033203, \"sigma_intercept_per_group\": 0.020204026252031326, \"sigma_obs\": 0.003806952852755785, \"slope\": -0.08101968467235565, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 11.7166166305542, \"sigma_intercept_per_group\": 0.021471288055181503, \"sigma_obs\": 0.003758426057174802, \"slope\": 0.02019699104130268, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 12.460502624511719, \"sigma_intercept_per_group\": 0.03466641902923584, \"sigma_obs\": 0.0037435663398355246, \"slope\": -0.1400316208600998, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 8.609964370727539, \"sigma_intercept_per_group\": 0.030886221677064896, \"sigma_obs\": 0.003914385102689266, \"slope\": -0.15775242447853088, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 12.509943962097168, \"sigma_intercept_per_group\": 0.03363047167658806, \"sigma_obs\": 0.00390998087823391, \"slope\": -0.171408012509346, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 17.57084846496582, \"sigma_intercept_per_group\": 0.02934347465634346, \"sigma_obs\": 0.004009643569588661, \"slope\": -0.14285391569137573, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 19.298473358154297, \"sigma_intercept_per_group\": 0.023920901119709015, \"sigma_obs\": 0.004121971782296896, \"slope\": -0.1692017912864685, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 21.430299758911133, \"sigma_intercept_per_group\": 0.02760780230164528, \"sigma_obs\": 0.004372606985270977, \"slope\": -0.11814606189727783, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 22.004989624023438, \"sigma_intercept_per_group\": 0.024713464081287384, \"sigma_obs\": 0.004514420870691538, \"slope\": -0.1364189237356186, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 27.83041763305664, \"sigma_intercept_per_group\": 0.014062801375985146, \"sigma_obs\": 0.003851646091789007, \"slope\": -0.07505016028881073, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 14.48312759399414, \"sigma_intercept_per_group\": 0.03694482892751694, \"sigma_obs\": 0.004519868176430464, \"slope\": -0.07044120132923126, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 13.240446090698242, \"sigma_intercept_per_group\": 0.03686143830418587, \"sigma_obs\": 0.004465859849005938, \"slope\": -0.07490574568510056, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 14.152892112731934, \"sigma_intercept_per_group\": 0.028852002695202827, \"sigma_obs\": 0.004569314885884523, \"slope\": -0.08772112429141998, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 17.156702041625977, \"sigma_intercept_per_group\": 0.027955148369073868, \"sigma_obs\": 0.004078602883964777, \"slope\": -0.12676462531089783, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 20.155445098876953, \"sigma_intercept_per_group\": 0.02234712615609169, \"sigma_obs\": 0.00386111275292933, \"slope\": -0.12284833192825317, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 18.32308006286621, \"sigma_intercept_per_group\": 0.027563828974962234, \"sigma_obs\": 0.0037586393300443888, \"slope\": -0.1771273910999298, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 13.935635566711426, \"sigma_intercept_per_group\": 0.03326108306646347, \"sigma_obs\": 0.004258283879607916, \"slope\": -0.20499573647975922, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 16.0164852142334, \"sigma_intercept_per_group\": 0.022702716290950775, \"sigma_obs\": 0.0037431770469993353, \"slope\": -0.05167687311768532, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 12.55821704864502, \"sigma_intercept_per_group\": 0.02638952061533928, \"sigma_obs\": 0.004308171104639769, \"slope\": -0.10705871880054474, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 11.718076705932617, \"sigma_intercept_per_group\": 0.02886764332652092, \"sigma_obs\": 0.0037320381961762905, \"slope\": -0.10676901042461395, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 16.367700576782227, \"sigma_intercept_per_group\": 0.020309776067733765, \"sigma_obs\": 0.004219661466777325, \"slope\": 0.07415870577096939, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 15.857398986816406, \"sigma_intercept_per_group\": 0.01234524231404066, \"sigma_obs\": 0.0033458464313298464, \"slope\": -0.12346990406513214, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 15.19300651550293, \"sigma_intercept_per_group\": 0.020751621574163437, \"sigma_obs\": 0.004105692263692617, \"slope\": 0.07095616310834885, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 12.423163414001465, \"sigma_intercept_per_group\": 0.030316641554236412, \"sigma_obs\": 0.003575571347028017, \"slope\": -0.038183845579624176, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 9.608722686767578, \"sigma_intercept_per_group\": 0.02533474937081337, \"sigma_obs\": 0.0031387703493237495, \"slope\": -0.027867645025253296, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 13.850154876708984, \"sigma_intercept_per_group\": 0.02312791720032692, \"sigma_obs\": 0.0034741514828056097, \"slope\": -0.10175292193889618, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 15.2943696975708, \"sigma_intercept_per_group\": 0.023627478629350662, \"sigma_obs\": 0.0034709556493908167, \"slope\": -0.02158830314874649, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 30.788785934448242, \"sigma_intercept_per_group\": 0.016106991097331047, \"sigma_obs\": 0.0037381169386208057, \"slope\": -0.02404995635151863, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 26.988794326782227, \"sigma_intercept_per_group\": 0.015009916387498379, \"sigma_obs\": 0.003713146084919572, \"slope\": -0.03395051136612892, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 28.382469177246094, \"sigma_intercept_per_group\": 0.011250090785324574, \"sigma_obs\": 0.003613783046603203, \"slope\": -0.12285957485437393, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 24.842002868652344, \"sigma_intercept_per_group\": 0.023143991827964783, \"sigma_obs\": 0.0044226814061403275, \"slope\": -0.04305879771709442, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 24.769502639770508, \"sigma_intercept_per_group\": 0.023475181311368942, \"sigma_obs\": 0.004411577247083187, \"slope\": -0.03506702557206154, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 11.019925117492676, \"sigma_intercept_per_group\": 0.03089105151593685, \"sigma_obs\": 0.003495164215564728, \"slope\": -0.08441152423620224, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 15.915265083312988, \"sigma_intercept_per_group\": 0.03252007067203522, \"sigma_obs\": 0.0036069105844944715, \"slope\": -0.07018949836492538, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 1.8965164422988892, \"sigma_intercept_per_group\": 0.024154508486390114, \"sigma_obs\": 0.0034237538930028677, \"slope\": -0.016448255628347397, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 21.5062313079834, \"sigma_intercept_per_group\": 0.01231597363948822, \"sigma_obs\": 0.003869893727824092, \"slope\": 0.017921073362231255, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 15.671550750732422, \"sigma_intercept_per_group\": 0.028697211295366287, \"sigma_obs\": 0.0038445231039077044, \"slope\": -0.0354447178542614, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 16.27359962463379, \"sigma_intercept_per_group\": 0.021603520959615707, \"sigma_obs\": 0.003730260767042637, \"slope\": -0.09096387773752213, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 12.733311653137207, \"sigma_intercept_per_group\": 0.030612511560320854, \"sigma_obs\": 0.003744696266949177, \"slope\": -0.14469154179096222, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 11.95956039428711, \"sigma_intercept_per_group\": 0.040118686854839325, \"sigma_obs\": 0.0037265149876475334, \"slope\": -0.11821498721837997, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 17.493253707885742, \"sigma_intercept_per_group\": 0.02082042209804058, \"sigma_obs\": 0.004020061809569597, \"slope\": 0.05059497058391571, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 11.930121421813965, \"sigma_intercept_per_group\": 0.02190708927810192, \"sigma_obs\": 0.0037442215252667665, \"slope\": -0.050620563328266144, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 11.957670211791992, \"sigma_intercept_per_group\": 0.02659446746110916, \"sigma_obs\": 0.003661220660433173, \"slope\": -0.06111733242869377, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 5.400100231170654, \"sigma_intercept_per_group\": 0.021783962845802307, \"sigma_obs\": 0.003560806391760707, \"slope\": -0.024638747796416283, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 26.982093811035156, \"sigma_intercept_per_group\": 0.0202653631567955, \"sigma_obs\": 0.0041946908459067345, \"slope\": -0.03700299933552742, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 10.796753883361816, \"sigma_intercept_per_group\": 0.02528885379433632, \"sigma_obs\": 0.003854234702885151, \"slope\": -0.12487374246120453, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 17.599937438964844, \"sigma_intercept_per_group\": 0.016845358535647392, \"sigma_obs\": 0.0034475428983569145, \"slope\": -0.007153451442718506, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 16.41366958618164, \"sigma_intercept_per_group\": 0.02634172886610031, \"sigma_obs\": 0.003884526900947094, \"slope\": 0.009853613562881947, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 6.493248462677002, \"sigma_intercept_per_group\": 0.02501804754137993, \"sigma_obs\": 0.0038102054968476295, \"slope\": -0.04363589361310005, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 22.2916202545166, \"sigma_intercept_per_group\": 0.0185194443911314, \"sigma_obs\": 0.004016925115138292, \"slope\": -0.05283670499920845, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 20.4633731842041, \"sigma_intercept_per_group\": 0.015369332395493984, \"sigma_obs\": 0.004136092495173216, \"slope\": -0.04211009666323662, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": 12.103629112243652, \"sigma_intercept_per_group\": 0.034596264362335205, \"sigma_obs\": 0.003892822889611125, \"slope\": -0.2044374942779541, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 13.065549850463867, \"sigma_intercept_per_group\": 0.03314082697033882, \"sigma_obs\": 0.0038386245723813772, \"slope\": -0.20909832417964935, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 12.347940444946289, \"sigma_intercept_per_group\": 0.024213556200265884, \"sigma_obs\": 0.003713190322741866, \"slope\": -0.1932622492313385, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 15.346322059631348, \"sigma_intercept_per_group\": 0.02771759405732155, \"sigma_obs\": 0.003808514215052128, \"slope\": -0.14788563549518585, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 16.38490104675293, \"sigma_intercept_per_group\": 0.024479826912283897, \"sigma_obs\": 0.0039930096827447414, \"slope\": 0.03990612551569939, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 24.13380241394043, \"sigma_intercept_per_group\": 0.021103499457240105, \"sigma_obs\": 0.003928186371922493, \"slope\": -0.18724535405635834, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 13.31982421875, \"sigma_intercept_per_group\": 0.02722674049437046, \"sigma_obs\": 0.003716974286362529, \"slope\": 0.10223346203565598, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 12.070789337158203, \"sigma_intercept_per_group\": 0.022633560001850128, \"sigma_obs\": 0.0037823771126568317, \"slope\": 0.054385531693696976, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 18.69684600830078, \"sigma_intercept_per_group\": 0.02522866800427437, \"sigma_obs\": 0.003815874457359314, \"slope\": -0.14581960439682007, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 9.997499465942383, \"sigma_intercept_per_group\": 0.017052436247467995, \"sigma_obs\": 0.0037147842813283205, \"slope\": -0.012992247007787228, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 20.99102020263672, \"sigma_intercept_per_group\": 0.02035355381667614, \"sigma_obs\": 0.003911517094820738, \"slope\": -0.1122102290391922, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 28.403263092041016, \"sigma_intercept_per_group\": 0.016377076506614685, \"sigma_obs\": 0.003470753785222769, \"slope\": -0.12129464000463486, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 11.255257606506348, \"sigma_intercept_per_group\": 0.04303179308772087, \"sigma_obs\": 0.004023298621177673, \"slope\": 0.06230935454368591, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 11.797900199890137, \"sigma_intercept_per_group\": 0.036736588925123215, \"sigma_obs\": 0.0040846518240869045, \"slope\": 0.03431926667690277, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 11.204254150390625, \"sigma_intercept_per_group\": 0.04166974499821663, \"sigma_obs\": 0.004022803623229265, \"slope\": 0.0440254881978035, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 9.698267936706543, \"sigma_intercept_per_group\": 0.06476177275180817, \"sigma_obs\": 0.0038900747895240784, \"slope\": -0.12984639406204224, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 6.694983005523682, \"sigma_intercept_per_group\": 0.059020936489105225, \"sigma_obs\": 0.004140704404562712, \"slope\": -0.12101075053215027, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 14.453996658325195, \"sigma_intercept_per_group\": 0.0320291705429554, \"sigma_obs\": 0.0039689792320132256, \"slope\": -0.1932290941476822, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 9.364727973937988, \"sigma_intercept_per_group\": 0.030703550204634666, \"sigma_obs\": 0.003710211720317602, \"slope\": -0.026806017383933067, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 7.72220516204834, \"sigma_intercept_per_group\": 0.03871581703424454, \"sigma_obs\": 0.003887245198711753, \"slope\": 0.07406149804592133, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 9.879158973693848, \"sigma_intercept_per_group\": 0.04272787272930145, \"sigma_obs\": 0.0039085266180336475, \"slope\": -0.004870525561273098, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 9.579302787780762, \"sigma_intercept_per_group\": 0.04472854733467102, \"sigma_obs\": 0.0038939628284424543, \"slope\": -0.009281007573008537, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 8.220423698425293, \"sigma_intercept_per_group\": 0.04203033074736595, \"sigma_obs\": 0.003798617050051689, \"slope\": 0.01493315864354372, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 9.35869312286377, \"sigma_intercept_per_group\": 0.05005304887890816, \"sigma_obs\": 0.004029959440231323, \"slope\": -0.037904076278209686, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 9.032892227172852, \"sigma_intercept_per_group\": 0.03458879888057709, \"sigma_obs\": 0.003936016000807285, \"slope\": -0.04023786634206772, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 11.847712516784668, \"sigma_intercept_per_group\": 0.040411628782749176, \"sigma_obs\": 0.004109691828489304, \"slope\": -0.041922323405742645, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 14.844436645507812, \"sigma_intercept_per_group\": 0.03346463292837143, \"sigma_obs\": 0.004119413439184427, \"slope\": -0.12652604281902313, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 12.56456184387207, \"sigma_intercept_per_group\": 0.04031257703900337, \"sigma_obs\": 0.00410359026864171, \"slope\": -0.12571406364440918, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 5.997925758361816, \"sigma_intercept_per_group\": 0.024596454575657845, \"sigma_obs\": 0.0037926388904452324, \"slope\": 0.03539293631911278, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 9.782280921936035, \"sigma_intercept_per_group\": 0.033036086708307266, \"sigma_obs\": 0.0037965455558151007, \"slope\": -0.05312689393758774, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 8.508468627929688, \"sigma_intercept_per_group\": 0.051230885088443756, \"sigma_obs\": 0.004084437619894743, \"slope\": 0.02281944826245308, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 14.217996597290039, \"sigma_intercept_per_group\": 0.024655461311340332, \"sigma_obs\": 0.0038463494274765253, \"slope\": -0.10754876583814621, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 8.330201148986816, \"sigma_intercept_per_group\": 0.0721680223941803, \"sigma_obs\": 0.004175007343292236, \"slope\": -0.033591289073228836, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 7.797253131866455, \"sigma_intercept_per_group\": 0.04515116661787033, \"sigma_obs\": 0.003574272384867072, \"slope\": -0.13971039652824402, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 9.244168281555176, \"sigma_intercept_per_group\": 0.04649439454078674, \"sigma_obs\": 0.003590142587199807, \"slope\": -0.14036864042282104, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 8.931635856628418, \"sigma_intercept_per_group\": 0.03880930691957474, \"sigma_obs\": 0.003483666805550456, \"slope\": -0.09509068727493286, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 8.50181770324707, \"sigma_intercept_per_group\": 0.043715301901102066, \"sigma_obs\": 0.003726834896951914, \"slope\": -0.024136148393154144, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 10.410006523132324, \"sigma_intercept_per_group\": 0.03176531940698624, \"sigma_obs\": 0.0036682910285890102, \"slope\": 0.05324765294790268, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 11.905487060546875, \"sigma_intercept_per_group\": 0.02955798991024494, \"sigma_obs\": 0.00420367531478405, \"slope\": 0.0022812492679804564, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 17.840267181396484, \"sigma_intercept_per_group\": 0.0237513966858387, \"sigma_obs\": 0.004049511160701513, \"slope\": -0.09839289635419846, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 9.860481262207031, \"sigma_intercept_per_group\": 0.018254553899168968, \"sigma_obs\": 0.003960245288908482, \"slope\": 0.016808299347758293, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 11.815430641174316, \"sigma_intercept_per_group\": 0.022933900356292725, \"sigma_obs\": 0.0035882361698895693, \"slope\": -0.0650993064045906, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 18.265501022338867, \"sigma_intercept_per_group\": 0.015209205448627472, \"sigma_obs\": 0.003768962575122714, \"slope\": 0.026170829311013222, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 15.542779922485352, \"sigma_intercept_per_group\": 0.024291008710861206, \"sigma_obs\": 0.0034525967203080654, \"slope\": -0.08556122332811356, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 10.48557186126709, \"sigma_intercept_per_group\": 0.033868517726659775, \"sigma_obs\": 0.003587119048461318, \"slope\": -0.02960086800158024, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 10.03592586517334, \"sigma_intercept_per_group\": 0.030025100335478783, \"sigma_obs\": 0.003775279503315687, \"slope\": -0.09876438230276108, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 10.707473754882812, \"sigma_intercept_per_group\": 0.030287664383649826, \"sigma_obs\": 0.003730952739715576, \"slope\": -0.11673575639724731, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 15.154701232910156, \"sigma_intercept_per_group\": 0.027836045250296593, \"sigma_obs\": 0.0038074939511716366, \"slope\": -0.09028230607509613, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 19.515066146850586, \"sigma_intercept_per_group\": 0.019328836351633072, \"sigma_obs\": 0.004140323493629694, \"slope\": -0.070875383913517, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 18.508256912231445, \"sigma_intercept_per_group\": 0.02096252702176571, \"sigma_obs\": 0.00382600468583405, \"slope\": -0.07502300292253494, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 9.770569801330566, \"sigma_intercept_per_group\": 0.019025884568691254, \"sigma_obs\": 0.003594964975491166, \"slope\": 0.04158288240432739, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 14.873461723327637, \"sigma_intercept_per_group\": 0.029640233144164085, \"sigma_obs\": 0.003554712515324354, \"slope\": -0.016334256157279015, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 10.226588249206543, \"sigma_intercept_per_group\": 0.02098632976412773, \"sigma_obs\": 0.003764075692743063, \"slope\": 0.03067786805331707, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 17.19078254699707, \"sigma_intercept_per_group\": 0.01858929544687271, \"sigma_obs\": 0.0039053969085216522, \"slope\": 0.10703245550394058, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 23.28681755065918, \"sigma_intercept_per_group\": 0.01593964919447899, \"sigma_obs\": 0.003971908241510391, \"slope\": 0.046251218765974045, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 22.795255661010742, \"sigma_intercept_per_group\": 0.013207176700234413, \"sigma_obs\": 0.0036905871238559484, \"slope\": -0.07100466638803482, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 14.228413581848145, \"sigma_intercept_per_group\": 0.016776068136096, \"sigma_obs\": 0.0037036610301584005, \"slope\": 0.09376782178878784, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 16.560230255126953, \"sigma_intercept_per_group\": 0.027479177340865135, \"sigma_obs\": 0.0036206217482686043, \"slope\": -0.15626713633537292, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 8.705890655517578, \"sigma_intercept_per_group\": 0.04198804497718811, \"sigma_obs\": 0.004014854785054922, \"slope\": -0.16900409758090973, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 13.71888256072998, \"sigma_intercept_per_group\": 0.033611368387937546, \"sigma_obs\": 0.003757402766495943, \"slope\": -0.10251419991254807, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 9.956019401550293, \"sigma_intercept_per_group\": 0.03057830035686493, \"sigma_obs\": 0.0041201915591955185, \"slope\": -0.07660342007875443, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 8.152240753173828, \"sigma_intercept_per_group\": 0.03957558050751686, \"sigma_obs\": 0.0035883234813809395, \"slope\": -0.07710444182157516, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 10.943075180053711, \"sigma_intercept_per_group\": 0.026744438335299492, \"sigma_obs\": 0.004203533288091421, \"slope\": 0.08572771400213242, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 19.607379913330078, \"sigma_intercept_per_group\": 0.0317360982298851, \"sigma_obs\": 0.004223405383527279, \"slope\": -0.1478157937526703, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 10.78364086151123, \"sigma_intercept_per_group\": 0.03137808293104172, \"sigma_obs\": 0.003529011271893978, \"slope\": -0.007289040833711624, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 10.810717582702637, \"sigma_intercept_per_group\": 0.031008074060082436, \"sigma_obs\": 0.00396741833537817, \"slope\": 0.017105810344219208, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 10.17393970489502, \"sigma_intercept_per_group\": 0.03310862183570862, \"sigma_obs\": 0.004149553366005421, \"slope\": 0.08290085196495056, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 18.876956939697266, \"sigma_intercept_per_group\": 0.02335520088672638, \"sigma_obs\": 0.0036220792680978775, \"slope\": -0.19991256296634674, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 8.241328239440918, \"sigma_intercept_per_group\": 0.03735516220331192, \"sigma_obs\": 0.00406649662181735, \"slope\": -0.06724727898836136, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 9.830537796020508, \"sigma_intercept_per_group\": 0.04357578977942467, \"sigma_obs\": 0.004139817785471678, \"slope\": -0.020358361303806305, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 8.306207656860352, \"sigma_intercept_per_group\": 0.03856808692216873, \"sigma_obs\": 0.004029534757137299, \"slope\": 0.102508544921875, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 8.787557601928711, \"sigma_intercept_per_group\": 0.045272164046764374, \"sigma_obs\": 0.004091773182153702, \"slope\": 0.09318110346794128, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 16.88427734375, \"sigma_intercept_per_group\": 0.030655113980174065, \"sigma_obs\": 0.004484442062675953, \"slope\": -0.04223690181970596, \"chain\": 0, \"draw\": 160}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 14.932190895080566, \"sigma_intercept_per_group\": 0.03546471893787384, \"sigma_obs\": 0.0040940348990261555, \"slope\": -0.07363881915807724, \"chain\": 0, \"draw\": 161}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 14.085847854614258, \"sigma_intercept_per_group\": 0.025002799928188324, \"sigma_obs\": 0.004182320088148117, \"slope\": 0.02148185297846794, \"chain\": 0, \"draw\": 162}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 14.968610763549805, \"sigma_intercept_per_group\": 0.026041671633720398, \"sigma_obs\": 0.0035872901789844036, \"slope\": -0.10208576917648315, \"chain\": 0, \"draw\": 163}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 14.1508207321167, \"sigma_intercept_per_group\": 0.025177959352731705, \"sigma_obs\": 0.0038478903006762266, \"slope\": -0.13238078355789185, \"chain\": 0, \"draw\": 164}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 12.232227325439453, \"sigma_intercept_per_group\": 0.03787561506032944, \"sigma_obs\": 0.003970097750425339, \"slope\": -0.017366968095302582, \"chain\": 0, \"draw\": 165}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 12.154205322265625, \"sigma_intercept_per_group\": 0.034512709826231, \"sigma_obs\": 0.0037342223804444075, \"slope\": -0.08651643246412277, \"chain\": 0, \"draw\": 166}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 12.794042587280273, \"sigma_intercept_per_group\": 0.023293690755963326, \"sigma_obs\": 0.00367665640078485, \"slope\": -0.07413945347070694, \"chain\": 0, \"draw\": 167}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 13.636106491088867, \"sigma_intercept_per_group\": 0.016057007014751434, \"sigma_obs\": 0.0035716742277145386, \"slope\": -0.021631930023431778, \"chain\": 0, \"draw\": 168}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 14.942415237426758, \"sigma_intercept_per_group\": 0.03126299008727074, \"sigma_obs\": 0.003889842890202999, \"slope\": -0.044561464339494705, \"chain\": 0, \"draw\": 169}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 13.179963111877441, \"sigma_intercept_per_group\": 0.028583751991391182, \"sigma_obs\": 0.0037529729306697845, \"slope\": 0.010475289076566696, \"chain\": 0, \"draw\": 170}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 9.240310668945312, \"sigma_intercept_per_group\": 0.024349039420485497, \"sigma_obs\": 0.0036968521308153868, \"slope\": -0.0390743650496006, \"chain\": 0, \"draw\": 171}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 8.920479774475098, \"sigma_intercept_per_group\": 0.03849320113658905, \"sigma_obs\": 0.003754358272999525, \"slope\": -0.05372386425733566, \"chain\": 0, \"draw\": 172}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 19.634098052978516, \"sigma_intercept_per_group\": 0.02117438055574894, \"sigma_obs\": 0.004409785382449627, \"slope\": -0.0323009118437767, \"chain\": 0, \"draw\": 173}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 18.518226623535156, \"sigma_intercept_per_group\": 0.023391228169202805, \"sigma_obs\": 0.0042332932353019714, \"slope\": -0.11285894364118576, \"chain\": 0, \"draw\": 174}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 18.983745574951172, \"sigma_intercept_per_group\": 0.027722306549549103, \"sigma_obs\": 0.004270520992577076, \"slope\": -0.03192416951060295, \"chain\": 0, \"draw\": 175}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 10.073293685913086, \"sigma_intercept_per_group\": 0.03763575851917267, \"sigma_obs\": 0.0039880890399217606, \"slope\": -0.05362405255436897, \"chain\": 0, \"draw\": 176}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 13.226552963256836, \"sigma_intercept_per_group\": 0.034785717725753784, \"sigma_obs\": 0.0038650583010166883, \"slope\": -0.1399623602628708, \"chain\": 0, \"draw\": 177}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 9.738555908203125, \"sigma_intercept_per_group\": 0.03855947405099869, \"sigma_obs\": 0.003913444466888905, \"slope\": -0.10837434977293015, \"chain\": 0, \"draw\": 178}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 11.186586380004883, \"sigma_intercept_per_group\": 0.036441024392843246, \"sigma_obs\": 0.004069548100233078, \"slope\": 0.00680095748975873, \"chain\": 0, \"draw\": 179}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 10.359151840209961, \"sigma_intercept_per_group\": 0.03877439349889755, \"sigma_obs\": 0.004309108015149832, \"slope\": 0.033348869532346725, \"chain\": 0, \"draw\": 180}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 8.879620552062988, \"sigma_intercept_per_group\": 0.027223916724324226, \"sigma_obs\": 0.004126219544559717, \"slope\": 0.0650327131152153, \"chain\": 0, \"draw\": 181}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 19.702600479125977, \"sigma_intercept_per_group\": 0.01948533020913601, \"sigma_obs\": 0.0036197190638631582, \"slope\": -0.1566077023744583, \"chain\": 0, \"draw\": 182}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 12.299826622009277, \"sigma_intercept_per_group\": 0.017045632004737854, \"sigma_obs\": 0.003580898279324174, \"slope\": -0.06432223320007324, \"chain\": 0, \"draw\": 183}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 15.168231010437012, \"sigma_intercept_per_group\": 0.024401726201176643, \"sigma_obs\": 0.00353601505048573, \"slope\": -0.06553037464618683, \"chain\": 0, \"draw\": 184}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 25.25004768371582, \"sigma_intercept_per_group\": 0.01219022087752819, \"sigma_obs\": 0.0039437091909348965, \"slope\": 0.016467992216348648, \"chain\": 0, \"draw\": 185}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 27.782081604003906, \"sigma_intercept_per_group\": 0.011725418269634247, \"sigma_obs\": 0.004247058182954788, \"slope\": 0.10770221054553986, \"chain\": 0, \"draw\": 186}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 14.63357925415039, \"sigma_intercept_per_group\": 0.021278521046042442, \"sigma_obs\": 0.0037753586657345295, \"slope\": 0.049011196941137314, \"chain\": 0, \"draw\": 187}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 16.643356323242188, \"sigma_intercept_per_group\": 0.02235504426062107, \"sigma_obs\": 0.003763253567740321, \"slope\": 0.010667447000741959, \"chain\": 0, \"draw\": 188}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 15.730588912963867, \"sigma_intercept_per_group\": 0.027272548526525497, \"sigma_obs\": 0.003750829491764307, \"slope\": -0.10263922065496445, \"chain\": 0, \"draw\": 189}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 18.403038024902344, \"sigma_intercept_per_group\": 0.01621513068675995, \"sigma_obs\": 0.003935098648071289, \"slope\": 0.0009536391589790583, \"chain\": 0, \"draw\": 190}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 16.708641052246094, \"sigma_intercept_per_group\": 0.02724185585975647, \"sigma_obs\": 0.003884347155690193, \"slope\": 0.008191204629838467, \"chain\": 0, \"draw\": 191}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 14.32320499420166, \"sigma_intercept_per_group\": 0.018069742247462273, \"sigma_obs\": 0.0036645864602178335, \"slope\": 0.024651754647493362, \"chain\": 0, \"draw\": 192}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 11.304518699645996, \"sigma_intercept_per_group\": 0.02508271113038063, \"sigma_obs\": 0.00365964462980628, \"slope\": 0.0055067697539925575, \"chain\": 0, \"draw\": 193}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 11.40913200378418, \"sigma_intercept_per_group\": 0.025004785507917404, \"sigma_obs\": 0.003850715234875679, \"slope\": 0.015841523185372353, \"chain\": 0, \"draw\": 194}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 9.450153350830078, \"sigma_intercept_per_group\": 0.01969931833446026, \"sigma_obs\": 0.003629690036177635, \"slope\": -0.026761850342154503, \"chain\": 0, \"draw\": 195}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 12.342084884643555, \"sigma_intercept_per_group\": 0.027082625776529312, \"sigma_obs\": 0.003651624545454979, \"slope\": -0.008165181614458561, \"chain\": 0, \"draw\": 196}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 10.826181411743164, \"sigma_intercept_per_group\": 0.028373248875141144, \"sigma_obs\": 0.004164338577538729, \"slope\": -0.12632839381694794, \"chain\": 0, \"draw\": 197}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 14.663969993591309, \"sigma_intercept_per_group\": 0.03609181568026543, \"sigma_obs\": 0.004041295498609543, \"slope\": -0.1583716869354248, \"chain\": 0, \"draw\": 198}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 3.978754997253418, \"sigma_intercept_per_group\": 0.09006468951702118, \"sigma_obs\": 0.0037665138952434063, \"slope\": -0.012875920161604881, \"chain\": 0, \"draw\": 199}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 8.712316513061523, \"sigma_intercept_per_group\": 0.02869509905576706, \"sigma_obs\": 0.004118396434932947, \"slope\": 0.03310050442814827, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.507787704467773, \"sigma_intercept_per_group\": 0.017188213765621185, \"sigma_obs\": 0.003609897568821907, \"slope\": -0.06697434186935425, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 14.00645923614502, \"sigma_intercept_per_group\": 0.02189568430185318, \"sigma_obs\": 0.003293012734502554, \"slope\": -0.021455051377415657, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 9.77452564239502, \"sigma_intercept_per_group\": 0.019858933985233307, \"sigma_obs\": 0.004026373382657766, \"slope\": 0.07783579081296921, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 21.771499633789062, \"sigma_intercept_per_group\": 0.016173509880900383, \"sigma_obs\": 0.0036369545850902796, \"slope\": -0.07456731796264648, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 20.616453170776367, \"sigma_intercept_per_group\": 0.01680498756468296, \"sigma_obs\": 0.0036438649985939264, \"slope\": -0.06052601337432861, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 13.591268539428711, \"sigma_intercept_per_group\": 0.023075059056282043, \"sigma_obs\": 0.004120629746466875, \"slope\": 0.0071127223782241344, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 20.041399002075195, \"sigma_intercept_per_group\": 0.017300156876444817, \"sigma_obs\": 0.00374815845862031, \"slope\": -0.1054905503988266, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 17.01093864440918, \"sigma_intercept_per_group\": 0.01860598847270012, \"sigma_obs\": 0.0039059221744537354, \"slope\": -0.08167783915996552, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 13.570305824279785, \"sigma_intercept_per_group\": 0.02077118307352066, \"sigma_obs\": 0.003717105370014906, \"slope\": 0.021844210103154182, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 15.074631690979004, \"sigma_intercept_per_group\": 0.020728761330246925, \"sigma_obs\": 0.0038991987239569426, \"slope\": 0.07760738581418991, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 9.145668029785156, \"sigma_intercept_per_group\": 0.028094004839658737, \"sigma_obs\": 0.003834961913526058, \"slope\": -0.03726140782237053, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 11.449712753295898, \"sigma_intercept_per_group\": 0.02627999521791935, \"sigma_obs\": 0.003862116253003478, \"slope\": -0.044536229223012924, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 9.501495361328125, \"sigma_intercept_per_group\": 0.02678113989531994, \"sigma_obs\": 0.003680682275444269, \"slope\": 0.08447472751140594, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 8.774459838867188, \"sigma_intercept_per_group\": 0.030217058956623077, \"sigma_obs\": 0.003518293146044016, \"slope\": 0.10931470990180969, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 15.327200889587402, \"sigma_intercept_per_group\": 0.032594479620456696, \"sigma_obs\": 0.003947428893297911, \"slope\": -0.08032526075839996, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 12.793622970581055, \"sigma_intercept_per_group\": 0.027791177853941917, \"sigma_obs\": 0.0037684449926018715, \"slope\": -0.16602616012096405, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 28.945266723632812, \"sigma_intercept_per_group\": 0.015971247106790543, \"sigma_obs\": 0.003958850167691708, \"slope\": -0.06335853040218353, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 20.93370246887207, \"sigma_intercept_per_group\": 0.027354072779417038, \"sigma_obs\": 0.004653914365917444, \"slope\": -0.14532670378684998, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 21.236400604248047, \"sigma_intercept_per_group\": 0.02035934291779995, \"sigma_obs\": 0.004338475409895182, \"slope\": -0.1156638115644455, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 14.413389205932617, \"sigma_intercept_per_group\": 0.024083444848656654, \"sigma_obs\": 0.003655033651739359, \"slope\": -0.08015765994787216, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 10.097532272338867, \"sigma_intercept_per_group\": 0.017798293381929398, \"sigma_obs\": 0.00403183326125145, \"slope\": -0.023905038833618164, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 15.696884155273438, \"sigma_intercept_per_group\": 0.026306336745619774, \"sigma_obs\": 0.003862431040033698, \"slope\": 0.02687586285173893, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 18.01478385925293, \"sigma_intercept_per_group\": 0.02123376727104187, \"sigma_obs\": 0.0034985824022442102, \"slope\": 0.054038360714912415, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 11.64186954498291, \"sigma_intercept_per_group\": 0.020097477361559868, \"sigma_obs\": 0.003973330836743116, \"slope\": -0.016070842742919922, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 7.163931846618652, \"sigma_intercept_per_group\": 0.033584341406822205, \"sigma_obs\": 0.003387065604329109, \"slope\": 0.18379881978034973, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 15.479260444641113, \"sigma_intercept_per_group\": 0.015884533524513245, \"sigma_obs\": 0.004122127313166857, \"slope\": -0.07805782556533813, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 24.72692108154297, \"sigma_intercept_per_group\": 0.009840931743383408, \"sigma_obs\": 0.003341321600601077, \"slope\": -0.017626890912652016, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 25.52565574645996, \"sigma_intercept_per_group\": 0.01689896360039711, \"sigma_obs\": 0.004098028875887394, \"slope\": 0.01377031859010458, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 9.951919555664062, \"sigma_intercept_per_group\": 0.03393377736210823, \"sigma_obs\": 0.003987752366811037, \"slope\": -0.2305678278207779, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 9.537137031555176, \"sigma_intercept_per_group\": 0.023715464398264885, \"sigma_obs\": 0.003818834200501442, \"slope\": -0.0587807297706604, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 16.224430084228516, \"sigma_intercept_per_group\": 0.029588330537080765, \"sigma_obs\": 0.003903080942109227, \"slope\": -0.13226017355918884, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 13.593737602233887, \"sigma_intercept_per_group\": 0.023948024958372116, \"sigma_obs\": 0.0042463247664272785, \"slope\": -0.047640811651945114, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 14.62016773223877, \"sigma_intercept_per_group\": 0.03339887410402298, \"sigma_obs\": 0.0042250934056937695, \"slope\": -0.09036428481340408, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 13.601906776428223, \"sigma_intercept_per_group\": 0.03453905135393143, \"sigma_obs\": 0.004173303954303265, \"slope\": -0.04728277772665024, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 12.033946990966797, \"sigma_intercept_per_group\": 0.04123838618397713, \"sigma_obs\": 0.004134566523134708, \"slope\": -0.06259626150131226, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 12.125531196594238, \"sigma_intercept_per_group\": 0.028916632756590843, \"sigma_obs\": 0.0040190573781728745, \"slope\": 0.05788237228989601, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 8.427424430847168, \"sigma_intercept_per_group\": 0.03856837376952171, \"sigma_obs\": 0.0041448092088103294, \"slope\": 0.01673239655792713, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 11.51894474029541, \"sigma_intercept_per_group\": 0.03783014044165611, \"sigma_obs\": 0.0039060078561306, \"slope\": 0.00017670731176622212, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 8.678235054016113, \"sigma_intercept_per_group\": 0.034743744879961014, \"sigma_obs\": 0.003868467640131712, \"slope\": 0.0180674958974123, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 16.672203063964844, \"sigma_intercept_per_group\": 0.014134937897324562, \"sigma_obs\": 0.003697075881063938, \"slope\": -0.04488518461585045, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 18.538528442382812, \"sigma_intercept_per_group\": 0.025408552959561348, \"sigma_obs\": 0.003916810266673565, \"slope\": -0.04039301350712776, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 17.026586532592773, \"sigma_intercept_per_group\": 0.020032737404108047, \"sigma_obs\": 0.0037774385418742895, \"slope\": -0.08278589695692062, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 22.65934181213379, \"sigma_intercept_per_group\": 0.02609773725271225, \"sigma_obs\": 0.004127947613596916, \"slope\": -0.13419225811958313, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 15.00639533996582, \"sigma_intercept_per_group\": 0.03032582253217697, \"sigma_obs\": 0.004217378329485655, \"slope\": 0.0118001913651824, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 13.891402244567871, \"sigma_intercept_per_group\": 0.026345841586589813, \"sigma_obs\": 0.003659695154055953, \"slope\": -0.08845174312591553, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 17.596717834472656, \"sigma_intercept_per_group\": 0.026042379438877106, \"sigma_obs\": 0.004004700109362602, \"slope\": -0.11115100234746933, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 15.74413776397705, \"sigma_intercept_per_group\": 0.02417515590786934, \"sigma_obs\": 0.004126451909542084, \"slope\": -0.00530660105869174, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 16.5755672454834, \"sigma_intercept_per_group\": 0.024202555418014526, \"sigma_obs\": 0.00401503499597311, \"slope\": -0.0005900822579860687, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 13.718358039855957, \"sigma_intercept_per_group\": 0.03761444240808487, \"sigma_obs\": 0.004077053163200617, \"slope\": -0.12597256898880005, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 11.154791831970215, \"sigma_intercept_per_group\": 0.028929267078638077, \"sigma_obs\": 0.0036963638849556446, \"slope\": -0.1460607498884201, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 11.601874351501465, \"sigma_intercept_per_group\": 0.02694510668516159, \"sigma_obs\": 0.0037344307638704777, \"slope\": -0.15015462040901184, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 12.331249237060547, \"sigma_intercept_per_group\": 0.03934849053621292, \"sigma_obs\": 0.003798350691795349, \"slope\": -0.1464746594429016, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 7.559034824371338, \"sigma_intercept_per_group\": 0.03560046851634979, \"sigma_obs\": 0.003753622528165579, \"slope\": -0.09113331139087677, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 14.616560935974121, \"sigma_intercept_per_group\": 0.027057332918047905, \"sigma_obs\": 0.003928984049707651, \"slope\": 0.012072039768099785, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 13.618410110473633, \"sigma_intercept_per_group\": 0.031786464154720306, \"sigma_obs\": 0.004229657351970673, \"slope\": -0.02794761024415493, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 10.605829238891602, \"sigma_intercept_per_group\": 0.021374529227614403, \"sigma_obs\": 0.0037833296228200197, \"slope\": -0.12977643311023712, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 23.017410278320312, \"sigma_intercept_per_group\": 0.019585495814681053, \"sigma_obs\": 0.0039551742374897, \"slope\": -0.04333559796214104, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 8.474204063415527, \"sigma_intercept_per_group\": 0.035447362810373306, \"sigma_obs\": 0.0040534911677241325, \"slope\": -0.03682297095656395, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 16.189239501953125, \"sigma_intercept_per_group\": 0.033621225506067276, \"sigma_obs\": 0.0037369406782090664, \"slope\": -0.09435811638832092, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 10.90764045715332, \"sigma_intercept_per_group\": 0.03139141947031021, \"sigma_obs\": 0.003914926666766405, \"slope\": -0.08511429280042648, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 19.054349899291992, \"sigma_intercept_per_group\": 0.02405834197998047, \"sigma_obs\": 0.003835296491160989, \"slope\": -0.07486049085855484, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 20.7358341217041, \"sigma_intercept_per_group\": 0.015813924372196198, \"sigma_obs\": 0.004191565793007612, \"slope\": 0.002777645830065012, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 12.85854434967041, \"sigma_intercept_per_group\": 0.0316132977604866, \"sigma_obs\": 0.0035755662247538567, \"slope\": -0.13731233775615692, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 9.339320182800293, \"sigma_intercept_per_group\": 0.02982524409890175, \"sigma_obs\": 0.003678976558148861, \"slope\": -0.09524305164813995, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 13.866783142089844, \"sigma_intercept_per_group\": 0.029121190309524536, \"sigma_obs\": 0.004098271485418081, \"slope\": -0.0011385922553017735, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 11.891185760498047, \"sigma_intercept_per_group\": 0.028623482212424278, \"sigma_obs\": 0.003947724122554064, \"slope\": -0.1478680670261383, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 15.072761535644531, \"sigma_intercept_per_group\": 0.03392435982823372, \"sigma_obs\": 0.004219946917146444, \"slope\": -0.06987901031970978, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 14.478137969970703, \"sigma_intercept_per_group\": 0.03379058837890625, \"sigma_obs\": 0.004128945525735617, \"slope\": -0.13712792098522186, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 18.954769134521484, \"sigma_intercept_per_group\": 0.025371862575411797, \"sigma_obs\": 0.004181382711976767, \"slope\": -0.055986613035202026, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 18.45830535888672, \"sigma_intercept_per_group\": 0.02748440019786358, \"sigma_obs\": 0.004135448019951582, \"slope\": -0.07843697816133499, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.666168212890625, \"sigma_intercept_per_group\": 0.02327948808670044, \"sigma_obs\": 0.004155345261096954, \"slope\": -0.07253752648830414, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 7.7592549324035645, \"sigma_intercept_per_group\": 0.028409739956259727, \"sigma_obs\": 0.00354367820546031, \"slope\": -0.02587258629500866, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": 4.496123790740967, \"sigma_intercept_per_group\": 0.027076762169599533, \"sigma_obs\": 0.003471170784905553, \"slope\": -0.015277793630957603, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 25.825439453125, \"sigma_intercept_per_group\": 0.021997418254613876, \"sigma_obs\": 0.004469236359000206, \"slope\": -0.06368249654769897, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 9.429516792297363, \"sigma_intercept_per_group\": 0.015785597264766693, \"sigma_obs\": 0.0035833511501550674, \"slope\": -0.10983148962259293, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 15.173460006713867, \"sigma_intercept_per_group\": 0.019354425370693207, \"sigma_obs\": 0.0038513559848070145, \"slope\": -0.1206052303314209, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 14.191303253173828, \"sigma_intercept_per_group\": 0.020259900018572807, \"sigma_obs\": 0.0035348618403077126, \"slope\": -0.09476853162050247, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 9.638189315795898, \"sigma_intercept_per_group\": 0.02288949117064476, \"sigma_obs\": 0.003726385300979018, \"slope\": -0.10472433269023895, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 25.84459114074707, \"sigma_intercept_per_group\": 0.011721521615982056, \"sigma_obs\": 0.0038357337471097708, \"slope\": 0.068968765437603, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 20.26111602783203, \"sigma_intercept_per_group\": 0.013428477570414543, \"sigma_obs\": 0.0036474287044256926, \"slope\": -0.044683150947093964, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 23.896913528442383, \"sigma_intercept_per_group\": 0.017145883291959763, \"sigma_obs\": 0.004085808992385864, \"slope\": -0.005923400167375803, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 11.58183479309082, \"sigma_intercept_per_group\": 0.02274119108915329, \"sigma_obs\": 0.003786948276683688, \"slope\": 0.08407970517873764, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 12.517780303955078, \"sigma_intercept_per_group\": 0.03857770562171936, \"sigma_obs\": 0.0042006997391581535, \"slope\": -0.024739909917116165, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 14.5899019241333, \"sigma_intercept_per_group\": 0.020520741119980812, \"sigma_obs\": 0.00397342536598444, \"slope\": -0.09213448315858841, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 15.004429817199707, \"sigma_intercept_per_group\": 0.0276782363653183, \"sigma_obs\": 0.003950426355004311, \"slope\": 0.006129947956651449, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 13.683221817016602, \"sigma_intercept_per_group\": 0.03339071199297905, \"sigma_obs\": 0.004093578085303307, \"slope\": -0.06475891917943954, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 10.980294227600098, \"sigma_intercept_per_group\": 0.03609205037355423, \"sigma_obs\": 0.003984956070780754, \"slope\": -0.05117488279938698, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 11.67459487915039, \"sigma_intercept_per_group\": 0.03257819637656212, \"sigma_obs\": 0.0037446748465299606, \"slope\": -0.054459426552057266, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 11.969382286071777, \"sigma_intercept_per_group\": 0.02830854244530201, \"sigma_obs\": 0.003690208774060011, \"slope\": -0.11995358765125275, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 15.152562141418457, \"sigma_intercept_per_group\": 0.023609116673469543, \"sigma_obs\": 0.0036327082198113203, \"slope\": -0.16097934544086456, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 25.24859619140625, \"sigma_intercept_per_group\": 0.01829933188855648, \"sigma_obs\": 0.0043555013835430145, \"slope\": -0.016816699877381325, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 12.496665000915527, \"sigma_intercept_per_group\": 0.035773903131484985, \"sigma_obs\": 0.0037844229955226183, \"slope\": -0.20636285841464996, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 8.310224533081055, \"sigma_intercept_per_group\": 0.029940932989120483, \"sigma_obs\": 0.003628823207691312, \"slope\": -0.16327165067195892, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 17.193164825439453, \"sigma_intercept_per_group\": 0.027690177783370018, \"sigma_obs\": 0.0037205261178314686, \"slope\": -0.1823575645685196, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 20.347694396972656, \"sigma_intercept_per_group\": 0.024939870461821556, \"sigma_obs\": 0.003652512561529875, \"slope\": -0.21694982051849365, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 21.697837829589844, \"sigma_intercept_per_group\": 0.019843757152557373, \"sigma_obs\": 0.0037271403707563877, \"slope\": -0.18288716673851013, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 22.731948852539062, \"sigma_intercept_per_group\": 0.022101033478975296, \"sigma_obs\": 0.0038737873546779156, \"slope\": -0.2144050896167755, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 21.007408142089844, \"sigma_intercept_per_group\": 0.02438249997794628, \"sigma_obs\": 0.004062800668179989, \"slope\": -0.22404225170612335, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 9.124610900878906, \"sigma_intercept_per_group\": 0.02882385440170765, \"sigma_obs\": 0.0037546500097960234, \"slope\": -0.10893178731203079, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 13.16147232055664, \"sigma_intercept_per_group\": 0.037364594638347626, \"sigma_obs\": 0.0037419190630316734, \"slope\": -0.1276782900094986, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 10.546119689941406, \"sigma_intercept_per_group\": 0.025619620457291603, \"sigma_obs\": 0.0033748953137546778, \"slope\": -0.16596098244190216, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 13.636390686035156, \"sigma_intercept_per_group\": 0.030528176575899124, \"sigma_obs\": 0.003404657356441021, \"slope\": -0.14792747795581818, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 13.954571723937988, \"sigma_intercept_per_group\": 0.020866628736257553, \"sigma_obs\": 0.0035093508195132017, \"slope\": -0.1387835443019867, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 14.490899085998535, \"sigma_intercept_per_group\": 0.02370751090347767, \"sigma_obs\": 0.0037405916955322027, \"slope\": -0.06144440174102783, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 18.079204559326172, \"sigma_intercept_per_group\": 0.025020189583301544, \"sigma_obs\": 0.003724867943674326, \"slope\": -0.07022619247436523, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 21.072519302368164, \"sigma_intercept_per_group\": 0.018208391964435577, \"sigma_obs\": 0.0038136299699544907, \"slope\": -0.14889943599700928, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 18.615982055664062, \"sigma_intercept_per_group\": 0.02383560873568058, \"sigma_obs\": 0.003845824860036373, \"slope\": -0.09729956835508347, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 21.985254287719727, \"sigma_intercept_per_group\": 0.021311461925506592, \"sigma_obs\": 0.004368526395410299, \"slope\": 0.011228587478399277, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 13.672605514526367, \"sigma_intercept_per_group\": 0.03566750884056091, \"sigma_obs\": 0.004203260410577059, \"slope\": -0.1259993016719818, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 17.065147399902344, \"sigma_intercept_per_group\": 0.012367756105959415, \"sigma_obs\": 0.0038218582049012184, \"slope\": 0.012463302351534367, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 13.569863319396973, \"sigma_intercept_per_group\": 0.031077200546860695, \"sigma_obs\": 0.003807653672993183, \"slope\": -0.09317614883184433, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 16.488840103149414, \"sigma_intercept_per_group\": 0.02601509913802147, \"sigma_obs\": 0.004337027668952942, \"slope\": 0.007903452031314373, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 11.695932388305664, \"sigma_intercept_per_group\": 0.02064860798418522, \"sigma_obs\": 0.003538568736985326, \"slope\": -0.09696491062641144, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 15.290154457092285, \"sigma_intercept_per_group\": 0.02949853613972664, \"sigma_obs\": 0.004041415173560381, \"slope\": 0.008231110870838165, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 5.839870929718018, \"sigma_intercept_per_group\": 0.045751169323921204, \"sigma_obs\": 0.004167898558080196, \"slope\": 0.051561057567596436, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 7.837277412414551, \"sigma_intercept_per_group\": 0.028544681146740913, \"sigma_obs\": 0.003409396391361952, \"slope\": -0.08134155720472336, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 8.59262752532959, \"sigma_intercept_per_group\": 0.045956455171108246, \"sigma_obs\": 0.0034735850058496, \"slope\": -0.05580933019518852, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 9.898056983947754, \"sigma_intercept_per_group\": 0.019840501248836517, \"sigma_obs\": 0.0038236500695347786, \"slope\": -0.04127027094364166, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 12.406968116760254, \"sigma_intercept_per_group\": 0.02194138988852501, \"sigma_obs\": 0.0038441820070147514, \"slope\": -0.07138677686452866, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 12.603928565979004, \"sigma_intercept_per_group\": 0.028178581967949867, \"sigma_obs\": 0.003869781270623207, \"slope\": -0.03731779009103775, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 13.812433242797852, \"sigma_intercept_per_group\": 0.03282785415649414, \"sigma_obs\": 0.003913742955774069, \"slope\": -0.05604518949985504, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 15.127762794494629, \"sigma_intercept_per_group\": 0.021336916834115982, \"sigma_obs\": 0.0036331377923488617, \"slope\": -0.029547518119215965, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 15.446651458740234, \"sigma_intercept_per_group\": 0.01966414786875248, \"sigma_obs\": 0.003600461408495903, \"slope\": -0.06570728868246078, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 18.309406280517578, \"sigma_intercept_per_group\": 0.025193631649017334, \"sigma_obs\": 0.0035236170515418053, \"slope\": -0.01091265119612217, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 13.770906448364258, \"sigma_intercept_per_group\": 0.018869923427700996, \"sigma_obs\": 0.00392458401620388, \"slope\": -0.07502394914627075, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 16.73085594177246, \"sigma_intercept_per_group\": 0.02828219346702099, \"sigma_obs\": 0.0036537512205541134, \"slope\": -0.05288789048790932, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 11.12020206451416, \"sigma_intercept_per_group\": 0.031309593468904495, \"sigma_obs\": 0.0040517402812838554, \"slope\": -0.08071941137313843, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 21.45343017578125, \"sigma_intercept_per_group\": 0.014436071738600731, \"sigma_obs\": 0.0038289905060082674, \"slope\": -0.06191151216626167, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 21.24761390686035, \"sigma_intercept_per_group\": 0.02198844775557518, \"sigma_obs\": 0.003870550775900483, \"slope\": -0.12467050552368164, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 11.261702537536621, \"sigma_intercept_per_group\": 0.01594000682234764, \"sigma_obs\": 0.004129118751734495, \"slope\": 0.026682967320084572, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 17.450197219848633, \"sigma_intercept_per_group\": 0.02940131165087223, \"sigma_obs\": 0.004235651344060898, \"slope\": -0.06351812928915024, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 19.803485870361328, \"sigma_intercept_per_group\": 0.022318309172987938, \"sigma_obs\": 0.003434739075601101, \"slope\": -0.07440034300088882, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 16.759645462036133, \"sigma_intercept_per_group\": 0.020669974386692047, \"sigma_obs\": 0.004173956345766783, \"slope\": -0.12736305594444275, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": 8.539742469787598, \"sigma_intercept_per_group\": 0.025706350803375244, \"sigma_obs\": 0.0034441070165485144, \"slope\": 0.025998571887612343, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 14.609037399291992, \"sigma_intercept_per_group\": 0.02242778241634369, \"sigma_obs\": 0.00382186914794147, \"slope\": -0.019005510956048965, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 15.45631217956543, \"sigma_intercept_per_group\": 0.01987844705581665, \"sigma_obs\": 0.003766962792724371, \"slope\": 0.010227945633232594, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 16.24106216430664, \"sigma_intercept_per_group\": 0.017757238820195198, \"sigma_obs\": 0.0037544243969023228, \"slope\": -0.05606347322463989, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 19.10081672668457, \"sigma_intercept_per_group\": 0.01826922595500946, \"sigma_obs\": 0.0038857534527778625, \"slope\": -0.10305102914571762, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 25.89117431640625, \"sigma_intercept_per_group\": 0.014704052358865738, \"sigma_obs\": 0.0040897480212152, \"slope\": -0.06409920752048492, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 8.132830619812012, \"sigma_intercept_per_group\": 0.033109527081251144, \"sigma_obs\": 0.004201536998152733, \"slope\": -0.20456400513648987, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 16.492578506469727, \"sigma_intercept_per_group\": 0.03266310691833496, \"sigma_obs\": 0.003976118750870228, \"slope\": -0.08417530357837677, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.496674537658691, \"sigma_intercept_per_group\": 0.018685059621930122, \"sigma_obs\": 0.004264213144779205, \"slope\": -0.057284075766801834, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 16.03705596923828, \"sigma_intercept_per_group\": 0.031922597438097, \"sigma_obs\": 0.004442037083208561, \"slope\": 0.02941078692674637, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 15.060057640075684, \"sigma_intercept_per_group\": 0.026408037170767784, \"sigma_obs\": 0.004428149200975895, \"slope\": 0.016186458989977837, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 12.80593204498291, \"sigma_intercept_per_group\": 0.03866364434361458, \"sigma_obs\": 0.0041431947611272335, \"slope\": -0.15650388598442078, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 16.18257713317871, \"sigma_intercept_per_group\": 0.02217864990234375, \"sigma_obs\": 0.0037803540471941233, \"slope\": 0.001550953951664269, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 18.272993087768555, \"sigma_intercept_per_group\": 0.02710249461233616, \"sigma_obs\": 0.004031510557979345, \"slope\": 0.016845157369971275, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 16.632896423339844, \"sigma_intercept_per_group\": 0.02507619373500347, \"sigma_obs\": 0.004354454576969147, \"slope\": 0.006311054807156324, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 19.36702537536621, \"sigma_intercept_per_group\": 0.022184692323207855, \"sigma_obs\": 0.0035511429887264967, \"slope\": -0.16474349796772003, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 13.933215141296387, \"sigma_intercept_per_group\": 0.022163979709148407, \"sigma_obs\": 0.004027615766972303, \"slope\": 0.08686059713363647, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 15.443680763244629, \"sigma_intercept_per_group\": 0.025649286806583405, \"sigma_obs\": 0.003537006676197052, \"slope\": -0.038136616349220276, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 14.594356536865234, \"sigma_intercept_per_group\": 0.025894612073898315, \"sigma_obs\": 0.003555211005732417, \"slope\": -0.04301964119076729, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 20.339641571044922, \"sigma_intercept_per_group\": 0.029181843623518944, \"sigma_obs\": 0.004372396040707827, \"slope\": -0.1404508352279663, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 18.267000198364258, \"sigma_intercept_per_group\": 0.019054612144827843, \"sigma_obs\": 0.0037782294675707817, \"slope\": -0.047685571014881134, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 15.717963218688965, \"sigma_intercept_per_group\": 0.023432210087776184, \"sigma_obs\": 0.0038111975882202387, \"slope\": -0.01867188699543476, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 20.670007705688477, \"sigma_intercept_per_group\": 0.015797140076756477, \"sigma_obs\": 0.0038177419919520617, \"slope\": -0.10116806626319885, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 8.44970703125, \"sigma_intercept_per_group\": 0.022414781153202057, \"sigma_obs\": 0.0036193495616316795, \"slope\": 0.0006300805835053325, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 17.63150405883789, \"sigma_intercept_per_group\": 0.02527356892824173, \"sigma_obs\": 0.004247661679983139, \"slope\": -0.016144366934895515, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 10.920976638793945, \"sigma_intercept_per_group\": 0.02711183950304985, \"sigma_obs\": 0.0037916949950158596, \"slope\": -0.0846024677157402, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 15.71737289428711, \"sigma_intercept_per_group\": 0.02744549699127674, \"sigma_obs\": 0.003822583705186844, \"slope\": 0.01729360781610012, \"chain\": 1, \"draw\": 160}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 17.56399917602539, \"sigma_intercept_per_group\": 0.021333210170269012, \"sigma_obs\": 0.0040526678785681725, \"slope\": -0.012071613222360611, \"chain\": 1, \"draw\": 161}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 15.631884574890137, \"sigma_intercept_per_group\": 0.01713913306593895, \"sigma_obs\": 0.004038084298372269, \"slope\": -0.1478000283241272, \"chain\": 1, \"draw\": 162}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 13.144031524658203, \"sigma_intercept_per_group\": 0.020699430257081985, \"sigma_obs\": 0.004301866982132196, \"slope\": -0.08031735569238663, \"chain\": 1, \"draw\": 163}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 13.277512550354004, \"sigma_intercept_per_group\": 0.021755453199148178, \"sigma_obs\": 0.004198925569653511, \"slope\": -0.044794946908950806, \"chain\": 1, \"draw\": 164}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 26.545345306396484, \"sigma_intercept_per_group\": 0.018710201606154442, \"sigma_obs\": 0.003922236151993275, \"slope\": -0.09289919584989548, \"chain\": 1, \"draw\": 165}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 21.471839904785156, \"sigma_intercept_per_group\": 0.022271018475294113, \"sigma_obs\": 0.004875507205724716, \"slope\": -0.08765967190265656, \"chain\": 1, \"draw\": 166}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 13.897507667541504, \"sigma_intercept_per_group\": 0.015213992446660995, \"sigma_obs\": 0.003615808207541704, \"slope\": -0.1144041121006012, \"chain\": 1, \"draw\": 167}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": -0.5908766984939575, \"sigma_intercept_per_group\": 0.02143259160220623, \"sigma_obs\": 0.0035877125337719917, \"slope\": -0.05699612572789192, \"chain\": 1, \"draw\": 168}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 28.159332275390625, \"sigma_intercept_per_group\": 0.014789368957281113, \"sigma_obs\": 0.004238128196448088, \"slope\": -0.048815079033374786, \"chain\": 1, \"draw\": 169}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 16.706207275390625, \"sigma_intercept_per_group\": 0.02272903174161911, \"sigma_obs\": 0.0033623133786022663, \"slope\": 0.018031584098935127, \"chain\": 1, \"draw\": 170}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 0.82951420545578, \"sigma_intercept_per_group\": 0.02935868687927723, \"sigma_obs\": 0.0038442297372967005, \"slope\": -0.0070158555172383785, \"chain\": 1, \"draw\": 171}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 10.602928161621094, \"sigma_intercept_per_group\": 0.044357433915138245, \"sigma_obs\": 0.0033096882980316877, \"slope\": 0.09555035084486008, \"chain\": 1, \"draw\": 172}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 10.141522407531738, \"sigma_intercept_per_group\": 0.04247916862368584, \"sigma_obs\": 0.003401275724172592, \"slope\": 0.0735011026263237, \"chain\": 1, \"draw\": 173}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 3.50913667678833, \"sigma_intercept_per_group\": 0.044105228036642075, \"sigma_obs\": 0.00355039956048131, \"slope\": 0.06943468749523163, \"chain\": 1, \"draw\": 174}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 8.680088996887207, \"sigma_intercept_per_group\": 0.050985343754291534, \"sigma_obs\": 0.0035983349662274122, \"slope\": 0.04184703156352043, \"chain\": 1, \"draw\": 175}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 18.196102142333984, \"sigma_intercept_per_group\": 0.02129681222140789, \"sigma_obs\": 0.003720004577189684, \"slope\": -0.09377849102020264, \"chain\": 1, \"draw\": 176}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 19.47500228881836, \"sigma_intercept_per_group\": 0.0237082839012146, \"sigma_obs\": 0.003656600834801793, \"slope\": -0.054708078503608704, \"chain\": 1, \"draw\": 177}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 14.016502380371094, \"sigma_intercept_per_group\": 0.024871904402971268, \"sigma_obs\": 0.004108318593353033, \"slope\": 0.007925109937787056, \"chain\": 1, \"draw\": 178}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 13.848589897155762, \"sigma_intercept_per_group\": 0.026997309178113937, \"sigma_obs\": 0.0040146480314433575, \"slope\": 0.0031293665524572134, \"chain\": 1, \"draw\": 179}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 9.475150108337402, \"sigma_intercept_per_group\": 0.021902963519096375, \"sigma_obs\": 0.0038559462409466505, \"slope\": -0.09677612781524658, \"chain\": 1, \"draw\": 180}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 20.669294357299805, \"sigma_intercept_per_group\": 0.021339640021324158, \"sigma_obs\": 0.004301368724554777, \"slope\": -0.05269527807831764, \"chain\": 1, \"draw\": 181}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 11.377640724182129, \"sigma_intercept_per_group\": 0.03127417713403702, \"sigma_obs\": 0.0038679013960063457, \"slope\": 0.0020127741154283285, \"chain\": 1, \"draw\": 182}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 25.147174835205078, \"sigma_intercept_per_group\": 0.028780559077858925, \"sigma_obs\": 0.00455885985866189, \"slope\": -0.12323874980211258, \"chain\": 1, \"draw\": 183}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 18.519697189331055, \"sigma_intercept_per_group\": 0.015613872557878494, \"sigma_obs\": 0.003772353520616889, \"slope\": 0.003017626702785492, \"chain\": 1, \"draw\": 184}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 17.4623966217041, \"sigma_intercept_per_group\": 0.012828466482460499, \"sigma_obs\": 0.003486870788037777, \"slope\": -0.00671220850199461, \"chain\": 1, \"draw\": 185}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 18.990398406982422, \"sigma_intercept_per_group\": 0.011578362435102463, \"sigma_obs\": 0.00404625479131937, \"slope\": -0.16260798275470734, \"chain\": 1, \"draw\": 186}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 16.30841636657715, \"sigma_intercept_per_group\": 0.02030067890882492, \"sigma_obs\": 0.003709173295646906, \"slope\": -0.04060513526201248, \"chain\": 1, \"draw\": 187}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 16.05609893798828, \"sigma_intercept_per_group\": 0.021605055779218674, \"sigma_obs\": 0.003877640701830387, \"slope\": -0.11274119466543198, \"chain\": 1, \"draw\": 188}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 16.094541549682617, \"sigma_intercept_per_group\": 0.020773490890860558, \"sigma_obs\": 0.0038448823615908623, \"slope\": -0.027238482609391212, \"chain\": 1, \"draw\": 189}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 11.074512481689453, \"sigma_intercept_per_group\": 0.025728853419423103, \"sigma_obs\": 0.003834865055978298, \"slope\": -0.01287584938108921, \"chain\": 1, \"draw\": 190}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 17.416553497314453, \"sigma_intercept_per_group\": 0.01771371066570282, \"sigma_obs\": 0.0036215318832546473, \"slope\": -0.1264183223247528, \"chain\": 1, \"draw\": 191}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 13.404699325561523, \"sigma_intercept_per_group\": 0.021941937506198883, \"sigma_obs\": 0.00395523477345705, \"slope\": 0.050610270351171494, \"chain\": 1, \"draw\": 192}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 17.420860290527344, \"sigma_intercept_per_group\": 0.030021507292985916, \"sigma_obs\": 0.003903088392689824, \"slope\": 0.014054903760552406, \"chain\": 1, \"draw\": 193}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 6.46450662612915, \"sigma_intercept_per_group\": 0.0287929680198431, \"sigma_obs\": 0.003783818567171693, \"slope\": -0.012268859893083572, \"chain\": 1, \"draw\": 194}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 13.829767227172852, \"sigma_intercept_per_group\": 0.018829982727766037, \"sigma_obs\": 0.004097567871212959, \"slope\": 0.03125123307108879, \"chain\": 1, \"draw\": 195}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 15.926284790039062, \"sigma_intercept_per_group\": 0.029161471873521805, \"sigma_obs\": 0.003788434900343418, \"slope\": -0.0010673088254407048, \"chain\": 1, \"draw\": 196}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 10.776860237121582, \"sigma_intercept_per_group\": 0.02204439789056778, \"sigma_obs\": 0.0036887521855533123, \"slope\": -0.09185497462749481, \"chain\": 1, \"draw\": 197}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 13.112374305725098, \"sigma_intercept_per_group\": 0.025609232485294342, \"sigma_obs\": 0.0036666507367044687, \"slope\": -0.04646673426032066, \"chain\": 1, \"draw\": 198}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 12.583026885986328, \"sigma_intercept_per_group\": 0.026393737643957138, \"sigma_obs\": 0.0039560007862746716, \"slope\": 0.00853246171027422, \"chain\": 1, \"draw\": 199}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 13.17716121673584, \"sigma_intercept_per_group\": 0.03693372383713722, \"sigma_obs\": 0.003973237704485655, \"slope\": -0.1824084371328354, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 12.183430671691895, \"sigma_intercept_per_group\": 0.03047395497560501, \"sigma_obs\": 0.00403497414663434, \"slope\": 0.09512017667293549, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 12.292304039001465, \"sigma_intercept_per_group\": 0.029791520908474922, \"sigma_obs\": 0.004140040837228298, \"slope\": 0.11165829002857208, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 13.008626937866211, \"sigma_intercept_per_group\": 0.026641855016350746, \"sigma_obs\": 0.0041254679672420025, \"slope\": 0.08219492435455322, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 9.87445068359375, \"sigma_intercept_per_group\": 0.02698078379034996, \"sigma_obs\": 0.0036891005001962185, \"slope\": 0.007112640887498856, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 7.39440393447876, \"sigma_intercept_per_group\": 0.0365755558013916, \"sigma_obs\": 0.0034265401773154736, \"slope\": -0.09570211172103882, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 15.499231338500977, \"sigma_intercept_per_group\": 0.024435382336378098, \"sigma_obs\": 0.0037295494694262743, \"slope\": -0.1218474805355072, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 14.488115310668945, \"sigma_intercept_per_group\": 0.023446012288331985, \"sigma_obs\": 0.003807508386671543, \"slope\": -0.007656001951545477, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 11.030312538146973, \"sigma_intercept_per_group\": 0.02391674369573593, \"sigma_obs\": 0.003822514321655035, \"slope\": -0.01943853311240673, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 23.756364822387695, \"sigma_intercept_per_group\": 0.017108839005231857, \"sigma_obs\": 0.0038082001265138388, \"slope\": -0.13911384344100952, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 7.638786315917969, \"sigma_intercept_per_group\": 0.02428957261145115, \"sigma_obs\": 0.003938715904951096, \"slope\": -0.055768631398677826, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 16.118080139160156, \"sigma_intercept_per_group\": 0.018547069281339645, \"sigma_obs\": 0.004452387802302837, \"slope\": 0.0634680688381195, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 17.147253036499023, \"sigma_intercept_per_group\": 0.031120412051677704, \"sigma_obs\": 0.003923085518181324, \"slope\": 0.036158688366413116, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 6.0814032554626465, \"sigma_intercept_per_group\": 0.013410842046141624, \"sigma_obs\": 0.004097376484423876, \"slope\": 0.0262808445841074, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 4.418337345123291, \"sigma_intercept_per_group\": 0.01814749836921692, \"sigma_obs\": 0.003569358726963401, \"slope\": -0.0733376294374466, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 5.519326686859131, \"sigma_intercept_per_group\": 0.02316119894385338, \"sigma_obs\": 0.004036236554384232, \"slope\": -0.07081339508295059, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 17.251338958740234, \"sigma_intercept_per_group\": 0.028441354632377625, \"sigma_obs\": 0.0038427654653787613, \"slope\": -0.10355879366397858, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 14.585026741027832, \"sigma_intercept_per_group\": 0.028804194182157516, \"sigma_obs\": 0.004007020965218544, \"slope\": -0.0774308443069458, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 19.976173400878906, \"sigma_intercept_per_group\": 0.020757529884576797, \"sigma_obs\": 0.0039736549369990826, \"slope\": -0.09621371328830719, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 26.469640731811523, \"sigma_intercept_per_group\": 0.015373590402305126, \"sigma_obs\": 0.0041052186861634254, \"slope\": -0.05818162485957146, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 24.156871795654297, \"sigma_intercept_per_group\": 0.015177697874605656, \"sigma_obs\": 0.0037636503111571074, \"slope\": -0.06736591458320618, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 10.960957527160645, \"sigma_intercept_per_group\": 0.017100967466831207, \"sigma_obs\": 0.003915443550795317, \"slope\": 0.02070636861026287, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 16.835216522216797, \"sigma_intercept_per_group\": 0.035187236964702606, \"sigma_obs\": 0.0042119198478758335, \"slope\": -0.005746287293732166, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 14.324230194091797, \"sigma_intercept_per_group\": 0.035162411630153656, \"sigma_obs\": 0.0036933175288140774, \"slope\": -0.12551997601985931, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 11.771883010864258, \"sigma_intercept_per_group\": 0.012483827769756317, \"sigma_obs\": 0.0036012392956763506, \"slope\": -0.18834224343299866, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 20.720022201538086, \"sigma_intercept_per_group\": 0.026224389672279358, \"sigma_obs\": 0.003803097177296877, \"slope\": -0.07581312954425812, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 11.685990333557129, \"sigma_intercept_per_group\": 0.032136425375938416, \"sigma_obs\": 0.003601448843255639, \"slope\": -0.12700000405311584, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 23.020856857299805, \"sigma_intercept_per_group\": 0.01824859157204628, \"sigma_obs\": 0.0041136350482702255, \"slope\": 0.10795908421278, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 24.082780838012695, \"sigma_intercept_per_group\": 0.01623510755598545, \"sigma_obs\": 0.004199255723506212, \"slope\": 0.10658622533082962, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 12.302596092224121, \"sigma_intercept_per_group\": 0.023967279121279716, \"sigma_obs\": 0.003624631091952324, \"slope\": -0.22059519588947296, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 12.028571128845215, \"sigma_intercept_per_group\": 0.02306697890162468, \"sigma_obs\": 0.003612468484789133, \"slope\": -0.17194311320781708, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 17.51373863220215, \"sigma_intercept_per_group\": 0.025448093190789223, \"sigma_obs\": 0.0037192152813076973, \"slope\": -0.14603333175182343, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 23.750335693359375, \"sigma_intercept_per_group\": 0.015389367006719112, \"sigma_obs\": 0.004024488385766745, \"slope\": -0.06292787939310074, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 11.594162940979004, \"sigma_intercept_per_group\": 0.02339203655719757, \"sigma_obs\": 0.0036471399944275618, \"slope\": -0.00417547021061182, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 13.162055015563965, \"sigma_intercept_per_group\": 0.013594195246696472, \"sigma_obs\": 0.003714452963322401, \"slope\": 0.022574981674551964, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 19.370502471923828, \"sigma_intercept_per_group\": 0.02037372626364231, \"sigma_obs\": 0.003992491867393255, \"slope\": -0.10009501129388809, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 20.404159545898438, \"sigma_intercept_per_group\": 0.020034579560160637, \"sigma_obs\": 0.0038412685971707106, \"slope\": -0.08820658177137375, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 24.160757064819336, \"sigma_intercept_per_group\": 0.015225299634039402, \"sigma_obs\": 0.004285207949578762, \"slope\": -0.1299940049648285, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 25.61117172241211, \"sigma_intercept_per_group\": 0.01925840601325035, \"sigma_obs\": 0.003966797608882189, \"slope\": -0.1003003790974617, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 10.116326332092285, \"sigma_intercept_per_group\": 0.03313928470015526, \"sigma_obs\": 0.004005897790193558, \"slope\": -0.04436126723885536, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 12.723892211914062, \"sigma_intercept_per_group\": 0.03319175913929939, \"sigma_obs\": 0.004038768354803324, \"slope\": -0.0368599109351635, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 13.48030948638916, \"sigma_intercept_per_group\": 0.041028596460819244, \"sigma_obs\": 0.0039721904322505, \"slope\": -0.04663801193237305, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 6.57923698425293, \"sigma_intercept_per_group\": 0.03924677520990372, \"sigma_obs\": 0.004030249547213316, \"slope\": -0.07524964958429337, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 6.33799409866333, \"sigma_intercept_per_group\": 0.04110728204250336, \"sigma_obs\": 0.003989604767411947, \"slope\": -0.08280286937952042, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 6.183966159820557, \"sigma_intercept_per_group\": 0.06577890366315842, \"sigma_obs\": 0.003587320912629366, \"slope\": -0.10411212593317032, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 10.709147453308105, \"sigma_intercept_per_group\": 0.03195951133966446, \"sigma_obs\": 0.004034210462123156, \"slope\": -0.14526420831680298, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 19.067062377929688, \"sigma_intercept_per_group\": 0.025403089821338654, \"sigma_obs\": 0.0040181358344852924, \"slope\": -0.08499740064144135, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 12.884732246398926, \"sigma_intercept_per_group\": 0.020505819469690323, \"sigma_obs\": 0.004025855101644993, \"slope\": -0.1145925298333168, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 15.931562423706055, \"sigma_intercept_per_group\": 0.02014259807765484, \"sigma_obs\": 0.0039741569198668, \"slope\": -0.06606557220220566, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 17.09235382080078, \"sigma_intercept_per_group\": 0.015831761062145233, \"sigma_obs\": 0.003842728678137064, \"slope\": -0.042212359607219696, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 11.240121841430664, \"sigma_intercept_per_group\": 0.019142059609293938, \"sigma_obs\": 0.004261084832251072, \"slope\": 0.011548626236617565, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 19.858034133911133, \"sigma_intercept_per_group\": 0.022003838792443275, \"sigma_obs\": 0.0038666361942887306, \"slope\": 0.10004404187202454, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 7.414374351501465, \"sigma_intercept_per_group\": 0.02560022845864296, \"sigma_obs\": 0.004155975300818682, \"slope\": 0.027032723650336266, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 16.484752655029297, \"sigma_intercept_per_group\": 0.02544526569545269, \"sigma_obs\": 0.0039049650076776743, \"slope\": 0.039617158472537994, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 20.513492584228516, \"sigma_intercept_per_group\": 0.016215888783335686, \"sigma_obs\": 0.004012623336166143, \"slope\": 0.007855422794818878, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 25.819652557373047, \"sigma_intercept_per_group\": 0.016792163252830505, \"sigma_obs\": 0.004223572555929422, \"slope\": 0.14790917932987213, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 6.873874187469482, \"sigma_intercept_per_group\": 0.01905755139887333, \"sigma_obs\": 0.003592745866626501, \"slope\": -0.059019360691308975, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 21.117996215820312, \"sigma_intercept_per_group\": 0.016480160877108574, \"sigma_obs\": 0.0037886733189225197, \"slope\": -0.08465376496315002, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.653610229492188, \"sigma_intercept_per_group\": 0.019966132938861847, \"sigma_obs\": 0.0038248992059379816, \"slope\": -0.11642725765705109, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 16.269926071166992, \"sigma_intercept_per_group\": 0.021656803786754608, \"sigma_obs\": 0.003942682407796383, \"slope\": -0.09261687099933624, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 11.553293228149414, \"sigma_intercept_per_group\": 0.022821424528956413, \"sigma_obs\": 0.004049976821988821, \"slope\": -0.10363283008337021, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 19.741308212280273, \"sigma_intercept_per_group\": 0.023141711950302124, \"sigma_obs\": 0.003932618536055088, \"slope\": 0.022833138704299927, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 15.257625579833984, \"sigma_intercept_per_group\": 0.026694290339946747, \"sigma_obs\": 0.0039934455417096615, \"slope\": 0.025730066001415253, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 16.774608612060547, \"sigma_intercept_per_group\": 0.01854456216096878, \"sigma_obs\": 0.0039028222672641277, \"slope\": 0.01887357048690319, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 17.481082916259766, \"sigma_intercept_per_group\": 0.02484436333179474, \"sigma_obs\": 0.003617029171437025, \"slope\": -0.16129851341247559, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 16.617170333862305, \"sigma_intercept_per_group\": 0.023128965869545937, \"sigma_obs\": 0.003420940600335598, \"slope\": -0.14216017723083496, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 14.35312557220459, \"sigma_intercept_per_group\": 0.02865028753876686, \"sigma_obs\": 0.0032419036142528057, \"slope\": -0.12116178870201111, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 15.628210067749023, \"sigma_intercept_per_group\": 0.02579426020383835, \"sigma_obs\": 0.003349846927449107, \"slope\": -0.09533970803022385, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 15.071962356567383, \"sigma_intercept_per_group\": 0.00880382303148508, \"sigma_obs\": 0.0040396424010396, \"slope\": 0.11279468983411789, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 19.420480728149414, \"sigma_intercept_per_group\": 0.018677843734622, \"sigma_obs\": 0.0035704567562788725, \"slope\": -0.10676943510770798, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 7.912126064300537, \"sigma_intercept_per_group\": 0.03708720579743385, \"sigma_obs\": 0.0034287255257368088, \"slope\": -0.12997201085090637, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 8.318370819091797, \"sigma_intercept_per_group\": 0.026792962104082108, \"sigma_obs\": 0.003598466981202364, \"slope\": -0.07526993006467819, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 17.200878143310547, \"sigma_intercept_per_group\": 0.03195926547050476, \"sigma_obs\": 0.0035010254941880703, \"slope\": -0.14151673018932343, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 13.686713218688965, \"sigma_intercept_per_group\": 0.025072511285543442, \"sigma_obs\": 0.00327779958024621, \"slope\": -0.14833737909793854, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 8.59303092956543, \"sigma_intercept_per_group\": 0.02965579740703106, \"sigma_obs\": 0.0041432916186749935, \"slope\": -0.0360986702144146, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 9.17374324798584, \"sigma_intercept_per_group\": 0.027645394206047058, \"sigma_obs\": 0.003708228934556246, \"slope\": -0.016106875613331795, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 10.62261962890625, \"sigma_intercept_per_group\": 0.019980501383543015, \"sigma_obs\": 0.0036049331538379192, \"slope\": 0.010228690691292286, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 15.723121643066406, \"sigma_intercept_per_group\": 0.0257529616355896, \"sigma_obs\": 0.0038695025723427534, \"slope\": -0.03463154286146164, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 17.688520431518555, \"sigma_intercept_per_group\": 0.029843509197235107, \"sigma_obs\": 0.0038707905914634466, \"slope\": -0.11584238708019257, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 13.892143249511719, \"sigma_intercept_per_group\": 0.02743297629058361, \"sigma_obs\": 0.003804484847933054, \"slope\": -0.10793740302324295, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 9.175664901733398, \"sigma_intercept_per_group\": 0.03162866458296776, \"sigma_obs\": 0.0036400253884494305, \"slope\": -0.06283335387706757, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 11.802810668945312, \"sigma_intercept_per_group\": 0.023435428738594055, \"sigma_obs\": 0.00396568002179265, \"slope\": -0.008883586153388023, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 12.7830228805542, \"sigma_intercept_per_group\": 0.02776724100112915, \"sigma_obs\": 0.003866383573040366, \"slope\": -0.06945513933897018, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 8.794185638427734, \"sigma_intercept_per_group\": 0.042739927768707275, \"sigma_obs\": 0.00385035527870059, \"slope\": -0.01600639708340168, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 8.081174850463867, \"sigma_intercept_per_group\": 0.033005695790052414, \"sigma_obs\": 0.003712268080562353, \"slope\": -0.0358070470392704, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 8.67324161529541, \"sigma_intercept_per_group\": 0.018497681245207787, \"sigma_obs\": 0.0036126181948930025, \"slope\": -0.05027533695101738, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 21.19099998474121, \"sigma_intercept_per_group\": 0.018422476947307587, \"sigma_obs\": 0.004221116192638874, \"slope\": -0.008574319072067738, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 18.360309600830078, \"sigma_intercept_per_group\": 0.02510129287838936, \"sigma_obs\": 0.004268635995686054, \"slope\": 0.053295597434043884, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 20.27689552307129, \"sigma_intercept_per_group\": 0.025652382522821426, \"sigma_obs\": 0.004280761815607548, \"slope\": -0.12360557913780212, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 16.30672264099121, \"sigma_intercept_per_group\": 0.012520162388682365, \"sigma_obs\": 0.0036169583909213543, \"slope\": -0.09904701262712479, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 19.684865951538086, \"sigma_intercept_per_group\": 0.011334850452840328, \"sigma_obs\": 0.0036920991260558367, \"slope\": -0.06005734205245972, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 12.935782432556152, \"sigma_intercept_per_group\": 0.025743739679455757, \"sigma_obs\": 0.0039942339062690735, \"slope\": -0.03913131356239319, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 18.973119735717773, \"sigma_intercept_per_group\": 0.0278635211288929, \"sigma_obs\": 0.003738034749403596, \"slope\": -0.13143043220043182, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 15.770606994628906, \"sigma_intercept_per_group\": 0.019624637439846992, \"sigma_obs\": 0.004118848126381636, \"slope\": 0.01560783851891756, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 10.92219066619873, \"sigma_intercept_per_group\": 0.02772507630288601, \"sigma_obs\": 0.0036236185114830732, \"slope\": 0.05049830302596092, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 25.003337860107422, \"sigma_intercept_per_group\": 0.018704421818256378, \"sigma_obs\": 0.004013000056147575, \"slope\": -0.1646987795829773, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 17.45308494567871, \"sigma_intercept_per_group\": 0.02029271423816681, \"sigma_obs\": 0.0037061255425214767, \"slope\": -0.11041276901960373, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 18.771381378173828, \"sigma_intercept_per_group\": 0.01603582128882408, \"sigma_obs\": 0.00368887884542346, \"slope\": -0.029595550149679184, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 21.723121643066406, \"sigma_intercept_per_group\": 0.014714517630636692, \"sigma_obs\": 0.003779559163376689, \"slope\": -0.046758465468883514, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 22.304752349853516, \"sigma_intercept_per_group\": 0.02558976411819458, \"sigma_obs\": 0.004298846703022718, \"slope\": -0.0011880629463121295, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 17.042757034301758, \"sigma_intercept_per_group\": 0.022563889622688293, \"sigma_obs\": 0.003826544852927327, \"slope\": -0.1176924929022789, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 13.568021774291992, \"sigma_intercept_per_group\": 0.020374925807118416, \"sigma_obs\": 0.0038830768316984177, \"slope\": 0.10472478717565536, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 16.045726776123047, \"sigma_intercept_per_group\": 0.030240049585700035, \"sigma_obs\": 0.003911558538675308, \"slope\": -0.033361222594976425, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 6.558498859405518, \"sigma_intercept_per_group\": 0.019842341542243958, \"sigma_obs\": 0.0038130879402160645, \"slope\": -0.10018996894359589, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": 2.920226812362671, \"sigma_intercept_per_group\": 0.023752573877573013, \"sigma_obs\": 0.003726399503648281, \"slope\": -0.07410614937543869, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": 4.57790470123291, \"sigma_intercept_per_group\": 0.024030717089772224, \"sigma_obs\": 0.003768355119973421, \"slope\": -0.08407002687454224, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 13.81795597076416, \"sigma_intercept_per_group\": 0.018867336213588715, \"sigma_obs\": 0.0037144033703953028, \"slope\": -0.13883139193058014, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 16.82986831665039, \"sigma_intercept_per_group\": 0.01747920550405979, \"sigma_obs\": 0.003720533102750778, \"slope\": -0.11618194729089737, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 9.12286376953125, \"sigma_intercept_per_group\": 0.034790437668561935, \"sigma_obs\": 0.0038631511852145195, \"slope\": 0.04207279533147812, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 20.42230224609375, \"sigma_intercept_per_group\": 0.01938435435295105, \"sigma_obs\": 0.004015116952359676, \"slope\": -0.035144202411174774, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 9.435833930969238, \"sigma_intercept_per_group\": 0.021513212472200394, \"sigma_obs\": 0.0036668535321950912, \"slope\": -0.08137902617454529, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 14.229713439941406, \"sigma_intercept_per_group\": 0.026428494602441788, \"sigma_obs\": 0.004123086575418711, \"slope\": -0.019304899498820305, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 13.02092456817627, \"sigma_intercept_per_group\": 0.03969613462686539, \"sigma_obs\": 0.004286119714379311, \"slope\": -0.054739490151405334, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 6.804050445556641, \"sigma_intercept_per_group\": 0.03920299932360649, \"sigma_obs\": 0.0030044519808143377, \"slope\": -0.06828231364488602, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 21.39185905456543, \"sigma_intercept_per_group\": 0.028337810188531876, \"sigma_obs\": 0.004374179057776928, \"slope\": -0.019043756648898125, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 20.924564361572266, \"sigma_intercept_per_group\": 0.02399461530148983, \"sigma_obs\": 0.004276785533875227, \"slope\": -0.015359468758106232, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 13.669327735900879, \"sigma_intercept_per_group\": 0.028089677914977074, \"sigma_obs\": 0.003827533917501569, \"slope\": -0.055729661136865616, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 15.341469764709473, \"sigma_intercept_per_group\": 0.028866900131106377, \"sigma_obs\": 0.004065294750034809, \"slope\": -0.05053899809718132, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 14.811396598815918, \"sigma_intercept_per_group\": 0.02101169526576996, \"sigma_obs\": 0.0033594670239835978, \"slope\": -0.07499421387910843, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 13.37186050415039, \"sigma_intercept_per_group\": 0.018800999969244003, \"sigma_obs\": 0.003583513433113694, \"slope\": -0.031698551028966904, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 13.160274505615234, \"sigma_intercept_per_group\": 0.02938317507505417, \"sigma_obs\": 0.003722685854882002, \"slope\": 0.08428796380758286, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 17.292184829711914, \"sigma_intercept_per_group\": 0.013917003758251667, \"sigma_obs\": 0.0034331753849983215, \"slope\": -0.10817209631204605, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 9.087478637695312, \"sigma_intercept_per_group\": 0.024819515645503998, \"sigma_obs\": 0.003644959768280387, \"slope\": 0.013987289741635323, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 9.294193267822266, \"sigma_intercept_per_group\": 0.024105561897158623, \"sigma_obs\": 0.0035991622135043144, \"slope\": 0.05240938812494278, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 16.291385650634766, \"sigma_intercept_per_group\": 0.013574044220149517, \"sigma_obs\": 0.0037869068328291178, \"slope\": -0.07887815684080124, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 18.788066864013672, \"sigma_intercept_per_group\": 0.01669347658753395, \"sigma_obs\": 0.0034595890901982784, \"slope\": -0.04186954349279404, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 24.74397850036621, \"sigma_intercept_per_group\": 0.01541996095329523, \"sigma_obs\": 0.0034497217275202274, \"slope\": -0.013944994658231735, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 24.978044509887695, \"sigma_intercept_per_group\": 0.015549544245004654, \"sigma_obs\": 0.003715468104928732, \"slope\": -0.07365527004003525, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 13.595277786254883, \"sigma_intercept_per_group\": 0.021518075838685036, \"sigma_obs\": 0.003803619649261236, \"slope\": 0.045899033546447754, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": 7.117865562438965, \"sigma_intercept_per_group\": 0.021004406735301018, \"sigma_obs\": 0.003736826591193676, \"slope\": 0.12902823090553284, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 18.24338150024414, \"sigma_intercept_per_group\": 0.02066941186785698, \"sigma_obs\": 0.003508147783577442, \"slope\": -0.11170295625925064, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 11.835806846618652, \"sigma_intercept_per_group\": 0.01844676397740841, \"sigma_obs\": 0.003532858332619071, \"slope\": 0.06131095439195633, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 21.751070022583008, \"sigma_intercept_per_group\": 0.020879235118627548, \"sigma_obs\": 0.004322160966694355, \"slope\": -0.0026529869064688683, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 16.37372398376465, \"sigma_intercept_per_group\": 0.02068150043487549, \"sigma_obs\": 0.003873966634273529, \"slope\": -0.035774506628513336, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 13.493744850158691, \"sigma_intercept_per_group\": 0.02396460995078087, \"sigma_obs\": 0.0038730893284082413, \"slope\": -0.06635000556707382, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 10.889129638671875, \"sigma_intercept_per_group\": 0.03163256123661995, \"sigma_obs\": 0.003678990760818124, \"slope\": -0.02229558676481247, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 11.428343772888184, \"sigma_intercept_per_group\": 0.03157050907611847, \"sigma_obs\": 0.003711791941896081, \"slope\": -0.017087003216147423, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 15.753670692443848, \"sigma_intercept_per_group\": 0.022118259221315384, \"sigma_obs\": 0.0038808223325759172, \"slope\": -0.026235954836010933, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 11.861520767211914, \"sigma_intercept_per_group\": 0.02875044383108616, \"sigma_obs\": 0.004220188595354557, \"slope\": 0.021380355581641197, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 10.741400718688965, \"sigma_intercept_per_group\": 0.03398916870355606, \"sigma_obs\": 0.0035665056202560663, \"slope\": -0.019819099456071854, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 6.687492847442627, \"sigma_intercept_per_group\": 0.027817554771900177, \"sigma_obs\": 0.0039457594975829124, \"slope\": -0.030621301382780075, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 19.403400421142578, \"sigma_intercept_per_group\": 0.01852985844016075, \"sigma_obs\": 0.0037066203076392412, \"slope\": -0.1509842574596405, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 11.143238067626953, \"sigma_intercept_per_group\": 0.0251423642039299, \"sigma_obs\": 0.003655478125438094, \"slope\": -0.059230756014585495, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 11.890541076660156, \"sigma_intercept_per_group\": 0.03647521883249283, \"sigma_obs\": 0.0034939327742904425, \"slope\": -0.07422930747270584, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 7.249098300933838, \"sigma_intercept_per_group\": 0.02970397286117077, \"sigma_obs\": 0.0032754121348261833, \"slope\": -0.13035732507705688, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 11.532354354858398, \"sigma_intercept_per_group\": 0.03882187232375145, \"sigma_obs\": 0.003720989217981696, \"slope\": -0.031113743782043457, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 6.0603203773498535, \"sigma_intercept_per_group\": 0.04260978475213051, \"sigma_obs\": 0.003647049656137824, \"slope\": -0.1448286920785904, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 6.061037063598633, \"sigma_intercept_per_group\": 0.042765989899635315, \"sigma_obs\": 0.003621108829975128, \"slope\": -0.1160290464758873, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 24.33364486694336, \"sigma_intercept_per_group\": 0.020805252715945244, \"sigma_obs\": 0.004039397928863764, \"slope\": -0.09427723288536072, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 5.215124130249023, \"sigma_intercept_per_group\": 0.029843075200915337, \"sigma_obs\": 0.0036353247705847025, \"slope\": 0.030288081616163254, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 14.011539459228516, \"sigma_intercept_per_group\": 0.03258681669831276, \"sigma_obs\": 0.0041891662403941154, \"slope\": -0.1572052389383316, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 10.9918212890625, \"sigma_intercept_per_group\": 0.020676549524068832, \"sigma_obs\": 0.003468635957688093, \"slope\": 0.05734783783555031, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 5.993073463439941, \"sigma_intercept_per_group\": 0.031519923359155655, \"sigma_obs\": 0.003597765229642391, \"slope\": 0.07412470132112503, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 19.851247787475586, \"sigma_intercept_per_group\": 0.014024845324456692, \"sigma_obs\": 0.0038224051240831614, \"slope\": -0.08921027183532715, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 15.393874168395996, \"sigma_intercept_per_group\": 0.03064781241118908, \"sigma_obs\": 0.003876163624227047, \"slope\": -0.034231048077344894, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 23.580076217651367, \"sigma_intercept_per_group\": 0.012710468843579292, \"sigma_obs\": 0.0036317105405032635, \"slope\": -0.022579310461878777, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 13.872029304504395, \"sigma_intercept_per_group\": 0.0185816902667284, \"sigma_obs\": 0.003746609203517437, \"slope\": -0.11028225719928741, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 14.308918952941895, \"sigma_intercept_per_group\": 0.028718963265419006, \"sigma_obs\": 0.0036467593163251877, \"slope\": -0.06508808583021164, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 21.67643165588379, \"sigma_intercept_per_group\": 0.01632065884768963, \"sigma_obs\": 0.004028779454529285, \"slope\": -0.02686937339603901, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 22.459579467773438, \"sigma_intercept_per_group\": 0.01787838712334633, \"sigma_obs\": 0.0039911651983857155, \"slope\": -0.024262232705950737, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 19.75680160522461, \"sigma_intercept_per_group\": 0.016528820618987083, \"sigma_obs\": 0.003799216588959098, \"slope\": -0.020315440371632576, \"chain\": 2, \"draw\": 160}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 5.56783390045166, \"sigma_intercept_per_group\": 0.011265551671385765, \"sigma_obs\": 0.003569004824385047, \"slope\": -0.061211083084344864, \"chain\": 2, \"draw\": 161}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 11.483259201049805, \"sigma_intercept_per_group\": 0.024660028517246246, \"sigma_obs\": 0.004088925197720528, \"slope\": 0.044608984142541885, \"chain\": 2, \"draw\": 162}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 15.238454818725586, \"sigma_intercept_per_group\": 0.03638046607375145, \"sigma_obs\": 0.0039014918729662895, \"slope\": -0.017039045691490173, \"chain\": 2, \"draw\": 163}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 14.790675163269043, \"sigma_intercept_per_group\": 0.019581466913223267, \"sigma_obs\": 0.004092498682439327, \"slope\": 0.11352530121803284, \"chain\": 2, \"draw\": 164}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 12.165291786193848, \"sigma_intercept_per_group\": 0.03291818127036095, \"sigma_obs\": 0.0040192510932683945, \"slope\": 0.042796652764081955, \"chain\": 2, \"draw\": 165}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 10.815678596496582, \"sigma_intercept_per_group\": 0.03128783404827118, \"sigma_obs\": 0.003833696711808443, \"slope\": -0.17351360619068146, \"chain\": 2, \"draw\": 166}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 10.019996643066406, \"sigma_intercept_per_group\": 0.03806672617793083, \"sigma_obs\": 0.003998609259724617, \"slope\": 0.014722789637744427, \"chain\": 2, \"draw\": 167}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 5.516522407531738, \"sigma_intercept_per_group\": 0.030213911086320877, \"sigma_obs\": 0.0039520543068647385, \"slope\": 0.06287272274494171, \"chain\": 2, \"draw\": 168}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 12.517433166503906, \"sigma_intercept_per_group\": 0.028103208169341087, \"sigma_obs\": 0.003823263570666313, \"slope\": -0.018373548984527588, \"chain\": 2, \"draw\": 169}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 10.818495750427246, \"sigma_intercept_per_group\": 0.030756382271647453, \"sigma_obs\": 0.003685292089357972, \"slope\": -0.01367238350212574, \"chain\": 2, \"draw\": 170}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 10.850357055664062, \"sigma_intercept_per_group\": 0.03847891464829445, \"sigma_obs\": 0.0037713968195021152, \"slope\": -0.10135984420776367, \"chain\": 2, \"draw\": 171}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 14.615951538085938, \"sigma_intercept_per_group\": 0.01985078863799572, \"sigma_obs\": 0.0035827327519655228, \"slope\": -0.10071585327386856, \"chain\": 2, \"draw\": 172}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 9.351394653320312, \"sigma_intercept_per_group\": 0.031576741486787796, \"sigma_obs\": 0.003990632016211748, \"slope\": 0.00317865377292037, \"chain\": 2, \"draw\": 173}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 8.159896850585938, \"sigma_intercept_per_group\": 0.0198106337338686, \"sigma_obs\": 0.0036995941773056984, \"slope\": 0.014233957976102829, \"chain\": 2, \"draw\": 174}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 17.647300720214844, \"sigma_intercept_per_group\": 0.027216382324695587, \"sigma_obs\": 0.0034775424282997847, \"slope\": -0.12325873225927353, \"chain\": 2, \"draw\": 175}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 13.664539337158203, \"sigma_intercept_per_group\": 0.0203691516071558, \"sigma_obs\": 0.0038946850690990686, \"slope\": 0.034780312329530716, \"chain\": 2, \"draw\": 176}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 22.53031349182129, \"sigma_intercept_per_group\": 0.022229749709367752, \"sigma_obs\": 0.003979563247412443, \"slope\": 0.01134731899946928, \"chain\": 2, \"draw\": 177}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 10.700955390930176, \"sigma_intercept_per_group\": 0.020197058096528053, \"sigma_obs\": 0.0036870744079351425, \"slope\": -0.08379533141851425, \"chain\": 2, \"draw\": 178}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 17.17133331298828, \"sigma_intercept_per_group\": 0.019779527559876442, \"sigma_obs\": 0.003767212387174368, \"slope\": 0.03274213522672653, \"chain\": 2, \"draw\": 179}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 12.540842056274414, \"sigma_intercept_per_group\": 0.020980726927518845, \"sigma_obs\": 0.003874877467751503, \"slope\": -0.03493115305900574, \"chain\": 2, \"draw\": 180}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 12.389744758605957, \"sigma_intercept_per_group\": 0.028748175129294395, \"sigma_obs\": 0.003951645456254482, \"slope\": 0.006182301789522171, \"chain\": 2, \"draw\": 181}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 11.04886245727539, \"sigma_intercept_per_group\": 0.02924446016550064, \"sigma_obs\": 0.0040565188974142075, \"slope\": 0.03554994612932205, \"chain\": 2, \"draw\": 182}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 4.52402400970459, \"sigma_intercept_per_group\": 0.033291831612586975, \"sigma_obs\": 0.003864249447360635, \"slope\": 0.026557771489024162, \"chain\": 2, \"draw\": 183}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 18.89640998840332, \"sigma_intercept_per_group\": 0.027641847729682922, \"sigma_obs\": 0.0037142883520573378, \"slope\": -0.14446255564689636, \"chain\": 2, \"draw\": 184}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 13.747883796691895, \"sigma_intercept_per_group\": 0.02443082630634308, \"sigma_obs\": 0.003831039648503065, \"slope\": -0.09978994727134705, \"chain\": 2, \"draw\": 185}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 12.70249080657959, \"sigma_intercept_per_group\": 0.037272267043590546, \"sigma_obs\": 0.003799194935709238, \"slope\": -0.0007416580920107663, \"chain\": 2, \"draw\": 186}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 8.409334182739258, \"sigma_intercept_per_group\": 0.022437863051891327, \"sigma_obs\": 0.003612769767642021, \"slope\": -0.01947115920484066, \"chain\": 2, \"draw\": 187}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 9.726239204406738, \"sigma_intercept_per_group\": 0.020800437778234482, \"sigma_obs\": 0.003562783356755972, \"slope\": -0.030699823051691055, \"chain\": 2, \"draw\": 188}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 9.808334350585938, \"sigma_intercept_per_group\": 0.03866278752684593, \"sigma_obs\": 0.0035302769392728806, \"slope\": -0.1481168121099472, \"chain\": 2, \"draw\": 189}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 31.160778045654297, \"sigma_intercept_per_group\": 0.017514046281576157, \"sigma_obs\": 0.004471666645258665, \"slope\": -0.011726020835340023, \"chain\": 2, \"draw\": 190}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 29.8184871673584, \"sigma_intercept_per_group\": 0.018708784133195877, \"sigma_obs\": 0.00429440476000309, \"slope\": -0.029848646372556686, \"chain\": 2, \"draw\": 191}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 7.917346000671387, \"sigma_intercept_per_group\": 0.03184760734438896, \"sigma_obs\": 0.0035885493271052837, \"slope\": -0.09243862330913544, \"chain\": 2, \"draw\": 192}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 12.945796012878418, \"sigma_intercept_per_group\": 0.030283281579613686, \"sigma_obs\": 0.0034034820273518562, \"slope\": -0.07004670053720474, \"chain\": 2, \"draw\": 193}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 13.998117446899414, \"sigma_intercept_per_group\": 0.03219619765877724, \"sigma_obs\": 0.0033185521606355906, \"slope\": -0.06051865592598915, \"chain\": 2, \"draw\": 194}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 11.877211570739746, \"sigma_intercept_per_group\": 0.019535958766937256, \"sigma_obs\": 0.0036375822965055704, \"slope\": -0.12140952050685883, \"chain\": 2, \"draw\": 195}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 12.26883602142334, \"sigma_intercept_per_group\": 0.024212835356593132, \"sigma_obs\": 0.0037574637681245804, \"slope\": -0.10064633190631866, \"chain\": 2, \"draw\": 196}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 18.880287170410156, \"sigma_intercept_per_group\": 0.012798869051039219, \"sigma_obs\": 0.0037516793236136436, \"slope\": -0.040569182485342026, \"chain\": 2, \"draw\": 197}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 12.08651351928711, \"sigma_intercept_per_group\": 0.018812764436006546, \"sigma_obs\": 0.004006052389740944, \"slope\": 0.07347340881824493, \"chain\": 2, \"draw\": 198}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 14.589849472045898, \"sigma_intercept_per_group\": 0.01822022907435894, \"sigma_obs\": 0.0038751140236854553, \"slope\": 0.06711599975824356, \"chain\": 2, \"draw\": 199}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 12.361600875854492, \"sigma_intercept_per_group\": 0.028140360489487648, \"sigma_obs\": 0.003802408231422305, \"slope\": -0.06610117107629776, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 15.873409271240234, \"sigma_intercept_per_group\": 0.02438879758119583, \"sigma_obs\": 0.0038534943014383316, \"slope\": -0.03855449706315994, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 21.214204788208008, \"sigma_intercept_per_group\": 0.02423245459794998, \"sigma_obs\": 0.004106416832655668, \"slope\": -0.02689395286142826, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 12.905478477478027, \"sigma_intercept_per_group\": 0.019509395584464073, \"sigma_obs\": 0.0036211656406521797, \"slope\": -0.0690508633852005, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 17.24794578552246, \"sigma_intercept_per_group\": 0.0258649755269289, \"sigma_obs\": 0.003876810660585761, \"slope\": -0.038770001381635666, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.25282096862793, \"sigma_intercept_per_group\": 0.01585693471133709, \"sigma_obs\": 0.003601778531447053, \"slope\": -0.09872516989707947, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 13.291997909545898, \"sigma_intercept_per_group\": 0.02542750909924507, \"sigma_obs\": 0.003889707615599036, \"slope\": -0.03997063264250755, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 17.83209228515625, \"sigma_intercept_per_group\": 0.026538146659731865, \"sigma_obs\": 0.004291446879506111, \"slope\": -0.14026090502738953, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 19.071096420288086, \"sigma_intercept_per_group\": 0.02615036629140377, \"sigma_obs\": 0.0042946054600179195, \"slope\": -0.16470679640769958, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 17.345232009887695, \"sigma_intercept_per_group\": 0.01755606196820736, \"sigma_obs\": 0.004100110847502947, \"slope\": -0.11843694746494293, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 17.717384338378906, \"sigma_intercept_per_group\": 0.019544731825590134, \"sigma_obs\": 0.004033248405903578, \"slope\": -0.10979137569665909, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 25.048236846923828, \"sigma_intercept_per_group\": 0.02552846632897854, \"sigma_obs\": 0.0040498473681509495, \"slope\": -0.15652649104595184, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 23.29694175720215, \"sigma_intercept_per_group\": 0.01431004237383604, \"sigma_obs\": 0.0036902017891407013, \"slope\": -0.08790673315525055, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 12.877184867858887, \"sigma_intercept_per_group\": 0.03176470473408699, \"sigma_obs\": 0.003978643100708723, \"slope\": -0.11524411290884018, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 9.31839370727539, \"sigma_intercept_per_group\": 0.029966965317726135, \"sigma_obs\": 0.0041527836583554745, \"slope\": -0.09948115795850754, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 21.66673469543457, \"sigma_intercept_per_group\": 0.024123452603816986, \"sigma_obs\": 0.003980083391070366, \"slope\": -0.04191594943404198, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.701443672180176, \"sigma_intercept_per_group\": 0.026971066370606422, \"sigma_obs\": 0.0038452399894595146, \"slope\": -0.08159507811069489, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 18.831811904907227, \"sigma_intercept_per_group\": 0.022433675825595856, \"sigma_obs\": 0.004269920289516449, \"slope\": -0.06706073880195618, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 18.908916473388672, \"sigma_intercept_per_group\": 0.02957177720963955, \"sigma_obs\": 0.0039044751320034266, \"slope\": -0.045775093138217926, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 17.89937400817871, \"sigma_intercept_per_group\": 0.018849266692996025, \"sigma_obs\": 0.003939352463930845, \"slope\": -0.05701761320233345, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 21.997528076171875, \"sigma_intercept_per_group\": 0.025249013677239418, \"sigma_obs\": 0.00374880013987422, \"slope\": -0.12955628335475922, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 14.531216621398926, \"sigma_intercept_per_group\": 0.017817527055740356, \"sigma_obs\": 0.004224112257361412, \"slope\": 0.05942375957965851, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 18.261371612548828, \"sigma_intercept_per_group\": 0.019314993172883987, \"sigma_obs\": 0.0035055309999734163, \"slope\": -0.10967536270618439, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 19.651763916015625, \"sigma_intercept_per_group\": 0.017176201567053795, \"sigma_obs\": 0.0037499014288187027, \"slope\": -0.08279482275247574, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 13.705538749694824, \"sigma_intercept_per_group\": 0.021192345768213272, \"sigma_obs\": 0.0037588346749544144, \"slope\": -0.03079596348106861, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 13.087117195129395, \"sigma_intercept_per_group\": 0.013638755306601524, \"sigma_obs\": 0.003318667644634843, \"slope\": -0.12518052756786346, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 22.154348373413086, \"sigma_intercept_per_group\": 0.02485818602144718, \"sigma_obs\": 0.00385349802672863, \"slope\": -0.021847620606422424, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 13.888901710510254, \"sigma_intercept_per_group\": 0.017795374616980553, \"sigma_obs\": 0.0037767146714031696, \"slope\": -0.03772188350558281, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 9.088028907775879, \"sigma_intercept_per_group\": 0.02427511103451252, \"sigma_obs\": 0.004116283729672432, \"slope\": -0.06256233900785446, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 19.481632232666016, \"sigma_intercept_per_group\": 0.03067091852426529, \"sigma_obs\": 0.003953658509999514, \"slope\": -0.0654958114027977, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 10.91746711730957, \"sigma_intercept_per_group\": 0.037415917962789536, \"sigma_obs\": 0.0037153104785829782, \"slope\": -0.00382295623421669, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 7.374217510223389, \"sigma_intercept_per_group\": 0.024352336302399635, \"sigma_obs\": 0.003835232462733984, \"slope\": -0.001272236229851842, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 11.956836700439453, \"sigma_intercept_per_group\": 0.035832881927490234, \"sigma_obs\": 0.003640893381088972, \"slope\": 0.034146975725889206, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 2.781386613845825, \"sigma_intercept_per_group\": 0.01681738719344139, \"sigma_obs\": 0.0034366771578788757, \"slope\": 0.0032114319037646055, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 3.7223868370056152, \"sigma_intercept_per_group\": 0.01613026298582554, \"sigma_obs\": 0.003447904484346509, \"slope\": -0.006294365972280502, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 3.0832388401031494, \"sigma_intercept_per_group\": 0.012857813388109207, \"sigma_obs\": 0.0037017399445176125, \"slope\": -0.019165148958563805, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 23.65922737121582, \"sigma_intercept_per_group\": 0.016735024750232697, \"sigma_obs\": 0.00406917929649353, \"slope\": 0.06742765009403229, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 9.382811546325684, \"sigma_intercept_per_group\": 0.02988557703793049, \"sigma_obs\": 0.003532164264470339, \"slope\": -0.09812019020318985, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 11.864426612854004, \"sigma_intercept_per_group\": 0.0309078861027956, \"sigma_obs\": 0.003509325673803687, \"slope\": -0.09588472545146942, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 11.226802825927734, \"sigma_intercept_per_group\": 0.0403156541287899, \"sigma_obs\": 0.0034810099750757217, \"slope\": -0.03503093868494034, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 640, \"mu_intercept_per_group\": 8.674186706542969, \"sigma_intercept_per_group\": 0.035502973943948746, \"sigma_obs\": 0.0036702840588986874, \"slope\": -0.09022203087806702, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 641, \"mu_intercept_per_group\": 16.190616607666016, \"sigma_intercept_per_group\": 0.02275421842932701, \"sigma_obs\": 0.003520113881677389, \"slope\": -0.08662882447242737, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 642, \"mu_intercept_per_group\": 17.45064353942871, \"sigma_intercept_per_group\": 0.019260531291365623, \"sigma_obs\": 0.0036970125511288643, \"slope\": -0.1146557480096817, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 643, \"mu_intercept_per_group\": 15.384599685668945, \"sigma_intercept_per_group\": 0.014457282610237598, \"sigma_obs\": 0.0035999687388539314, \"slope\": -0.024444833397865295, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 644, \"mu_intercept_per_group\": 22.263885498046875, \"sigma_intercept_per_group\": 0.01816783845424652, \"sigma_obs\": 0.0037953562568873167, \"slope\": 0.002262124326080084, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 645, \"mu_intercept_per_group\": 14.38448429107666, \"sigma_intercept_per_group\": 0.013349777087569237, \"sigma_obs\": 0.004031170159578323, \"slope\": 0.07591721415519714, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 646, \"mu_intercept_per_group\": 12.92251205444336, \"sigma_intercept_per_group\": 0.02184978313744068, \"sigma_obs\": 0.003968381322920322, \"slope\": 0.10549578815698624, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 647, \"mu_intercept_per_group\": 18.15878677368164, \"sigma_intercept_per_group\": 0.019266236573457718, \"sigma_obs\": 0.0033728021662682295, \"slope\": -0.08620139956474304, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 648, \"mu_intercept_per_group\": 14.70617389678955, \"sigma_intercept_per_group\": 0.026883292943239212, \"sigma_obs\": 0.004106463864445686, \"slope\": 0.006462950259447098, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 649, \"mu_intercept_per_group\": 22.05457305908203, \"sigma_intercept_per_group\": 0.02226286381483078, \"sigma_obs\": 0.0038672059308737516, \"slope\": -0.12130913138389587, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 650, \"mu_intercept_per_group\": 22.58128547668457, \"sigma_intercept_per_group\": 0.020046841353178024, \"sigma_obs\": 0.004219965077936649, \"slope\": -0.10437450557947159, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 651, \"mu_intercept_per_group\": 25.674026489257812, \"sigma_intercept_per_group\": 0.018917130306363106, \"sigma_obs\": 0.004126339685171843, \"slope\": -0.011999617330729961, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 652, \"mu_intercept_per_group\": 8.978728294372559, \"sigma_intercept_per_group\": 0.025372007861733437, \"sigma_obs\": 0.003432460129261017, \"slope\": -0.11534163355827332, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 653, \"mu_intercept_per_group\": 10.751423835754395, \"sigma_intercept_per_group\": 0.033424947410821915, \"sigma_obs\": 0.004173813387751579, \"slope\": 0.0433078296482563, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 654, \"mu_intercept_per_group\": 13.34144115447998, \"sigma_intercept_per_group\": 0.028060801327228546, \"sigma_obs\": 0.00415931548923254, \"slope\": 0.06948907673358917, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 655, \"mu_intercept_per_group\": 9.934840202331543, \"sigma_intercept_per_group\": 0.03447360545396805, \"sigma_obs\": 0.003976365085691214, \"slope\": 0.03906016796827316, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 656, \"mu_intercept_per_group\": 15.661323547363281, \"sigma_intercept_per_group\": 0.01866043172776699, \"sigma_obs\": 0.004105535801500082, \"slope\": 0.02416158840060234, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 657, \"mu_intercept_per_group\": 9.637003898620605, \"sigma_intercept_per_group\": 0.023069169372320175, \"sigma_obs\": 0.0033738494385033846, \"slope\": -0.060159120708703995, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 658, \"mu_intercept_per_group\": 14.594827651977539, \"sigma_intercept_per_group\": 0.029455266892910004, \"sigma_obs\": 0.003498203819617629, \"slope\": -0.03153162822127342, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 659, \"mu_intercept_per_group\": 6.157402515411377, \"sigma_intercept_per_group\": 0.027937917038798332, \"sigma_obs\": 0.0037048107478767633, \"slope\": -0.04951483756303787, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 660, \"mu_intercept_per_group\": 13.135860443115234, \"sigma_intercept_per_group\": 0.04723101109266281, \"sigma_obs\": 0.0039037547539919615, \"slope\": -0.05837622657418251, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 661, \"mu_intercept_per_group\": 6.211585998535156, \"sigma_intercept_per_group\": 0.03497209772467613, \"sigma_obs\": 0.0042889900505542755, \"slope\": -0.02914448454976082, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 662, \"mu_intercept_per_group\": 5.903736591339111, \"sigma_intercept_per_group\": 0.03472550958395004, \"sigma_obs\": 0.004272794350981712, \"slope\": -0.034427326172590256, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 663, \"mu_intercept_per_group\": 9.192914962768555, \"sigma_intercept_per_group\": 0.043704066425561905, \"sigma_obs\": 0.004251537844538689, \"slope\": -0.010331572964787483, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 664, \"mu_intercept_per_group\": 7.700229167938232, \"sigma_intercept_per_group\": 0.05709071084856987, \"sigma_obs\": 0.004052750766277313, \"slope\": -0.08225273340940475, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 665, \"mu_intercept_per_group\": 7.764811992645264, \"sigma_intercept_per_group\": 0.05243897810578346, \"sigma_obs\": 0.004015900194644928, \"slope\": -0.07664567977190018, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 666, \"mu_intercept_per_group\": 5.66094446182251, \"sigma_intercept_per_group\": 0.08038558065891266, \"sigma_obs\": 0.003963982220739126, \"slope\": -0.03977704048156738, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 667, \"mu_intercept_per_group\": 13.06719970703125, \"sigma_intercept_per_group\": 0.03697153553366661, \"sigma_obs\": 0.003980990499258041, \"slope\": -0.1078299954533577, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 668, \"mu_intercept_per_group\": 6.539645195007324, \"sigma_intercept_per_group\": 0.04769882187247276, \"sigma_obs\": 0.003818526631221175, \"slope\": -0.14013083279132843, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 669, \"mu_intercept_per_group\": 5.911694526672363, \"sigma_intercept_per_group\": 0.05026666074991226, \"sigma_obs\": 0.0035322150215506554, \"slope\": -0.18063002824783325, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 670, \"mu_intercept_per_group\": 5.423000335693359, \"sigma_intercept_per_group\": 0.05280081555247307, \"sigma_obs\": 0.0035263062454760075, \"slope\": -0.17878873646259308, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 671, \"mu_intercept_per_group\": 7.182383060455322, \"sigma_intercept_per_group\": 0.047252312302589417, \"sigma_obs\": 0.003534996882081032, \"slope\": -0.14658232033252716, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 672, \"mu_intercept_per_group\": 5.392993927001953, \"sigma_intercept_per_group\": 0.0553717203438282, \"sigma_obs\": 0.003409245051443577, \"slope\": 0.011672078631818295, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 673, \"mu_intercept_per_group\": 6.480783462524414, \"sigma_intercept_per_group\": 0.04954388737678528, \"sigma_obs\": 0.004026616923511028, \"slope\": 0.051514413207769394, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 674, \"mu_intercept_per_group\": 19.481538772583008, \"sigma_intercept_per_group\": 0.018777163699269295, \"sigma_obs\": 0.0035460260696709156, \"slope\": -0.11650729924440384, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 675, \"mu_intercept_per_group\": 18.6069278717041, \"sigma_intercept_per_group\": 0.020195815712213516, \"sigma_obs\": 0.004089668393135071, \"slope\": -0.10754993557929993, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 676, \"mu_intercept_per_group\": 16.114030838012695, \"sigma_intercept_per_group\": 0.026498276740312576, \"sigma_obs\": 0.003957449458539486, \"slope\": -0.028877155855298042, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 677, \"mu_intercept_per_group\": 14.707819938659668, \"sigma_intercept_per_group\": 0.020827636122703552, \"sigma_obs\": 0.00397288566455245, \"slope\": 0.0028392006643116474, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 678, \"mu_intercept_per_group\": 25.326744079589844, \"sigma_intercept_per_group\": 0.019758429378271103, \"sigma_obs\": 0.003813344519585371, \"slope\": -0.11186791211366653, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 679, \"mu_intercept_per_group\": 9.535052299499512, \"sigma_intercept_per_group\": 0.018397076055407524, \"sigma_obs\": 0.003878561547026038, \"slope\": 0.06076241657137871, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 680, \"mu_intercept_per_group\": 25.46215057373047, \"sigma_intercept_per_group\": 0.018504230305552483, \"sigma_obs\": 0.0037077092565596104, \"slope\": -0.23311389982700348, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 681, \"mu_intercept_per_group\": 19.97104263305664, \"sigma_intercept_per_group\": 0.013701697811484337, \"sigma_obs\": 0.003859205637127161, \"slope\": 0.04149157926440239, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 682, \"mu_intercept_per_group\": 11.657902717590332, \"sigma_intercept_per_group\": 0.019747983664274216, \"sigma_obs\": 0.003430241486057639, \"slope\": -0.16108916699886322, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 683, \"mu_intercept_per_group\": 14.88440990447998, \"sigma_intercept_per_group\": 0.024916816502809525, \"sigma_obs\": 0.003648380283266306, \"slope\": 0.12746287882328033, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 684, \"mu_intercept_per_group\": 17.92243766784668, \"sigma_intercept_per_group\": 0.018913080915808678, \"sigma_obs\": 0.003158043837174773, \"slope\": -0.14778973162174225, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 685, \"mu_intercept_per_group\": 11.799944877624512, \"sigma_intercept_per_group\": 0.04231458902359009, \"sigma_obs\": 0.004380516242235899, \"slope\": 0.04971249774098396, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 686, \"mu_intercept_per_group\": 13.77824878692627, \"sigma_intercept_per_group\": 0.025149893015623093, \"sigma_obs\": 0.004134595859795809, \"slope\": 0.06891936808824539, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 687, \"mu_intercept_per_group\": 16.862123489379883, \"sigma_intercept_per_group\": 0.01668529585003853, \"sigma_obs\": 0.0038621309213340282, \"slope\": -0.12236056476831436, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 688, \"mu_intercept_per_group\": 21.043201446533203, \"sigma_intercept_per_group\": 0.021605752408504486, \"sigma_obs\": 0.0036680568009614944, \"slope\": 0.022116664797067642, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 689, \"mu_intercept_per_group\": 14.0904541015625, \"sigma_intercept_per_group\": 0.02881951816380024, \"sigma_obs\": 0.0037648025900125504, \"slope\": -0.05156036093831062, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 690, \"mu_intercept_per_group\": 13.16589641571045, \"sigma_intercept_per_group\": 0.02711445838212967, \"sigma_obs\": 0.003880951786413789, \"slope\": -0.14943327009677887, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 691, \"mu_intercept_per_group\": 15.718064308166504, \"sigma_intercept_per_group\": 0.031584467738866806, \"sigma_obs\": 0.004130300134420395, \"slope\": -0.1014295369386673, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 692, \"mu_intercept_per_group\": 12.983793258666992, \"sigma_intercept_per_group\": 0.02732446789741516, \"sigma_obs\": 0.004198220558464527, \"slope\": -0.10054661333560944, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 693, \"mu_intercept_per_group\": 13.79709243774414, \"sigma_intercept_per_group\": 0.025222022086381912, \"sigma_obs\": 0.0038021253421902657, \"slope\": -0.13668866455554962, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 694, \"mu_intercept_per_group\": 23.137889862060547, \"sigma_intercept_per_group\": 0.020892923697829247, \"sigma_obs\": 0.0037316717207431793, \"slope\": -0.028216330334544182, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 695, \"mu_intercept_per_group\": 20.642452239990234, \"sigma_intercept_per_group\": 0.017592884600162506, \"sigma_obs\": 0.0036080717109143734, \"slope\": -0.027459748089313507, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 696, \"mu_intercept_per_group\": 14.487262725830078, \"sigma_intercept_per_group\": 0.026176128536462784, \"sigma_obs\": 0.004586083348840475, \"slope\": -0.13876113295555115, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 697, \"mu_intercept_per_group\": 20.703872680664062, \"sigma_intercept_per_group\": 0.030635014176368713, \"sigma_obs\": 0.004069051239639521, \"slope\": -0.14127327501773834, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 698, \"mu_intercept_per_group\": 13.301088333129883, \"sigma_intercept_per_group\": 0.023626599460840225, \"sigma_obs\": 0.0037402831949293613, \"slope\": 0.009581081569194794, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 699, \"mu_intercept_per_group\": 17.459379196166992, \"sigma_intercept_per_group\": 0.024053428322076797, \"sigma_obs\": 0.003720719600096345, \"slope\": 0.0022541936486959457, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 700, \"mu_intercept_per_group\": 11.1731595993042, \"sigma_intercept_per_group\": 0.023839348927140236, \"sigma_obs\": 0.0035347321536391973, \"slope\": 0.047945138067007065, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 701, \"mu_intercept_per_group\": 5.787180423736572, \"sigma_intercept_per_group\": 0.0395207516849041, \"sigma_obs\": 0.003969969227910042, \"slope\": 0.06591223180294037, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 702, \"mu_intercept_per_group\": 15.916841506958008, \"sigma_intercept_per_group\": 0.029831046238541603, \"sigma_obs\": 0.003851477289572358, \"slope\": -0.028714695945382118, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 703, \"mu_intercept_per_group\": 11.182661056518555, \"sigma_intercept_per_group\": 0.039130330085754395, \"sigma_obs\": 0.004351438954472542, \"slope\": -0.0993882343173027, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 704, \"mu_intercept_per_group\": 12.30872917175293, \"sigma_intercept_per_group\": 0.03510668873786926, \"sigma_obs\": 0.004357711877673864, \"slope\": -0.10534989088773727, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 705, \"mu_intercept_per_group\": 14.733028411865234, \"sigma_intercept_per_group\": 0.04114241898059845, \"sigma_obs\": 0.004092846065759659, \"slope\": -0.11275974661111832, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 706, \"mu_intercept_per_group\": 11.085291862487793, \"sigma_intercept_per_group\": 0.02500595897436142, \"sigma_obs\": 0.003951319493353367, \"slope\": -0.010520581156015396, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 707, \"mu_intercept_per_group\": 10.009393692016602, \"sigma_intercept_per_group\": 0.02642872929573059, \"sigma_obs\": 0.0036245740484446287, \"slope\": -0.06488559395074844, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 708, \"mu_intercept_per_group\": 21.047557830810547, \"sigma_intercept_per_group\": 0.022146252915263176, \"sigma_obs\": 0.004375292919576168, \"slope\": -0.054816633462905884, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 709, \"mu_intercept_per_group\": 13.709709167480469, \"sigma_intercept_per_group\": 0.021033743396401405, \"sigma_obs\": 0.004109727218747139, \"slope\": 0.04888681694865227, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 710, \"mu_intercept_per_group\": 27.250457763671875, \"sigma_intercept_per_group\": 0.014531767927110195, \"sigma_obs\": 0.0038531855680048466, \"slope\": -0.0047751362435519695, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 711, \"mu_intercept_per_group\": 16.232269287109375, \"sigma_intercept_per_group\": 0.01994231343269348, \"sigma_obs\": 0.003656958229839802, \"slope\": 0.043657414615154266, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 712, \"mu_intercept_per_group\": 22.10015869140625, \"sigma_intercept_per_group\": 0.018315857276320457, \"sigma_obs\": 0.004184548277407885, \"slope\": -0.07070712000131607, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 713, \"mu_intercept_per_group\": 19.563312530517578, \"sigma_intercept_per_group\": 0.01587674207985401, \"sigma_obs\": 0.003818599507212639, \"slope\": -0.0626598447561264, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 714, \"mu_intercept_per_group\": 10.874320983886719, \"sigma_intercept_per_group\": 0.027334893122315407, \"sigma_obs\": 0.003906119614839554, \"slope\": 0.030476592481136322, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 715, \"mu_intercept_per_group\": 16.939542770385742, \"sigma_intercept_per_group\": 0.025238264352083206, \"sigma_obs\": 0.0036136331036686897, \"slope\": 0.005764187313616276, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 716, \"mu_intercept_per_group\": 9.165738105773926, \"sigma_intercept_per_group\": 0.030369503423571587, \"sigma_obs\": 0.0038077388890087605, \"slope\": -0.08639807254076004, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 717, \"mu_intercept_per_group\": 23.449752807617188, \"sigma_intercept_per_group\": 0.021296868100762367, \"sigma_obs\": 0.004192679189145565, \"slope\": -0.054105717688798904, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 718, \"mu_intercept_per_group\": 10.348953247070312, \"sigma_intercept_per_group\": 0.028212623670697212, \"sigma_obs\": 0.004128644242882729, \"slope\": 0.0012751291505992413, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 719, \"mu_intercept_per_group\": 17.176015853881836, \"sigma_intercept_per_group\": 0.030276458710432053, \"sigma_obs\": 0.004147992469370365, \"slope\": -0.10196651518344879, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 720, \"mu_intercept_per_group\": 18.605892181396484, \"sigma_intercept_per_group\": 0.0191794503480196, \"sigma_obs\": 0.00378240249119699, \"slope\": 0.07049952447414398, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 721, \"mu_intercept_per_group\": 9.769885063171387, \"sigma_intercept_per_group\": 0.029057785868644714, \"sigma_obs\": 0.003958772402256727, \"slope\": -0.15052850544452667, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 722, \"mu_intercept_per_group\": 13.469815254211426, \"sigma_intercept_per_group\": 0.046017471700906754, \"sigma_obs\": 0.004324278328567743, \"slope\": -0.11089521646499634, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 723, \"mu_intercept_per_group\": 11.415139198303223, \"sigma_intercept_per_group\": 0.01999712362885475, \"sigma_obs\": 0.004523123614490032, \"slope\": -0.05274149402976036, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 724, \"mu_intercept_per_group\": 13.979793548583984, \"sigma_intercept_per_group\": 0.019952824339270592, \"sigma_obs\": 0.004440448712557554, \"slope\": -0.06607487797737122, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 725, \"mu_intercept_per_group\": 19.267465591430664, \"sigma_intercept_per_group\": 0.01767335832118988, \"sigma_obs\": 0.0042856535874307156, \"slope\": -0.04493775591254234, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 726, \"mu_intercept_per_group\": 20.462257385253906, \"sigma_intercept_per_group\": 0.01978462003171444, \"sigma_obs\": 0.004189937375485897, \"slope\": -0.01966213993728161, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 727, \"mu_intercept_per_group\": 23.001943588256836, \"sigma_intercept_per_group\": 0.020531389862298965, \"sigma_obs\": 0.0038578829262405634, \"slope\": 0.04013422131538391, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 728, \"mu_intercept_per_group\": 11.338105201721191, \"sigma_intercept_per_group\": 0.027729909867048264, \"sigma_obs\": 0.0038015961181372404, \"slope\": -0.12831425666809082, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 729, \"mu_intercept_per_group\": 12.099005699157715, \"sigma_intercept_per_group\": 0.024451706558465958, \"sigma_obs\": 0.0035713252145797014, \"slope\": -0.12480844557285309, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 730, \"mu_intercept_per_group\": 15.84872817993164, \"sigma_intercept_per_group\": 0.020426902920007706, \"sigma_obs\": 0.0035228861961513758, \"slope\": -0.08788477629423141, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 731, \"mu_intercept_per_group\": 16.548860549926758, \"sigma_intercept_per_group\": 0.022467922419309616, \"sigma_obs\": 0.0037170310970395803, \"slope\": -0.045063089579343796, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 732, \"mu_intercept_per_group\": 6.52247953414917, \"sigma_intercept_per_group\": 0.02807536907494068, \"sigma_obs\": 0.003736466635018587, \"slope\": -0.003394198836758733, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 733, \"mu_intercept_per_group\": 8.723944664001465, \"sigma_intercept_per_group\": 0.0266726091504097, \"sigma_obs\": 0.003595964517444372, \"slope\": -0.022969549521803856, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 734, \"mu_intercept_per_group\": 5.630246639251709, \"sigma_intercept_per_group\": 0.03203155845403671, \"sigma_obs\": 0.003351920982822776, \"slope\": -0.035009920597076416, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 735, \"mu_intercept_per_group\": 6.492148399353027, \"sigma_intercept_per_group\": 0.053549665957689285, \"sigma_obs\": 0.003274596994742751, \"slope\": -0.1044263243675232, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 736, \"mu_intercept_per_group\": 7.641847610473633, \"sigma_intercept_per_group\": 0.06616637855768204, \"sigma_obs\": 0.0037172455340623856, \"slope\": -0.1103043258190155, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 737, \"mu_intercept_per_group\": 12.60428524017334, \"sigma_intercept_per_group\": 0.024870919063687325, \"sigma_obs\": 0.0036014881916344166, \"slope\": -0.11947675794363022, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 738, \"mu_intercept_per_group\": 14.527270317077637, \"sigma_intercept_per_group\": 0.03121117688715458, \"sigma_obs\": 0.003907289355993271, \"slope\": -0.12906132638454437, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 739, \"mu_intercept_per_group\": 11.978426933288574, \"sigma_intercept_per_group\": 0.036967676132917404, \"sigma_obs\": 0.003833954455330968, \"slope\": -0.09505493938922882, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 740, \"mu_intercept_per_group\": 9.171082496643066, \"sigma_intercept_per_group\": 0.0471370667219162, \"sigma_obs\": 0.0033090286888182163, \"slope\": -0.10825354605913162, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 741, \"mu_intercept_per_group\": 5.227231502532959, \"sigma_intercept_per_group\": 0.03577052429318428, \"sigma_obs\": 0.0033383516129106283, \"slope\": -0.02263212949037552, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 742, \"mu_intercept_per_group\": 6.56898307800293, \"sigma_intercept_per_group\": 0.029294228181242943, \"sigma_obs\": 0.003534243442118168, \"slope\": -0.019459795206785202, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 743, \"mu_intercept_per_group\": 13.468836784362793, \"sigma_intercept_per_group\": 0.02446342073380947, \"sigma_obs\": 0.0035231264773756266, \"slope\": 0.020618421956896782, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 744, \"mu_intercept_per_group\": 12.235457420349121, \"sigma_intercept_per_group\": 0.030427346006035805, \"sigma_obs\": 0.003798222169280052, \"slope\": -0.06322171539068222, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 745, \"mu_intercept_per_group\": 21.074886322021484, \"sigma_intercept_per_group\": 0.028864862397313118, \"sigma_obs\": 0.0040960051119327545, \"slope\": -0.06334464251995087, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 746, \"mu_intercept_per_group\": 12.707307815551758, \"sigma_intercept_per_group\": 0.02044355496764183, \"sigma_obs\": 0.0038156616501510143, \"slope\": -0.09123990684747696, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 747, \"mu_intercept_per_group\": 19.724002838134766, \"sigma_intercept_per_group\": 0.021899882704019547, \"sigma_obs\": 0.004018060863018036, \"slope\": -0.07992665469646454, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 748, \"mu_intercept_per_group\": 10.818511962890625, \"sigma_intercept_per_group\": 0.017468156293034554, \"sigma_obs\": 0.003556182375177741, \"slope\": 0.0014184970641508698, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 749, \"mu_intercept_per_group\": 12.668169021606445, \"sigma_intercept_per_group\": 0.01964138075709343, \"sigma_obs\": 0.003698668209835887, \"slope\": -0.04129771515727043, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 750, \"mu_intercept_per_group\": 18.132343292236328, \"sigma_intercept_per_group\": 0.015415417961776257, \"sigma_obs\": 0.0034464364871382713, \"slope\": -0.1480836123228073, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 751, \"mu_intercept_per_group\": 11.968131065368652, \"sigma_intercept_per_group\": 0.017758280038833618, \"sigma_obs\": 0.0038311018142849207, \"slope\": 0.04504188522696495, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 752, \"mu_intercept_per_group\": 12.030715942382812, \"sigma_intercept_per_group\": 0.02552945166826248, \"sigma_obs\": 0.0034479324240237474, \"slope\": -0.015908317640423775, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 753, \"mu_intercept_per_group\": 9.83479118347168, \"sigma_intercept_per_group\": 0.026856468990445137, \"sigma_obs\": 0.0038677463307976723, \"slope\": -0.006477858871221542, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 754, \"mu_intercept_per_group\": 12.98498249053955, \"sigma_intercept_per_group\": 0.03935275971889496, \"sigma_obs\": 0.0036802731920033693, \"slope\": -0.03772147744894028, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 755, \"mu_intercept_per_group\": 9.834077835083008, \"sigma_intercept_per_group\": 0.02313833124935627, \"sigma_obs\": 0.003882430726662278, \"slope\": -0.031097926199436188, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 756, \"mu_intercept_per_group\": 22.65818977355957, \"sigma_intercept_per_group\": 0.01839509792625904, \"sigma_obs\": 0.003994125407189131, \"slope\": -0.043712981045246124, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 757, \"mu_intercept_per_group\": 20.503870010375977, \"sigma_intercept_per_group\": 0.023347333073616028, \"sigma_obs\": 0.003977717366069555, \"slope\": -0.07382366061210632, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 758, \"mu_intercept_per_group\": 8.79287338256836, \"sigma_intercept_per_group\": 0.02287294901907444, \"sigma_obs\": 0.003667054697871208, \"slope\": -0.10345937311649323, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 759, \"mu_intercept_per_group\": 15.273025512695312, \"sigma_intercept_per_group\": 0.020697377622127533, \"sigma_obs\": 0.0033749660942703485, \"slope\": -0.22140510380268097, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 760, \"mu_intercept_per_group\": 16.883426666259766, \"sigma_intercept_per_group\": 0.021664990112185478, \"sigma_obs\": 0.0040430594235658646, \"slope\": 0.02376951277256012, \"chain\": 3, \"draw\": 160}, {\"mouse\": 7, \"draws\": 761, \"mu_intercept_per_group\": 10.907695770263672, \"sigma_intercept_per_group\": 0.03899649903178215, \"sigma_obs\": 0.003585653379559517, \"slope\": -0.14120975136756897, \"chain\": 3, \"draw\": 161}, {\"mouse\": 7, \"draws\": 762, \"mu_intercept_per_group\": 20.716094970703125, \"sigma_intercept_per_group\": 0.018235500901937485, \"sigma_obs\": 0.0043016765266656876, \"slope\": 0.0456329770386219, \"chain\": 3, \"draw\": 162}, {\"mouse\": 7, \"draws\": 763, \"mu_intercept_per_group\": 17.105226516723633, \"sigma_intercept_per_group\": 0.018048705533146858, \"sigma_obs\": 0.0038391994312405586, \"slope\": -0.051057491451501846, \"chain\": 3, \"draw\": 163}, {\"mouse\": 7, \"draws\": 764, \"mu_intercept_per_group\": 14.853615760803223, \"sigma_intercept_per_group\": 0.024355053901672363, \"sigma_obs\": 0.003980436362326145, \"slope\": -0.06930292397737503, \"chain\": 3, \"draw\": 164}, {\"mouse\": 7, \"draws\": 765, \"mu_intercept_per_group\": 18.904415130615234, \"sigma_intercept_per_group\": 0.019287284463644028, \"sigma_obs\": 0.0034100222401320934, \"slope\": -0.1471555233001709, \"chain\": 3, \"draw\": 165}, {\"mouse\": 7, \"draws\": 766, \"mu_intercept_per_group\": 18.57416534423828, \"sigma_intercept_per_group\": 0.018714582547545433, \"sigma_obs\": 0.003635912435129285, \"slope\": -0.10363640636205673, \"chain\": 3, \"draw\": 166}, {\"mouse\": 7, \"draws\": 767, \"mu_intercept_per_group\": 12.665432929992676, \"sigma_intercept_per_group\": 0.019967438653111458, \"sigma_obs\": 0.003596111899241805, \"slope\": 0.02778019569814205, \"chain\": 3, \"draw\": 167}, {\"mouse\": 7, \"draws\": 768, \"mu_intercept_per_group\": 10.950264930725098, \"sigma_intercept_per_group\": 0.021058350801467896, \"sigma_obs\": 0.003717272076755762, \"slope\": -0.007540809456259012, \"chain\": 3, \"draw\": 168}, {\"mouse\": 7, \"draws\": 769, \"mu_intercept_per_group\": 30.12200355529785, \"sigma_intercept_per_group\": 0.01494961604475975, \"sigma_obs\": 0.0038236884865909815, \"slope\": -0.029754867777228355, \"chain\": 3, \"draw\": 169}, {\"mouse\": 7, \"draws\": 770, \"mu_intercept_per_group\": 12.146805763244629, \"sigma_intercept_per_group\": 0.02187524549663067, \"sigma_obs\": 0.004175608977675438, \"slope\": -0.09609630703926086, \"chain\": 3, \"draw\": 170}, {\"mouse\": 7, \"draws\": 771, \"mu_intercept_per_group\": 17.048494338989258, \"sigma_intercept_per_group\": 0.017946965992450714, \"sigma_obs\": 0.004288452211767435, \"slope\": -0.05896240472793579, \"chain\": 3, \"draw\": 171}, {\"mouse\": 7, \"draws\": 772, \"mu_intercept_per_group\": 13.561958312988281, \"sigma_intercept_per_group\": 0.019367478787899017, \"sigma_obs\": 0.0037592845037579536, \"slope\": -0.07931350916624069, \"chain\": 3, \"draw\": 172}, {\"mouse\": 7, \"draws\": 773, \"mu_intercept_per_group\": 19.975175857543945, \"sigma_intercept_per_group\": 0.016925526782870293, \"sigma_obs\": 0.0035284003242850304, \"slope\": 0.033204637467861176, \"chain\": 3, \"draw\": 173}, {\"mouse\": 7, \"draws\": 774, \"mu_intercept_per_group\": 7.67903995513916, \"sigma_intercept_per_group\": 0.02132849395275116, \"sigma_obs\": 0.003714463673532009, \"slope\": 0.004246294032782316, \"chain\": 3, \"draw\": 174}, {\"mouse\": 7, \"draws\": 775, \"mu_intercept_per_group\": 24.072181701660156, \"sigma_intercept_per_group\": 0.02033775858581066, \"sigma_obs\": 0.003508510999381542, \"slope\": -0.03395059332251549, \"chain\": 3, \"draw\": 175}, {\"mouse\": 7, \"draws\": 776, \"mu_intercept_per_group\": 10.724080085754395, \"sigma_intercept_per_group\": 0.01190205104649067, \"sigma_obs\": 0.003927657846361399, \"slope\": 0.027522984892129898, \"chain\": 3, \"draw\": 176}, {\"mouse\": 7, \"draws\": 777, \"mu_intercept_per_group\": 20.498632431030273, \"sigma_intercept_per_group\": 0.018605314195156097, \"sigma_obs\": 0.0035914697218686342, \"slope\": -0.0067428345791995525, \"chain\": 3, \"draw\": 177}, {\"mouse\": 7, \"draws\": 778, \"mu_intercept_per_group\": 20.128538131713867, \"sigma_intercept_per_group\": 0.01640230417251587, \"sigma_obs\": 0.0036268390249460936, \"slope\": -0.0029500587843358517, \"chain\": 3, \"draw\": 178}, {\"mouse\": 7, \"draws\": 779, \"mu_intercept_per_group\": 15.536770820617676, \"sigma_intercept_per_group\": 0.016244670376181602, \"sigma_obs\": 0.003908174578100443, \"slope\": -0.028380515053868294, \"chain\": 3, \"draw\": 179}, {\"mouse\": 7, \"draws\": 780, \"mu_intercept_per_group\": 17.826305389404297, \"sigma_intercept_per_group\": 0.024103514850139618, \"sigma_obs\": 0.0038101617246866226, \"slope\": -0.20060719549655914, \"chain\": 3, \"draw\": 180}, {\"mouse\": 7, \"draws\": 781, \"mu_intercept_per_group\": 16.1995792388916, \"sigma_intercept_per_group\": 0.024155009537935257, \"sigma_obs\": 0.004278211388736963, \"slope\": -0.02646697498857975, \"chain\": 3, \"draw\": 181}, {\"mouse\": 7, \"draws\": 782, \"mu_intercept_per_group\": 16.054126739501953, \"sigma_intercept_per_group\": 0.020719125866889954, \"sigma_obs\": 0.004003976471722126, \"slope\": -0.09513265639543533, \"chain\": 3, \"draw\": 182}, {\"mouse\": 7, \"draws\": 783, \"mu_intercept_per_group\": 7.618954658508301, \"sigma_intercept_per_group\": 0.03524177521467209, \"sigma_obs\": 0.0037530141416937113, \"slope\": 0.1161617711186409, \"chain\": 3, \"draw\": 183}, {\"mouse\": 7, \"draws\": 784, \"mu_intercept_per_group\": 4.673473358154297, \"sigma_intercept_per_group\": 0.04205735772848129, \"sigma_obs\": 0.003741899272426963, \"slope\": 0.09078943729400635, \"chain\": 3, \"draw\": 184}, {\"mouse\": 7, \"draws\": 785, \"mu_intercept_per_group\": 10.666196823120117, \"sigma_intercept_per_group\": 0.04724092036485672, \"sigma_obs\": 0.004060819279402494, \"slope\": -0.2228860855102539, \"chain\": 3, \"draw\": 185}, {\"mouse\": 7, \"draws\": 786, \"mu_intercept_per_group\": 12.619956970214844, \"sigma_intercept_per_group\": 0.03659761697053909, \"sigma_obs\": 0.004191072192043066, \"slope\": -0.1775510311126709, \"chain\": 3, \"draw\": 186}, {\"mouse\": 7, \"draws\": 787, \"mu_intercept_per_group\": 18.254344940185547, \"sigma_intercept_per_group\": 0.015526872128248215, \"sigma_obs\": 0.003801182843744755, \"slope\": 0.011996283195912838, \"chain\": 3, \"draw\": 187}, {\"mouse\": 7, \"draws\": 788, \"mu_intercept_per_group\": 15.289955139160156, \"sigma_intercept_per_group\": 0.021884860470891, \"sigma_obs\": 0.003346404992043972, \"slope\": -0.13017795979976654, \"chain\": 3, \"draw\": 188}, {\"mouse\": 7, \"draws\": 789, \"mu_intercept_per_group\": 17.305349349975586, \"sigma_intercept_per_group\": 0.02656746283173561, \"sigma_obs\": 0.0042939153499901295, \"slope\": 0.116448774933815, \"chain\": 3, \"draw\": 189}, {\"mouse\": 7, \"draws\": 790, \"mu_intercept_per_group\": 17.64442253112793, \"sigma_intercept_per_group\": 0.020024800673127174, \"sigma_obs\": 0.0035846466198563576, \"slope\": -0.22716383635997772, \"chain\": 3, \"draw\": 190}, {\"mouse\": 7, \"draws\": 791, \"mu_intercept_per_group\": 24.544832229614258, \"sigma_intercept_per_group\": 0.019109565764665604, \"sigma_obs\": 0.0036085464525967836, \"slope\": -0.12149377167224884, \"chain\": 3, \"draw\": 191}, {\"mouse\": 7, \"draws\": 792, \"mu_intercept_per_group\": 16.875078201293945, \"sigma_intercept_per_group\": 0.022942913696169853, \"sigma_obs\": 0.003801124868914485, \"slope\": -0.16660180687904358, \"chain\": 3, \"draw\": 192}, {\"mouse\": 7, \"draws\": 793, \"mu_intercept_per_group\": 18.091154098510742, \"sigma_intercept_per_group\": 0.016902292147278786, \"sigma_obs\": 0.0040965694934129715, \"slope\": -0.060472436249256134, \"chain\": 3, \"draw\": 193}, {\"mouse\": 7, \"draws\": 794, \"mu_intercept_per_group\": 15.666172981262207, \"sigma_intercept_per_group\": 0.024194005876779556, \"sigma_obs\": 0.004028658848255873, \"slope\": -0.06982123851776123, \"chain\": 3, \"draw\": 194}, {\"mouse\": 7, \"draws\": 795, \"mu_intercept_per_group\": 13.424943923950195, \"sigma_intercept_per_group\": 0.026318136602640152, \"sigma_obs\": 0.0038204151205718517, \"slope\": 0.021468255668878555, \"chain\": 3, \"draw\": 195}, {\"mouse\": 7, \"draws\": 796, \"mu_intercept_per_group\": 15.570969581604004, \"sigma_intercept_per_group\": 0.029330583289265633, \"sigma_obs\": 0.0035247360356152058, \"slope\": -0.023876121267676353, \"chain\": 3, \"draw\": 196}, {\"mouse\": 7, \"draws\": 797, \"mu_intercept_per_group\": 6.5744194984436035, \"sigma_intercept_per_group\": 0.024411462247371674, \"sigma_obs\": 0.0038599087856709957, \"slope\": -0.058964572846889496, \"chain\": 3, \"draw\": 197}, {\"mouse\": 7, \"draws\": 798, \"mu_intercept_per_group\": 28.4127254486084, \"sigma_intercept_per_group\": 0.02084348350763321, \"sigma_obs\": 0.004394568968564272, \"slope\": -0.17829076945781708, \"chain\": 3, \"draw\": 198}, {\"mouse\": 7, \"draws\": 799, \"mu_intercept_per_group\": 17.879596710205078, \"sigma_intercept_per_group\": 0.020366456359624863, \"sigma_obs\": 0.004180810879915953, \"slope\": -0.0048983278684318066, \"chain\": 3, \"draw\": 199}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 23,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Initialize:\n",
    "window = BayesRegression(df=df_null, y='Power', treatment='stim', group='mouse')\n",
    "# Fit:\n",
    "window.fit(model=models.model_hierarchical, add_group_intercept=True,\n",
    "           add_group_slope=False, robust_slopes=False,\n",
    "           do_make_change='subtract', dist_y='gamma')\n",
    "# Plot:\n",
    "window.plot(independent_axes=False,\n",
    "            ).properties(title='Posterior')\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Include all samples in each trial\n",
    "The mean of every one of the 30 trials we drew for each mouse is a manifestation of the same underlying process that generates power for each mouse. Let's try to include all samples that come in each trial"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 24,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "97e780cadf84474686dc995f4c07ebde",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/660 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c52a07212761435d8ff3ca203b305b67",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/660 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f191532e3794479e99ffa47961e6a463",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/660 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "0232e5e01e794debb5aa241357d58ec7",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/660 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# NBVAL_SKIP\n",
    "# Initialize:\n",
    "window = BayesRegression(df=df_monster, y='Power', treatment='stim', group='mouse')\n",
    "# Fit:\n",
    "window.fit(model=models.model_hierarchical, add_group_intercept=True,\n",
    "           num_warmup=500, n_draws=160, progress_bar=True,\n",
    "           add_group_slope=False, robust_slopes=False,\n",
    "           do_make_change='subtract', dist_y='gamma');"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "subslide"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-a626c7533b75476e952c3d36e9b53710\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-a626c7533b75476e952c3d36e9b53710\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-a626c7533b75476e952c3d36e9b53710\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}}}}, {\"data\": {\"name\": \"data-c54f06698bcfb14c39ffe654ff76d8c7\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.17693592607975006, 0.19885632395744324], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-69.18878060153263, 487.9857026681875], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-69.18878060153263, 487.9857026681875], \"zero\": false}}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-69.18878060153263, 487.9857026681875], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\", \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-6261aaeda45fc4e9dc2b4f9d39bcc965\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 246.68020890792593, \"mu_intercept_per_group higher interval\": -5.86566686630249, \"mu_intercept_per_group lower interval\": -18.76958465576172, \"mu_intercept_per_group center interval\": -9.807680130004883, \"mu_intercept_per_group higher interval75\": -7.482207775115967, \"mu_intercept_per_group lower interval75\": -14.84196949005127, \"sigma_intercept_per_group higher interval\": 0.03375045210123062, \"sigma_intercept_per_group lower interval\": 0.011746767908334732, \"sigma_intercept_per_group center interval\": 0.02185261808335781, \"sigma_obs higher interval\": 0.003638071473687887, \"sigma_obs lower interval\": 0.0035575919318944216, \"sigma_obs center interval\": 0.0036001012194901705, \"higher interval\": 0.19885632395744324, \"lower interval\": 0.17693592607975006, \"center interval\": 0.18880786001682281, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 153.4379262163082, \"mu_intercept_per_group higher interval\": -5.386823654174805, \"mu_intercept_per_group lower interval\": -16.363231658935547, \"mu_intercept_per_group center interval\": -8.241783142089844, \"mu_intercept_per_group higher interval75\": -5.989358425140381, \"mu_intercept_per_group lower interval75\": -12.067502975463867, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": 97.75801840385334, \"mu_intercept_per_group higher interval\": -5.1961517333984375, \"mu_intercept_per_group lower interval\": -16.279985427856445, \"mu_intercept_per_group center interval\": -8.670272827148438, \"mu_intercept_per_group higher interval75\": -6.303857326507568, \"mu_intercept_per_group lower interval75\": -12.449019432067871, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": 259.2147944426915, \"mu_intercept_per_group higher interval\": -2.9383795261383057, \"mu_intercept_per_group lower interval\": -9.103045463562012, \"mu_intercept_per_group center interval\": -4.7221527099609375, \"mu_intercept_per_group higher interval75\": -3.2880685329437256, \"mu_intercept_per_group lower interval75\": -6.8048224449157715, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 26.996524183149205, \"mu_intercept_per_group higher interval\": -2.0070154666900635, \"mu_intercept_per_group lower interval\": -6.819550037384033, \"mu_intercept_per_group center interval\": -3.5662479400634766, \"mu_intercept_per_group higher interval75\": -2.3406660556793213, \"mu_intercept_per_group lower interval75\": -5.132424831390381, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -47.827989146286455, \"mu_intercept_per_group higher interval\": -0.28019747138023376, \"mu_intercept_per_group lower interval\": -2.3854494094848633, \"mu_intercept_per_group center interval\": -1.2025550603866577, \"mu_intercept_per_group higher interval75\": -0.5923544764518738, \"mu_intercept_per_group lower interval75\": -1.9305877685546875, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -80.69074523128057, \"mu_intercept_per_group higher interval\": 13.586897850036621, \"mu_intercept_per_group lower interval\": 4.554792881011963, \"mu_intercept_per_group center interval\": 6.610581398010254, \"mu_intercept_per_group higher interval75\": 10.22288703918457, \"mu_intercept_per_group lower interval75\": 5.081120491027832, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": 611.1700378665317, \"mu_intercept_per_group higher interval\": 18.463560104370117, \"mu_intercept_per_group lower interval\": 5.940617084503174, \"mu_intercept_per_group center interval\": 9.475008010864258, \"mu_intercept_per_group higher interval75\": 14.704259872436523, \"mu_intercept_per_group lower interval75\": 7.612643718719482, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-c54f06698bcfb14c39ffe654ff76d8c7\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -9.851624488830566, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -10.593274116516113, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -8.804131507873535, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -9.093019485473633, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -11.623002052307129, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -9.663583755493164, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -9.241058349609375, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -9.04588794708252, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -9.058162689208984, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -9.243983268737793, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -9.199454307556152, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -8.934907913208008, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -14.2112455368042, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -13.564764022827148, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -13.971097946166992, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.729043006896973, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -14.117697715759277, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -14.457470893859863, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -13.540362358093262, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -14.841485023498535, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -13.327742576599121, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -12.355661392211914, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -14.764278411865234, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -14.664400100708008, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -13.996867179870605, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -14.989302635192871, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -13.437544822692871, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -13.617106437683105, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -16.81715965270996, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -16.711620330810547, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -17.97140121459961, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -17.110422134399414, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -14.383461952209473, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -13.38559341430664, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -13.990649223327637, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -13.286002159118652, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -15.132838249206543, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -15.865083694458008, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -12.832552909851074, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -13.29058837890625, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -12.082025527954102, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -13.696651458740234, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -13.51311206817627, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -12.065013885498047, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -14.313226699829102, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -11.000338554382324, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -12.037189483642578, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -12.324677467346191, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -13.417756080627441, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -12.928510665893555, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": -8.074151039123535, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -9.716476440429688, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -5.38045072555542, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -5.4341301918029785, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -5.210064888000488, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -5.498199939727783, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -5.032169342041016, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -4.887807369232178, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -4.304141521453857, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -5.630006313323975, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -5.093763828277588, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -9.3933744430542, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -9.472959518432617, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -9.580178260803223, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -9.769248008728027, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -9.763938903808594, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -9.204566955566406, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -9.919172286987305, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -10.04228687286377, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -9.533844947814941, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -7.777149677276611, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -5.937911033630371, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -5.934097766876221, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -5.872723579406738, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": -5.781371593475342, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -6.500571250915527, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -6.29168176651001, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -9.332966804504395, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -8.566055297851562, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -12.747147560119629, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -14.824766159057617, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -13.223275184631348, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -14.391583442687988, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -14.504562377929688, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -13.074117660522461, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -13.724332809448242, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -12.190608024597168, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": -8.720621109008789, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -8.772547721862793, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -11.351672172546387, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -11.376028060913086, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -12.397343635559082, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -11.784248352050781, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -13.295707702636719, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -13.053016662597656, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -12.82558822631836, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -10.47623062133789, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -11.515580177307129, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -11.70767593383789, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -11.612456321716309, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -11.31374740600586, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -12.464703559875488, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -12.073406219482422, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -6.85251522064209, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -9.189528465270996, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -11.047605514526367, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -11.454651832580566, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -12.702256202697754, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -12.336421966552734, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -18.76958465576172, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -19.507965087890625, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -16.186267852783203, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -13.559771537780762, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -14.20267391204834, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -16.650508880615234, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -15.609031677246094, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -13.455955505371094, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -13.151280403137207, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -15.190564155578613, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -13.681694030761719, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -14.643214225769043, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -14.625734329223633, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -14.264836311340332, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -14.59488296508789, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -12.469386100769043, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -11.627408981323242, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -11.068796157836914, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -11.281523704528809, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -11.116693496704102, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -10.538206100463867, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -10.453330039978027, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -10.998038291931152, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -10.55263614654541, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -10.286195755004883, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -10.227828979492188, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -9.542647361755371, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -9.54321002960205, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -10.298198699951172, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -9.788155555725098, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -10.504138946533203, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -10.226339340209961, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -11.428483009338379, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -12.490617752075195, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -7.117382526397705, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -7.545733451843262, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -7.82615327835083, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -6.990138530731201, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -7.236833572387695, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -9.769430160522461, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -11.64118766784668, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -11.391876220703125, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -11.45602035522461, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -8.160775184631348, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -7.561171531677246, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -8.286128044128418, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -8.254199028015137, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -8.291871070861816, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -9.068643569946289, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -10.296796798706055, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -10.132622718811035, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -16.92349624633789, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -18.36072540283203, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -18.445323944091797, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -16.545536041259766, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -15.687419891357422, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -12.87869930267334, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -22.542404174804688, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -15.548715591430664, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -17.444591522216797, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -16.874855041503906, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -18.150819778442383, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -17.172765731811523, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -17.34222984313965, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": -19.005916595458984, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -17.572147369384766, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -16.90898323059082, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -19.238187789916992, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -18.668596267700195, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -17.455039978027344, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -8.914315223693848, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -7.575784206390381, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -7.830623149871826, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -10.07348346710205, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -9.812929153442383, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -9.981400489807129, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -9.31966781616211, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -10.352869987487793, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -9.404488563537598, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -8.726993560791016, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -10.293545722961426, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -11.848428726196289, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -14.61726188659668, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -12.712618827819824, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -8.979381561279297, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -9.96892261505127, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.285028457641602, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -10.26827335357666, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -10.348662376403809, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -9.168214797973633, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -11.007803916931152, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -11.270756721496582, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -10.185099601745605, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -9.851644515991211, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -9.217644691467285, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -9.669071197509766, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -9.548715591430664, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -11.948126792907715, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -11.00711441040039, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -11.298539161682129, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -10.275769233703613, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -10.245580673217773, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -10.342629432678223, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -10.090191841125488, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -7.9419050216674805, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -7.888082027435303, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -6.541024208068848, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -6.4741716384887695, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -8.174796104431152, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -7.374598503112793, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -6.704504013061523, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -8.928976058959961, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -7.490107536315918, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -9.011640548706055, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -8.580904006958008, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -8.483851432800293, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -7.79026985168457, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.628410339355469, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -8.9325590133667, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -7.157540798187256, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -7.708485126495361, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -7.355049133300781, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -7.018417835235596, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -8.361577033996582, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -8.183733940124512, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -8.235001564025879, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -8.571562767028809, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -6.3101115226745605, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -7.018278121948242, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -6.977924346923828, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -7.372382640838623, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -7.256320953369141, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -7.233795166015625, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -8.49091625213623, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -9.214484214782715, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -10.787452697753906, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -10.45181655883789, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -9.881135940551758, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -9.545537948608398, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -9.980905532836914, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": -6.5249924659729, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -7.9755964279174805, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -8.612462997436523, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -8.219758987426758, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -7.963944911956787, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -8.776134490966797, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -9.43143081665039, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -10.85197639465332, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -10.068879127502441, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -9.709246635437012, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -9.575889587402344, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -10.080343246459961, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -8.67544174194336, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -8.023117065429688, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -8.47940444946289, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -8.149895668029785, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -8.759527206420898, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": -6.353415012359619, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -6.213578224182129, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -5.86566686630249, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -19.327342987060547, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -17.311426162719727, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -14.308171272277832, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -13.396991729736328, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.715051651000977, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -15.751935005187988, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -15.423849105834961, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -14.576160430908203, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -14.363265037536621, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -12.96366024017334, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -13.87910270690918, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -11.591469764709473, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -14.575644493103027, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -14.689902305603027, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -15.00460433959961, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -12.933090209960938, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -15.31631088256836, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -13.693306922912598, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -14.91311264038086, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -15.819818496704102, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -15.280932426452637, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -14.879806518554688, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -14.711051940917969, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -14.395410537719727, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -13.27812671661377, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -12.352173805236816, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -10.401369094848633, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -9.829854965209961, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -8.18619155883789, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -8.66999340057373, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -9.958154678344727, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -9.593432426452637, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -10.769091606140137, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -10.004193305969238, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -10.890406608581543, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -9.666512489318848, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -8.603235244750977, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.630160331726074, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -9.9837646484375, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -8.492984771728516, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -13.278030395507812, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -13.134513854980469, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -12.976862907409668, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -11.514472007751465, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -13.755633354187012, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -10.823258399963379, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -10.945013999938965, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -12.669825553894043, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -13.221829414367676, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -12.845072746276855, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -14.953858375549316, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -4.729133129119873, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -4.548620223999023, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -4.99838924407959, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -4.793203830718994, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -7.848435878753662, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -7.398036479949951, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": -8.277606010437012, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -8.299333572387695, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -9.523959159851074, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -8.183238983154297, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -9.84847354888916, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -8.982048034667969, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -9.32981014251709, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -9.218888282775879, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -8.747058868408203, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -9.451587677001953, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -8.976151466369629, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -10.148067474365234, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -16.634719848632812, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -13.924173355102539, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -14.84196949005127, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -12.997241020202637, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -12.172097206115723, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -12.224699974060059, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -16.475446701049805, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -22.25055503845215, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -12.725021362304688, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -10.97195053100586, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -10.968955039978027, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -10.317915916442871, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -12.809236526489258, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -12.792585372924805, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -14.153106689453125, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": -15.465877532958984, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.954972267150879, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -8.55903434753418, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -9.115021705627441, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -9.238870620727539, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -9.192914962768555, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -8.47585678100586, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -8.087279319763184, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -9.007800102233887, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -9.210658073425293, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -9.000494003295898, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -11.10288143157959, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -11.148441314697266, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -10.655070304870605, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -10.40219497680664, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -12.071128845214844, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -7.3215203285217285, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -6.908425331115723, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -7.004328727722168, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -7.524672031402588, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -7.762434005737305, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -8.050886154174805, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -8.872756004333496, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -11.756394386291504, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -7.700242519378662, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -7.483798503875732, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -7.367605686187744, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -7.472713470458984, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -9.43480396270752, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -7.030799865722656, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": -7.482207775115967, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -12.969368934631348, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -13.436347961425781, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -12.058253288269043, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -11.859895706176758, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -11.603286743164062, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": -13.032825469970703, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -12.195805549621582, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -11.49155044555664, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -12.611146926879883, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -10.519026756286621, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -11.463098526000977, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -10.673408508300781, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -12.180203437805176, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -11.599772453308105, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -12.220952033996582, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -10.257567405700684, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -10.443148612976074, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -9.67309284210205, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -9.264528274536133, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -9.035514831542969, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -11.879414558410645, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -11.78432846069336, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -12.515641212463379, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -10.765889167785645, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -10.750504493713379, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -10.787971496582031, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -10.69991683959961, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -9.415861129760742, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -8.839190483093262, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -12.824247360229492, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -12.086606979370117, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -12.281907081604004, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -11.686670303344727, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -10.803545951843262, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -12.325039863586426, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -10.761834144592285, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -10.596420288085938, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -11.28418254852295, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -12.91223430633545, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -11.278482437133789, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -12.274307250976562, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -11.702899932861328, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -13.681374549865723, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -14.477100372314453, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -14.371209144592285, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -14.394993782043457, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -14.533173561096191, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -11.855740547180176, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -13.92996883392334, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -14.760699272155762, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -11.185495376586914, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -12.835426330566406, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -13.144542694091797, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -13.600672721862793, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -15.38377571105957, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -13.606863021850586, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -13.265087127685547, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -13.628849029541016, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -15.011651039123535, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -17.774574279785156, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -18.67198371887207, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -15.473930358886719, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -11.308130264282227, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -11.705024719238281, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -8.439077377319336, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -8.944109916687012, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -10.272186279296875, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -18.75371551513672, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -17.906389236450195, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -21.123910903930664, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -19.832918167114258, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -20.83233642578125, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -18.55301856994629, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -19.926511764526367, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -20.052583694458008, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -10.44214916229248, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -10.604362487792969, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -10.795086860656738, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -8.453054428100586, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -8.739181518554688, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -9.087434768676758, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -8.729281425476074, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -8.495954513549805, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -9.306235313415527, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -10.284454345703125, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -9.956564903259277, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -10.20787525177002, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -11.150190353393555, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -11.230859756469727, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -13.22197437286377, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -15.436800956726074, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -15.656484603881836, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -15.69136905670166, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -16.518627166748047, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -16.37407112121582, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -15.856636047363281, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -13.168560981750488, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -12.187348365783691, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -12.000370979309082, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -11.742568016052246, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -10.521302223205566, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -10.248671531677246, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -10.099864959716797, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -10.644795417785645, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": -8.764814376831055, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": -10.25143051147461, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -8.947707176208496, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -9.025116920471191, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -10.162772178649902, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -8.695560455322266, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -14.067776679992676, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -13.395378112792969, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -12.221824645996094, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -11.7846040725708, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -12.379312515258789, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -11.680336952209473, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -11.611162185668945, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -13.801671028137207, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -13.680171966552734, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -13.08855152130127, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -12.703925132751465, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -12.404776573181152, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -11.335338592529297, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -10.328210830688477, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -15.149999618530273, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -14.909625053405762, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -14.167028427124023, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -18.85173225402832, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -16.696041107177734, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -14.410198211669922, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": -14.482259750366211, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -14.800610542297363, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -14.598974227905273, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -15.078454971313477, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -14.47150993347168, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -13.112748146057129, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -12.199393272399902, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -10.107108116149902, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -9.946240425109863, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -10.492698669433594, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -8.24332046508789, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -7.799241542816162, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -8.215629577636719, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -10.566386222839355, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -12.110265731811523, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -10.62038803100586, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -9.512286186218262, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -9.29843521118164, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -10.841090202331543, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -10.408195495605469, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -11.931687355041504, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -11.51518726348877, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -10.837364196777344, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -7.363087177276611, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -7.297500133514404, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -7.184803485870361, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -9.840415000915527, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -9.620916366577148, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -9.531041145324707, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -9.775530815124512, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -13.2416410446167, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": -12.479275703430176, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -10.308774948120117, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -13.033088684082031, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -11.920709609985352, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -12.347607612609863, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -14.002656936645508, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -13.718914031982422, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -12.631888389587402, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -12.660639762878418, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -12.867996215820312, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -13.427590370178223, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -14.38259220123291, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -13.775948524475098, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -13.804679870605469, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -14.020081520080566, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": -10.551556587219238, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -12.248726844787598, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -14.781445503234863, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -12.331197738647461, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -10.008559226989746, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -9.367363929748535, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -9.590958595275879, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -9.57936954498291, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -9.234673500061035, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -9.207507133483887, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -8.088523864746094, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -8.085479736328125, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -9.875282287597656, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -12.18527603149414, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -12.462112426757812, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -13.711477279663086, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -15.210104942321777, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": -15.821167945861816, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -15.639816284179688, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -20.180330276489258, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -16.050382614135742, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -14.000548362731934, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -14.804583549499512, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -14.11005687713623, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -13.604371070861816, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -16.89350700378418, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -17.043394088745117, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -18.620887756347656, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -17.242355346679688, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -18.76848602294922, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -18.645761489868164, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -18.606204986572266, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -17.98621368408203, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -20.126649856567383, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -18.1478214263916, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -17.565275192260742, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -18.739498138427734, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -18.749195098876953, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -18.637252807617188, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -19.325294494628906, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -18.093353271484375, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": -20.975679397583008, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -17.751113891601562, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -18.311607360839844, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": -18.146329879760742, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -18.93073844909668, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -18.398386001586914, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": -17.398426055908203, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -9.606353759765625, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": -10.549662590026855, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": -10.017539978027344, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -10.648676872253418, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -10.307941436767578, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -9.387676239013672, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -10.218058586120605, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -10.085677146911621, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -12.148161888122559, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -12.040152549743652, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -16.555862426757812, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -17.341968536376953, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -15.287552833557129, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -17.18736457824707, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -16.410188674926758, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -15.947684288024902, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -18.018848419189453, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -16.82005500793457, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": -15.86064624786377, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": -16.848609924316406, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -15.364187240600586, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": -8.529664993286133, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -8.565625190734863, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -8.804603576660156, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -9.800691604614258, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -10.605224609375, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -12.0894136428833, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -11.662813186645508, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -11.572234153747559, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -9.721075057983398, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -9.48402214050293, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -9.836634635925293, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -7.260185718536377, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -7.8033342361450195, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -8.62105941772461, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -8.771944046020508, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -8.69017505645752, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -8.684611320495605, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -7.97740364074707, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -8.192066192626953, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -7.053494930267334, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -7.887849807739258, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -7.688833236694336, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -7.356691360473633, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -11.844321250915527, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -11.675236701965332, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -11.6438627243042, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -11.190482139587402, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -11.882271766662598, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -11.952474594116211, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -11.745379447937012, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -11.784679412841797, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -10.551338195800781, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -10.114668846130371, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -11.85512638092041, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -12.067502975463867, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": -12.263293266296387, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": -11.330323219299316, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": -10.16634750366211, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -12.422002792358398, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -14.905791282653809, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -12.719289779663086, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -14.885536193847656, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -13.788555145263672, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -11.286567687988281, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -11.470149993896484, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -11.705706596374512, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -12.14986801147461, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -12.427521705627441, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -12.080053329467773, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -11.04504680633545, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -10.545846939086914, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": -11.033795356750488, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -10.63413143157959, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -11.15628719329834, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -11.159872055053711, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -10.859193801879883, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -10.099026679992676, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": -9.81385612487793, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": -10.156739234924316, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -11.215834617614746, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -10.584491729736328, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -6.784483909606934, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -7.553809642791748, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -4.260471343994141, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -4.78641939163208, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -4.144386291503906, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -5.129573822021484, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -3.6122500896453857, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -4.3750200271606445, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -3.9339284896850586, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -4.165874481201172, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": -3.649487018585205, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -7.698469161987305, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -8.193337440490723, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -7.692523002624512, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -8.399910926818848, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -7.326940059661865, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -9.008371353149414, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": -8.43190860748291, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": -8.017098426818848, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -8.083162307739258, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -6.4302520751953125, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -4.934736251831055, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -4.99753475189209, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -4.972352027893066, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -5.386823654174805, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -4.610748767852783, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -5.143852710723877, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -8.12186336517334, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -6.716584205627441, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": -10.605537414550781, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -12.987680435180664, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -11.353755950927734, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -12.92531681060791, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -11.546575546264648, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -11.27349853515625, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -10.825203895568848, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -9.012487411499023, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": -6.487373352050781, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": -6.402134418487549, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.774800300598145, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -10.133796691894531, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -9.960758209228516, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -10.057219505310059, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": -9.877751350402832, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -10.194048881530762, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -9.828524589538574, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -9.108601570129395, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -9.240880012512207, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -9.662944793701172, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -9.604839324951172, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -9.778409004211426, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -11.559121131896973, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -9.63019847869873, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -6.116044998168945, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -8.847260475158691, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -9.158397674560547, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -9.56347942352295, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -10.99738883972168, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -9.527101516723633, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -15.425337791442871, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -16.605077743530273, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -13.048630714416504, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -11.26810359954834, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -11.671223640441895, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -14.319704055786133, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -11.839753150939941, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -12.399782180786133, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -12.296150207519531, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -11.113602638244629, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -12.898321151733398, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -14.470512390136719, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -14.486980438232422, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -11.586691856384277, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -11.338854789733887, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -10.435816764831543, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -9.140275001525879, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -9.6119966506958, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -9.6206636428833, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -9.274335861206055, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -8.171449661254883, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -8.880675315856934, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -8.84261417388916, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -8.681678771972656, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -8.537386894226074, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -8.257012367248535, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -8.174871444702148, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -8.531773567199707, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -8.468480110168457, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -8.330525398254395, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -7.763249397277832, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -9.23439884185791, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -10.352523803710938, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -9.7440767288208, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -6.493594646453857, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -5.668495178222656, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": -6.536485195159912, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -5.962561130523682, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": -5.989358425140381, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -8.179424285888672, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -9.224543571472168, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -9.734447479248047, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": -10.175919532775879, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -7.314866542816162, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -6.186788082122803, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -6.772833824157715, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -6.679537773132324, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -7.271623134613037, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -7.01442813873291, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -8.877090454101562, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -8.152281761169434, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -15.871238708496094, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -14.757542610168457, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -17.056076049804688, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -15.685678482055664, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": -14.16133975982666, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -11.59614372253418, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -19.791913986206055, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -12.628913879394531, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -15.65161418914795, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": -14.883509635925293, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -14.066912651062012, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -15.01733684539795, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -15.25434684753418, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": -15.52501392364502, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -15.031102180480957, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -15.354179382324219, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": -15.391670227050781, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -14.733786582946777, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -16.239402770996094, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -7.869515419006348, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -6.1625285148620605, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -6.961767673492432, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -8.26362419128418, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -8.425446510314941, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -8.244565963745117, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": -8.431330680847168, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": -8.356810569763184, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": -8.35568904876709, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -8.324518203735352, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -7.427779674530029, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -11.001151084899902, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -10.739099502563477, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -11.851920127868652, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -8.638216972351074, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -7.424707889556885, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -7.502957820892334, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -7.972844123840332, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -8.299049377441406, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -7.995639801025391, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -10.174504280090332, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -8.856024742126465, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -8.558749198913574, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -8.252449989318848, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -7.966894626617432, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -7.745606899261475, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -8.220741271972656, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -10.056746482849121, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -9.162074089050293, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -9.309950828552246, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -9.200614929199219, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -8.04164981842041, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -7.989147186279297, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -8.158720016479492, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -6.167340278625488, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -6.509913921356201, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -5.995239734649658, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -5.821988582611084, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -7.00992488861084, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": -5.858956813812256, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -6.020576477050781, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -7.388912200927734, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -7.001800060272217, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -7.297293663024902, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -6.904263973236084, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -6.767678260803223, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -6.345089435577393, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -6.655992031097412, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -7.338032245635986, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -5.748055458068848, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": -6.153923511505127, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": -6.204908847808838, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -5.740651607513428, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -7.072974681854248, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -6.769132137298584, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -6.7029571533203125, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -7.297674179077148, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -5.420949935913086, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -5.996258735656738, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -6.040907859802246, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -6.022488594055176, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -6.190249443054199, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -5.972683906555176, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -6.332711696624756, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -6.481632709503174, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -9.382779121398926, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -8.370268821716309, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -8.605881690979004, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -7.688397407531738, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -8.153436660766602, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -6.076013565063477, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -6.282687187194824, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -7.190821170806885, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -6.822272777557373, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -6.849215984344482, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": -7.452500820159912, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -6.93101692199707, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -8.192855834960938, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -8.188567161560059, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": -7.691595554351807, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -7.546297550201416, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -8.439072608947754, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -6.498575210571289, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -6.522630214691162, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -7.221312522888184, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -6.64341402053833, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -7.810487747192383, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": -4.836653709411621, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -5.4737114906311035, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -4.680009841918945, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -14.71117877960205, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -13.231066703796387, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -12.881993293762207, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -10.80652141571045, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -11.428923606872559, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -13.088447570800781, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -12.403549194335938, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": -12.388936042785645, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -11.835264205932617, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -11.763348579406738, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -11.139649391174316, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -9.626166343688965, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -12.119199752807617, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -12.37428092956543, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -11.929868698120117, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -12.059250831604004, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -11.419142723083496, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -12.620949745178223, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -13.116007804870605, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -13.077399253845215, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -13.461737632751465, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -11.684602737426758, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -12.882208824157715, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -12.14332103729248, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -10.666753768920898, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -9.616438865661621, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -8.78840160369873, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -7.9378533363342285, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": -6.78215217590332, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": -7.98124361038208, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -7.439107418060303, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -8.732728958129883, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -8.265485763549805, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -8.473344802856445, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -9.175088882446289, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -7.924549579620361, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -7.85422420501709, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -8.313323020935059, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -7.848830699920654, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": -6.831625461578369, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -10.96494197845459, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": -10.748037338256836, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -10.895454406738281, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -10.013161659240723, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -11.744898796081543, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -8.813811302185059, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -8.972053527832031, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -10.550374984741211, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -11.876424789428711, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -10.929095268249512, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -12.96820068359375, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -3.8297979831695557, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -4.09927225112915, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -4.590153217315674, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -4.119028091430664, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -6.685900688171387, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -6.5281524658203125, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -6.612931251525879, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -6.643036842346191, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -7.364760875701904, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -7.121610164642334, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -7.828948497772217, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -8.35095500946045, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -8.238360404968262, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -8.080526351928711, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -7.574469566345215, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -7.984649181365967, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -7.666357040405273, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -7.885285377502441, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -13.649304389953613, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -11.747048377990723, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -12.455309867858887, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -11.088165283203125, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -10.226978302001953, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -10.333722114562988, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -12.658970832824707, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -17.99748420715332, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -11.507952690124512, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -8.743481636047363, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -8.540989875793457, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -8.308331489562988, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -10.409808158874512, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.620538711547852, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -11.50767707824707, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -13.277064323425293, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -6.9937214851379395, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -7.777700424194336, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -7.282313823699951, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -7.079543590545654, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -7.220000743865967, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -7.683372497558594, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -7.039926528930664, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -7.488051891326904, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -7.797805309295654, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -7.752614498138428, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -9.179603576660156, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": -9.563591957092285, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -9.184999465942383, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -8.46463680267334, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -10.848094940185547, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -5.596824645996094, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -5.436007022857666, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -5.630349159240723, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -6.366314888000488, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -6.2108964920043945, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -6.523582935333252, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -7.5760955810546875, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -9.887060165405273, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -6.501410484313965, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -6.363732814788818, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -6.268908977508545, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -6.240509986877441, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -8.031135559082031, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -6.380482196807861, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": -6.168534755706787, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -11.134572982788086, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -10.617363929748535, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -10.207976341247559, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -10.33414077758789, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -10.301100730895996, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": -10.34332275390625, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -11.227458953857422, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -10.35970401763916, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -10.311380386352539, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -9.21191120147705, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -9.802841186523438, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.167405128479004, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -9.907194137573242, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -9.707542419433594, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -10.583898544311523, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -8.141343116760254, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -8.365325927734375, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -7.992537498474121, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -8.287038803100586, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -7.695856094360352, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -10.52297592163086, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -9.778302192687988, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -10.227386474609375, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -9.15649127960205, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": -8.477409362792969, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -9.543404579162598, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": -9.375753402709961, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -7.4569621086120605, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -8.041787147521973, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -9.744007110595703, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -10.0101318359375, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -10.217740058898926, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -9.67767333984375, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -9.037591934204102, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -9.875791549682617, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -8.751954078674316, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -9.460350036621094, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.78790283203125, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -10.130443572998047, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -9.183836936950684, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -10.277303695678711, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -9.653280258178711, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -11.628171920776367, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -11.7589750289917, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -11.612820625305176, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -12.499763488769531, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -11.79002571105957, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -10.061283111572266, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -11.270356178283691, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -11.914552688598633, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -10.077983856201172, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -10.068305969238281, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -11.516246795654297, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -11.973291397094727, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -11.533452987670898, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -11.37985610961914, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -11.270061492919922, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -11.925480842590332, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -12.290231704711914, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -14.637188911437988, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -16.00838851928711, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -13.500164031982422, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -9.3949556350708, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -10.260808944702148, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -6.478891849517822, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -7.64636754989624, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -8.549432754516602, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -15.287691116333008, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -15.460411071777344, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -17.755287170410156, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -16.716646194458008, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -16.87953758239746, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -16.023426055908203, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -15.582951545715332, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -16.49396324157715, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -8.918719291687012, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -8.765458106994629, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -9.00108814239502, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -7.093249797821045, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -6.7425007820129395, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": -7.852930545806885, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -7.743824005126953, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -7.695345401763916, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -7.991128921508789, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -8.206735610961914, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -8.624382019042969, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -8.596165657043457, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.990116119384766, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -9.033246994018555, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -12.233370780944824, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -13.357138633728027, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -12.939226150512695, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -13.312416076660156, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -12.572054862976074, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -13.724356651306152, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -13.320147514343262, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -10.426800727844238, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -10.903331756591797, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -9.496400833129883, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -10.395065307617188, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -9.169426918029785, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -8.991691589355469, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": -8.417693138122559, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": -8.901578903198242, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -7.588583469390869, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -8.831604957580566, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -7.686142444610596, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -7.944189548492432, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -8.483185768127441, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -7.567653656005859, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -11.330217361450195, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -11.603011131286621, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -10.051122665405273, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -10.252095222473145, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -10.2603759765625, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -9.28430461883545, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -10.427631378173828, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -11.725006103515625, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -10.91124439239502, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -10.752559661865234, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -11.004341125488281, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -10.303412437438965, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -9.126507759094238, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -9.320602416992188, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -12.058330535888672, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -13.501537322998047, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -10.594620704650879, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -14.82206916809082, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -14.859207153320312, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -12.444636344909668, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -11.417515754699707, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": -11.351978302001953, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -10.844133377075195, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -10.527763366699219, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -10.834626197814941, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -12.19316291809082, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -9.068493843078613, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -9.031841278076172, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -8.890425682067871, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -8.049285888671875, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -6.234132766723633, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -6.019498348236084, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -6.042847633361816, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -9.737372398376465, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -8.987885475158691, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -10.00374698638916, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -8.215415954589844, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -8.45422649383545, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -8.39857006072998, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -9.335271835327148, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -9.188724517822266, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -8.8259916305542, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -9.159540176391602, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -5.7754950523376465, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -6.398288249969482, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -6.005887031555176, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -7.583805561065674, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -7.6820197105407715, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -7.90962553024292, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -7.95316743850708, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -11.122175216674805, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -10.834539413452148, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -8.287318229675293, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": -10.842634201049805, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -11.078690528869629, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -11.045512199401855, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -11.285313606262207, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -11.067142486572266, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -10.333518028259277, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -10.578166961669922, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -10.715497016906738, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -11.639104843139648, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -12.060778617858887, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -11.169048309326172, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -12.006462097167969, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -12.334375381469727, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -9.823528289794922, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -9.184955596923828, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -11.07061767578125, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -10.850611686706543, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -7.421445846557617, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -9.054793357849121, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -8.856281280517578, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -6.67641544342041, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -8.808252334594727, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -6.5838541984558105, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -7.823910236358643, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -7.905125141143799, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -8.072981834411621, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -9.48575210571289, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -10.347667694091797, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -11.662759780883789, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -12.511637687683105, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -14.626730918884277, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -14.772651672363281, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -16.251832962036133, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -14.267406463623047, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -11.99155330657959, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -12.080535888671875, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -12.18567180633545, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -11.547022819519043, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -13.317028045654297, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -14.921419143676758, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -12.853697776794434, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -15.958690643310547, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -14.362780570983887, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -13.528738021850586, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -13.429788589477539, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -15.014694213867188, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -16.685443878173828, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -14.087014198303223, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -15.159664154052734, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -15.669918060302734, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -15.266392707824707, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -16.454748153686523, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -15.451108932495117, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": -15.872716903686523, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -16.1271915435791, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -16.20937156677246, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -15.113572120666504, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -16.363231658935547, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -14.758134841918945, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -16.919519424438477, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -13.18451976776123, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -8.584428787231445, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -8.354183197021484, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": -7.897542953491211, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -9.818014144897461, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -7.913071632385254, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -8.472869873046875, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -7.50337028503418, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -9.066357612609863, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -8.53838062286377, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -8.886520385742188, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -15.011272430419922, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -14.354790687561035, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -14.180647850036621, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -13.39687442779541, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": -12.890908241271973, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": -14.394158363342285, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -15.718833923339844, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -13.214241981506348, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -14.723939895629883, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -12.98116683959961, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -14.370396614074707, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -7.884150505065918, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -7.222442150115967, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -7.809812068939209, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -8.511399269104004, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -8.575699806213379, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -10.221336364746094, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -9.742719650268555, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -9.158608436584473, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": -7.647387981414795, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": -7.455506801605225, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": -8.01889705657959, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": -7.468222141265869, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -7.893853664398193, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -8.244715690612793, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -8.665383338928223, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": -9.01965045928955, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -8.95269775390625, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": -8.338408470153809, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -8.311362266540527, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -7.172788619995117, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -7.95962381362915, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -8.07254695892334, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -7.204686164855957, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -11.447648048400879, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -12.228047370910645, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -11.317634582519531, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -10.870038986206055, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": -12.098483085632324, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -11.743831634521484, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -12.055479049682617, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -11.665326118469238, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -10.452956199645996, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": -9.865130424499512, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -11.855265617370605, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -11.364409446716309, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -11.996438026428223, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -12.385367393493652, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": -10.407864570617676, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -12.110824584960938, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -12.876176834106445, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -15.70751953125, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -13.771004676818848, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -16.001636505126953, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -11.170762062072754, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -12.000483512878418, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -12.128211975097656, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -11.469437599182129, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": -11.996685981750488, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -12.988693237304688, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -11.420990943908691, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -10.714858055114746, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": -11.203015327453613, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -10.312018394470215, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": -10.7760009765625, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": -10.62553596496582, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -11.590021133422852, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": -10.000452995300293, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -10.422992706298828, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": -10.080204963684082, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": -11.57633113861084, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": -10.529803276062012, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -7.037881851196289, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -8.302251815795898, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -4.861050605773926, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -4.484891891479492, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -4.553126811981201, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -4.662881374359131, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -4.417755603790283, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -4.910811901092529, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -4.4033122062683105, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -3.912036895751953, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -3.9549801349639893, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -7.208376884460449, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -7.706581115722656, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -8.447404861450195, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -7.7373785972595215, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -7.708994388580322, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -8.680890083312988, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -8.69361686706543, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -7.975279331207275, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -7.709714889526367, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -6.508571147918701, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -4.881943702697754, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -4.966244697570801, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -4.78423547744751, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -4.845292568206787, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -5.543205738067627, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -5.577106952667236, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -8.403943061828613, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": -6.946186542510986, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -11.154786109924316, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -13.394046783447266, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -11.849854469299316, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -12.415608406066895, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -12.007187843322754, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -10.74623966217041, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -11.732085227966309, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -10.023104667663574, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -7.586278915405273, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -7.455413341522217, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -10.266925811767578, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -8.922574043273926, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -10.511691093444824, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -9.939892768859863, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.695605278015137, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -9.562189102172852, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -9.681805610656738, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -9.782240867614746, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -8.630509376525879, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -8.855262756347656, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -9.184484481811523, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -8.961798667907715, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -11.286850929260254, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -9.175556182861328, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -6.8074164390563965, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": -8.643304824829102, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -8.833028793334961, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -9.552534103393555, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -10.603963851928711, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -10.847040176391602, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -16.828893661499023, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -18.055946350097656, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -12.25049114227295, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -12.448899269104004, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -12.305310249328613, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -14.124710083007812, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -12.449019432067871, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -11.98206901550293, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -11.517051696777344, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -12.097792625427246, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -12.42745304107666, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -14.045775413513184, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -13.942665100097656, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -12.892756462097168, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -13.070834159851074, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -11.558881759643555, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -10.289420127868652, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -9.548531532287598, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -9.780393600463867, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -9.847517967224121, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -8.862573623657227, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -8.65005874633789, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -9.382956504821777, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -9.64990520477295, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": -9.367914199829102, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": -8.03258228302002, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -8.781704902648926, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -8.873079299926758, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -8.765074729919434, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -8.002171516418457, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -8.481122970581055, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -9.05484676361084, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -9.969876289367676, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -11.075017929077148, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -5.56382942199707, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -6.616144180297852, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -6.391448020935059, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -6.146801948547363, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.877919673919678, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -8.784939765930176, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -9.290788650512695, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -10.092151641845703, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": -9.25985050201416, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -7.425848484039307, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -6.189228534698486, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -7.105620861053467, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -7.207167625427246, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -7.1179890632629395, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -7.336030006408691, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -8.53834056854248, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -9.108002662658691, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -14.830260276794434, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -17.185462951660156, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -15.373597145080566, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -15.05878734588623, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -13.237135887145996, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -10.521673202514648, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -19.459592819213867, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -12.77586841583252, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -14.612886428833008, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -13.912336349487305, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -15.386208534240723, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -14.496955871582031, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -15.616334915161133, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -15.343432426452637, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": -15.57786750793457, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -15.244278907775879, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -15.373337745666504, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -16.510028839111328, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -16.063766479492188, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -7.434024810791016, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -6.359696865081787, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -7.023039817810059, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -8.45052433013916, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -8.50468921661377, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -8.317551612854004, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -8.842100143432617, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -7.829134464263916, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -8.443354606628418, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -8.528440475463867, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -7.433631420135498, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -11.366190910339355, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -11.487279891967773, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -10.873893737792969, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -7.953674793243408, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -9.043959617614746, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -7.571133613586426, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -9.167332649230957, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -9.22920036315918, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -7.749976634979248, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -9.485520362854004, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -9.558971405029297, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -9.242197036743164, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -8.389689445495605, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.986049175262451, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -7.939853668212891, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -8.025477409362793, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -9.798044204711914, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -8.910064697265625, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -8.644339561462402, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -8.47162914276123, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -8.992490768432617, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -8.70028018951416, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -9.042204856872559, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -6.897375106811523, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -6.253714561462402, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -5.731706142425537, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -5.1961517333984375, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -6.687386989593506, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -6.272985458374023, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -5.811789512634277, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -7.017706394195557, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -7.163666248321533, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -7.07087516784668, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -6.612777233123779, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -6.44852352142334, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -6.516042232513428, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -6.6033549308776855, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -6.945231914520264, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -6.286407947540283, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -5.9532670974731445, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": -5.793153285980225, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -6.8703694343566895, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": -6.9184794425964355, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": -6.987246513366699, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -7.612975597381592, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -7.089613437652588, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -5.220559597015381, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -6.309560298919678, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -6.1052727699279785, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -5.923365592956543, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": -5.6926374435424805, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": -6.7284955978393555, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -6.981760025024414, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -7.670392990112305, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -8.593595504760742, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -9.460906028747559, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": -7.986255168914795, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -8.414737701416016, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -8.051430702209473, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -6.546506881713867, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -6.62329626083374, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -7.201033592224121, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": -6.997493267059326, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -7.186775207519531, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -7.784112930297852, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -7.455981731414795, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -9.6963472366333, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -9.211112022399902, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -8.615071296691895, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -8.831884384155273, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -8.183555603027344, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -6.744656085968018, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -6.165415287017822, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -7.003814697265625, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -7.126833915710449, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -7.624880313873291, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -5.27862024307251, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -5.329865455627441, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -4.79013204574585, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -15.255629539489746, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": -13.10225772857666, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -13.299938201904297, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -10.509306907653809, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -11.278899192810059, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -13.075965881347656, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -13.193696975708008, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -12.13432502746582, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": -11.544530868530273, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": -12.254440307617188, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -11.256677627563477, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -9.24073314666748, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -13.26752758026123, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -11.711874008178711, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": -12.107666015625, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -12.49039077758789, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -11.510320663452148, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -12.789005279541016, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -12.965875625610352, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -13.440556526184082, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": -12.935181617736816, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": -12.585945129394531, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -12.836762428283691, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": -13.05434513092041, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": -10.055023193359375, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -9.636289596557617, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -8.662613868713379, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -9.1491117477417, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -6.403409004211426, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -7.563633441925049, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -7.942143440246582, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -8.514138221740723, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -8.339614868164062, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -8.53172492980957, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -8.924644470214844, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -7.523374080657959, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -8.11363410949707, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -7.583475112915039, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -8.914551734924316, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": -7.59495210647583, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -10.408060073852539, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": -12.107131004333496, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -9.929945945739746, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -10.515772819519043, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -12.24309253692627, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -9.440649032592773, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -9.507796287536621, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -10.594572067260742, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -10.321135520935059, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -10.93638801574707, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -12.396105766296387, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -3.8326284885406494, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -3.874495267868042, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -4.283148765563965, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -4.202067852020264, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -6.71360969543457, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -6.5928215980529785, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -6.649409294128418, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -6.632644176483154, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -6.9088006019592285, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -8.115894317626953, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": -7.053569316864014, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -8.572206497192383, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -8.318761825561523, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": -8.070542335510254, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -8.093010902404785, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -9.144524574279785, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -7.008109092712402, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -8.386369705200195, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -14.962732315063477, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -11.990336418151855, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -11.937858581542969, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -10.761756896972656, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -10.97829818725586, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -9.957612991333008, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -13.30827808380127, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -18.20355224609375, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -10.243486404418945, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -10.212509155273438, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": -10.102747917175293, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -8.879531860351562, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -10.94552230834961, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": -10.738237380981445, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -11.55812931060791, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -12.129766464233398, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -8.159052848815918, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -7.960541725158691, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -7.436365127563477, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -7.345530986785889, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -7.375087261199951, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -7.308013916015625, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -6.2547607421875, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -8.171603202819824, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": -7.307666301727295, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -7.54347562789917, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -9.506094932556152, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": -10.119277000427246, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -9.589120864868164, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -8.38620376586914, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -11.248230934143066, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -5.862124919891357, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -5.463159561157227, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -6.068930625915527, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -6.1273674964904785, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.521869659423828, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -6.463087558746338, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -7.110462188720703, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -9.628852844238281, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -7.012094020843506, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -6.745218753814697, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -6.855048656463623, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -5.890373706817627, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -8.485527038574219, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -6.081881523132324, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -6.264965057373047, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -11.44893741607666, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -10.910845756530762, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": -10.106712341308594, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -10.102458000183105, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -9.727493286132812, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": -11.246182441711426, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -10.559623718261719, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": -10.023141860961914, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -10.56458854675293, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": -9.065013885498047, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -9.630987167358398, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": -9.621627807617188, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -9.754430770874023, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": -9.777823448181152, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": -9.8089599609375, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -9.296844482421875, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -9.30306339263916, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -8.287066459655762, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": -8.032702445983887, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -7.737759113311768, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -10.240459442138672, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -9.78650951385498, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -10.54364013671875, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -9.133692741394043, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -8.501397132873535, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -9.207874298095703, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -9.224843978881836, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -7.86361837387085, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -7.517457962036133, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -10.553731918334961, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": -10.442585945129395, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -10.159224510192871, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -9.959710121154785, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -9.114307403564453, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -9.74736499786377, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -9.09874153137207, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -9.969940185546875, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -8.905924797058105, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -10.32229995727539, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -10.242536544799805, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -9.374312400817871, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -10.689253807067871, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -10.898482322692871, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": -11.07215690612793, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -12.007759094238281, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -11.960660934448242, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -12.870683670043945, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -11.36689567565918, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -10.136443138122559, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -11.434286117553711, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -10.764805793762207, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -10.678425788879395, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -11.187084197998047, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -11.662741661071777, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -12.077077865600586, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -11.32813835144043, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -10.312041282653809, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -10.872803688049316, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -13.48287296295166, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -15.123278617858887, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -16.133203506469727, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -13.469136238098145, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -10.143458366394043, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": -9.321259498596191, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -7.428215503692627, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -7.317838191986084, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -8.419309616088867, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -16.16616439819336, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -15.052878379821777, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -17.366073608398438, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -17.605560302734375, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -17.073806762695312, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -16.403608322143555, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -15.977180480957031, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -15.886157035827637, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -8.276000022888184, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -9.001201629638672, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -8.824300765991211, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -6.916149139404297, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -6.9543633460998535, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -7.3828911781311035, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": -7.041392803192139, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -7.0137434005737305, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -7.631060600280762, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -8.824135780334473, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -8.301162719726562, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -8.329082489013672, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -8.326737403869629, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": -8.230084419250488, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -11.83926010131836, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -14.139296531677246, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -14.485081672668457, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": -14.15733528137207, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -12.667623519897461, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -13.73106575012207, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -13.738646507263184, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -11.34078598022461, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -10.322614669799805, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": -10.40048885345459, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -10.402188301086426, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -9.426457405090332, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -8.22807502746582, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -8.343188285827637, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -8.310812950134277, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -7.120408058166504, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -9.076619148254395, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -7.468583583831787, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -7.681987285614014, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -8.299936294555664, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -7.154465198516846, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -11.773426055908203, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": -12.007054328918457, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -9.876861572265625, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -10.681716918945312, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -10.582509994506836, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -9.49457836151123, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -10.014411926269531, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -12.219635963439941, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -11.104462623596191, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -11.753150939941406, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -10.620562553405762, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -10.675411224365234, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -9.319618225097656, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -9.376197814941406, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -12.375014305114746, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -13.390501976013184, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -11.577620506286621, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": -15.596985816955566, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -14.831947326660156, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -12.448200225830078, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -11.793540000915527, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -11.921236038208008, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -11.78522777557373, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -11.685782432556152, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -11.592490196228027, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -11.915972709655762, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -10.13662338256836, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -8.284628868103027, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -8.059141159057617, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -8.960013389587402, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -7.080596446990967, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -6.303857326507568, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -6.608936786651611, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -9.405355453491211, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": -9.529542922973633, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -9.936470985412598, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -7.869573593139648, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -8.224592208862305, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -9.01838493347168, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -8.840397834777832, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -10.071359634399414, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -9.827476501464844, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -8.909775733947754, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": -6.1656694412231445, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -6.137988567352295, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -6.142375946044922, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -8.370516777038574, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -8.485040664672852, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -8.634536743164062, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": -8.922847747802734, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -11.329963684082031, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -10.41037654876709, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -9.030210494995117, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -10.961108207702637, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -10.738873481750488, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -10.448390007019043, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": -12.320303916931152, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -12.359390258789062, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -11.412613868713379, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -9.842954635620117, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": -11.933849334716797, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -12.076140403747559, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -12.01351261138916, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -11.671770095825195, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -11.557403564453125, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -11.777539253234863, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -9.364644050598145, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -9.928903579711914, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -10.752791404724121, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -10.886780738830566, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -7.5234551429748535, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -8.985288619995117, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -8.50300121307373, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -7.083637714385986, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -8.643061637878418, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -6.8666582107543945, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -7.759244441986084, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -7.9635820388793945, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -7.987215995788574, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -11.043526649475098, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -9.830126762390137, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -12.431546211242676, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -12.19079875946045, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -15.233949661254883, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -15.479727745056152, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -15.646200180053711, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": -15.127071380615234, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -12.892071723937988, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -12.360160827636719, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -11.626749992370605, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": -11.596542358398438, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -13.3951416015625, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -15.18194580078125, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -15.689735412597656, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -15.701537132263184, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -15.073882102966309, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": -15.855364799499512, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": -15.906293869018555, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -14.969801902770996, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -17.006940841674805, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -14.886451721191406, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -14.95926570892334, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -16.011926651000977, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -15.588326454162598, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -16.279985427856445, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -15.884343147277832, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -16.029590606689453, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -16.253360748291016, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -16.31010627746582, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -16.84382438659668, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -15.93847370147705, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -15.683954238891602, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -16.20218849182129, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -13.951407432556152, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -8.75363826751709, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -8.744316101074219, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -8.781010627746582, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -8.544942855834961, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -9.33665657043457, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -7.621401309967041, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -8.66136360168457, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -8.32052230834961, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -9.993941307067871, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": -9.50870132446289, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -14.80935001373291, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -14.161215782165527, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": -14.226594924926758, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -13.713505744934082, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": -14.307723999023438, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -12.872706413269043, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -14.137105941772461, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -14.612154960632324, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -13.960301399230957, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -14.099410057067871, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -13.366686820983887, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -7.014652729034424, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -7.747760772705078, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -8.05859661102295, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -8.971078872680664, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -8.350561141967773, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -10.822115898132324, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -10.446824073791504, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -10.161876678466797, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -8.346480369567871, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -8.221733093261719, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -7.4953460693359375, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": -4.4651947021484375, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": -4.071032524108887, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -4.878485679626465, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -4.495409965515137, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -4.778892993927002, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -3.8636436462402344, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": -4.732561111450195, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -4.077816963195801, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": -3.7448761463165283, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -4.527496814727783, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": -4.548728942871094, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": -3.3851613998413086, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -6.2507758140563965, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": -7.577321529388428, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": -6.278017044067383, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": -5.624145030975342, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -7.045640468597412, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -6.753748893737793, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -6.607899188995361, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": -6.524211406707764, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -5.996279716491699, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": -4.832637786865234, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -6.423463821411133, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": -6.617916584014893, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": -6.688039779663086, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": -7.313354969024658, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -5.787234783172607, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": -7.268190860748291, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -7.4051337242126465, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": -8.752531051635742, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -7.847912788391113, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": -8.558843612670898, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -5.585297107696533, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -7.092940330505371, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -7.2682271003723145, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -6.954495429992676, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -6.8048224449157715, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -7.040626049041748, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -5.6131463050842285, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -6.398091793060303, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -5.328056812286377, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -5.954373359680176, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": -6.407882213592529, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -6.220874786376953, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": -6.226785659790039, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -5.535874843597412, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": -5.384990215301514, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": -5.60226583480835, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": -5.7768025398254395, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": -6.769672870635986, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": -3.6471774578094482, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.2124104499816895, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": -2.531613349914551, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": -2.9643988609313965, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -2.481722116470337, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -2.857008934020996, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -2.3027243614196777, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -2.369565963745117, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -2.1467344760894775, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -2.1540892124176025, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.3781323432922363, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -4.650877952575684, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -4.7508087158203125, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -4.603630065917969, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": -4.141909122467041, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": -4.706629753112793, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": -4.546579360961914, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -4.705005168914795, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -4.543768882751465, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -4.5500807762146, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -3.425657272338867, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -2.453583002090454, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": -2.401217222213745, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -2.5824670791625977, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.7619118690490723, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -3.1059117317199707, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -3.103563070297241, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -4.900404453277588, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -4.009464740753174, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -5.505279064178467, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": -7.005808353424072, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": -6.255640029907227, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": -7.323478698730469, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.700334548950195, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -7.200850009918213, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -5.683073043823242, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": -5.6137566566467285, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": -4.254715442657471, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": -4.335273742675781, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": -5.090284824371338, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": -5.8007283210754395, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": -5.0847697257995605, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": -5.251226425170898, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -5.472654342651367, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": -5.4119038581848145, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": -5.108021259307861, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -5.113678455352783, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": -4.742451190948486, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": -5.608653545379639, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.657304286956787, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": -5.004990577697754, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": -6.146199703216553, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -5.456408500671387, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -3.4926717281341553, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": -4.152259349822998, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": -4.634077548980713, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -5.980301380157471, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": -5.953535556793213, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -5.683080196380615, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -8.457954406738281, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -7.343505382537842, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -6.680629730224609, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": -7.830854892730713, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": -7.475622177124023, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": -7.479725360870361, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -7.275534152984619, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -6.3264007568359375, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -6.733271598815918, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -5.3663482666015625, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": -6.757221221923828, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": -7.079226016998291, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": -7.052643775939941, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -7.670816421508789, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -7.831424713134766, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -5.673741340637207, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -5.2887115478515625, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -4.82011604309082, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": -4.735052585601807, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -5.177676677703857, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -4.185025215148926, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -5.281758785247803, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": -5.053088188171387, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -4.987194538116455, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -5.692770481109619, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": -5.078647136688232, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -4.434950351715088, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": -4.468170166015625, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -4.615714073181152, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -5.045149803161621, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -4.091817378997803, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -5.403796195983887, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": -5.977889060974121, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": -5.573631286621094, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -3.144230365753174, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -3.297851800918579, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": -3.50142502784729, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -2.9383795261383057, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -3.321011543273926, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": -4.739062786102295, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -5.362175464630127, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": -5.294633388519287, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -5.487259387969971, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": -3.8401553630828857, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -3.4172585010528564, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -3.7148146629333496, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": -3.4519717693328857, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -4.468782901763916, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": -3.7090020179748535, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -5.17562198638916, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": -4.791464805603027, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": -8.469317436218262, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -8.951935768127441, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": -8.752230644226074, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": -8.525711059570312, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": -7.594056129455566, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": -5.4420342445373535, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": -11.442623138427734, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -7.05925989151001, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -9.009539604187012, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": -8.0965576171875, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -8.548924446105957, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": -7.576032638549805, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -8.297035217285156, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": -8.929366111755371, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": -7.948174476623535, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -8.475569725036621, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -8.841524124145508, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": -7.693042278289795, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -8.059242248535156, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -3.7619149684906006, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -3.969062089920044, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -4.336879730224609, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -4.833128452301025, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -4.606860160827637, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -4.693568229675293, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -5.345755577087402, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": -4.091735363006592, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -4.516643047332764, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -4.434087753295898, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": -5.195588111877441, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -6.797750473022461, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": -7.116320610046387, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -5.192755222320557, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -5.172474384307861, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": -4.087462425231934, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -4.653280735015869, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -5.5943708419799805, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": -5.343291282653809, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -4.048859596252441, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": -4.82941198348999, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -4.736727237701416, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -5.886011123657227, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -4.211130142211914, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -4.9919352531433105, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -4.928150653839111, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -3.9328155517578125, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": -4.747169017791748, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -5.454480171203613, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -5.448852062225342, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -5.141651153564453, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": -5.015182018280029, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -5.151602268218994, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -5.232419013977051, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": -3.1104226112365723, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -3.852212905883789, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": -3.480557918548584, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -3.2880685329437256, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": -4.155666351318359, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -3.9214439392089844, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -3.0718629360198975, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": -4.028192043304443, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -4.15199613571167, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -3.8369364738464355, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -3.7850348949432373, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -3.7293596267700195, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -4.001599311828613, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -3.771817922592163, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": -4.2409281730651855, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": -3.376891613006592, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -3.2043914794921875, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -3.917228937149048, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -3.683015823364258, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": -3.3007078170776367, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -3.756033420562744, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -3.5576651096343994, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -3.608534812927246, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -2.9610366821289062, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": -3.5294759273529053, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -3.6959989070892334, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": -3.4683854579925537, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -3.475247383117676, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -3.73671293258667, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -3.441636562347412, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": -4.364984512329102, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -5.160479545593262, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -4.852465629577637, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": -4.386254787445068, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -4.661422252655029, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": -4.219639301300049, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": -2.8732542991638184, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -4.018141746520996, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": -3.6744465827941895, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -4.111606597900391, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": -4.165467739105225, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -3.509472608566284, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -3.3874385356903076, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": -5.2424235343933105, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": -4.875796318054199, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": -4.0063581466674805, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -3.840270757675171, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -4.166221618652344, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": -3.791804313659668, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -3.3116302490234375, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": -3.767601728439331, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -4.398008346557617, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": -4.605267524719238, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": -3.2276647090911865, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": -3.4993104934692383, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": -2.5941312313079834, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -8.700529098510742, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": -6.00996732711792, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": -6.587067604064941, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -5.673789978027344, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -6.77787446975708, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": -6.601485252380371, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -7.057787895202637, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -7.349900722503662, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -5.885043144226074, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": -5.862990856170654, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -6.146670341491699, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -6.463149547576904, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -6.034718990325928, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -7.240029811859131, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -7.270077705383301, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": -6.3339433670043945, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -6.072902202606201, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -7.342334747314453, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -7.594297885894775, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -7.503993034362793, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -7.999755859375, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -6.995380878448486, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": -6.451685428619385, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -6.3102898597717285, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -6.024908542633057, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": -5.531137943267822, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": -4.802505970001221, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": -4.660428047180176, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": -3.46517014503479, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -4.236396789550781, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": -4.348811149597168, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -4.817853927612305, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -4.66499137878418, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -4.789389610290527, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -5.150897026062012, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -4.222580909729004, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -4.473111152648926, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": -4.082411766052246, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -4.620270729064941, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": -4.000030040740967, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -6.269591808319092, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -6.80250358581543, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": -6.0629472732543945, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -6.364255428314209, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": -7.006587982177734, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -4.763122081756592, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -4.742313385009766, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -6.326752662658691, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -6.503209114074707, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": -6.400110244750977, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -6.574813365936279, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": -2.554067373275757, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -1.9594141244888306, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -2.626640558242798, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -2.1319119930267334, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": -3.72029185295105, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -3.5649983882904053, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": -3.8354148864746094, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": -3.3434596061706543, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -4.069168567657471, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": -4.230885028839111, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -4.287948131561279, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": -4.548680305480957, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": -4.4285149574279785, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": -4.72823429107666, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -4.634169101715088, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -4.29194974899292, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -4.360034465789795, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -4.511038780212402, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -7.288619041442871, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -7.369436740875244, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": -6.983633041381836, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": -5.9416890144348145, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": -5.42965841293335, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -5.640103340148926, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": -7.137578010559082, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -10.397228240966797, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": -5.313264846801758, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": -4.296082496643066, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -4.797342300415039, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -5.18768835067749, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": -6.084588527679443, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -5.776798248291016, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": -6.369850158691406, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": -6.9111247062683105, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -4.479602813720703, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -3.8752877712249756, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -4.473843574523926, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -4.335937023162842, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": -4.242465972900391, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": -3.667379856109619, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -4.132870674133301, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -3.9678637981414795, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": -4.754471778869629, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -4.793647289276123, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": -5.408947467803955, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": -5.492337703704834, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": -5.385361671447754, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -5.552547454833984, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": -6.60469388961792, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -2.847346305847168, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -3.1153645515441895, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -3.0109503269195557, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -3.448930025100708, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -3.5146026611328125, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.773453950881958, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.4434027671813965, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -5.845037937164307, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -3.3439273834228516, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -3.5143988132476807, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": -3.529521942138672, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": -3.46156644821167, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": -4.211008548736572, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -2.815542459487915, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": -3.5889859199523926, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -6.4818925857543945, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -6.270923137664795, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -5.858028888702393, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -6.083117961883545, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -6.2024126052856445, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": -5.751458644866943, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": -5.70267391204834, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -6.360776901245117, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -5.672219276428223, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -5.162337303161621, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -4.87339973449707, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -5.855421543121338, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.377645015716553, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": -5.572293758392334, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -5.058868885040283, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": -4.13148832321167, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": -4.470322608947754, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": -5.044578552246094, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": -5.050568103790283, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -3.8862462043762207, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -5.687005519866943, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.778645038604736, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": -5.130939960479736, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -4.4524617195129395, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -4.798315525054932, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": -4.788690567016602, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -4.805228233337402, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -3.708239793777466, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -4.496054172515869, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -6.2481303215026855, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": -6.208493232727051, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": -5.638308048248291, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": -6.6094889640808105, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -5.940882682800293, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": -4.870668411254883, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -5.392248153686523, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -4.93410062789917, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": -5.3558454513549805, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -5.8303117752075195, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -4.998587131500244, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": -5.831279277801514, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": -5.6341962814331055, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -5.602822303771973, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -5.743920803070068, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -6.048460960388184, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": -6.953797817230225, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -7.3769378662109375, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": -6.297316551208496, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": -5.606019496917725, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -6.783804416656494, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -5.462093353271484, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": -5.811466693878174, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": -5.856975555419922, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": -7.0012030601501465, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": -6.664778232574463, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -5.5683722496032715, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -5.612614154815674, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -5.096993446350098, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": -7.468817710876465, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -8.645752906799316, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": -9.103045463562012, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -6.341405391693115, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": -4.796304702758789, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -5.666258811950684, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -3.9581050872802734, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -3.8193132877349854, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": -5.151919841766357, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": -9.32603931427002, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -6.951363563537598, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -12.172569274902344, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -9.620279312133789, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -9.069825172424316, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -10.371658325195312, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": -10.157044410705566, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": -8.461028099060059, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": -5.2941179275512695, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -5.488392353057861, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -5.164551734924316, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -3.824673891067505, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -3.709726572036743, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -4.032395362854004, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -4.077763557434082, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -4.130234718322754, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -4.836045742034912, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": -4.883211612701416, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -4.449584484100342, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -4.417517185211182, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": -5.168157577514648, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": -5.363668441772461, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -7.311577796936035, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": -7.1391448974609375, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": -7.777771949768066, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -7.579893589019775, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -7.161425590515137, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -7.199687957763672, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": -7.910067081451416, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": -6.49989128112793, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": -6.26507568359375, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -6.267812728881836, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -6.0630903244018555, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -4.299042224884033, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": -5.233388423919678, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -5.236589431762695, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -4.967183589935303, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": -4.1031174659729, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -4.816502571105957, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -4.26674222946167, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -4.637521743774414, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": -4.783592224121094, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": -3.6830286979675293, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": -6.446967601776123, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": -5.9991230964660645, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": -5.274527072906494, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -5.592042922973633, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -5.668954372406006, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": -5.521432876586914, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": -5.4170002937316895, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -7.1148152351379395, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -6.796136379241943, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": -6.508797645568848, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": -5.995060920715332, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": -6.6115875244140625, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -5.552478790283203, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -4.320967197418213, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": -6.113180160522461, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -6.288466930389404, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -5.017216682434082, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -9.61325740814209, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": -7.690115451812744, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -7.30750846862793, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -6.420309543609619, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": -6.748944282531738, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": -6.273843765258789, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -6.1579413414001465, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -6.24082612991333, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -6.266751766204834, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -5.317060470581055, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": -4.2370734214782715, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -4.830300331115723, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -4.441035747528076, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -3.520125389099121, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": -3.9427051544189453, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": -4.164914608001709, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": -4.633415699005127, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": -5.012077331542969, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -5.577658176422119, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -3.8646767139434814, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -4.515129089355469, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -5.002838611602783, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": -5.152456283569336, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -5.427723407745361, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -5.226616859436035, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -5.29499626159668, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.3291478157043457, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": -3.8070168495178223, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -3.4469172954559326, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -4.125557899475098, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -4.617308139801025, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": -4.619353294372559, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": -4.595637321472168, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -5.592173099517822, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": -6.122406005859375, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": -5.069957256317139, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": -6.05607271194458, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": -6.322469234466553, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -6.183130264282227, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": -6.353452682495117, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -6.412219047546387, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": -6.161712646484375, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -6.204931735992432, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": -6.2284321784973145, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -6.438796520233154, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -5.868676662445068, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": -7.194488048553467, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -5.932461261749268, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": -6.6272172927856445, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": -6.1236042976379395, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -5.268127918243408, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -6.21993350982666, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -6.140072822570801, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": -4.146174430847168, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -4.991800785064697, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": -5.379293441772461, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": -4.453949451446533, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -4.017897129058838, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": -3.918119192123413, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": -4.097125053405762, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": -4.330342769622803, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -4.840630531311035, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -6.543200969696045, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -6.119840621948242, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": -6.264693737030029, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -6.909795761108398, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -7.568028926849365, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -7.527130126953125, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -8.825040817260742, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": -7.597271919250488, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": -6.911983966827393, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -6.568662643432617, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -6.650530815124512, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": -6.667719841003418, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": -8.108125686645508, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -8.893248558044434, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": -8.63908576965332, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": -8.130635261535645, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -8.704039573669434, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -8.556929588317871, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -8.520505905151367, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -8.32738971710205, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -10.016140937805176, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -7.751852512359619, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": -9.002931594848633, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -7.567327976226807, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -8.434462547302246, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -9.005170822143555, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -10.244596481323242, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": -9.000879287719727, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -10.177730560302734, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": -8.664528846740723, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": -8.363438606262207, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -8.822105407714844, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -8.257913589477539, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -8.396563529968262, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": -8.717286109924316, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": -4.1521501541137695, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": -4.381858825683594, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": -5.459375858306885, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -4.552024841308594, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -5.423214435577393, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": -4.1766839027404785, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": -4.247849941253662, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -5.131702899932861, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": -4.8990254402160645, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -4.823692321777344, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": -7.7395477294921875, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -9.042439460754395, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -8.67538070678711, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": -8.017312049865723, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": -8.628585815429688, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": -8.104585647583008, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": -9.071730613708496, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -8.939050674438477, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -7.127598285675049, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": -8.139835357666016, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -8.309562683105469, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": -4.132501602172852, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -3.9787166118621826, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -4.509105205535889, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": -4.776891231536865, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -4.711182117462158, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -5.634485721588135, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -5.543056011199951, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -4.933659553527832, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -4.653660297393799, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": -4.540064334869385, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -4.322659969329834, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": -3.2160682678222656, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": -3.1503524780273438, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -3.154973030090332, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -3.6993825435638428, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": -3.5863540172576904, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -3.6957690715789795, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -3.0974276065826416, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -3.471959352493286, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": -3.2102572917938232, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -2.8224105834960938, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": -2.695841073989868, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": -3.2250771522521973, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -4.391496181488037, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": -4.2693257331848145, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": -5.523819446563721, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -4.7754011154174805, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": -4.798484802246094, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": -4.897063255310059, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": -5.103401184082031, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -4.573517799377441, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": -4.7928290367126465, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": -3.387516498565674, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -5.246242046356201, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": -4.365924835205078, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": -4.70215368270874, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": -5.150832176208496, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": -4.720948696136475, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": -5.241862773895264, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -5.436944007873535, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": -5.250262260437012, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": -5.867660045623779, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": -6.199116230010986, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -5.454075336456299, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -5.099089622497559, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -4.9395341873168945, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -5.1202826499938965, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -5.292822360992432, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -5.066089630126953, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -4.443789005279541, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": -3.829704999923706, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": -4.451542854309082, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": -4.943082809448242, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": -4.021325588226318, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": -5.21320104598999, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": -4.182582378387451, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": -3.070464849472046, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -4.925419807434082, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": -5.190820693969727, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": -4.0811567306518555, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": -4.749053001403809, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": -2.8098151683807373, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -3.033369541168213, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -2.0070154666900635, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": -1.8347281217575073, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": -2.144105911254883, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": -2.353419780731201, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": -1.6818358898162842, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": -1.6209059953689575, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -1.7081159353256226, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": -1.4941926002502441, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -1.5644822120666504, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -3.5098400115966797, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -3.209838628768921, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": -3.4945502281188965, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -3.415635347366333, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -3.4234721660614014, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": -3.2571933269500732, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": -3.1588056087493896, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": -2.9789884090423584, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -2.9133501052856445, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": -2.3872969150543213, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -2.3875670433044434, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -2.324662923812866, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -2.291844606399536, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": -2.2619130611419678, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": -2.1550426483154297, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": -2.2293331623077393, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": -3.6478919982910156, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -3.381657838821411, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -4.8553385734558105, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": -5.972522735595703, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": -4.222433090209961, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -5.179210186004639, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -5.0110321044921875, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": -4.753268718719482, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": -4.381407737731934, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": -4.4969377517700195, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -2.741515874862671, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": -2.770547866821289, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": -3.370682716369629, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": -3.4866318702697754, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": -4.463639259338379, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": -4.5936760902404785, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -4.369146823883057, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": -4.232141971588135, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": -3.986844539642334, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -4.245208740234375, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -4.060065269470215, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": -3.383484363555908, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": -3.3818578720092773, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": -4.560321807861328, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -3.8793609142303467, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": -4.104524612426758, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": -3.0438332557678223, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": -3.7577364444732666, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": -3.836346387863159, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -4.417436122894287, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": -4.598402500152588, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": -4.273797512054443, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": -5.948584079742432, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": -5.523548126220703, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": -5.334526538848877, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": -6.16411828994751, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": -6.291115760803223, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": -5.488147735595703, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": -6.084145545959473, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -5.468303203582764, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -4.3605499267578125, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": -5.810192584991455, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": -5.80193567276001, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": -4.695533752441406, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": -4.761996746063232, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -6.156547546386719, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -6.265928268432617, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -3.905517339706421, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -4.674711227416992, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -4.404232978820801, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": -4.414945125579834, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": -3.6202003955841064, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": -3.5070831775665283, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -3.8916783332824707, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -3.474385976791382, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": -3.839395523071289, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": -4.073233127593994, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": -3.0155794620513916, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": -3.951336622238159, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -3.9323551654815674, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": -3.5236833095550537, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": -2.9192757606506348, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": -3.9267947673797607, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -3.6702234745025635, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -4.596139430999756, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": -4.236914157867432, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": -2.5385448932647705, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -2.6649394035339355, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -2.6408231258392334, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": -2.3756258487701416, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": -2.5461554527282715, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -3.197763442993164, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": -3.8799164295196533, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -3.4827263355255127, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": -3.24053955078125, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": -2.2780933380126953, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -3.25518536567688, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": -2.9563307762145996, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -2.7817699909210205, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": -2.500922203063965, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": -3.527482271194458, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": -2.9213085174560547, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": -3.6521008014678955, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": -6.641815185546875, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": -6.895459175109863, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": -6.3789496421813965, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -6.216711044311523, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": -5.817533016204834, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -5.039096832275391, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": -7.664427280426025, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": -6.759448528289795, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -5.945134162902832, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -7.0006818771362305, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": -6.461031913757324, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -7.2749552726745605, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": -6.960305213928223, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": -7.136066913604736, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": -5.193940162658691, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": -5.051795959472656, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": -5.784646034240723, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -6.329106330871582, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": -6.040773868560791, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -2.9474081993103027, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": -3.0106089115142822, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -3.045865774154663, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -3.2070584297180176, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": -3.271054267883301, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": -3.307243824005127, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": -3.289296865463257, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -3.477045774459839, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -4.032845973968506, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -4.0605082511901855, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": -3.5073561668395996, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -5.079497337341309, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -4.988544940948486, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -3.9411513805389404, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -3.8062539100646973, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -3.3497555255889893, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -3.569349765777588, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -3.9238440990448, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": -3.978806495666504, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": -3.0066308975219727, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": -3.926762342453003, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -4.322369575500488, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": -3.5430142879486084, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -3.8352396488189697, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -3.8052420616149902, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -3.8384222984313965, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -2.632709503173828, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -4.114975452423096, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": -4.2314534187316895, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": -4.404394626617432, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -3.6645560264587402, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -3.5687692165374756, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": -3.662562608718872, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": -3.6080362796783447, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -2.4620444774627686, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -2.0879948139190674, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -2.149364709854126, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": -2.4797139167785645, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": -3.0565314292907715, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": -2.3406660556793213, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": -2.400101661682129, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": -2.7424070835113525, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -3.213590621948242, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": -2.88499116897583, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -3.038557291030884, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -2.664194345474243, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": -2.8238189220428467, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -2.760932445526123, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -3.1783807277679443, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -2.640887975692749, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": -2.7908642292022705, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": -2.524254560470581, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": -2.4667599201202393, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": -2.347156524658203, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": -2.3926002979278564, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": -2.289705991744995, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": -2.6834497451782227, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -2.1849350929260254, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -2.509713888168335, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": -2.352776050567627, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": -2.4423108100891113, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -2.516552209854126, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -2.89945650100708, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -3.098738670349121, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": -3.6454076766967773, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": -4.265998363494873, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -4.327999114990234, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": -3.932969331741333, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": -3.6663167476654053, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": -3.165194272994995, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -2.572188377380371, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": -3.1041557788848877, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": -2.875343084335327, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": -3.109771728515625, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -3.232915163040161, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -2.988302230834961, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": -3.1662814617156982, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -3.4214487075805664, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -4.101804733276367, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": -3.743385076522827, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -3.8181614875793457, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -3.5863101482391357, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": -3.108229875564575, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": -2.706930160522461, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -3.1580193042755127, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -2.788930654525757, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -3.2309956550598145, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -1.9728314876556396, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": -2.3518455028533936, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": -2.473067283630371, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": -5.332357406616211, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": -5.381455421447754, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": -4.615597248077393, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": -4.889718055725098, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": -4.4609832763671875, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": -5.806756973266602, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": -5.286625385284424, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -5.524487018585205, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -4.521651268005371, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -5.12087869644165, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": -4.983374118804932, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": -4.846686363220215, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": -4.549624919891357, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": -4.8745832443237305, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.427802562713623, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": -4.724285125732422, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": -4.929312229156494, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": -5.307123184204102, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": -5.964105129241943, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": -5.6698174476623535, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": -4.639018535614014, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": -5.195610523223877, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": -4.9866557121276855, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": -5.252693176269531, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": -4.868904113769531, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": -3.7882955074310303, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": -3.7022202014923096, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": -3.5920870304107666, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": -2.960514783859253, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": -3.0206875801086426, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": -3.43034291267395, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": -3.2613840103149414, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": -3.61409330368042, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": -3.643528699874878, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.2535321712493896, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -3.8252780437469482, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": -2.8267228603363037, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": -3.782644748687744, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": -3.2677431106567383, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": -2.7394590377807617, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": -4.586507797241211, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": -4.732074737548828, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -4.968839645385742, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": -4.675271034240723, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": -4.870193004608154, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -3.9732182025909424, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": -3.564786434173584, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -5.132424831390381, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -5.385344505310059, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -5.661250591278076, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": -4.237105846405029, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -1.5702146291732788, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -1.7159725427627563, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -1.6724237203598022, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -2.0121443271636963, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -2.938324451446533, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -2.7914986610412598, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -2.8377532958984375, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": -2.627164125442505, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -3.2317397594451904, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -2.8942012786865234, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": -3.293412685394287, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": -3.8311445713043213, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": -3.7580695152282715, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -3.092212200164795, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -2.8050055503845215, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -4.064183235168457, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": -3.645002841949463, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": -3.076366901397705, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -6.792789459228516, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": -4.6451897621154785, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": -5.35081672668457, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": -4.651253700256348, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": -4.434096336364746, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": -4.811375141143799, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": -5.682912349700928, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": -7.590211391448975, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": -4.6606292724609375, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": -3.5575826168060303, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": -3.7162833213806152, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": -3.779306173324585, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -4.743076801300049, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": -4.450291633605957, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": -4.985365390777588, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": -5.02490234375, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": -2.75164532661438, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": -3.2992801666259766, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": -2.7618889808654785, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -2.561657190322876, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": -2.5778698921203613, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -2.048013925552368, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": -3.668407678604126, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": -2.402118444442749, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -3.1823861598968506, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": -3.261369466781616, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": -3.910154342651367, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": -3.923431396484375, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": -4.29631233215332, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": -3.8419671058654785, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -5.084696292877197, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": -2.3924612998962402, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -2.0784921646118164, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -2.356757164001465, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -3.1755475997924805, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -3.189838409423828, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -2.32490873336792, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -2.7461585998535156, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -4.324718475341797, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -2.423102617263794, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": -2.4673519134521484, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": -2.4462523460388184, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": -2.630737066268921, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -3.705571174621582, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": -2.0518798828125, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": -2.238481044769287, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": -4.5069732666015625, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -4.775793552398682, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": -4.211631774902344, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": -4.166933536529541, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": -4.3499064445495605, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": -4.7391815185546875, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": -4.608121395111084, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -4.532625198364258, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": -4.210813999176025, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": -3.9007232189178467, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": -3.6870005130767822, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": -3.8026609420776367, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -4.258692264556885, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -4.513071537017822, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -3.5466809272766113, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -3.189875841140747, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": -3.130948781967163, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": -3.3508801460266113, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": -3.2309508323669434, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": -3.6773369312286377, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -3.764237880706787, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -4.597661972045898, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -4.337717056274414, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": -3.167217493057251, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": -3.907944440841675, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": -3.430443048477173, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": -3.634525775909424, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": -2.508734703063965, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -3.0726072788238525, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": -4.056229591369629, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": -4.0263261795043945, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": -4.596679210662842, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": -4.5367350578308105, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": -3.896312713623047, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": -4.317710876464844, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -4.3585968017578125, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": -3.373908519744873, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -4.021493434906006, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -4.3133440017700195, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": -4.013141632080078, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": -4.388591766357422, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -4.437829494476318, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -4.567445278167725, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": -4.853612422943115, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": -4.11179256439209, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -4.661942005157471, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -6.344722270965576, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -3.9799797534942627, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -4.599727630615234, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -5.223723888397217, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -3.9218454360961914, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -3.711454153060913, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": -4.266801357269287, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": -5.6389689445495605, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -5.074189186096191, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": -4.804760456085205, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": -4.506194114685059, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -4.417525768280029, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": -4.978493690490723, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -6.543245792388916, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": -6.004430294036865, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -5.752226829528809, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": -4.472527980804443, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -4.127964973449707, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -2.4681849479675293, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.899723768234253, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -3.469630479812622, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -6.732649803161621, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": -7.628556251525879, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": -7.007566452026367, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": -7.510087966918945, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -7.596124172210693, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": -6.759806156158447, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": -6.572453498840332, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -7.216283321380615, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": -3.394761085510254, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": -3.5830938816070557, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -3.972700357437134, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": -2.687992811203003, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -2.640437602996826, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": -2.6268911361694336, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -3.1473395824432373, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": -3.3164284229278564, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -3.1227779388427734, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": -3.5324432849884033, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -3.489243745803833, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -3.5340919494628906, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -3.3475990295410156, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -3.4157185554504395, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -5.84027099609375, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": -5.2672905921936035, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": -4.948997974395752, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": -4.900701522827148, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": -5.157842636108398, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": -4.902860164642334, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": -5.401073932647705, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": -3.591236114501953, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": -3.6667087078094482, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": -4.798236846923828, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -4.659868240356445, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -3.2778127193450928, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": -3.623180627822876, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": -3.568042278289795, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": -3.634218454360962, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": -3.0686845779418945, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": -3.514482259750366, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": -3.2363946437835693, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": -2.9840352535247803, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -3.7173821926116943, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -2.7388837337493896, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -5.413711071014404, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": -4.079289436340332, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": -3.775406837463379, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": -3.903639554977417, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": -3.9414424896240234, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": -4.3830718994140625, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": -3.5963191986083984, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -4.528805255889893, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -4.785755634307861, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": -4.740671157836914, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": -4.571068286895752, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": -4.587764263153076, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": -4.0866522789001465, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": -3.407818078994751, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": -5.464204788208008, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -5.632685661315918, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -4.239137649536133, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": -7.8659186363220215, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -5.434419631958008, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -5.407713890075684, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -6.021812915802002, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -6.029812335968018, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": -5.301197528839111, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": -5.334539890289307, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -5.26688814163208, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -4.240052223205566, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -4.368261337280273, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -3.18776273727417, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": -3.5277905464172363, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": -3.6785292625427246, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -2.5285444259643555, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": -2.9731125831604004, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": -2.829897880554199, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -4.158510208129883, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -4.003491401672363, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -3.814572334289551, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": -3.232607841491699, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": -3.3436439037323, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": -4.358837604522705, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": -4.363704681396484, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -4.069090843200684, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -3.9309959411621094, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": -4.411968231201172, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -2.548729419708252, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": -2.49269962310791, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -2.437382221221924, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": -2.942302942276001, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": -3.8632140159606934, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -3.9833905696868896, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -2.968825101852417, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": -4.591165065765381, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": -4.5309038162231445, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": -3.943223237991333, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": -4.770256996154785, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": -4.093761444091797, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -3.8612608909606934, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": -4.252291202545166, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -4.2185258865356445, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": -5.181571960449219, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": -4.663662910461426, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": -4.433403015136719, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -5.282678604125977, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -5.20654821395874, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -4.824530601501465, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -5.099240779876709, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -4.2522687911987305, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": -4.258301258087158, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -3.9566400051116943, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": -4.13801908493042, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": -4.612829685211182, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": -2.847416877746582, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": -3.4255168437957764, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": -3.2269604206085205, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": -2.788729429244995, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -2.824359893798828, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": -3.052668333053589, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": -3.418741464614868, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -3.387570381164551, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -3.9114391803741455, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -4.065336227416992, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": -4.3415327072143555, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": -5.4453349113464355, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -5.5228962898254395, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -5.544732093811035, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": -5.4729461669921875, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -6.660963535308838, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -6.4763922691345215, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -4.478976249694824, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": -4.907191753387451, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": -5.86683988571167, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": -4.188579082489014, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": -5.674649238586426, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -5.717710018157959, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": -6.036621570587158, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": -5.85478401184082, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -5.709803581237793, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": -5.727370738983154, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": -6.035646438598633, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -6.362344741821289, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -6.7093424797058105, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -7.108487129211426, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -5.4198808670043945, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -6.380059242248535, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": -6.642141819000244, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": -7.352542877197266, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": -6.631113529205322, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -7.120119094848633, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -6.907416820526123, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": -7.215344429016113, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -6.971077919006348, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": -6.897181987762451, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": -7.283603668212891, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -6.49800443649292, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": -5.1211724281311035, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": -3.6746926307678223, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": -3.4845449924468994, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": -3.575435161590576, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": -3.6247293949127197, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": -2.869335412979126, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": -3.906411647796631, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": -3.589778423309326, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": -3.0932862758636475, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": -3.6840925216674805, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.7941360473632812, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": -6.279681205749512, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": -5.739294528961182, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -6.042718410491943, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": -5.980036735534668, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -5.620779991149902, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -5.187619209289551, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -6.674992084503174, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -6.819550037384033, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": -6.114410877227783, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": -5.5620951652526855, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -5.536381721496582, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": -3.0471675395965576, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -2.9261879920959473, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": -3.1725387573242188, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -3.752673864364624, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -3.8568577766418457, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -4.942365646362305, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -3.1797034740448, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": -3.2032883167266846, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": -3.29259991645813, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": -3.0837907791137695, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": -2.9839587211608887, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": -1.5793304443359375, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": -0.3386399745941162, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": -0.6066361665725708, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": -1.1273313760757446, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": -1.139746069908142, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": -0.8700952529907227, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -1.3974287509918213, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": -1.1432844400405884, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": -1.0779393911361694, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": -0.8921818137168884, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": -0.9124529957771301, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": -0.6906599402427673, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": -1.468015193939209, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": -1.774086356163025, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": -1.6288797855377197, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": -0.7182140350341797, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": -1.4240251779556274, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": -1.5990158319473267, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": -2.260577917098999, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": -1.4570704698562622, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": -0.7702620029449463, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": -2.093247175216675, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": -1.460252285003662, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": -1.5284886360168457, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": -1.7178409099578857, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": -1.849600911140442, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": -1.5821080207824707, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": -1.5546361207962036, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": -2.485996723175049, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": -1.959211826324463, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": -2.1365835666656494, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": -2.3494980335235596, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": -1.414552927017212, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": -1.3385727405548096, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": -1.3192826509475708, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": -1.3542405366897583, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": -1.2869433164596558, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": -2.1492984294891357, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": -0.2042546570301056, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": -0.6039175391197205, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": -1.4348515272140503, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": -0.7525573372840881, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": -1.740633249282837, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": -2.3854494094848633, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": -2.030940532684326, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": -0.9836751818656921, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": -1.2793201208114624, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": -1.2328218221664429, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": -1.6185036897659302, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": -1.5202380418777466, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": -0.9224631786346436, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -0.6605522036552429, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": -0.8635042905807495, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": -0.7943082451820374, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": -0.8728619813919067, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": -0.7869472503662109, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": -0.17961649596691132, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": -0.30677372217178345, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": -0.3844347298145294, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": -0.47244492173194885, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": -0.5176213979721069, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": -1.193021297454834, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": -1.5825754404067993, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": -1.656615138053894, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": -1.6231993436813354, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": -1.6169003248214722, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": -1.7128803730010986, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": -1.599549412727356, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": -1.5501813888549805, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": -1.5531164407730103, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": -0.5559641122817993, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": -0.5147886276245117, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": -0.48789647221565247, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": -0.6109480261802673, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": -0.5583378076553345, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": -0.5488558411598206, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": -0.5581833720207214, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": -1.4750500917434692, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": -1.0945720672607422, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": -0.9208037853240967, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": -2.634246587753296, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": -1.0617647171020508, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": -0.9755017757415771, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": -0.8871098160743713, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": -2.1612138748168945, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": -1.959204912185669, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": -1.7251263856887817, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": -0.9083702564239502, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": -0.9043962359428406, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": -0.795539140701294, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": -1.005604863166809, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": -0.5135535597801208, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": -1.041568398475647, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": -0.43796899914741516, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": -0.4092741310596466, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": -0.39452773332595825, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": -0.5989896655082703, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": -0.4781475365161896, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": -1.2757444381713867, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": -1.3071010112762451, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -1.4424288272857666, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": -0.7024034261703491, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": -1.3886243104934692, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": -0.6554731726646423, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": -1.3257298469543457, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": -1.3706328868865967, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": -1.6659761667251587, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": -1.8181687593460083, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -2.0179829597473145, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -1.406087875366211, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": -1.0864651203155518, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": -2.1734182834625244, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": -1.8220123052597046, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": -1.6228489875793457, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": -1.2134534120559692, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": -0.9925497770309448, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": -1.258803367614746, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": -1.4048693180084229, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": -1.2095900774002075, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": -0.7187108397483826, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": -2.2112927436828613, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": -2.2117886543273926, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": -1.924555778503418, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": -1.9193533658981323, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": -1.7649424076080322, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": -1.8945544958114624, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": -1.9902231693267822, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": -2.00016713142395, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": -1.4538748264312744, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": -1.0874958038330078, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -1.1027657985687256, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": -0.8530477285385132, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": -1.0660871267318726, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": -1.3925387859344482, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": -1.6132956743240356, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": -1.685394525527954, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": -1.6273133754730225, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": -1.569743037223816, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": -1.0141254663467407, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": -1.2763803005218506, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": -1.2423560619354248, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": -1.409285068511963, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": -1.8523666858673096, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": -0.630407452583313, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": -1.2426462173461914, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -1.19795823097229, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": -0.7800688147544861, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": -0.5423478484153748, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": -1.1780658960342407, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": -1.181146264076233, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": -0.9817159175872803, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": -0.9313755035400391, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": -0.9490402936935425, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": -0.8036763072013855, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": -1.26613187789917, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": -0.8601390719413757, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": -0.8201642036437988, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": -0.5648239850997925, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": -1.3028912544250488, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": -1.2925969362258911, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": -3.579207420349121, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": -1.7752635478973389, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": -2.7721197605133057, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": -0.83809494972229, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": -1.651466965675354, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": -1.4543590545654297, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": -2.081183433532715, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": -2.2773990631103516, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": -2.692565679550171, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": -1.6770504713058472, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": -1.5986809730529785, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": -2.257812976837158, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": -2.227414131164551, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": -2.062645673751831, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": -2.1379172801971436, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": -1.982905626296997, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": -1.619933843612671, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": -1.43576979637146, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": -1.947229027748108, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": -1.2781716585159302, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": -0.6059046387672424, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": -1.1831443309783936, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": -0.3439643681049347, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": -0.3802606165409088, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": -1.5765905380249023, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": -1.5360254049301147, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": -1.588009238243103, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -1.4076342582702637, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -1.331429362297058, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": -1.5125035047531128, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": -1.175573706626892, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": -1.4759044647216797, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -1.777660608291626, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": -0.7045328617095947, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": -0.8186622858047485, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": -0.7953992486000061, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -1.9781798124313354, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": -2.040315628051758, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": -0.666896402835846, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": -1.6265122890472412, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": -1.8275490999221802, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -1.355084776878357, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": -0.5356783866882324, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": -0.9541614651679993, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": -1.0470136404037476, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": -0.38598668575286865, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": -2.0536797046661377, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": -2.166334390640259, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": -2.1086857318878174, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -1.0443857908248901, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -1.5650837421417236, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": -1.616254448890686, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": -1.8000385761260986, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": 0.08724179863929749, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -0.32694634795188904, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": -1.1668390035629272, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": -1.1467140913009644, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": -1.2304414510726929, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": -0.28019747138023376, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": -0.7151187062263489, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": -0.5330749154090881, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": -0.7170394659042358, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": -0.7086692452430725, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -0.5447890162467957, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": -0.8425978422164917, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -0.7691192626953125, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": -0.7283124923706055, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": -1.035970687866211, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": -1.0237685441970825, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": -1.0436331033706665, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": -0.9203091263771057, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": -0.8533544540405273, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": -0.37059545516967773, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": -0.30060404539108276, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": -0.531226634979248, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": -0.4825955033302307, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": -0.6969283223152161, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": -0.8991882801055908, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -0.8116040229797363, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": -0.8294022679328918, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": -0.8432760834693909, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": -1.1694259643554688, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": -0.8039877414703369, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": -0.787101686000824, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": -1.7842700481414795, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": -1.7787739038467407, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": -0.7393859624862671, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": -0.47591856122016907, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": -0.8940849304199219, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": -0.8242979645729065, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": -0.7360490560531616, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": -1.048547625541687, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": -1.2236298322677612, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": -1.2562119960784912, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": -0.8217189908027649, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": -0.7889475226402283, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": -0.9303635954856873, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": -1.3767677545547485, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": -0.9082226753234863, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": -0.8722160458564758, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": -0.946395993232727, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": -0.7337520122528076, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": -0.7785698771476746, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": -0.8139783143997192, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": -1.0860705375671387, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": -1.166969895362854, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": -0.6989108324050903, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": -0.5923544764518738, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": -0.4918759763240814, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": -1.1514378786087036, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": -0.9468256235122681, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": -0.8423957228660583, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": -1.3712998628616333, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": -0.7293978929519653, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": -1.507312536239624, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": -1.626999020576477, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": -1.2152295112609863, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": -1.5028148889541626, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": -1.337175726890564, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": -1.137499213218689, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": -1.3662246465682983, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -2.0934667587280273, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": -1.9115415811538696, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": -2.006162643432617, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": -1.9136282205581665, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": -2.0810935497283936, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": -2.0864152908325195, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": -1.831087350845337, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": -1.9696316719055176, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": -2.1387741565704346, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": -2.5705578327178955, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": -2.068910598754883, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": -2.0467514991760254, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": -0.8598767518997192, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": -1.1387608051300049, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": -1.3851009607315063, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": -1.0754187107086182, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": -1.063109278678894, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": -1.449560523033142, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": -1.0850414037704468, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": -1.336409330368042, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": -1.1986602544784546, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": -0.6825391054153442, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": -0.6786816716194153, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": -1.236074447631836, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": -0.6231013536453247, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": -0.463207483291626, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": -0.6072850823402405, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": -1.0374064445495605, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": -2.1740801334381104, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": -1.8932750225067139, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": -1.8794344663619995, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": -1.9947861433029175, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": -1.5080268383026123, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": -1.5660001039505005, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": -1.3381221294403076, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -2.2366812229156494, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": -2.2404003143310547, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": -2.2413597106933594, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": -1.8062713146209717, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": -0.7263314127922058, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": -0.7975068092346191, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": -0.7957483530044556, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": -0.7118898034095764, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": -0.7321929931640625, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": -0.7853003144264221, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": -0.7524705529212952, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": -0.49633389711380005, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": -0.9018470048904419, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": -0.8959497213363647, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": -0.9241054058074951, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": -1.198999047279358, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": -1.0940786600112915, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": -0.2030409872531891, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": -1.1595209836959839, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": -0.8241695761680603, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": -0.5313515067100525, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": -1.1857420206069946, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": -2.24733567237854, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": -1.7090815305709839, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": -1.7544888257980347, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": -2.4426357746124268, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": -1.2136198282241821, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": -0.6513227224349976, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": -2.5740435123443604, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": -3.206010580062866, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": -0.6772065758705139, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": -1.7722936868667603, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": -1.067476511001587, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -1.0568757057189941, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": -1.032668113708496, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -1.4348303079605103, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": -1.563767671585083, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": -1.7050107717514038, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": -1.2523306608200073, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": -0.9818125367164612, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": -0.6945610046386719, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": -0.6241200566291809, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": -0.6277928948402405, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": -0.943081796169281, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": -0.6452227234840393, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": -0.8966981768608093, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": -0.7916486859321594, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": -0.7835677862167358, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": -1.3107515573501587, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": -1.0993295907974243, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": -1.8770077228546143, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": -1.8487263917922974, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": -1.9059489965438843, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": -0.23495134711265564, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": -0.7346991300582886, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": -0.6860364675521851, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -0.7511520981788635, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -0.8476157188415527, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -1.2829341888427734, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -0.7268734574317932, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": -2.0280601978302, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": -0.6003614068031311, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": -0.19366997480392456, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": -0.7375174760818481, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": -0.7599180340766907, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": -0.9997471570968628, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": -0.7191975712776184, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": -0.8507235646247864, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": -1.813844919204712, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": -1.9269781112670898, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": -1.6688692569732666, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": -1.6972726583480835, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": -1.6687583923339844, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": -0.9452236890792847, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": -1.3404637575149536, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": -1.5771164894104004, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": -1.3309500217437744, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": -1.1251492500305176, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": -1.192922830581665, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": -1.333432674407959, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": -1.1278433799743652, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": -1.084143042564392, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": -1.2883034944534302, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": -0.5458956360816956, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": -0.5883055329322815, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": -1.4416223764419556, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": -1.354504108428955, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": -1.3765846490859985, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": -1.4383494853973389, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": -1.3342781066894531, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": -1.3334842920303345, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": -0.23088467121124268, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": -0.2701609432697296, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": -0.966873824596405, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": -1.2145929336547852, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": -0.4861750304698944, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": -0.462912380695343, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": -1.2776682376861572, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": -1.3254425525665283, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": -1.5401476621627808, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": -1.594929575920105, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": -1.7677198648452759, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": -1.4388046264648438, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": -1.4498974084854126, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": -1.0218411684036255, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": -1.2970685958862305, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": -1.3577823638916016, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": -0.25416600704193115, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": -0.7554976344108582, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": -1.0868221521377563, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": -2.2906394004821777, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": -2.378765821456909, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": -2.5859439373016357, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": -2.1249704360961914, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": -1.6778484582901, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": -2.277637004852295, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": -1.9305877685546875, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": -1.7422462701797485, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": -2.014101505279541, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": -1.9917324781417847, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": -1.2047291994094849, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": -2.077045202255249, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": -1.653107762336731, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": -1.5376180410385132, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": -1.4543657302856445, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": -1.5344308614730835, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": -0.553213894367218, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": -1.7032865285873413, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": -1.5616077184677124, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": -0.9944790005683899, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": -1.905419111251831, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": -1.9244791269302368, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": -0.7353504300117493, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": -1.112964391708374, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": -0.8417492508888245, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": -2.4756593704223633, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": -2.687723159790039, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": -2.790431022644043, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": -2.8153600692749023, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": -3.1138272285461426, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": -2.2507729530334473, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": -2.919771194458008, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": -1.5954054594039917, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": -1.065798282623291, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": -1.1142011880874634, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": -1.1895217895507812, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": -0.7141769528388977, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": -0.5605641603469849, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": -0.9276348352432251, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": -0.9833197593688965, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": -0.9504334926605225, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -1.2587393522262573, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": -1.7300000190734863, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -1.88367760181427, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": -1.8614481687545776, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": -1.1292585134506226, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": -1.1820170879364014, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": -2.3315131664276123, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": -2.017615556716919, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -2.0742287635803223, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": -1.877847671508789, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": -1.979557752609253, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": -1.7299554347991943, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": -2.2394981384277344, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": -1.6015499830245972, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": -1.3728324174880981, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": -1.137937307357788, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": -1.2004764080047607, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": -1.4159290790557861, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": -1.4189338684082031, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": -1.4090567827224731, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": -1.4107979536056519, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": -0.4066404700279236, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": -1.389673113822937, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": -1.1020009517669678, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": -1.0727314949035645, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": -1.1451019048690796, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": -1.0572686195373535, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": -2.1062779426574707, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": -1.6030666828155518, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": -1.0114842653274536, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": -0.9377049803733826, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": -0.9836239814758301, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": -1.28663969039917, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": -1.1798229217529297, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": -1.2984422445297241, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": -1.204878330230713, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -1.1810373067855835, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": -1.2803964614868164, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": -1.2376000881195068, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": -1.5662354230880737, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": -1.8467607498168945, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": -1.099025011062622, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": -1.55122971534729, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": -1.7043029069900513, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": -2.004977226257324, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": -2.2644708156585693, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": -1.1932313442230225, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": -0.9867665767669678, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": -0.918413519859314, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": -2.0863423347473145, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": -2.14388370513916, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": -2.146881103515625, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -1.9218058586120605, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": -1.8001434803009033, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -0.9418633580207825, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": -1.3270677328109741, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": -0.99443519115448, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -1.134224534034729, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": -1.3806407451629639, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": -0.47156664729118347, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": -1.3198784589767456, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": -0.9727766513824463, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -0.712227463722229, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": -1.2042841911315918, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": -1.30672025680542, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": -1.7680153846740723, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": -1.8652113676071167, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": -0.9121977686882019, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": -1.7785627841949463, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": -1.4213629961013794, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -0.8279338479042053, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": -0.7687971591949463, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": -0.8542805910110474, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": -0.819174587726593, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": -1.3057807683944702, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -1.2841225862503052, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": -0.6265795230865479, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": -1.8401150703430176, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": -1.3862075805664062, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": -1.6940453052520752, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": -1.4079958200454712, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": -1.5120048522949219, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": -1.5034242868423462, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": -1.1250765323638916, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -1.1370294094085693, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": -1.4609625339508057, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": -1.3878421783447266, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": -1.32957923412323, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": -1.3149738311767578, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": -1.1686830520629883, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": -0.7331857681274414, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": -0.6091421842575073, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": -1.4375454187393188, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": -1.3129926919937134, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": -1.4415607452392578, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": -0.6036281585693359, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": -1.4913184642791748, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": -1.3650431632995605, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": -1.0206013917922974, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": -0.9081404209136963, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": -1.5527735948562622, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": -1.1987990140914917, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": -1.086661696434021, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": -0.9421762228012085, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": -0.9798345565795898, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": -1.1713215112686157, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": -1.4503273963928223, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": -1.2748398780822754, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": -1.7251726388931274, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": -1.90568208694458, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -1.7606265544891357, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": -0.29791513085365295, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -4.2716755867004395, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": -1.6680243015289307, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": -2.2965054512023926, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": -1.0968902111053467, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": -1.5245212316513062, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": -1.230912208557129, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": -1.9569684267044067, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": -2.143126964569092, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": -1.9057914018630981, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": -1.9545046091079712, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": -2.1852407455444336, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": -2.1063785552978516, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": -2.018118143081665, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": -2.3353257179260254, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": -2.7735626697540283, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": -2.036341428756714, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": -1.949866533279419, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": -2.4541397094726562, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": -2.3564720153808594, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": -2.262061595916748, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": -2.3837432861328125, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": -2.694272518157959, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": -1.0280643701553345, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": -1.5657631158828735, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": -1.5768442153930664, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": -1.6732062101364136, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": -1.8823237419128418, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": -2.0594394207000732, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": -1.6474961042404175, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": -1.6091055870056152, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": -1.4945740699768066, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": -1.0027194023132324, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": -0.8738247156143188, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": -0.8441886901855469, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": -0.8196900486946106, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": -1.0549908876419067, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": -1.150259017944336, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": -1.2988754510879517, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": -1.2661845684051514, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": -2.148043155670166, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": -2.4858853816986084, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": -2.454902172088623, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": -2.189439058303833, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": -2.1197290420532227, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": -1.3636078834533691, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": -2.370382785797119, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": -2.1345653533935547, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -1.6626505851745605, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": -1.8472392559051514, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": -2.360694646835327, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": -0.6291685104370117, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": -0.7307078242301941, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": -1.1867907047271729, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": -1.1127946376800537, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -1.049731731414795, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -1.2533459663391113, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": -0.7303784489631653, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": -0.7168490290641785, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": -0.5208616256713867, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": -0.8286248445510864, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": -1.0105972290039062, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 6.44242525100708, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 7.119933128356934, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 7.0878586769104, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 6.75143575668335, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 7.646886825561523, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 7.599708080291748, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": 6.78194522857666, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": 6.350749492645264, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 6.363409519195557, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": 5.933447360992432, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 5.853187561035156, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 6.542262554168701, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 10.160593032836914, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 8.65396499633789, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 8.961529731750488, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 10.434885025024414, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 9.038124084472656, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 9.4014310836792, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 9.322399139404297, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 9.3804292678833, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 9.130976676940918, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 8.232771873474121, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 9.134203910827637, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 8.617166519165039, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": 8.790091514587402, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": 9.15243148803711, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 9.096107482910156, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 8.670356750488281, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 11.807844161987305, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 11.304010391235352, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 11.720206260681152, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 11.0661039352417, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 10.297859191894531, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": 9.616209983825684, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 10.214313507080078, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 9.734882354736328, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 10.050962448120117, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 10.531621932983398, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 9.262715339660645, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 9.040542602539062, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 9.38218879699707, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 8.908907890319824, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 9.480887413024902, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 8.625937461853027, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 8.439367294311523, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 8.332025527954102, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 8.197508811950684, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 9.362689971923828, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 8.541336059570312, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 9.307796478271484, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 5.951233386993408, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 7.334356784820557, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 3.441554546356201, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 3.300849199295044, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 3.2934024333953857, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 3.7783255577087402, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 3.935070037841797, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 4.069378852844238, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 3.716883420944214, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 3.746779203414917, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 3.510507822036743, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 5.755338191986084, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 6.816492080688477, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 6.112684726715088, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 6.285821914672852, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 5.922773838043213, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 6.711319446563721, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 6.064018726348877, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 6.776413440704346, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 6.8418073654174805, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 5.3042988777160645, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 4.150613784790039, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 4.161302089691162, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 4.496865749359131, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 4.090243339538574, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 4.55704927444458, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 4.461277961730957, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 5.868112087249756, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 5.99063777923584, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 8.52448558807373, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 10.493786811828613, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 10.167278289794922, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 9.832326889038086, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 10.711143493652344, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 8.819849967956543, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 8.912633895874023, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 7.799365997314453, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 6.33791446685791, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 6.37909460067749, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 8.133611679077148, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 7.808767318725586, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 9.09640884399414, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 9.279224395751953, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 8.12138843536377, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 7.908900260925293, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 8.650402069091797, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 8.575915336608887, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 7.963813304901123, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 8.189574241638184, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 8.077909469604492, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 7.635969161987305, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 8.57835865020752, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 9.099989891052246, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 4.646775722503662, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 6.7272844314575195, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": 7.051004409790039, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 7.874227523803711, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 8.037461280822754, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 7.502870559692383, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 13.849235534667969, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 14.555395126342773, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 10.024314880371094, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 9.102640151977539, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 9.062414169311523, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 10.54573917388916, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 9.662028312683105, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 9.06899642944336, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 10.745865821838379, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 9.776222229003906, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 10.970254898071289, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 11.96401309967041, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 11.819497108459473, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 10.018353462219238, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 9.855454444885254, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 8.792333602905273, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 7.454135417938232, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 8.417159080505371, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 8.611626625061035, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 6.239546775817871, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 7.452734470367432, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 7.50393533706665, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": 8.455405235290527, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 7.529179096221924, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 7.229579925537109, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 6.525679588317871, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 7.389513969421387, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 7.169402599334717, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 6.796781539916992, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 7.173099517822266, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 6.562859058380127, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 7.2335100173950195, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 7.369751453399658, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 8.221086502075195, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 4.627559661865234, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 5.113148212432861, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 5.001250743865967, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 4.953166961669922, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 4.870550632476807, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 6.696098327636719, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 8.15292739868164, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 8.938582420349121, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 8.223645210266113, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": 5.709514617919922, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 4.716357231140137, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 5.730381488800049, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 5.989377021789551, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 5.813709259033203, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 5.983046531677246, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 6.9822869300842285, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 7.143868446350098, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 12.603129386901855, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 13.318949699401855, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 14.398468017578125, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 12.56020450592041, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 11.881718635559082, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 10.041082382202148, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 15.112136840820312, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 10.072324752807617, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 12.215296745300293, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 13.262344360351562, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 11.681585311889648, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 12.267688751220703, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 11.200095176696777, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 13.316904067993164, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 11.860135078430176, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 13.34777545928955, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 12.337682723999023, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 13.658371925354004, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 13.182790756225586, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 5.588159561157227, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 5.5253496170043945, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 5.918810844421387, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 7.770699501037598, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 7.8333563804626465, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 6.336348056793213, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": 6.174731731414795, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 7.269944667816162, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 6.351038932800293, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 6.33950662612915, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 6.419040203094482, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 8.586856842041016, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 10.861992835998535, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 9.917713165283203, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 5.787021636962891, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": 6.693829536437988, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 6.5373735427856445, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 6.018726348876953, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 5.741212844848633, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 5.311969757080078, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 7.759718418121338, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 6.36519718170166, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 5.80181884765625, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": 6.205177307128906, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 6.555182933807373, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 7.000260829925537, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 6.809412479400635, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 7.5207600593566895, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 6.041316032409668, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 5.883327960968018, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 6.839687347412109, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": 6.217465877532959, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 5.955320835113525, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 6.888370513916016, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 5.873354911804199, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 5.6609649658203125, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.788509368896484, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 4.332564353942871, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 5.441709041595459, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 5.527358531951904, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 5.228763580322266, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 5.9253740310668945, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 5.4029011726379395, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 5.944394588470459, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 5.360775947570801, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 5.563313961029053, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": 5.347412109375, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 5.707730293273926, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 5.9847331047058105, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": 4.589234828948975, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 4.597904682159424, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 4.9350199699401855, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 5.081120491027832, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 6.6459174156188965, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 6.509714603424072, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.557188034057617, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 5.8516998291015625, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 4.778357028961182, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.554792881011963, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 4.9315080642700195, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 5.116124629974365, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 5.141764163970947, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 4.61113977432251, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 5.955816268920898, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 6.014526844024658, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 6.595561981201172, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 7.24875020980835, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 6.798802852630615, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 7.02449893951416, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 6.75741720199585, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 4.89534330368042, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 4.854712009429932, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 5.248372554779053, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 5.4784159660339355, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 5.148327350616455, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 5.844515800476074, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 5.94085693359375, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 7.710791110992432, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 7.136485576629639, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 7.1948676109313965, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 7.068617820739746, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 7.0412726402282715, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 5.577961444854736, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 6.063137054443359, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 6.08484411239624, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 5.061281204223633, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 5.277675151824951, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 4.835519790649414, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 4.051097869873047, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 4.234492301940918, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 13.54055404663086, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 12.169087409973145, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 11.858327865600586, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 8.562613487243652, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 9.596062660217285, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 11.716014862060547, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 10.148331642150879, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 11.377574920654297, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 10.052515029907227, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 9.619640350341797, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": 10.12104320526123, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 7.71097469329834, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 10.455362319946289, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 9.480401039123535, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 8.835434913635254, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 10.35590648651123, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 9.454895973205566, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 9.522154808044434, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 10.69210433959961, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 9.89820384979248, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 10.385075569152832, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 9.640055656433105, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 11.137589454650879, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 10.630555152893066, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 8.652636528015137, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 7.972969055175781, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 7.905138969421387, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 7.219156742095947, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 4.805926322937012, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 5.998935699462891, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 6.304920196533203, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 6.693556308746338, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 7.294597625732422, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 7.1022515296936035, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 7.9989399909973145, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 7.282175064086914, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 6.3523077964782715, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 6.280169486999512, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 7.244989395141602, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 6.345453262329102, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 8.540804862976074, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 8.607023239135742, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 7.57801628112793, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 7.548185348510742, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 10.406472206115723, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 6.508364200592041, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 6.934550762176514, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 8.719722747802734, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 8.32511043548584, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 8.030926704406738, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 9.917937278747559, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 3.0378055572509766, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 3.4540836811065674, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 3.886277198791504, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 3.4497852325439453, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 5.634133338928223, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 5.176501274108887, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 5.658136367797852, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 6.040293216705322, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 7.010168075561523, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 5.627787113189697, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 6.835237503051758, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 6.047579288482666, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 6.360288619995117, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 6.499030590057373, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 6.444857597351074, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 6.178199291229248, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 5.760493278503418, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 6.602076530456543, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 11.737799644470215, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 9.446699142456055, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 9.271122932434082, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 8.458904266357422, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 8.216804504394531, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 8.339337348937988, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.396873474121094, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 13.146418571472168, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 9.120341300964355, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 7.542057991027832, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 6.612941741943359, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 7.144115924835205, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 8.564892768859863, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.30569076538086, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 8.717899322509766, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 10.7899169921875, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 5.776623725891113, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 6.6342573165893555, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 6.428171157836914, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 6.43193244934082, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 6.259112358093262, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 6.5758538246154785, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 5.506444454193115, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 6.3477959632873535, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 6.1728129386901855, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 6.343296527862549, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 8.123056411743164, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 8.212301254272461, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 7.309240818023682, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 6.520120143890381, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 8.738837242126465, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 5.494771480560303, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 5.228726387023926, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 5.386542797088623, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": 5.221736431121826, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": 4.91135835647583, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": 5.129876613616943, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 6.467576026916504, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 6.78586483001709, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 5.894855499267578, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 6.256791591644287, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 5.770027160644531, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 5.016124248504639, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 6.512770175933838, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 5.377038478851318, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 4.671774387359619, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 9.381853103637695, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 8.205405235290527, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": 7.49556827545166, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": 7.3695831298828125, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 7.504415512084961, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 8.773069381713867, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 8.396282196044922, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 7.213515758514404, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 8.378059387207031, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 8.653185844421387, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 7.6507086753845215, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 7.640504837036133, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": 8.275436401367188, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": 7.91212797164917, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": 8.251493453979492, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 7.766905784606934, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 7.664503574371338, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 6.081905841827393, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 6.450358867645264, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 5.78774356842041, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 8.115100860595703, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 8.393680572509766, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 8.888397216796875, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 8.50220775604248, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 7.62954568862915, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 7.329501628875732, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 7.118637561798096, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 6.446343898773193, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 7.15817928314209, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 8.638924598693848, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 8.744651794433594, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 9.004300117492676, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 7.582159996032715, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 7.16995096206665, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 8.094589233398438, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 8.173418998718262, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 7.786073207855225, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 7.542136192321777, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 9.262347221374512, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 8.472554206848145, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 8.396621704101562, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 7.448306560516357, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 9.599287033081055, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 9.6124267578125, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 10.75981616973877, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 9.809743881225586, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 9.578779220581055, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 8.749266624450684, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 9.265604972839355, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 8.716691970825195, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 8.401588439941406, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 7.894198417663574, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 9.121498107910156, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 8.73010540008545, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 9.707252502441406, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 9.032855033874512, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 10.13469409942627, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 9.839611053466797, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 11.05491828918457, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 13.115935325622559, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 12.38604736328125, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 11.210824966430664, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 7.949946880340576, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 7.453067779541016, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 6.420390605926514, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 6.397250175476074, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 7.119836330413818, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 13.327613830566406, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 12.316282272338867, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 13.807828903198242, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 14.341822624206543, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 11.986412048339844, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 13.454182624816895, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 12.272390365600586, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 13.51424789428711, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 7.534616470336914, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 6.95334529876709, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 6.58003044128418, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 6.370406150817871, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 6.196560382843018, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 6.947127342224121, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 6.14371395111084, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.077942848205566, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 6.546658039093018, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.809438228607178, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 6.651566982269287, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 6.584951877593994, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 7.917222499847412, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 8.109935760498047, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 8.196521759033203, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 10.529877662658691, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 11.544147491455078, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 11.828389167785645, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 10.63341999053955, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 11.072500228881836, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 10.423125267028809, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 8.992118835449219, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 8.325664520263672, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 7.849891185760498, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 7.363802909851074, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 7.216925144195557, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 7.056357383728027, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 7.232532978057861, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 7.127587795257568, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 6.342020511627197, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 7.160610198974609, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 6.107128143310547, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 6.145669937133789, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 7.111682891845703, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 6.072910308837891, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 10.38752269744873, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 9.405823707580566, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 8.136987686157227, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 8.295087814331055, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 8.015007972717285, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 7.715789318084717, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 8.484610557556152, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 9.49968147277832, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 8.772159576416016, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 8.810076713562012, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 9.422101020812988, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 8.773214340209961, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 7.799867630004883, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 8.123867988586426, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 8.721755981445312, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 10.22288703918457, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 9.164045333862305, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 11.509112358093262, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 12.715229988098145, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 10.288811683654785, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 9.621590614318848, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": 10.064018249511719, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 9.560905456542969, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 9.443747520446777, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 9.246569633483887, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 10.02010726928711, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 6.724331855773926, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 7.8802385330200195, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": 7.443273067474365, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 7.819050312042236, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 5.0905632972717285, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 5.180716037750244, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 5.335208415985107, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 7.521187782287598, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 7.990299224853516, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 7.368868827819824, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 7.028357028961182, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 6.496448040008545, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 6.549635410308838, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 6.86488676071167, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 8.43232250213623, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 7.825453281402588, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 7.35949182510376, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 5.520208358764648, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 4.91188383102417, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 5.286657333374023, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 6.930163860321045, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 6.360686302185059, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": 6.513362884521484, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 7.297323226928711, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 8.539663314819336, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 8.901529312133789, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 7.2059502601623535, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 8.735586166381836, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 8.106321334838867, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 8.984590530395508, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 8.53218936920166, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 8.71702766418457, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 8.729817390441895, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 8.97480297088623, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 8.807027816772461, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 9.317878723144531, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 11.190193176269531, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 10.322629928588867, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 10.049152374267578, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 10.764819145202637, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 8.090039253234863, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 7.6282830238342285, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 9.552068710327148, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 8.701016426086426, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 6.308617115020752, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 6.649825096130371, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 5.87125825881958, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 5.823843955993652, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 6.828389644622803, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 6.3411455154418945, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 6.211709022521973, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 6.140937805175781, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 5.988331317901611, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 9.219610214233398, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 8.404141426086426, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.733304977416992, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 10.323922157287598, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 12.470230102539062, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 12.656524658203125, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 12.382938385009766, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 10.457259178161621, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 9.89118480682373, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 9.103690147399902, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 9.936705589294434, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 9.260136604309082, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 12.350250244140625, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 11.197752952575684, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 12.077271461486816, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 12.11439037322998, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 12.137679100036621, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 12.568549156188965, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 12.59296989440918, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 12.61994457244873, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 13.75624942779541, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 12.995519638061523, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 12.715022087097168, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 12.58169174194336, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 13.586897850036621, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 11.938750267028809, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 13.606650352478027, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 11.192628860473633, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 11.908283233642578, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 13.234382629394531, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 13.134452819824219, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 12.159107208251953, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 14.019562721252441, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 13.090171813964844, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 12.800149917602539, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 7.402369499206543, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 6.842586517333984, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 6.986385345458984, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 7.476758003234863, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 6.49592399597168, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 6.018400192260742, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 7.325270652770996, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 8.079042434692383, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 7.734365940093994, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 7.277247905731201, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 10.899203300476074, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 11.419858932495117, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 10.695928573608398, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 11.180797576904297, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 10.426112174987793, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 12.719986915588379, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": 11.186307907104492, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": 11.689884185791016, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 11.111427307128906, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 10.560688972473145, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 10.19147777557373, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 6.237336158752441, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 6.605474472045898, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 5.980112075805664, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 7.268651962280273, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 7.508934020996094, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 8.009002685546875, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 8.484498977661133, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 9.157941818237305, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 8.21286678314209, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 6.970890998840332, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 6.187521934509277, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 9.213627815246582, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 9.834117889404297, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 9.729364395141602, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 9.672246932983398, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 10.909956932067871, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 10.370231628417969, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 9.904123306274414, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 8.957792282104492, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 8.40782356262207, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 8.692178726196289, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 8.433756828308105, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 8.968855857849121, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 13.960990905761719, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 13.406194686889648, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 12.736788749694824, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 13.955178260803223, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 13.107860565185547, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 13.100902557373047, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 13.665458679199219, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 13.348406791687012, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 13.394099235534668, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 11.303171157836914, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 12.553191184997559, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 12.651515007019043, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 12.478144645690918, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 13.423978805541992, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 12.812862396240234, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 12.730733871459961, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 16.500648498535156, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 16.81934356689453, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 15.435750007629395, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 16.746749877929688, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 15.079421997070312, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 14.319287300109863, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 12.707924842834473, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 14.636408805847168, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 13.334298133850098, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 14.044265747070312, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 14.274371147155762, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 14.010676383972168, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 13.74808120727539, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 13.67876148223877, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 12.22245979309082, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 11.113139152526855, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 12.065282821655273, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 11.848932266235352, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 12.413116455078125, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 12.429065704345703, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 13.095636367797852, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 12.541633605957031, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 8.320059776306152, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 9.778614044189453, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 5.030928134918213, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 4.664797306060791, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 4.608709812164307, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 5.176743984222412, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 5.524876117706299, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 5.531571865081787, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 5.082027912139893, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 5.238330364227295, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 5.1273040771484375, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 8.060755729675293, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 9.402769088745117, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 9.09987735748291, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 9.3138427734375, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 9.066337585449219, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 9.208731651306152, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 9.222782135009766, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 9.138355255126953, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 9.563375473022461, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 7.112536430358887, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 6.145611763000488, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 6.3184309005737305, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 6.203390598297119, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 5.786012649536133, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 6.408137798309326, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 6.436429500579834, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 8.718072891235352, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 8.073888778686523, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 12.50383472442627, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 14.6437349319458, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 13.905681610107422, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 14.383466720581055, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 14.96165657043457, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 12.443949699401855, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 12.591570854187012, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 11.093611717224121, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 9.042926788330078, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": 8.879538536071777, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 11.699110984802246, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 11.002934455871582, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 13.15277099609375, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 12.102582931518555, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 12.63425350189209, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 12.645500183105469, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 12.180895805358887, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 11.41718578338623, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 11.626137733459473, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 11.092533111572266, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 11.016407012939453, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 11.056938171386719, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 12.859992980957031, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 12.762211799621582, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 7.210906028747559, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 10.110258102416992, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 9.963737487792969, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 10.98570728302002, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 11.430583000183105, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 11.19536304473877, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 19.51195526123047, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 20.299570083618164, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 13.546540260314941, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 12.784123420715332, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 13.257153511047363, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 14.41031551361084, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 14.123627662658691, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 13.036506652832031, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 14.61015796661377, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 14.42878246307373, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 14.399157524108887, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 16.9290828704834, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 16.628997802734375, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 14.44288158416748, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 14.6681489944458, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 12.307303428649902, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 10.730957984924316, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 11.716023445129395, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 11.298872947692871, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 9.422407150268555, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 10.2095308303833, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 10.915311813354492, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 11.465434074401855, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 10.02987003326416, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 10.669035911560059, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 10.48486328125, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 9.880863189697266, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 9.725358963012695, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 10.35915756225586, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 9.679999351501465, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 9.510231971740723, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 10.098800659179688, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 11.089457511901855, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 12.32906723022461, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 6.986202716827393, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 7.250833988189697, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 7.04548978805542, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 6.986104488372803, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 7.013962268829346, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 9.223431587219238, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 11.426567077636719, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 11.302207946777344, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 11.74538516998291, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 8.104558944702148, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 7.035085201263428, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 8.313529014587402, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 8.5067777633667, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 8.43693733215332, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 8.399803161621094, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 10.22137451171875, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 9.824759483337402, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 16.846460342407227, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 18.349695205688477, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 19.47640037536621, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 17.065519332885742, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 16.75712776184082, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 14.039481163024902, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 22.547077178955078, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 14.686722755432129, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 16.801464080810547, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 16.774049758911133, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 18.21277618408203, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 17.137020111083984, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 17.786558151245117, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 17.626907348632812, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 17.509769439697266, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 18.067750930786133, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 18.299070358276367, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 19.217119216918945, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 17.755247116088867, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 8.556084632873535, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 8.208080291748047, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 8.31843090057373, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 10.522472381591797, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 10.476648330688477, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 9.22039794921875, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 9.400035858154297, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 9.675834655761719, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 9.214376449584961, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 9.036466598510742, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 9.208574295043945, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 13.298826217651367, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 15.42348861694336, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 13.83507251739502, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 8.707788467407227, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 9.251585006713867, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 9.052249908447266, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 9.82917594909668, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 9.725754737854004, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 8.806682586669922, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 11.270689964294434, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 10.202579498291016, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.697301864624023, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 9.532554626464844, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 9.436655044555664, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 9.737995147705078, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 9.288839340209961, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 10.736775398254395, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 9.34485149383545, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 9.227876663208008, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 9.469313621520996, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 9.402536392211914, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 9.817926406860352, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 8.816874504089355, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 7.913830757141113, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 7.687036514282227, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 5.940617084503174, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 6.010695934295654, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 7.686226844787598, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 7.617751121520996, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 6.943645477294922, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 8.945474624633789, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 7.830075263977051, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 8.398107528686523, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 7.702796459197998, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 7.623422145843506, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 8.159574508666992, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 7.408087253570557, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 8.166772842407227, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 6.511370658874512, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 6.518929958343506, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 6.797684669494629, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 7.244635105133057, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 8.963022232055664, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 9.203293800354004, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 9.164643287658691, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 8.455629348754883, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 6.460043430328369, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 7.253722190856934, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 6.924093246459961, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 6.812102317810059, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 6.81666898727417, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.717197895050049, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 8.326837539672852, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 8.827495574951172, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 9.544142723083496, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 9.923998832702637, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 10.47934627532959, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 8.906576156616211, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 10.105539321899414, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 6.374002933502197, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 6.927292346954346, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 7.512913703918457, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 7.590645790100098, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 7.832711696624756, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 8.02859115600586, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 9.093605995178223, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 9.966830253601074, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 10.196884155273438, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 10.178518295288086, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 9.909396171569824, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 9.83348560333252, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 8.311078071594238, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 8.138319969177246, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 8.105721473693848, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 7.768963813781738, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 8.123887062072754, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 6.734941005706787, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 5.612227439880371, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 6.318391799926758, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 19.546354293823242, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 16.8531436920166, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.997653007507324, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 12.138011932373047, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": 13.087748527526855, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 16.428693771362305, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 14.098936080932617, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 15.820218086242676, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 13.744246482849121, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 13.664725303649902, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 14.161970138549805, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 11.34384822845459, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 14.073280334472656, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 14.033628463745117, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 13.442943572998047, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 13.735260963439941, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 14.390303611755371, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 13.460063934326172, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 14.478861808776855, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 14.643204689025879, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 14.704259872436523, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 14.675769805908203, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 13.97838020324707, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 14.072586059570312, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 11.780965805053711, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 11.392871856689453, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 10.689013481140137, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 9.544307708740234, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 7.048957824707031, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 8.053902626037598, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 9.534790992736816, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 9.681097030639648, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 10.349991798400879, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 9.835482597351074, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 11.408327102661133, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 9.545672416687012, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 8.696833610534668, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 8.653395652770996, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 9.718098640441895, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 8.718841552734375, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 12.103772163391113, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 11.731871604919434, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.670454025268555, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 11.462501525878906, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 14.681675910949707, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 9.380514144897461, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 10.400063514709473, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 12.273658752441406, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 12.116131782531738, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 12.536803245544434, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 14.159012794494629, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 4.433682441711426, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 4.811509609222412, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 5.004357814788818, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 4.47194242477417, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 7.308453559875488, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 8.388505935668945, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 7.639347553253174, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 8.648792266845703, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 9.313817977905273, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 7.86465311050415, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 9.162460327148438, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 8.700263977050781, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 9.498454093933105, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 9.134915351867676, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": 9.36000919342041, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 9.6476411819458, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 9.04462718963623, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 9.78683853149414, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 16.923458099365234, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 14.022960662841797, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 12.665775299072266, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 12.419373512268066, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.995328903198242, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 11.994388580322266, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 15.71795654296875, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 18.86307144165039, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 12.670778274536133, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 10.841840744018555, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 9.537745475769043, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 10.45400333404541, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 12.47652816772461, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 12.57809066772461, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 12.601237297058105, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 15.345636367797852, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 8.889330863952637, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 8.67694091796875, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 8.750593185424805, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 8.834709167480469, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 8.95480728149414, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 9.38204288482666, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 8.554287910461426, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 9.700864791870117, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 9.475761413574219, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 9.394735336303711, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 11.08381462097168, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 11.075885772705078, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 10.54545783996582, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 10.084576606750488, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": 12.314638137817383, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 7.384014129638672, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 7.612643718719482, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 7.098739147186279, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 6.884673118591309, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 7.425764083862305, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 7.199800491333008, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 9.15973949432373, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 9.876193046569824, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 8.387222290039062, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 8.401693344116211, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 8.204906463623047, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 6.897432327270508, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 9.02954387664795, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 6.972280979156494, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 7.341432094573975, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 12.322853088378906, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 12.525711059570312, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 11.230805397033691, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 11.255461692810059, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 10.802995681762695, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 11.960826873779297, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 12.253438949584961, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 10.763121604919434, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 11.498046875, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 10.979312896728516, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 11.600772857666016, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 11.025726318359375, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 11.452569007873535, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 11.625408172607422, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 11.477405548095703, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 10.357848167419434, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 10.142298698425293, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 8.808533668518066, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 9.186028480529785, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 8.140854835510254, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 11.249858856201172, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 11.950621604919434, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 12.186288833618164, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 11.27682876586914, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 11.212031364440918, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 10.776966094970703, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 10.444023132324219, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 10.02772045135498, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 9.24424934387207, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 12.052868843078613, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 12.713994979858398, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 12.409842491149902, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 10.791082382202148, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 10.720513343811035, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 11.113096237182617, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 10.711718559265137, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.298882484436035, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 10.683910369873047, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 12.63023567199707, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 11.501649856567383, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 11.917733192443848, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 10.243572235107422, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 13.912221908569336, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 14.090718269348145, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 14.244917869567871, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 14.9103422164917, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 14.042609214782715, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 12.648893356323242, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 12.636263847351074, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 12.347711563110352, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 11.52521800994873, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 11.574653625488281, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 12.863534927368164, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 13.17519474029541, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 14.078084945678711, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 13.49814510345459, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 13.377963066101074, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 14.087303161621094, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 15.894698143005371, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 18.06110382080078, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 17.932432174682617, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 16.70292091369629, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 10.4523344039917, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 10.77991008758545, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 9.05896282196045, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 9.13316535949707, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 10.163662910461426, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 18.26988410949707, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 17.265840530395508, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 19.590431213378906, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 18.463560104370117, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 19.313377380371094, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 18.08652114868164, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 18.456092834472656, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.99809455871582, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 10.037954330444336, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 9.698882102966309, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 9.882332801818848, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 9.11053466796875, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 8.414717674255371, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 9.429102897644043, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 8.984553337097168, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 9.016618728637695, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 9.321554183959961, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 9.575602531433105, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 9.47808837890625, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 9.523959159851074, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 10.553288459777832, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 10.81861686706543, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 13.002190589904785, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 14.9756441116333, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 16.933565139770508, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 16.22969627380371, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 14.819085121154785, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 15.049208641052246, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 15.333222389221191, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 11.949214935302734, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 11.668681144714355, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 10.402152061462402, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 10.90945053100586, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 10.81752872467041, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 10.330848693847656, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 10.589546203613281, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 9.973832130432129, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 8.202228546142578, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 9.831948280334473, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 8.61691665649414, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 8.925427436828613, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 9.665080070495605, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 8.663387298583984, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 14.242582321166992, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 13.165971755981445, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 11.419358253479004, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 11.59504222869873, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 11.449594497680664, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 11.234237670898438, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 11.625036239624023, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 12.98870849609375, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 12.557905197143555, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 12.145800590515137, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": 12.233484268188477, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": 12.661812782287598, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 10.791397094726562, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 10.943082809448242, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 13.470155715942383, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 13.865983009338379, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 13.21607780456543, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 16.27344512939453, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 18.273025512695312, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 14.289527893066406, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 14.269876480102539, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 13.634252548217773, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 13.781076431274414, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 13.776945114135742, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 13.86768913269043, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 14.022978782653809, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 9.793961524963379, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 10.889704704284668, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 10.075024604797363, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 10.746500968933105, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 7.293745994567871, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 7.528172016143799, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 7.686507225036621, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 10.343385696411133, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 11.31760311126709, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": 10.842963218688965, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 10.001209259033203, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 8.664310455322266, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 9.291108131408691, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 9.455000877380371, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 11.80007266998291, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 10.777748107910156, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 9.823101997375488, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 7.634424686431885, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 7.167606353759766, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 7.066221237182617, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 9.72808837890625, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 9.412628173828125, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 8.98169994354248, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 9.864893913269043, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 12.189886093139648, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 12.023582458496094, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 9.691656112670898, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 12.405975341796875, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 11.562335968017578, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 11.639060974121094, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 13.219423294067383, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 13.162672996520996, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 12.658014297485352, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 11.928388595581055, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 12.68416976928711, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 13.170607566833496, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 15.06847095489502, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 14.663665771484375, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 14.32145881652832, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 14.355459213256836, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 11.188118934631348, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 11.107966423034668, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 14.007497787475586, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 12.092328071594238, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.752177238464355, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 9.303275108337402, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 9.167104721069336, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 8.066573143005371, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 9.59017276763916, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 8.78339958190918, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 9.151691436767578, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 8.965655326843262, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 8.980620384216309, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 12.573892593383789, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 12.082387924194336, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 13.643655776977539, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 13.934240341186523, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 16.283496856689453, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 18.458879470825195, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 16.87954330444336, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 16.068159103393555, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 14.545585632324219, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 13.890661239624023, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 14.142515182495117, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 12.367781639099121, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 16.947235107421875, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 17.293228149414062, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 16.411766052246094, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 17.661447525024414, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 17.440860748291016, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 16.905393600463867, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 18.042564392089844, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 17.89263153076172, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 18.60683822631836, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 18.22900390625, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 18.15667724609375, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 19.945480346679688, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 16.9851016998291, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 18.945213317871094, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 19.10544776916504, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 18.38855743408203, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 19.600540161132812, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 16.65052604675293, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 17.229984283447266, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 17.919578552246094, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.845430374145508, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 17.767263412475586, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 16.67557716369629, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 9.868005752563477, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 9.700410842895508, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 9.360735893249512, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 10.022723197937012, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 9.826160430908203, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 9.114191055297852, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 9.566826820373535, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 10.331360816955566, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.619444847106934, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 10.980886459350586, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 15.400731086730957, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 15.731500625610352, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 15.671440124511719, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 15.543590545654297, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 15.1685152053833, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 16.88866424560547, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 16.123300552368164, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 16.42278480529785, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 15.62364673614502, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 15.247666358947754, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 14.932868003845215, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 8.2759370803833, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 9.66146469116211, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 7.956097602844238, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 10.982549667358398, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 10.347886085510254, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 12.057632446289062, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 12.04118537902832, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 12.49259090423584, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 10.704244613647461, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 9.934815406799316, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 9.355141639709473, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 25,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# NBVAL_SKIP\n",
    "alt.data_transformers.disable_max_rows()\n",
    "chart_power_difference_monster = window.plot(independent_axes=False).properties(title='Posterior')\n",
    "chart_power_difference_monster"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "Much tighter credible intervals here!\n",
    "\n",
    "Same with linear mixed model:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Using formula Log_power ~  C(stim, Treatment) + (1 | mouse)\n",
      "                         Coef. Std.Err.       z  P>|z| [0.025 0.975]\n",
      "Intercept                1.952    0.033  58.716  0.000  1.887  2.017\n",
      "C(stim, Treatment)[T.1]  0.140    0.002  64.581  0.000  0.135  0.144\n",
      "1 | mouse                0.048    0.007   6.574  0.000  0.033  0.062\n",
      "Group Var                0.002    0.004                             \n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/home/m/venvs/jb1/lib/python3.9/site-packages/statsmodels/regression/mixed_linear_model.py:2237: ConvergenceWarning: The MLE may be on the boundary of the parameter space.\n",
      "  warnings.warn(msg, ConvergenceWarning)\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-039ddb627ad4449086c8202493ac23d1\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-039ddb627ad4449086c8202493ac23d1\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-039ddb627ad4449086c8202493ac23d1\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.144], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.144], \"zero\": true}, \"title\": \"\\u0394 Log_power\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.144], \"zero\": true}}}}], \"data\": {\"name\": \"data-063f70b53db191562db0db28221b259e\"}, \"title\": \"LME\", \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-063f70b53db191562db0db28221b259e\": [{\"index\": \"C(stim, Treatment)[T.1]\", \"center interval\": 0.14, \"Std.Err.\": 0.002, \"z\": 64.581, \"p\": 0.0, \"higher interval\": 0.135, \"lower interval\": 0.144, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 26,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# NBVAL_SKIP\n",
    "window = LMERegression(df=df_monster,\n",
    "                         y='Log power', treatment='stim', group='mouse')\n",
    "window.fit()\n",
    "\n",
    "chart_power_difference_monster_lme = window.plot().properties(title='LME')\n",
    "chart_power_difference_monster_lme"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-b9499802216349e18196b78eeedbc6b6\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-b9499802216349e18196b78eeedbc6b6\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-b9499802216349e18196b78eeedbc6b6\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"hconcat\": [{\"layer\": [{\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}, \"title\": \"\\u0394 Power\"}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}}}}, {\"data\": {\"name\": \"data-c54f06698bcfb14c39ffe654ff76d8c7\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [0, 0.19885632395744324], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [0.17693592607975006, 0.19885632395744324], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-69.18878060153263, 487.9857026681875], \"zero\": false}, \"title\": \"Power diff\"}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-69.18878060153263, 487.9857026681875], \"zero\": false}}}}, {\"data\": {\"name\": \"data-6261aaeda45fc4e9dc2b4f9d39bcc965\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power diff\", \"scale\": {\"domain\": [-69.18878060153263, 487.9857026681875], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"Posterior\"}, {\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.144], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.144], \"zero\": true}, \"title\": \"\\u0394 Log_power\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.144], \"zero\": true}}}}], \"data\": {\"name\": \"data-063f70b53db191562db0db28221b259e\"}, \"title\": \"LME\"}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-6261aaeda45fc4e9dc2b4f9d39bcc965\": [{\"mouse\": 0, \"combined_condition\": 1.0, \"Power diff\": 246.68020890792593, \"mu_intercept_per_group higher interval\": -5.86566686630249, \"mu_intercept_per_group lower interval\": -18.76958465576172, \"mu_intercept_per_group center interval\": -9.807680130004883, \"mu_intercept_per_group higher interval75\": -7.482207775115967, \"mu_intercept_per_group lower interval75\": -14.84196949005127, \"sigma_intercept_per_group higher interval\": 0.03375045210123062, \"sigma_intercept_per_group lower interval\": 0.011746767908334732, \"sigma_intercept_per_group center interval\": 0.02185261808335781, \"sigma_obs higher interval\": 0.003638071473687887, \"sigma_obs lower interval\": 0.0035575919318944216, \"sigma_obs center interval\": 0.0036001012194901705, \"higher interval\": 0.19885632395744324, \"lower interval\": 0.17693592607975006, \"center interval\": 0.18880786001682281, \"zero\": 0}, {\"mouse\": 1, \"combined_condition\": 1.0, \"Power diff\": 153.4379262163082, \"mu_intercept_per_group higher interval\": -5.386823654174805, \"mu_intercept_per_group lower interval\": -16.363231658935547, \"mu_intercept_per_group center interval\": -8.241783142089844, \"mu_intercept_per_group higher interval75\": -5.989358425140381, \"mu_intercept_per_group lower interval75\": -12.067502975463867, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"combined_condition\": 1.0, \"Power diff\": 97.75801840385334, \"mu_intercept_per_group higher interval\": -5.1961517333984375, \"mu_intercept_per_group lower interval\": -16.279985427856445, \"mu_intercept_per_group center interval\": -8.670272827148438, \"mu_intercept_per_group higher interval75\": -6.303857326507568, \"mu_intercept_per_group lower interval75\": -12.449019432067871, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"combined_condition\": 1.0, \"Power diff\": 259.2147944426915, \"mu_intercept_per_group higher interval\": -2.9383795261383057, \"mu_intercept_per_group lower interval\": -9.103045463562012, \"mu_intercept_per_group center interval\": -4.7221527099609375, \"mu_intercept_per_group higher interval75\": -3.2880685329437256, \"mu_intercept_per_group lower interval75\": -6.8048224449157715, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"combined_condition\": 1.0, \"Power diff\": 26.996524183149205, \"mu_intercept_per_group higher interval\": -2.0070154666900635, \"mu_intercept_per_group lower interval\": -6.819550037384033, \"mu_intercept_per_group center interval\": -3.5662479400634766, \"mu_intercept_per_group higher interval75\": -2.3406660556793213, \"mu_intercept_per_group lower interval75\": -5.132424831390381, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"combined_condition\": 1.0, \"Power diff\": -47.827989146286455, \"mu_intercept_per_group higher interval\": -0.28019747138023376, \"mu_intercept_per_group lower interval\": -2.3854494094848633, \"mu_intercept_per_group center interval\": -1.2025550603866577, \"mu_intercept_per_group higher interval75\": -0.5923544764518738, \"mu_intercept_per_group lower interval75\": -1.9305877685546875, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"combined_condition\": 1.0, \"Power diff\": -80.69074523128057, \"mu_intercept_per_group higher interval\": 13.586897850036621, \"mu_intercept_per_group lower interval\": 4.554792881011963, \"mu_intercept_per_group center interval\": 6.610581398010254, \"mu_intercept_per_group higher interval75\": 10.22288703918457, \"mu_intercept_per_group lower interval75\": 5.081120491027832, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"combined_condition\": 1.0, \"Power diff\": 611.1700378665317, \"mu_intercept_per_group higher interval\": 18.463560104370117, \"mu_intercept_per_group lower interval\": 5.940617084503174, \"mu_intercept_per_group center interval\": 9.475008010864258, \"mu_intercept_per_group higher interval75\": 14.704259872436523, \"mu_intercept_per_group lower interval75\": 7.612643718719482, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-c54f06698bcfb14c39ffe654ff76d8c7\": [{\"mouse\": 0, \"draws\": 0, \"mu_intercept_per_group\": -9.851624488830566, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 0, \"draws\": 1, \"mu_intercept_per_group\": -10.593274116516113, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 0, \"draws\": 2, \"mu_intercept_per_group\": -8.804131507873535, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 0, \"draws\": 3, \"mu_intercept_per_group\": -9.093019485473633, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 0, \"draws\": 4, \"mu_intercept_per_group\": -11.623002052307129, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 0, \"draws\": 5, \"mu_intercept_per_group\": -9.663583755493164, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 0, \"draws\": 6, \"mu_intercept_per_group\": -9.241058349609375, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 0, \"draws\": 7, \"mu_intercept_per_group\": -9.04588794708252, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 0, \"draws\": 8, \"mu_intercept_per_group\": -9.058162689208984, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 0, \"draws\": 9, \"mu_intercept_per_group\": -9.243983268737793, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 0, \"draws\": 10, \"mu_intercept_per_group\": -9.199454307556152, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 0, \"draws\": 11, \"mu_intercept_per_group\": -8.934907913208008, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 0, \"draws\": 12, \"mu_intercept_per_group\": -14.2112455368042, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 0, \"draws\": 13, \"mu_intercept_per_group\": -13.564764022827148, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 0, \"draws\": 14, \"mu_intercept_per_group\": -13.971097946166992, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 0, \"draws\": 15, \"mu_intercept_per_group\": -13.729043006896973, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 0, \"draws\": 16, \"mu_intercept_per_group\": -14.117697715759277, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 0, \"draws\": 17, \"mu_intercept_per_group\": -14.457470893859863, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 0, \"draws\": 18, \"mu_intercept_per_group\": -13.540362358093262, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 0, \"draws\": 19, \"mu_intercept_per_group\": -14.841485023498535, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 0, \"draws\": 20, \"mu_intercept_per_group\": -13.327742576599121, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 0, \"draws\": 21, \"mu_intercept_per_group\": -12.355661392211914, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 0, \"draws\": 22, \"mu_intercept_per_group\": -14.764278411865234, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 0, \"draws\": 23, \"mu_intercept_per_group\": -14.664400100708008, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 0, \"draws\": 24, \"mu_intercept_per_group\": -13.996867179870605, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 0, \"draws\": 25, \"mu_intercept_per_group\": -14.989302635192871, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 0, \"draws\": 26, \"mu_intercept_per_group\": -13.437544822692871, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 0, \"draws\": 27, \"mu_intercept_per_group\": -13.617106437683105, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 0, \"draws\": 28, \"mu_intercept_per_group\": -16.81715965270996, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 0, \"draws\": 29, \"mu_intercept_per_group\": -16.711620330810547, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 0, \"draws\": 30, \"mu_intercept_per_group\": -17.97140121459961, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 0, \"draws\": 31, \"mu_intercept_per_group\": -17.110422134399414, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 0, \"draws\": 32, \"mu_intercept_per_group\": -14.383461952209473, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 0, \"draws\": 33, \"mu_intercept_per_group\": -13.38559341430664, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 0, \"draws\": 34, \"mu_intercept_per_group\": -13.990649223327637, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 0, \"draws\": 35, \"mu_intercept_per_group\": -13.286002159118652, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 0, \"draws\": 36, \"mu_intercept_per_group\": -15.132838249206543, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 0, \"draws\": 37, \"mu_intercept_per_group\": -15.865083694458008, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 0, \"draws\": 38, \"mu_intercept_per_group\": -12.832552909851074, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 0, \"draws\": 39, \"mu_intercept_per_group\": -13.29058837890625, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 0, \"draws\": 40, \"mu_intercept_per_group\": -12.082025527954102, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 0, \"draws\": 41, \"mu_intercept_per_group\": -13.696651458740234, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 0, \"draws\": 42, \"mu_intercept_per_group\": -13.51311206817627, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 0, \"draws\": 43, \"mu_intercept_per_group\": -12.065013885498047, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 0, \"draws\": 44, \"mu_intercept_per_group\": -14.313226699829102, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 0, \"draws\": 45, \"mu_intercept_per_group\": -11.000338554382324, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 0, \"draws\": 46, \"mu_intercept_per_group\": -12.037189483642578, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 0, \"draws\": 47, \"mu_intercept_per_group\": -12.324677467346191, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 0, \"draws\": 48, \"mu_intercept_per_group\": -13.417756080627441, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 0, \"draws\": 49, \"mu_intercept_per_group\": -12.928510665893555, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 0, \"draws\": 50, \"mu_intercept_per_group\": -8.074151039123535, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 0, \"draws\": 51, \"mu_intercept_per_group\": -9.716476440429688, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 0, \"draws\": 52, \"mu_intercept_per_group\": -5.38045072555542, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 0, \"draws\": 53, \"mu_intercept_per_group\": -5.4341301918029785, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 0, \"draws\": 54, \"mu_intercept_per_group\": -5.210064888000488, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 0, \"draws\": 55, \"mu_intercept_per_group\": -5.498199939727783, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 0, \"draws\": 56, \"mu_intercept_per_group\": -5.032169342041016, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 0, \"draws\": 57, \"mu_intercept_per_group\": -4.887807369232178, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 0, \"draws\": 58, \"mu_intercept_per_group\": -4.304141521453857, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 0, \"draws\": 59, \"mu_intercept_per_group\": -5.630006313323975, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 0, \"draws\": 60, \"mu_intercept_per_group\": -5.093763828277588, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 0, \"draws\": 61, \"mu_intercept_per_group\": -9.3933744430542, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 0, \"draws\": 62, \"mu_intercept_per_group\": -9.472959518432617, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 0, \"draws\": 63, \"mu_intercept_per_group\": -9.580178260803223, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 0, \"draws\": 64, \"mu_intercept_per_group\": -9.769248008728027, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 0, \"draws\": 65, \"mu_intercept_per_group\": -9.763938903808594, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 0, \"draws\": 66, \"mu_intercept_per_group\": -9.204566955566406, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 0, \"draws\": 67, \"mu_intercept_per_group\": -9.919172286987305, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 0, \"draws\": 68, \"mu_intercept_per_group\": -10.04228687286377, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 0, \"draws\": 69, \"mu_intercept_per_group\": -9.533844947814941, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 0, \"draws\": 70, \"mu_intercept_per_group\": -7.777149677276611, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 0, \"draws\": 71, \"mu_intercept_per_group\": -5.937911033630371, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 0, \"draws\": 72, \"mu_intercept_per_group\": -5.934097766876221, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 0, \"draws\": 73, \"mu_intercept_per_group\": -5.872723579406738, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 0, \"draws\": 74, \"mu_intercept_per_group\": -5.781371593475342, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 0, \"draws\": 75, \"mu_intercept_per_group\": -6.500571250915527, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 0, \"draws\": 76, \"mu_intercept_per_group\": -6.29168176651001, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 0, \"draws\": 77, \"mu_intercept_per_group\": -9.332966804504395, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 0, \"draws\": 78, \"mu_intercept_per_group\": -8.566055297851562, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 0, \"draws\": 79, \"mu_intercept_per_group\": -12.747147560119629, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 0, \"draws\": 80, \"mu_intercept_per_group\": -14.824766159057617, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 0, \"draws\": 81, \"mu_intercept_per_group\": -13.223275184631348, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 0, \"draws\": 82, \"mu_intercept_per_group\": -14.391583442687988, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 0, \"draws\": 83, \"mu_intercept_per_group\": -14.504562377929688, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 0, \"draws\": 84, \"mu_intercept_per_group\": -13.074117660522461, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 0, \"draws\": 85, \"mu_intercept_per_group\": -13.724332809448242, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 0, \"draws\": 86, \"mu_intercept_per_group\": -12.190608024597168, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 0, \"draws\": 87, \"mu_intercept_per_group\": -8.720621109008789, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 0, \"draws\": 88, \"mu_intercept_per_group\": -8.772547721862793, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 0, \"draws\": 89, \"mu_intercept_per_group\": -11.351672172546387, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 0, \"draws\": 90, \"mu_intercept_per_group\": -11.376028060913086, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 0, \"draws\": 91, \"mu_intercept_per_group\": -12.397343635559082, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 0, \"draws\": 92, \"mu_intercept_per_group\": -11.784248352050781, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 0, \"draws\": 93, \"mu_intercept_per_group\": -13.295707702636719, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 0, \"draws\": 94, \"mu_intercept_per_group\": -13.053016662597656, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 0, \"draws\": 95, \"mu_intercept_per_group\": -12.82558822631836, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 0, \"draws\": 96, \"mu_intercept_per_group\": -10.47623062133789, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 0, \"draws\": 97, \"mu_intercept_per_group\": -11.515580177307129, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 0, \"draws\": 98, \"mu_intercept_per_group\": -11.70767593383789, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 0, \"draws\": 99, \"mu_intercept_per_group\": -11.612456321716309, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 0, \"draws\": 100, \"mu_intercept_per_group\": -11.31374740600586, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 0, \"draws\": 101, \"mu_intercept_per_group\": -12.464703559875488, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 0, \"draws\": 102, \"mu_intercept_per_group\": -12.073406219482422, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 0, \"draws\": 103, \"mu_intercept_per_group\": -6.85251522064209, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 0, \"draws\": 104, \"mu_intercept_per_group\": -9.189528465270996, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 0, \"draws\": 105, \"mu_intercept_per_group\": -11.047605514526367, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 0, \"draws\": 106, \"mu_intercept_per_group\": -11.454651832580566, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 0, \"draws\": 107, \"mu_intercept_per_group\": -12.702256202697754, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 0, \"draws\": 108, \"mu_intercept_per_group\": -12.336421966552734, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 0, \"draws\": 109, \"mu_intercept_per_group\": -18.76958465576172, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 0, \"draws\": 110, \"mu_intercept_per_group\": -19.507965087890625, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 0, \"draws\": 111, \"mu_intercept_per_group\": -16.186267852783203, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 0, \"draws\": 112, \"mu_intercept_per_group\": -13.559771537780762, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 0, \"draws\": 113, \"mu_intercept_per_group\": -14.20267391204834, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 0, \"draws\": 114, \"mu_intercept_per_group\": -16.650508880615234, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 0, \"draws\": 115, \"mu_intercept_per_group\": -15.609031677246094, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 0, \"draws\": 116, \"mu_intercept_per_group\": -13.455955505371094, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 0, \"draws\": 117, \"mu_intercept_per_group\": -13.151280403137207, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 0, \"draws\": 118, \"mu_intercept_per_group\": -15.190564155578613, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 0, \"draws\": 119, \"mu_intercept_per_group\": -13.681694030761719, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 0, \"draws\": 120, \"mu_intercept_per_group\": -14.643214225769043, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 0, \"draws\": 121, \"mu_intercept_per_group\": -14.625734329223633, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 0, \"draws\": 122, \"mu_intercept_per_group\": -14.264836311340332, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 0, \"draws\": 123, \"mu_intercept_per_group\": -14.59488296508789, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 0, \"draws\": 124, \"mu_intercept_per_group\": -12.469386100769043, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 0, \"draws\": 125, \"mu_intercept_per_group\": -11.627408981323242, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 0, \"draws\": 126, \"mu_intercept_per_group\": -11.068796157836914, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 0, \"draws\": 127, \"mu_intercept_per_group\": -11.281523704528809, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 0, \"draws\": 128, \"mu_intercept_per_group\": -11.116693496704102, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 0, \"draws\": 129, \"mu_intercept_per_group\": -10.538206100463867, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 0, \"draws\": 130, \"mu_intercept_per_group\": -10.453330039978027, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 0, \"draws\": 131, \"mu_intercept_per_group\": -10.998038291931152, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 0, \"draws\": 132, \"mu_intercept_per_group\": -10.55263614654541, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 0, \"draws\": 133, \"mu_intercept_per_group\": -10.286195755004883, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 0, \"draws\": 134, \"mu_intercept_per_group\": -10.227828979492188, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 0, \"draws\": 135, \"mu_intercept_per_group\": -9.542647361755371, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 0, \"draws\": 136, \"mu_intercept_per_group\": -9.54321002960205, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 0, \"draws\": 137, \"mu_intercept_per_group\": -10.298198699951172, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 0, \"draws\": 138, \"mu_intercept_per_group\": -9.788155555725098, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 0, \"draws\": 139, \"mu_intercept_per_group\": -10.504138946533203, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 0, \"draws\": 140, \"mu_intercept_per_group\": -10.226339340209961, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 0, \"draws\": 141, \"mu_intercept_per_group\": -11.428483009338379, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 0, \"draws\": 142, \"mu_intercept_per_group\": -12.490617752075195, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 0, \"draws\": 143, \"mu_intercept_per_group\": -7.117382526397705, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 0, \"draws\": 144, \"mu_intercept_per_group\": -7.545733451843262, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 0, \"draws\": 145, \"mu_intercept_per_group\": -7.82615327835083, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 0, \"draws\": 146, \"mu_intercept_per_group\": -6.990138530731201, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 0, \"draws\": 147, \"mu_intercept_per_group\": -7.236833572387695, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 0, \"draws\": 148, \"mu_intercept_per_group\": -9.769430160522461, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 0, \"draws\": 149, \"mu_intercept_per_group\": -11.64118766784668, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 0, \"draws\": 150, \"mu_intercept_per_group\": -11.391876220703125, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 0, \"draws\": 151, \"mu_intercept_per_group\": -11.45602035522461, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 0, \"draws\": 152, \"mu_intercept_per_group\": -8.160775184631348, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 0, \"draws\": 153, \"mu_intercept_per_group\": -7.561171531677246, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 0, \"draws\": 154, \"mu_intercept_per_group\": -8.286128044128418, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 0, \"draws\": 155, \"mu_intercept_per_group\": -8.254199028015137, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 0, \"draws\": 156, \"mu_intercept_per_group\": -8.291871070861816, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 0, \"draws\": 157, \"mu_intercept_per_group\": -9.068643569946289, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 0, \"draws\": 158, \"mu_intercept_per_group\": -10.296796798706055, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 0, \"draws\": 159, \"mu_intercept_per_group\": -10.132622718811035, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 0, \"draws\": 160, \"mu_intercept_per_group\": -16.92349624633789, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 0, \"draws\": 161, \"mu_intercept_per_group\": -18.36072540283203, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 0, \"draws\": 162, \"mu_intercept_per_group\": -18.445323944091797, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 0, \"draws\": 163, \"mu_intercept_per_group\": -16.545536041259766, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 0, \"draws\": 164, \"mu_intercept_per_group\": -15.687419891357422, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 0, \"draws\": 165, \"mu_intercept_per_group\": -12.87869930267334, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 0, \"draws\": 166, \"mu_intercept_per_group\": -22.542404174804688, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 0, \"draws\": 167, \"mu_intercept_per_group\": -15.548715591430664, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 0, \"draws\": 168, \"mu_intercept_per_group\": -17.444591522216797, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 0, \"draws\": 169, \"mu_intercept_per_group\": -16.874855041503906, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 0, \"draws\": 170, \"mu_intercept_per_group\": -18.150819778442383, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 0, \"draws\": 171, \"mu_intercept_per_group\": -17.172765731811523, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 0, \"draws\": 172, \"mu_intercept_per_group\": -17.34222984313965, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 0, \"draws\": 173, \"mu_intercept_per_group\": -19.005916595458984, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 0, \"draws\": 174, \"mu_intercept_per_group\": -17.572147369384766, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 0, \"draws\": 175, \"mu_intercept_per_group\": -16.90898323059082, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 0, \"draws\": 176, \"mu_intercept_per_group\": -19.238187789916992, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 0, \"draws\": 177, \"mu_intercept_per_group\": -18.668596267700195, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 0, \"draws\": 178, \"mu_intercept_per_group\": -17.455039978027344, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 0, \"draws\": 179, \"mu_intercept_per_group\": -8.914315223693848, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 0, \"draws\": 180, \"mu_intercept_per_group\": -7.575784206390381, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 0, \"draws\": 181, \"mu_intercept_per_group\": -7.830623149871826, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 0, \"draws\": 182, \"mu_intercept_per_group\": -10.07348346710205, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 0, \"draws\": 183, \"mu_intercept_per_group\": -9.812929153442383, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 0, \"draws\": 184, \"mu_intercept_per_group\": -9.981400489807129, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 0, \"draws\": 185, \"mu_intercept_per_group\": -9.31966781616211, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 0, \"draws\": 186, \"mu_intercept_per_group\": -10.352869987487793, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 0, \"draws\": 187, \"mu_intercept_per_group\": -9.404488563537598, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 0, \"draws\": 188, \"mu_intercept_per_group\": -8.726993560791016, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 0, \"draws\": 189, \"mu_intercept_per_group\": -10.293545722961426, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 0, \"draws\": 190, \"mu_intercept_per_group\": -11.848428726196289, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 0, \"draws\": 191, \"mu_intercept_per_group\": -14.61726188659668, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 0, \"draws\": 192, \"mu_intercept_per_group\": -12.712618827819824, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 0, \"draws\": 193, \"mu_intercept_per_group\": -8.979381561279297, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 0, \"draws\": 194, \"mu_intercept_per_group\": -9.96892261505127, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 0, \"draws\": 195, \"mu_intercept_per_group\": -8.285028457641602, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 0, \"draws\": 196, \"mu_intercept_per_group\": -10.26827335357666, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 0, \"draws\": 197, \"mu_intercept_per_group\": -10.348662376403809, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 0, \"draws\": 198, \"mu_intercept_per_group\": -9.168214797973633, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 0, \"draws\": 199, \"mu_intercept_per_group\": -11.007803916931152, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 0, \"draws\": 200, \"mu_intercept_per_group\": -11.270756721496582, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 0, \"draws\": 201, \"mu_intercept_per_group\": -10.185099601745605, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 0, \"draws\": 202, \"mu_intercept_per_group\": -9.851644515991211, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 0, \"draws\": 203, \"mu_intercept_per_group\": -9.217644691467285, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 0, \"draws\": 204, \"mu_intercept_per_group\": -9.669071197509766, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 0, \"draws\": 205, \"mu_intercept_per_group\": -9.548715591430664, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 0, \"draws\": 206, \"mu_intercept_per_group\": -11.948126792907715, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 0, \"draws\": 207, \"mu_intercept_per_group\": -11.00711441040039, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 0, \"draws\": 208, \"mu_intercept_per_group\": -11.298539161682129, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 0, \"draws\": 209, \"mu_intercept_per_group\": -10.275769233703613, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 0, \"draws\": 210, \"mu_intercept_per_group\": -10.245580673217773, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 0, \"draws\": 211, \"mu_intercept_per_group\": -10.342629432678223, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 0, \"draws\": 212, \"mu_intercept_per_group\": -10.090191841125488, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 0, \"draws\": 213, \"mu_intercept_per_group\": -7.9419050216674805, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 0, \"draws\": 214, \"mu_intercept_per_group\": -7.888082027435303, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 0, \"draws\": 215, \"mu_intercept_per_group\": -6.541024208068848, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 0, \"draws\": 216, \"mu_intercept_per_group\": -6.4741716384887695, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 0, \"draws\": 217, \"mu_intercept_per_group\": -8.174796104431152, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 0, \"draws\": 218, \"mu_intercept_per_group\": -7.374598503112793, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 0, \"draws\": 219, \"mu_intercept_per_group\": -6.704504013061523, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 0, \"draws\": 220, \"mu_intercept_per_group\": -8.928976058959961, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 0, \"draws\": 221, \"mu_intercept_per_group\": -7.490107536315918, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 0, \"draws\": 222, \"mu_intercept_per_group\": -9.011640548706055, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 0, \"draws\": 223, \"mu_intercept_per_group\": -8.580904006958008, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 0, \"draws\": 224, \"mu_intercept_per_group\": -8.483851432800293, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 0, \"draws\": 225, \"mu_intercept_per_group\": -7.79026985168457, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 0, \"draws\": 226, \"mu_intercept_per_group\": -7.628410339355469, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 0, \"draws\": 227, \"mu_intercept_per_group\": -8.9325590133667, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 0, \"draws\": 228, \"mu_intercept_per_group\": -7.157540798187256, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 0, \"draws\": 229, \"mu_intercept_per_group\": -7.708485126495361, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 0, \"draws\": 230, \"mu_intercept_per_group\": -7.355049133300781, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 0, \"draws\": 231, \"mu_intercept_per_group\": -7.018417835235596, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 0, \"draws\": 232, \"mu_intercept_per_group\": -8.361577033996582, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 0, \"draws\": 233, \"mu_intercept_per_group\": -8.183733940124512, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 0, \"draws\": 234, \"mu_intercept_per_group\": -8.235001564025879, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 0, \"draws\": 235, \"mu_intercept_per_group\": -8.571562767028809, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 0, \"draws\": 236, \"mu_intercept_per_group\": -6.3101115226745605, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 0, \"draws\": 237, \"mu_intercept_per_group\": -7.018278121948242, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 0, \"draws\": 238, \"mu_intercept_per_group\": -6.977924346923828, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 0, \"draws\": 239, \"mu_intercept_per_group\": -7.372382640838623, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 0, \"draws\": 240, \"mu_intercept_per_group\": -7.256320953369141, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 0, \"draws\": 241, \"mu_intercept_per_group\": -7.233795166015625, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 0, \"draws\": 242, \"mu_intercept_per_group\": -8.49091625213623, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 0, \"draws\": 243, \"mu_intercept_per_group\": -9.214484214782715, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 0, \"draws\": 244, \"mu_intercept_per_group\": -10.787452697753906, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 0, \"draws\": 245, \"mu_intercept_per_group\": -10.45181655883789, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 0, \"draws\": 246, \"mu_intercept_per_group\": -9.881135940551758, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 0, \"draws\": 247, \"mu_intercept_per_group\": -9.545537948608398, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 0, \"draws\": 248, \"mu_intercept_per_group\": -9.980905532836914, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 0, \"draws\": 249, \"mu_intercept_per_group\": -6.5249924659729, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 0, \"draws\": 250, \"mu_intercept_per_group\": -7.9755964279174805, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 0, \"draws\": 251, \"mu_intercept_per_group\": -8.612462997436523, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 0, \"draws\": 252, \"mu_intercept_per_group\": -8.219758987426758, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 0, \"draws\": 253, \"mu_intercept_per_group\": -7.963944911956787, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 0, \"draws\": 254, \"mu_intercept_per_group\": -8.776134490966797, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 0, \"draws\": 255, \"mu_intercept_per_group\": -9.43143081665039, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 0, \"draws\": 256, \"mu_intercept_per_group\": -10.85197639465332, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 0, \"draws\": 257, \"mu_intercept_per_group\": -10.068879127502441, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 0, \"draws\": 258, \"mu_intercept_per_group\": -9.709246635437012, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 0, \"draws\": 259, \"mu_intercept_per_group\": -9.575889587402344, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 0, \"draws\": 260, \"mu_intercept_per_group\": -10.080343246459961, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 0, \"draws\": 261, \"mu_intercept_per_group\": -8.67544174194336, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 0, \"draws\": 262, \"mu_intercept_per_group\": -8.023117065429688, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 0, \"draws\": 263, \"mu_intercept_per_group\": -8.47940444946289, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 0, \"draws\": 264, \"mu_intercept_per_group\": -8.149895668029785, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 0, \"draws\": 265, \"mu_intercept_per_group\": -8.759527206420898, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 0, \"draws\": 266, \"mu_intercept_per_group\": -6.353415012359619, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 0, \"draws\": 267, \"mu_intercept_per_group\": -6.213578224182129, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 0, \"draws\": 268, \"mu_intercept_per_group\": -5.86566686630249, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 0, \"draws\": 269, \"mu_intercept_per_group\": -19.327342987060547, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 0, \"draws\": 270, \"mu_intercept_per_group\": -17.311426162719727, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 0, \"draws\": 271, \"mu_intercept_per_group\": -14.308171272277832, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 0, \"draws\": 272, \"mu_intercept_per_group\": -13.396991729736328, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 0, \"draws\": 273, \"mu_intercept_per_group\": -13.715051651000977, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 0, \"draws\": 274, \"mu_intercept_per_group\": -15.751935005187988, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 0, \"draws\": 275, \"mu_intercept_per_group\": -15.423849105834961, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 0, \"draws\": 276, \"mu_intercept_per_group\": -14.576160430908203, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 0, \"draws\": 277, \"mu_intercept_per_group\": -14.363265037536621, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 0, \"draws\": 278, \"mu_intercept_per_group\": -12.96366024017334, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 0, \"draws\": 279, \"mu_intercept_per_group\": -13.87910270690918, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 0, \"draws\": 280, \"mu_intercept_per_group\": -11.591469764709473, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 0, \"draws\": 281, \"mu_intercept_per_group\": -14.575644493103027, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 0, \"draws\": 282, \"mu_intercept_per_group\": -14.689902305603027, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 0, \"draws\": 283, \"mu_intercept_per_group\": -15.00460433959961, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 0, \"draws\": 284, \"mu_intercept_per_group\": -12.933090209960938, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 0, \"draws\": 285, \"mu_intercept_per_group\": -15.31631088256836, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 0, \"draws\": 286, \"mu_intercept_per_group\": -13.693306922912598, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 0, \"draws\": 287, \"mu_intercept_per_group\": -14.91311264038086, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 0, \"draws\": 288, \"mu_intercept_per_group\": -15.819818496704102, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 0, \"draws\": 289, \"mu_intercept_per_group\": -15.280932426452637, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 0, \"draws\": 290, \"mu_intercept_per_group\": -14.879806518554688, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 0, \"draws\": 291, \"mu_intercept_per_group\": -14.711051940917969, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 0, \"draws\": 292, \"mu_intercept_per_group\": -14.395410537719727, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 0, \"draws\": 293, \"mu_intercept_per_group\": -13.27812671661377, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 0, \"draws\": 294, \"mu_intercept_per_group\": -12.352173805236816, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 0, \"draws\": 295, \"mu_intercept_per_group\": -10.401369094848633, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 0, \"draws\": 296, \"mu_intercept_per_group\": -9.829854965209961, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 0, \"draws\": 297, \"mu_intercept_per_group\": -8.18619155883789, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 0, \"draws\": 298, \"mu_intercept_per_group\": -8.66999340057373, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 0, \"draws\": 299, \"mu_intercept_per_group\": -9.958154678344727, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 0, \"draws\": 300, \"mu_intercept_per_group\": -9.593432426452637, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 0, \"draws\": 301, \"mu_intercept_per_group\": -10.769091606140137, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 0, \"draws\": 302, \"mu_intercept_per_group\": -10.004193305969238, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 0, \"draws\": 303, \"mu_intercept_per_group\": -10.890406608581543, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 0, \"draws\": 304, \"mu_intercept_per_group\": -9.666512489318848, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 0, \"draws\": 305, \"mu_intercept_per_group\": -8.603235244750977, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 0, \"draws\": 306, \"mu_intercept_per_group\": -8.630160331726074, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 0, \"draws\": 307, \"mu_intercept_per_group\": -9.9837646484375, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 0, \"draws\": 308, \"mu_intercept_per_group\": -8.492984771728516, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 0, \"draws\": 309, \"mu_intercept_per_group\": -13.278030395507812, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 0, \"draws\": 310, \"mu_intercept_per_group\": -13.134513854980469, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 0, \"draws\": 311, \"mu_intercept_per_group\": -12.976862907409668, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 0, \"draws\": 312, \"mu_intercept_per_group\": -11.514472007751465, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 0, \"draws\": 313, \"mu_intercept_per_group\": -13.755633354187012, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 0, \"draws\": 314, \"mu_intercept_per_group\": -10.823258399963379, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 0, \"draws\": 315, \"mu_intercept_per_group\": -10.945013999938965, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 0, \"draws\": 316, \"mu_intercept_per_group\": -12.669825553894043, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 0, \"draws\": 317, \"mu_intercept_per_group\": -13.221829414367676, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 0, \"draws\": 318, \"mu_intercept_per_group\": -12.845072746276855, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 0, \"draws\": 319, \"mu_intercept_per_group\": -14.953858375549316, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 0, \"draws\": 320, \"mu_intercept_per_group\": -4.729133129119873, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 0, \"draws\": 321, \"mu_intercept_per_group\": -4.548620223999023, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 0, \"draws\": 322, \"mu_intercept_per_group\": -4.99838924407959, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 0, \"draws\": 323, \"mu_intercept_per_group\": -4.793203830718994, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 0, \"draws\": 324, \"mu_intercept_per_group\": -7.848435878753662, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 0, \"draws\": 325, \"mu_intercept_per_group\": -7.398036479949951, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 0, \"draws\": 326, \"mu_intercept_per_group\": -8.277606010437012, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 0, \"draws\": 327, \"mu_intercept_per_group\": -8.299333572387695, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 0, \"draws\": 328, \"mu_intercept_per_group\": -9.523959159851074, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 0, \"draws\": 329, \"mu_intercept_per_group\": -8.183238983154297, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 0, \"draws\": 330, \"mu_intercept_per_group\": -9.84847354888916, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 0, \"draws\": 331, \"mu_intercept_per_group\": -8.982048034667969, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 0, \"draws\": 332, \"mu_intercept_per_group\": -9.32981014251709, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 0, \"draws\": 333, \"mu_intercept_per_group\": -9.218888282775879, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 0, \"draws\": 334, \"mu_intercept_per_group\": -8.747058868408203, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 0, \"draws\": 335, \"mu_intercept_per_group\": -9.451587677001953, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 0, \"draws\": 336, \"mu_intercept_per_group\": -8.976151466369629, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 0, \"draws\": 337, \"mu_intercept_per_group\": -10.148067474365234, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 0, \"draws\": 338, \"mu_intercept_per_group\": -16.634719848632812, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 0, \"draws\": 339, \"mu_intercept_per_group\": -13.924173355102539, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 0, \"draws\": 340, \"mu_intercept_per_group\": -14.84196949005127, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 0, \"draws\": 341, \"mu_intercept_per_group\": -12.997241020202637, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 0, \"draws\": 342, \"mu_intercept_per_group\": -12.172097206115723, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 0, \"draws\": 343, \"mu_intercept_per_group\": -12.224699974060059, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 0, \"draws\": 344, \"mu_intercept_per_group\": -16.475446701049805, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 0, \"draws\": 345, \"mu_intercept_per_group\": -22.25055503845215, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 0, \"draws\": 346, \"mu_intercept_per_group\": -12.725021362304688, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 0, \"draws\": 347, \"mu_intercept_per_group\": -10.97195053100586, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 0, \"draws\": 348, \"mu_intercept_per_group\": -10.968955039978027, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 0, \"draws\": 349, \"mu_intercept_per_group\": -10.317915916442871, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 0, \"draws\": 350, \"mu_intercept_per_group\": -12.809236526489258, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 0, \"draws\": 351, \"mu_intercept_per_group\": -12.792585372924805, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 0, \"draws\": 352, \"mu_intercept_per_group\": -14.153106689453125, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 0, \"draws\": 353, \"mu_intercept_per_group\": -15.465877532958984, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 0, \"draws\": 354, \"mu_intercept_per_group\": -8.954972267150879, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 0, \"draws\": 355, \"mu_intercept_per_group\": -8.55903434753418, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 0, \"draws\": 356, \"mu_intercept_per_group\": -9.115021705627441, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 0, \"draws\": 357, \"mu_intercept_per_group\": -9.238870620727539, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 0, \"draws\": 358, \"mu_intercept_per_group\": -9.192914962768555, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 0, \"draws\": 359, \"mu_intercept_per_group\": -8.47585678100586, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 0, \"draws\": 360, \"mu_intercept_per_group\": -8.087279319763184, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 0, \"draws\": 361, \"mu_intercept_per_group\": -9.007800102233887, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 0, \"draws\": 362, \"mu_intercept_per_group\": -9.210658073425293, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 0, \"draws\": 363, \"mu_intercept_per_group\": -9.000494003295898, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 0, \"draws\": 364, \"mu_intercept_per_group\": -11.10288143157959, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 0, \"draws\": 365, \"mu_intercept_per_group\": -11.148441314697266, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 0, \"draws\": 366, \"mu_intercept_per_group\": -10.655070304870605, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 0, \"draws\": 367, \"mu_intercept_per_group\": -10.40219497680664, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 0, \"draws\": 368, \"mu_intercept_per_group\": -12.071128845214844, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 0, \"draws\": 369, \"mu_intercept_per_group\": -7.3215203285217285, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 0, \"draws\": 370, \"mu_intercept_per_group\": -6.908425331115723, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 0, \"draws\": 371, \"mu_intercept_per_group\": -7.004328727722168, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 0, \"draws\": 372, \"mu_intercept_per_group\": -7.524672031402588, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 0, \"draws\": 373, \"mu_intercept_per_group\": -7.762434005737305, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 0, \"draws\": 374, \"mu_intercept_per_group\": -8.050886154174805, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 0, \"draws\": 375, \"mu_intercept_per_group\": -8.872756004333496, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 0, \"draws\": 376, \"mu_intercept_per_group\": -11.756394386291504, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 0, \"draws\": 377, \"mu_intercept_per_group\": -7.700242519378662, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 0, \"draws\": 378, \"mu_intercept_per_group\": -7.483798503875732, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 0, \"draws\": 379, \"mu_intercept_per_group\": -7.367605686187744, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 0, \"draws\": 380, \"mu_intercept_per_group\": -7.472713470458984, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 0, \"draws\": 381, \"mu_intercept_per_group\": -9.43480396270752, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 0, \"draws\": 382, \"mu_intercept_per_group\": -7.030799865722656, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 0, \"draws\": 383, \"mu_intercept_per_group\": -7.482207775115967, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 0, \"draws\": 384, \"mu_intercept_per_group\": -12.969368934631348, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 0, \"draws\": 385, \"mu_intercept_per_group\": -13.436347961425781, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 0, \"draws\": 386, \"mu_intercept_per_group\": -12.058253288269043, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 0, \"draws\": 387, \"mu_intercept_per_group\": -11.859895706176758, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 0, \"draws\": 388, \"mu_intercept_per_group\": -11.603286743164062, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 0, \"draws\": 389, \"mu_intercept_per_group\": -13.032825469970703, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 0, \"draws\": 390, \"mu_intercept_per_group\": -12.195805549621582, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 0, \"draws\": 391, \"mu_intercept_per_group\": -11.49155044555664, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 0, \"draws\": 392, \"mu_intercept_per_group\": -12.611146926879883, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 0, \"draws\": 393, \"mu_intercept_per_group\": -10.519026756286621, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 0, \"draws\": 394, \"mu_intercept_per_group\": -11.463098526000977, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 0, \"draws\": 395, \"mu_intercept_per_group\": -10.673408508300781, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 0, \"draws\": 396, \"mu_intercept_per_group\": -12.180203437805176, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 0, \"draws\": 397, \"mu_intercept_per_group\": -11.599772453308105, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 0, \"draws\": 398, \"mu_intercept_per_group\": -12.220952033996582, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 0, \"draws\": 399, \"mu_intercept_per_group\": -10.257567405700684, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 0, \"draws\": 400, \"mu_intercept_per_group\": -10.443148612976074, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 0, \"draws\": 401, \"mu_intercept_per_group\": -9.67309284210205, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 0, \"draws\": 402, \"mu_intercept_per_group\": -9.264528274536133, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 0, \"draws\": 403, \"mu_intercept_per_group\": -9.035514831542969, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 0, \"draws\": 404, \"mu_intercept_per_group\": -11.879414558410645, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 0, \"draws\": 405, \"mu_intercept_per_group\": -11.78432846069336, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 0, \"draws\": 406, \"mu_intercept_per_group\": -12.515641212463379, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 0, \"draws\": 407, \"mu_intercept_per_group\": -10.765889167785645, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 0, \"draws\": 408, \"mu_intercept_per_group\": -10.750504493713379, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 0, \"draws\": 409, \"mu_intercept_per_group\": -10.787971496582031, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 0, \"draws\": 410, \"mu_intercept_per_group\": -10.69991683959961, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 0, \"draws\": 411, \"mu_intercept_per_group\": -9.415861129760742, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 0, \"draws\": 412, \"mu_intercept_per_group\": -8.839190483093262, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 0, \"draws\": 413, \"mu_intercept_per_group\": -12.824247360229492, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 0, \"draws\": 414, \"mu_intercept_per_group\": -12.086606979370117, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 0, \"draws\": 415, \"mu_intercept_per_group\": -12.281907081604004, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 0, \"draws\": 416, \"mu_intercept_per_group\": -11.686670303344727, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 0, \"draws\": 417, \"mu_intercept_per_group\": -10.803545951843262, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 0, \"draws\": 418, \"mu_intercept_per_group\": -12.325039863586426, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 0, \"draws\": 419, \"mu_intercept_per_group\": -10.761834144592285, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 0, \"draws\": 420, \"mu_intercept_per_group\": -10.596420288085938, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 0, \"draws\": 421, \"mu_intercept_per_group\": -11.28418254852295, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 0, \"draws\": 422, \"mu_intercept_per_group\": -12.91223430633545, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 0, \"draws\": 423, \"mu_intercept_per_group\": -11.278482437133789, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 0, \"draws\": 424, \"mu_intercept_per_group\": -12.274307250976562, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 0, \"draws\": 425, \"mu_intercept_per_group\": -11.702899932861328, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 0, \"draws\": 426, \"mu_intercept_per_group\": -13.681374549865723, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 0, \"draws\": 427, \"mu_intercept_per_group\": -14.477100372314453, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 0, \"draws\": 428, \"mu_intercept_per_group\": -14.371209144592285, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 0, \"draws\": 429, \"mu_intercept_per_group\": -14.394993782043457, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 0, \"draws\": 430, \"mu_intercept_per_group\": -14.533173561096191, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 0, \"draws\": 431, \"mu_intercept_per_group\": -11.855740547180176, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 0, \"draws\": 432, \"mu_intercept_per_group\": -13.92996883392334, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 0, \"draws\": 433, \"mu_intercept_per_group\": -14.760699272155762, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 0, \"draws\": 434, \"mu_intercept_per_group\": -11.185495376586914, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 0, \"draws\": 435, \"mu_intercept_per_group\": -12.835426330566406, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 0, \"draws\": 436, \"mu_intercept_per_group\": -13.144542694091797, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 0, \"draws\": 437, \"mu_intercept_per_group\": -13.600672721862793, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 0, \"draws\": 438, \"mu_intercept_per_group\": -15.38377571105957, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 0, \"draws\": 439, \"mu_intercept_per_group\": -13.606863021850586, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 0, \"draws\": 440, \"mu_intercept_per_group\": -13.265087127685547, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 0, \"draws\": 441, \"mu_intercept_per_group\": -13.628849029541016, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 0, \"draws\": 442, \"mu_intercept_per_group\": -15.011651039123535, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 0, \"draws\": 443, \"mu_intercept_per_group\": -17.774574279785156, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 0, \"draws\": 444, \"mu_intercept_per_group\": -18.67198371887207, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 0, \"draws\": 445, \"mu_intercept_per_group\": -15.473930358886719, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 0, \"draws\": 446, \"mu_intercept_per_group\": -11.308130264282227, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 0, \"draws\": 447, \"mu_intercept_per_group\": -11.705024719238281, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 0, \"draws\": 448, \"mu_intercept_per_group\": -8.439077377319336, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 0, \"draws\": 449, \"mu_intercept_per_group\": -8.944109916687012, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 0, \"draws\": 450, \"mu_intercept_per_group\": -10.272186279296875, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 0, \"draws\": 451, \"mu_intercept_per_group\": -18.75371551513672, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 0, \"draws\": 452, \"mu_intercept_per_group\": -17.906389236450195, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 0, \"draws\": 453, \"mu_intercept_per_group\": -21.123910903930664, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 0, \"draws\": 454, \"mu_intercept_per_group\": -19.832918167114258, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 0, \"draws\": 455, \"mu_intercept_per_group\": -20.83233642578125, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 0, \"draws\": 456, \"mu_intercept_per_group\": -18.55301856994629, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 0, \"draws\": 457, \"mu_intercept_per_group\": -19.926511764526367, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 0, \"draws\": 458, \"mu_intercept_per_group\": -20.052583694458008, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 0, \"draws\": 459, \"mu_intercept_per_group\": -10.44214916229248, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 0, \"draws\": 460, \"mu_intercept_per_group\": -10.604362487792969, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 0, \"draws\": 461, \"mu_intercept_per_group\": -10.795086860656738, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 0, \"draws\": 462, \"mu_intercept_per_group\": -8.453054428100586, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 0, \"draws\": 463, \"mu_intercept_per_group\": -8.739181518554688, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 0, \"draws\": 464, \"mu_intercept_per_group\": -9.087434768676758, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 0, \"draws\": 465, \"mu_intercept_per_group\": -8.729281425476074, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 0, \"draws\": 466, \"mu_intercept_per_group\": -8.495954513549805, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 0, \"draws\": 467, \"mu_intercept_per_group\": -9.306235313415527, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 0, \"draws\": 468, \"mu_intercept_per_group\": -10.284454345703125, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 0, \"draws\": 469, \"mu_intercept_per_group\": -9.956564903259277, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 0, \"draws\": 470, \"mu_intercept_per_group\": -10.20787525177002, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 0, \"draws\": 471, \"mu_intercept_per_group\": -11.150190353393555, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 0, \"draws\": 472, \"mu_intercept_per_group\": -11.230859756469727, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 0, \"draws\": 473, \"mu_intercept_per_group\": -13.22197437286377, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 0, \"draws\": 474, \"mu_intercept_per_group\": -15.436800956726074, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 0, \"draws\": 475, \"mu_intercept_per_group\": -15.656484603881836, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 0, \"draws\": 476, \"mu_intercept_per_group\": -15.69136905670166, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 0, \"draws\": 477, \"mu_intercept_per_group\": -16.518627166748047, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 0, \"draws\": 478, \"mu_intercept_per_group\": -16.37407112121582, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 0, \"draws\": 479, \"mu_intercept_per_group\": -15.856636047363281, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 0, \"draws\": 480, \"mu_intercept_per_group\": -13.168560981750488, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 0, \"draws\": 481, \"mu_intercept_per_group\": -12.187348365783691, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 0, \"draws\": 482, \"mu_intercept_per_group\": -12.000370979309082, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 0, \"draws\": 483, \"mu_intercept_per_group\": -11.742568016052246, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 0, \"draws\": 484, \"mu_intercept_per_group\": -10.521302223205566, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 0, \"draws\": 485, \"mu_intercept_per_group\": -10.248671531677246, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 0, \"draws\": 486, \"mu_intercept_per_group\": -10.099864959716797, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 0, \"draws\": 487, \"mu_intercept_per_group\": -10.644795417785645, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 0, \"draws\": 488, \"mu_intercept_per_group\": -8.764814376831055, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 0, \"draws\": 489, \"mu_intercept_per_group\": -10.25143051147461, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 0, \"draws\": 490, \"mu_intercept_per_group\": -8.947707176208496, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 0, \"draws\": 491, \"mu_intercept_per_group\": -9.025116920471191, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 0, \"draws\": 492, \"mu_intercept_per_group\": -10.162772178649902, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 0, \"draws\": 493, \"mu_intercept_per_group\": -8.695560455322266, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 0, \"draws\": 494, \"mu_intercept_per_group\": -14.067776679992676, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 0, \"draws\": 495, \"mu_intercept_per_group\": -13.395378112792969, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 0, \"draws\": 496, \"mu_intercept_per_group\": -12.221824645996094, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 0, \"draws\": 497, \"mu_intercept_per_group\": -11.7846040725708, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 0, \"draws\": 498, \"mu_intercept_per_group\": -12.379312515258789, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 0, \"draws\": 499, \"mu_intercept_per_group\": -11.680336952209473, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 0, \"draws\": 500, \"mu_intercept_per_group\": -11.611162185668945, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 0, \"draws\": 501, \"mu_intercept_per_group\": -13.801671028137207, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 0, \"draws\": 502, \"mu_intercept_per_group\": -13.680171966552734, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 0, \"draws\": 503, \"mu_intercept_per_group\": -13.08855152130127, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 0, \"draws\": 504, \"mu_intercept_per_group\": -12.703925132751465, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 0, \"draws\": 505, \"mu_intercept_per_group\": -12.404776573181152, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 0, \"draws\": 506, \"mu_intercept_per_group\": -11.335338592529297, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 0, \"draws\": 507, \"mu_intercept_per_group\": -10.328210830688477, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 0, \"draws\": 508, \"mu_intercept_per_group\": -15.149999618530273, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 0, \"draws\": 509, \"mu_intercept_per_group\": -14.909625053405762, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 0, \"draws\": 510, \"mu_intercept_per_group\": -14.167028427124023, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 0, \"draws\": 511, \"mu_intercept_per_group\": -18.85173225402832, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 0, \"draws\": 512, \"mu_intercept_per_group\": -16.696041107177734, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 0, \"draws\": 513, \"mu_intercept_per_group\": -14.410198211669922, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 0, \"draws\": 514, \"mu_intercept_per_group\": -14.482259750366211, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 0, \"draws\": 515, \"mu_intercept_per_group\": -14.800610542297363, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 0, \"draws\": 516, \"mu_intercept_per_group\": -14.598974227905273, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 0, \"draws\": 517, \"mu_intercept_per_group\": -15.078454971313477, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 0, \"draws\": 518, \"mu_intercept_per_group\": -14.47150993347168, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 0, \"draws\": 519, \"mu_intercept_per_group\": -13.112748146057129, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 0, \"draws\": 520, \"mu_intercept_per_group\": -12.199393272399902, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 0, \"draws\": 521, \"mu_intercept_per_group\": -10.107108116149902, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 0, \"draws\": 522, \"mu_intercept_per_group\": -9.946240425109863, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 0, \"draws\": 523, \"mu_intercept_per_group\": -10.492698669433594, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 0, \"draws\": 524, \"mu_intercept_per_group\": -8.24332046508789, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 0, \"draws\": 525, \"mu_intercept_per_group\": -7.799241542816162, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 0, \"draws\": 526, \"mu_intercept_per_group\": -8.215629577636719, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 0, \"draws\": 527, \"mu_intercept_per_group\": -10.566386222839355, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 0, \"draws\": 528, \"mu_intercept_per_group\": -12.110265731811523, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 0, \"draws\": 529, \"mu_intercept_per_group\": -10.62038803100586, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 0, \"draws\": 530, \"mu_intercept_per_group\": -9.512286186218262, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 0, \"draws\": 531, \"mu_intercept_per_group\": -9.29843521118164, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 0, \"draws\": 532, \"mu_intercept_per_group\": -10.841090202331543, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 0, \"draws\": 533, \"mu_intercept_per_group\": -10.408195495605469, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 0, \"draws\": 534, \"mu_intercept_per_group\": -11.931687355041504, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 0, \"draws\": 535, \"mu_intercept_per_group\": -11.51518726348877, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 0, \"draws\": 536, \"mu_intercept_per_group\": -10.837364196777344, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 0, \"draws\": 537, \"mu_intercept_per_group\": -7.363087177276611, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 0, \"draws\": 538, \"mu_intercept_per_group\": -7.297500133514404, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 0, \"draws\": 539, \"mu_intercept_per_group\": -7.184803485870361, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 0, \"draws\": 540, \"mu_intercept_per_group\": -9.840415000915527, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 0, \"draws\": 541, \"mu_intercept_per_group\": -9.620916366577148, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 0, \"draws\": 542, \"mu_intercept_per_group\": -9.531041145324707, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 0, \"draws\": 543, \"mu_intercept_per_group\": -9.775530815124512, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 0, \"draws\": 544, \"mu_intercept_per_group\": -13.2416410446167, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 0, \"draws\": 545, \"mu_intercept_per_group\": -12.479275703430176, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 0, \"draws\": 546, \"mu_intercept_per_group\": -10.308774948120117, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 0, \"draws\": 547, \"mu_intercept_per_group\": -13.033088684082031, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 0, \"draws\": 548, \"mu_intercept_per_group\": -11.920709609985352, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 0, \"draws\": 549, \"mu_intercept_per_group\": -12.347607612609863, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 0, \"draws\": 550, \"mu_intercept_per_group\": -14.002656936645508, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 0, \"draws\": 551, \"mu_intercept_per_group\": -13.718914031982422, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 0, \"draws\": 552, \"mu_intercept_per_group\": -12.631888389587402, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 0, \"draws\": 553, \"mu_intercept_per_group\": -12.660639762878418, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 0, \"draws\": 554, \"mu_intercept_per_group\": -12.867996215820312, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 0, \"draws\": 555, \"mu_intercept_per_group\": -13.427590370178223, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 0, \"draws\": 556, \"mu_intercept_per_group\": -14.38259220123291, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 0, \"draws\": 557, \"mu_intercept_per_group\": -13.775948524475098, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 0, \"draws\": 558, \"mu_intercept_per_group\": -13.804679870605469, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 0, \"draws\": 559, \"mu_intercept_per_group\": -14.020081520080566, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 0, \"draws\": 560, \"mu_intercept_per_group\": -10.551556587219238, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 0, \"draws\": 561, \"mu_intercept_per_group\": -12.248726844787598, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 0, \"draws\": 562, \"mu_intercept_per_group\": -14.781445503234863, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 0, \"draws\": 563, \"mu_intercept_per_group\": -12.331197738647461, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 0, \"draws\": 564, \"mu_intercept_per_group\": -10.008559226989746, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 0, \"draws\": 565, \"mu_intercept_per_group\": -9.367363929748535, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 0, \"draws\": 566, \"mu_intercept_per_group\": -9.590958595275879, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 0, \"draws\": 567, \"mu_intercept_per_group\": -9.57936954498291, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 0, \"draws\": 568, \"mu_intercept_per_group\": -9.234673500061035, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 0, \"draws\": 569, \"mu_intercept_per_group\": -9.207507133483887, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 0, \"draws\": 570, \"mu_intercept_per_group\": -8.088523864746094, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 0, \"draws\": 571, \"mu_intercept_per_group\": -8.085479736328125, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 0, \"draws\": 572, \"mu_intercept_per_group\": -9.875282287597656, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 0, \"draws\": 573, \"mu_intercept_per_group\": -12.18527603149414, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 0, \"draws\": 574, \"mu_intercept_per_group\": -12.462112426757812, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 0, \"draws\": 575, \"mu_intercept_per_group\": -13.711477279663086, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 0, \"draws\": 576, \"mu_intercept_per_group\": -15.210104942321777, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 0, \"draws\": 577, \"mu_intercept_per_group\": -15.821167945861816, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 0, \"draws\": 578, \"mu_intercept_per_group\": -15.639816284179688, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 0, \"draws\": 579, \"mu_intercept_per_group\": -20.180330276489258, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 0, \"draws\": 580, \"mu_intercept_per_group\": -16.050382614135742, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 0, \"draws\": 581, \"mu_intercept_per_group\": -14.000548362731934, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 0, \"draws\": 582, \"mu_intercept_per_group\": -14.804583549499512, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 0, \"draws\": 583, \"mu_intercept_per_group\": -14.11005687713623, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 0, \"draws\": 584, \"mu_intercept_per_group\": -13.604371070861816, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 0, \"draws\": 585, \"mu_intercept_per_group\": -16.89350700378418, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 0, \"draws\": 586, \"mu_intercept_per_group\": -17.043394088745117, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 0, \"draws\": 587, \"mu_intercept_per_group\": -18.620887756347656, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 0, \"draws\": 588, \"mu_intercept_per_group\": -17.242355346679688, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 0, \"draws\": 589, \"mu_intercept_per_group\": -18.76848602294922, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 0, \"draws\": 590, \"mu_intercept_per_group\": -18.645761489868164, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 0, \"draws\": 591, \"mu_intercept_per_group\": -18.606204986572266, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 0, \"draws\": 592, \"mu_intercept_per_group\": -17.98621368408203, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 0, \"draws\": 593, \"mu_intercept_per_group\": -20.126649856567383, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 0, \"draws\": 594, \"mu_intercept_per_group\": -18.1478214263916, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 0, \"draws\": 595, \"mu_intercept_per_group\": -17.565275192260742, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 0, \"draws\": 596, \"mu_intercept_per_group\": -18.739498138427734, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 0, \"draws\": 597, \"mu_intercept_per_group\": -18.749195098876953, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 0, \"draws\": 598, \"mu_intercept_per_group\": -18.637252807617188, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 0, \"draws\": 599, \"mu_intercept_per_group\": -19.325294494628906, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 0, \"draws\": 600, \"mu_intercept_per_group\": -18.093353271484375, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 0, \"draws\": 601, \"mu_intercept_per_group\": -20.975679397583008, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 0, \"draws\": 602, \"mu_intercept_per_group\": -17.751113891601562, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 0, \"draws\": 603, \"mu_intercept_per_group\": -18.311607360839844, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 0, \"draws\": 604, \"mu_intercept_per_group\": -18.146329879760742, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 0, \"draws\": 605, \"mu_intercept_per_group\": -18.93073844909668, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 0, \"draws\": 606, \"mu_intercept_per_group\": -18.398386001586914, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 0, \"draws\": 607, \"mu_intercept_per_group\": -17.398426055908203, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 0, \"draws\": 608, \"mu_intercept_per_group\": -9.606353759765625, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 0, \"draws\": 609, \"mu_intercept_per_group\": -10.549662590026855, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 0, \"draws\": 610, \"mu_intercept_per_group\": -10.017539978027344, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 0, \"draws\": 611, \"mu_intercept_per_group\": -10.648676872253418, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 0, \"draws\": 612, \"mu_intercept_per_group\": -10.307941436767578, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 0, \"draws\": 613, \"mu_intercept_per_group\": -9.387676239013672, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 0, \"draws\": 614, \"mu_intercept_per_group\": -10.218058586120605, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 0, \"draws\": 615, \"mu_intercept_per_group\": -10.085677146911621, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 0, \"draws\": 616, \"mu_intercept_per_group\": -12.148161888122559, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 0, \"draws\": 617, \"mu_intercept_per_group\": -12.040152549743652, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 0, \"draws\": 618, \"mu_intercept_per_group\": -16.555862426757812, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 0, \"draws\": 619, \"mu_intercept_per_group\": -17.341968536376953, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 0, \"draws\": 620, \"mu_intercept_per_group\": -15.287552833557129, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 0, \"draws\": 621, \"mu_intercept_per_group\": -17.18736457824707, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 0, \"draws\": 622, \"mu_intercept_per_group\": -16.410188674926758, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 0, \"draws\": 623, \"mu_intercept_per_group\": -15.947684288024902, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 0, \"draws\": 624, \"mu_intercept_per_group\": -18.018848419189453, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 0, \"draws\": 625, \"mu_intercept_per_group\": -16.82005500793457, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 0, \"draws\": 626, \"mu_intercept_per_group\": -15.86064624786377, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 0, \"draws\": 627, \"mu_intercept_per_group\": -16.848609924316406, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 0, \"draws\": 628, \"mu_intercept_per_group\": -15.364187240600586, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 0, \"draws\": 629, \"mu_intercept_per_group\": -8.529664993286133, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 0, \"draws\": 630, \"mu_intercept_per_group\": -8.565625190734863, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 0, \"draws\": 631, \"mu_intercept_per_group\": -8.804603576660156, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 0, \"draws\": 632, \"mu_intercept_per_group\": -9.800691604614258, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 0, \"draws\": 633, \"mu_intercept_per_group\": -10.605224609375, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 0, \"draws\": 634, \"mu_intercept_per_group\": -12.0894136428833, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 0, \"draws\": 635, \"mu_intercept_per_group\": -11.662813186645508, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 0, \"draws\": 636, \"mu_intercept_per_group\": -11.572234153747559, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 0, \"draws\": 637, \"mu_intercept_per_group\": -9.721075057983398, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 0, \"draws\": 638, \"mu_intercept_per_group\": -9.48402214050293, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 0, \"draws\": 639, \"mu_intercept_per_group\": -9.836634635925293, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 1, \"draws\": 0, \"mu_intercept_per_group\": -7.260185718536377, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 1, \"draws\": 1, \"mu_intercept_per_group\": -7.8033342361450195, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 1, \"draws\": 2, \"mu_intercept_per_group\": -8.62105941772461, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 1, \"draws\": 3, \"mu_intercept_per_group\": -8.771944046020508, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 1, \"draws\": 4, \"mu_intercept_per_group\": -8.69017505645752, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 1, \"draws\": 5, \"mu_intercept_per_group\": -8.684611320495605, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 1, \"draws\": 6, \"mu_intercept_per_group\": -7.97740364074707, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 1, \"draws\": 7, \"mu_intercept_per_group\": -8.192066192626953, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 1, \"draws\": 8, \"mu_intercept_per_group\": -7.053494930267334, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 1, \"draws\": 9, \"mu_intercept_per_group\": -7.887849807739258, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 1, \"draws\": 10, \"mu_intercept_per_group\": -7.688833236694336, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 1, \"draws\": 11, \"mu_intercept_per_group\": -7.356691360473633, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 1, \"draws\": 12, \"mu_intercept_per_group\": -11.844321250915527, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 1, \"draws\": 13, \"mu_intercept_per_group\": -11.675236701965332, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 1, \"draws\": 14, \"mu_intercept_per_group\": -11.6438627243042, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 1, \"draws\": 15, \"mu_intercept_per_group\": -11.190482139587402, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 1, \"draws\": 16, \"mu_intercept_per_group\": -11.882271766662598, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 1, \"draws\": 17, \"mu_intercept_per_group\": -11.952474594116211, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 1, \"draws\": 18, \"mu_intercept_per_group\": -11.745379447937012, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 1, \"draws\": 19, \"mu_intercept_per_group\": -11.784679412841797, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 1, \"draws\": 20, \"mu_intercept_per_group\": -10.551338195800781, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 1, \"draws\": 21, \"mu_intercept_per_group\": -10.114668846130371, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 1, \"draws\": 22, \"mu_intercept_per_group\": -11.85512638092041, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 1, \"draws\": 23, \"mu_intercept_per_group\": -12.067502975463867, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 1, \"draws\": 24, \"mu_intercept_per_group\": -12.263293266296387, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 1, \"draws\": 25, \"mu_intercept_per_group\": -11.330323219299316, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 1, \"draws\": 26, \"mu_intercept_per_group\": -10.16634750366211, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 1, \"draws\": 27, \"mu_intercept_per_group\": -12.422002792358398, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 1, \"draws\": 28, \"mu_intercept_per_group\": -14.905791282653809, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 1, \"draws\": 29, \"mu_intercept_per_group\": -12.719289779663086, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 1, \"draws\": 30, \"mu_intercept_per_group\": -14.885536193847656, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 1, \"draws\": 31, \"mu_intercept_per_group\": -13.788555145263672, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 1, \"draws\": 32, \"mu_intercept_per_group\": -11.286567687988281, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 1, \"draws\": 33, \"mu_intercept_per_group\": -11.470149993896484, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 1, \"draws\": 34, \"mu_intercept_per_group\": -11.705706596374512, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 1, \"draws\": 35, \"mu_intercept_per_group\": -12.14986801147461, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 1, \"draws\": 36, \"mu_intercept_per_group\": -12.427521705627441, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 1, \"draws\": 37, \"mu_intercept_per_group\": -12.080053329467773, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 1, \"draws\": 38, \"mu_intercept_per_group\": -11.04504680633545, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 1, \"draws\": 39, \"mu_intercept_per_group\": -10.545846939086914, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 1, \"draws\": 40, \"mu_intercept_per_group\": -11.033795356750488, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 1, \"draws\": 41, \"mu_intercept_per_group\": -10.63413143157959, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 1, \"draws\": 42, \"mu_intercept_per_group\": -11.15628719329834, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 1, \"draws\": 43, \"mu_intercept_per_group\": -11.159872055053711, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 1, \"draws\": 44, \"mu_intercept_per_group\": -10.859193801879883, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 1, \"draws\": 45, \"mu_intercept_per_group\": -10.099026679992676, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 1, \"draws\": 46, \"mu_intercept_per_group\": -9.81385612487793, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 1, \"draws\": 47, \"mu_intercept_per_group\": -10.156739234924316, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 1, \"draws\": 48, \"mu_intercept_per_group\": -11.215834617614746, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 1, \"draws\": 49, \"mu_intercept_per_group\": -10.584491729736328, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 1, \"draws\": 50, \"mu_intercept_per_group\": -6.784483909606934, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 1, \"draws\": 51, \"mu_intercept_per_group\": -7.553809642791748, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 1, \"draws\": 52, \"mu_intercept_per_group\": -4.260471343994141, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 1, \"draws\": 53, \"mu_intercept_per_group\": -4.78641939163208, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 1, \"draws\": 54, \"mu_intercept_per_group\": -4.144386291503906, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 1, \"draws\": 55, \"mu_intercept_per_group\": -5.129573822021484, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 1, \"draws\": 56, \"mu_intercept_per_group\": -3.6122500896453857, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 1, \"draws\": 57, \"mu_intercept_per_group\": -4.3750200271606445, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 1, \"draws\": 58, \"mu_intercept_per_group\": -3.9339284896850586, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 1, \"draws\": 59, \"mu_intercept_per_group\": -4.165874481201172, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 1, \"draws\": 60, \"mu_intercept_per_group\": -3.649487018585205, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 1, \"draws\": 61, \"mu_intercept_per_group\": -7.698469161987305, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 1, \"draws\": 62, \"mu_intercept_per_group\": -8.193337440490723, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 1, \"draws\": 63, \"mu_intercept_per_group\": -7.692523002624512, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 1, \"draws\": 64, \"mu_intercept_per_group\": -8.399910926818848, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 1, \"draws\": 65, \"mu_intercept_per_group\": -7.326940059661865, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 1, \"draws\": 66, \"mu_intercept_per_group\": -9.008371353149414, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 1, \"draws\": 67, \"mu_intercept_per_group\": -8.43190860748291, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 1, \"draws\": 68, \"mu_intercept_per_group\": -8.017098426818848, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 1, \"draws\": 69, \"mu_intercept_per_group\": -8.083162307739258, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 1, \"draws\": 70, \"mu_intercept_per_group\": -6.4302520751953125, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 1, \"draws\": 71, \"mu_intercept_per_group\": -4.934736251831055, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 1, \"draws\": 72, \"mu_intercept_per_group\": -4.99753475189209, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 1, \"draws\": 73, \"mu_intercept_per_group\": -4.972352027893066, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 1, \"draws\": 74, \"mu_intercept_per_group\": -5.386823654174805, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 1, \"draws\": 75, \"mu_intercept_per_group\": -4.610748767852783, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 1, \"draws\": 76, \"mu_intercept_per_group\": -5.143852710723877, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 1, \"draws\": 77, \"mu_intercept_per_group\": -8.12186336517334, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 1, \"draws\": 78, \"mu_intercept_per_group\": -6.716584205627441, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 1, \"draws\": 79, \"mu_intercept_per_group\": -10.605537414550781, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 1, \"draws\": 80, \"mu_intercept_per_group\": -12.987680435180664, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 1, \"draws\": 81, \"mu_intercept_per_group\": -11.353755950927734, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 1, \"draws\": 82, \"mu_intercept_per_group\": -12.92531681060791, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 1, \"draws\": 83, \"mu_intercept_per_group\": -11.546575546264648, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 1, \"draws\": 84, \"mu_intercept_per_group\": -11.27349853515625, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 1, \"draws\": 85, \"mu_intercept_per_group\": -10.825203895568848, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 1, \"draws\": 86, \"mu_intercept_per_group\": -9.012487411499023, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 1, \"draws\": 87, \"mu_intercept_per_group\": -6.487373352050781, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 1, \"draws\": 88, \"mu_intercept_per_group\": -6.402134418487549, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 1, \"draws\": 89, \"mu_intercept_per_group\": -8.774800300598145, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 1, \"draws\": 90, \"mu_intercept_per_group\": -10.133796691894531, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 1, \"draws\": 91, \"mu_intercept_per_group\": -9.960758209228516, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 1, \"draws\": 92, \"mu_intercept_per_group\": -10.057219505310059, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 1, \"draws\": 93, \"mu_intercept_per_group\": -9.877751350402832, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 1, \"draws\": 94, \"mu_intercept_per_group\": -10.194048881530762, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 1, \"draws\": 95, \"mu_intercept_per_group\": -9.828524589538574, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 1, \"draws\": 96, \"mu_intercept_per_group\": -9.108601570129395, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 1, \"draws\": 97, \"mu_intercept_per_group\": -9.240880012512207, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 1, \"draws\": 98, \"mu_intercept_per_group\": -9.662944793701172, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 1, \"draws\": 99, \"mu_intercept_per_group\": -9.604839324951172, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 1, \"draws\": 100, \"mu_intercept_per_group\": -9.778409004211426, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 1, \"draws\": 101, \"mu_intercept_per_group\": -11.559121131896973, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 1, \"draws\": 102, \"mu_intercept_per_group\": -9.63019847869873, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 1, \"draws\": 103, \"mu_intercept_per_group\": -6.116044998168945, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 1, \"draws\": 104, \"mu_intercept_per_group\": -8.847260475158691, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 1, \"draws\": 105, \"mu_intercept_per_group\": -9.158397674560547, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 1, \"draws\": 106, \"mu_intercept_per_group\": -9.56347942352295, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 1, \"draws\": 107, \"mu_intercept_per_group\": -10.99738883972168, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 1, \"draws\": 108, \"mu_intercept_per_group\": -9.527101516723633, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 1, \"draws\": 109, \"mu_intercept_per_group\": -15.425337791442871, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 1, \"draws\": 110, \"mu_intercept_per_group\": -16.605077743530273, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 1, \"draws\": 111, \"mu_intercept_per_group\": -13.048630714416504, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 1, \"draws\": 112, \"mu_intercept_per_group\": -11.26810359954834, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 1, \"draws\": 113, \"mu_intercept_per_group\": -11.671223640441895, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 1, \"draws\": 114, \"mu_intercept_per_group\": -14.319704055786133, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 1, \"draws\": 115, \"mu_intercept_per_group\": -11.839753150939941, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 1, \"draws\": 116, \"mu_intercept_per_group\": -12.399782180786133, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 1, \"draws\": 117, \"mu_intercept_per_group\": -12.296150207519531, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 1, \"draws\": 118, \"mu_intercept_per_group\": -11.113602638244629, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 1, \"draws\": 119, \"mu_intercept_per_group\": -12.898321151733398, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 1, \"draws\": 120, \"mu_intercept_per_group\": -14.470512390136719, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 1, \"draws\": 121, \"mu_intercept_per_group\": -14.486980438232422, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 1, \"draws\": 122, \"mu_intercept_per_group\": -11.586691856384277, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 1, \"draws\": 123, \"mu_intercept_per_group\": -11.338854789733887, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 1, \"draws\": 124, \"mu_intercept_per_group\": -10.435816764831543, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 1, \"draws\": 125, \"mu_intercept_per_group\": -9.140275001525879, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 1, \"draws\": 126, \"mu_intercept_per_group\": -9.6119966506958, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 1, \"draws\": 127, \"mu_intercept_per_group\": -9.6206636428833, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 1, \"draws\": 128, \"mu_intercept_per_group\": -9.274335861206055, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 1, \"draws\": 129, \"mu_intercept_per_group\": -8.171449661254883, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 1, \"draws\": 130, \"mu_intercept_per_group\": -8.880675315856934, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 1, \"draws\": 131, \"mu_intercept_per_group\": -8.84261417388916, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 1, \"draws\": 132, \"mu_intercept_per_group\": -8.681678771972656, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 1, \"draws\": 133, \"mu_intercept_per_group\": -8.537386894226074, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 1, \"draws\": 134, \"mu_intercept_per_group\": -8.257012367248535, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 1, \"draws\": 135, \"mu_intercept_per_group\": -8.174871444702148, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 1, \"draws\": 136, \"mu_intercept_per_group\": -8.531773567199707, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 1, \"draws\": 137, \"mu_intercept_per_group\": -8.468480110168457, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 1, \"draws\": 138, \"mu_intercept_per_group\": -8.330525398254395, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 1, \"draws\": 139, \"mu_intercept_per_group\": -7.763249397277832, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 1, \"draws\": 140, \"mu_intercept_per_group\": -9.23439884185791, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 1, \"draws\": 141, \"mu_intercept_per_group\": -10.352523803710938, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 1, \"draws\": 142, \"mu_intercept_per_group\": -9.7440767288208, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 1, \"draws\": 143, \"mu_intercept_per_group\": -6.493594646453857, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 1, \"draws\": 144, \"mu_intercept_per_group\": -5.668495178222656, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 1, \"draws\": 145, \"mu_intercept_per_group\": -6.536485195159912, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 1, \"draws\": 146, \"mu_intercept_per_group\": -5.962561130523682, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 1, \"draws\": 147, \"mu_intercept_per_group\": -5.989358425140381, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 1, \"draws\": 148, \"mu_intercept_per_group\": -8.179424285888672, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 1, \"draws\": 149, \"mu_intercept_per_group\": -9.224543571472168, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 1, \"draws\": 150, \"mu_intercept_per_group\": -9.734447479248047, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 1, \"draws\": 151, \"mu_intercept_per_group\": -10.175919532775879, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 1, \"draws\": 152, \"mu_intercept_per_group\": -7.314866542816162, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 1, \"draws\": 153, \"mu_intercept_per_group\": -6.186788082122803, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 1, \"draws\": 154, \"mu_intercept_per_group\": -6.772833824157715, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 1, \"draws\": 155, \"mu_intercept_per_group\": -6.679537773132324, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 1, \"draws\": 156, \"mu_intercept_per_group\": -7.271623134613037, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 1, \"draws\": 157, \"mu_intercept_per_group\": -7.01442813873291, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 1, \"draws\": 158, \"mu_intercept_per_group\": -8.877090454101562, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 1, \"draws\": 159, \"mu_intercept_per_group\": -8.152281761169434, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 1, \"draws\": 160, \"mu_intercept_per_group\": -15.871238708496094, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 1, \"draws\": 161, \"mu_intercept_per_group\": -14.757542610168457, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 1, \"draws\": 162, \"mu_intercept_per_group\": -17.056076049804688, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 1, \"draws\": 163, \"mu_intercept_per_group\": -15.685678482055664, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 1, \"draws\": 164, \"mu_intercept_per_group\": -14.16133975982666, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 1, \"draws\": 165, \"mu_intercept_per_group\": -11.59614372253418, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 1, \"draws\": 166, \"mu_intercept_per_group\": -19.791913986206055, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 1, \"draws\": 167, \"mu_intercept_per_group\": -12.628913879394531, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 1, \"draws\": 168, \"mu_intercept_per_group\": -15.65161418914795, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 1, \"draws\": 169, \"mu_intercept_per_group\": -14.883509635925293, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 1, \"draws\": 170, \"mu_intercept_per_group\": -14.066912651062012, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 1, \"draws\": 171, \"mu_intercept_per_group\": -15.01733684539795, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 1, \"draws\": 172, \"mu_intercept_per_group\": -15.25434684753418, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 1, \"draws\": 173, \"mu_intercept_per_group\": -15.52501392364502, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 1, \"draws\": 174, \"mu_intercept_per_group\": -15.031102180480957, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 1, \"draws\": 175, \"mu_intercept_per_group\": -15.354179382324219, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 1, \"draws\": 176, \"mu_intercept_per_group\": -15.391670227050781, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 1, \"draws\": 177, \"mu_intercept_per_group\": -14.733786582946777, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 1, \"draws\": 178, \"mu_intercept_per_group\": -16.239402770996094, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 1, \"draws\": 179, \"mu_intercept_per_group\": -7.869515419006348, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 1, \"draws\": 180, \"mu_intercept_per_group\": -6.1625285148620605, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 1, \"draws\": 181, \"mu_intercept_per_group\": -6.961767673492432, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 1, \"draws\": 182, \"mu_intercept_per_group\": -8.26362419128418, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 1, \"draws\": 183, \"mu_intercept_per_group\": -8.425446510314941, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 1, \"draws\": 184, \"mu_intercept_per_group\": -8.244565963745117, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 1, \"draws\": 185, \"mu_intercept_per_group\": -8.431330680847168, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 1, \"draws\": 186, \"mu_intercept_per_group\": -8.356810569763184, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 1, \"draws\": 187, \"mu_intercept_per_group\": -8.35568904876709, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 1, \"draws\": 188, \"mu_intercept_per_group\": -8.324518203735352, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 1, \"draws\": 189, \"mu_intercept_per_group\": -7.427779674530029, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 1, \"draws\": 190, \"mu_intercept_per_group\": -11.001151084899902, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 1, \"draws\": 191, \"mu_intercept_per_group\": -10.739099502563477, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 1, \"draws\": 192, \"mu_intercept_per_group\": -11.851920127868652, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 1, \"draws\": 193, \"mu_intercept_per_group\": -8.638216972351074, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 1, \"draws\": 194, \"mu_intercept_per_group\": -7.424707889556885, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 1, \"draws\": 195, \"mu_intercept_per_group\": -7.502957820892334, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 1, \"draws\": 196, \"mu_intercept_per_group\": -7.972844123840332, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 1, \"draws\": 197, \"mu_intercept_per_group\": -8.299049377441406, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 1, \"draws\": 198, \"mu_intercept_per_group\": -7.995639801025391, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 1, \"draws\": 199, \"mu_intercept_per_group\": -10.174504280090332, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 1, \"draws\": 200, \"mu_intercept_per_group\": -8.856024742126465, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 1, \"draws\": 201, \"mu_intercept_per_group\": -8.558749198913574, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 1, \"draws\": 202, \"mu_intercept_per_group\": -8.252449989318848, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 1, \"draws\": 203, \"mu_intercept_per_group\": -7.966894626617432, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 1, \"draws\": 204, \"mu_intercept_per_group\": -7.745606899261475, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 1, \"draws\": 205, \"mu_intercept_per_group\": -8.220741271972656, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 1, \"draws\": 206, \"mu_intercept_per_group\": -10.056746482849121, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 1, \"draws\": 207, \"mu_intercept_per_group\": -9.162074089050293, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 1, \"draws\": 208, \"mu_intercept_per_group\": -9.309950828552246, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 1, \"draws\": 209, \"mu_intercept_per_group\": -9.200614929199219, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 1, \"draws\": 210, \"mu_intercept_per_group\": -8.04164981842041, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 1, \"draws\": 211, \"mu_intercept_per_group\": -7.989147186279297, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 1, \"draws\": 212, \"mu_intercept_per_group\": -8.158720016479492, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 1, \"draws\": 213, \"mu_intercept_per_group\": -6.167340278625488, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 1, \"draws\": 214, \"mu_intercept_per_group\": -6.509913921356201, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 1, \"draws\": 215, \"mu_intercept_per_group\": -5.995239734649658, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 1, \"draws\": 216, \"mu_intercept_per_group\": -5.821988582611084, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 1, \"draws\": 217, \"mu_intercept_per_group\": -7.00992488861084, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 1, \"draws\": 218, \"mu_intercept_per_group\": -5.858956813812256, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 1, \"draws\": 219, \"mu_intercept_per_group\": -6.020576477050781, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 1, \"draws\": 220, \"mu_intercept_per_group\": -7.388912200927734, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 1, \"draws\": 221, \"mu_intercept_per_group\": -7.001800060272217, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 1, \"draws\": 222, \"mu_intercept_per_group\": -7.297293663024902, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 1, \"draws\": 223, \"mu_intercept_per_group\": -6.904263973236084, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 1, \"draws\": 224, \"mu_intercept_per_group\": -6.767678260803223, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 1, \"draws\": 225, \"mu_intercept_per_group\": -6.345089435577393, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 1, \"draws\": 226, \"mu_intercept_per_group\": -6.655992031097412, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 1, \"draws\": 227, \"mu_intercept_per_group\": -7.338032245635986, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 1, \"draws\": 228, \"mu_intercept_per_group\": -5.748055458068848, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 1, \"draws\": 229, \"mu_intercept_per_group\": -6.153923511505127, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 1, \"draws\": 230, \"mu_intercept_per_group\": -6.204908847808838, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 1, \"draws\": 231, \"mu_intercept_per_group\": -5.740651607513428, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 1, \"draws\": 232, \"mu_intercept_per_group\": -7.072974681854248, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 1, \"draws\": 233, \"mu_intercept_per_group\": -6.769132137298584, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 1, \"draws\": 234, \"mu_intercept_per_group\": -6.7029571533203125, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 1, \"draws\": 235, \"mu_intercept_per_group\": -7.297674179077148, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 1, \"draws\": 236, \"mu_intercept_per_group\": -5.420949935913086, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 1, \"draws\": 237, \"mu_intercept_per_group\": -5.996258735656738, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 1, \"draws\": 238, \"mu_intercept_per_group\": -6.040907859802246, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 1, \"draws\": 239, \"mu_intercept_per_group\": -6.022488594055176, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 1, \"draws\": 240, \"mu_intercept_per_group\": -6.190249443054199, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 1, \"draws\": 241, \"mu_intercept_per_group\": -5.972683906555176, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 1, \"draws\": 242, \"mu_intercept_per_group\": -6.332711696624756, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 1, \"draws\": 243, \"mu_intercept_per_group\": -6.481632709503174, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 1, \"draws\": 244, \"mu_intercept_per_group\": -9.382779121398926, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 1, \"draws\": 245, \"mu_intercept_per_group\": -8.370268821716309, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 1, \"draws\": 246, \"mu_intercept_per_group\": -8.605881690979004, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 1, \"draws\": 247, \"mu_intercept_per_group\": -7.688397407531738, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 1, \"draws\": 248, \"mu_intercept_per_group\": -8.153436660766602, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 1, \"draws\": 249, \"mu_intercept_per_group\": -6.076013565063477, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 1, \"draws\": 250, \"mu_intercept_per_group\": -6.282687187194824, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 1, \"draws\": 251, \"mu_intercept_per_group\": -7.190821170806885, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 1, \"draws\": 252, \"mu_intercept_per_group\": -6.822272777557373, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 1, \"draws\": 253, \"mu_intercept_per_group\": -6.849215984344482, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 1, \"draws\": 254, \"mu_intercept_per_group\": -7.452500820159912, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 1, \"draws\": 255, \"mu_intercept_per_group\": -6.93101692199707, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 1, \"draws\": 256, \"mu_intercept_per_group\": -8.192855834960938, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 1, \"draws\": 257, \"mu_intercept_per_group\": -8.188567161560059, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 1, \"draws\": 258, \"mu_intercept_per_group\": -7.691595554351807, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 1, \"draws\": 259, \"mu_intercept_per_group\": -7.546297550201416, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 1, \"draws\": 260, \"mu_intercept_per_group\": -8.439072608947754, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 1, \"draws\": 261, \"mu_intercept_per_group\": -6.498575210571289, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 1, \"draws\": 262, \"mu_intercept_per_group\": -6.522630214691162, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 1, \"draws\": 263, \"mu_intercept_per_group\": -7.221312522888184, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 1, \"draws\": 264, \"mu_intercept_per_group\": -6.64341402053833, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 1, \"draws\": 265, \"mu_intercept_per_group\": -7.810487747192383, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 1, \"draws\": 266, \"mu_intercept_per_group\": -4.836653709411621, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 1, \"draws\": 267, \"mu_intercept_per_group\": -5.4737114906311035, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 1, \"draws\": 268, \"mu_intercept_per_group\": -4.680009841918945, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 1, \"draws\": 269, \"mu_intercept_per_group\": -14.71117877960205, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 1, \"draws\": 270, \"mu_intercept_per_group\": -13.231066703796387, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 1, \"draws\": 271, \"mu_intercept_per_group\": -12.881993293762207, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 1, \"draws\": 272, \"mu_intercept_per_group\": -10.80652141571045, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 1, \"draws\": 273, \"mu_intercept_per_group\": -11.428923606872559, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 1, \"draws\": 274, \"mu_intercept_per_group\": -13.088447570800781, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 1, \"draws\": 275, \"mu_intercept_per_group\": -12.403549194335938, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 1, \"draws\": 276, \"mu_intercept_per_group\": -12.388936042785645, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 1, \"draws\": 277, \"mu_intercept_per_group\": -11.835264205932617, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 1, \"draws\": 278, \"mu_intercept_per_group\": -11.763348579406738, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 1, \"draws\": 279, \"mu_intercept_per_group\": -11.139649391174316, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 1, \"draws\": 280, \"mu_intercept_per_group\": -9.626166343688965, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 1, \"draws\": 281, \"mu_intercept_per_group\": -12.119199752807617, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 1, \"draws\": 282, \"mu_intercept_per_group\": -12.37428092956543, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 1, \"draws\": 283, \"mu_intercept_per_group\": -11.929868698120117, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 1, \"draws\": 284, \"mu_intercept_per_group\": -12.059250831604004, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 1, \"draws\": 285, \"mu_intercept_per_group\": -11.419142723083496, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 1, \"draws\": 286, \"mu_intercept_per_group\": -12.620949745178223, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 1, \"draws\": 287, \"mu_intercept_per_group\": -13.116007804870605, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 1, \"draws\": 288, \"mu_intercept_per_group\": -13.077399253845215, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 1, \"draws\": 289, \"mu_intercept_per_group\": -13.461737632751465, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 1, \"draws\": 290, \"mu_intercept_per_group\": -11.684602737426758, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 1, \"draws\": 291, \"mu_intercept_per_group\": -12.882208824157715, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 1, \"draws\": 292, \"mu_intercept_per_group\": -12.14332103729248, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 1, \"draws\": 293, \"mu_intercept_per_group\": -10.666753768920898, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 1, \"draws\": 294, \"mu_intercept_per_group\": -9.616438865661621, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 1, \"draws\": 295, \"mu_intercept_per_group\": -8.78840160369873, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 1, \"draws\": 296, \"mu_intercept_per_group\": -7.9378533363342285, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 1, \"draws\": 297, \"mu_intercept_per_group\": -6.78215217590332, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 1, \"draws\": 298, \"mu_intercept_per_group\": -7.98124361038208, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 1, \"draws\": 299, \"mu_intercept_per_group\": -7.439107418060303, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 1, \"draws\": 300, \"mu_intercept_per_group\": -8.732728958129883, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 1, \"draws\": 301, \"mu_intercept_per_group\": -8.265485763549805, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 1, \"draws\": 302, \"mu_intercept_per_group\": -8.473344802856445, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 1, \"draws\": 303, \"mu_intercept_per_group\": -9.175088882446289, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 1, \"draws\": 304, \"mu_intercept_per_group\": -7.924549579620361, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 1, \"draws\": 305, \"mu_intercept_per_group\": -7.85422420501709, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 1, \"draws\": 306, \"mu_intercept_per_group\": -8.313323020935059, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 1, \"draws\": 307, \"mu_intercept_per_group\": -7.848830699920654, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 1, \"draws\": 308, \"mu_intercept_per_group\": -6.831625461578369, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 1, \"draws\": 309, \"mu_intercept_per_group\": -10.96494197845459, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 1, \"draws\": 310, \"mu_intercept_per_group\": -10.748037338256836, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 1, \"draws\": 311, \"mu_intercept_per_group\": -10.895454406738281, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 1, \"draws\": 312, \"mu_intercept_per_group\": -10.013161659240723, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 1, \"draws\": 313, \"mu_intercept_per_group\": -11.744898796081543, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 1, \"draws\": 314, \"mu_intercept_per_group\": -8.813811302185059, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 1, \"draws\": 315, \"mu_intercept_per_group\": -8.972053527832031, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 1, \"draws\": 316, \"mu_intercept_per_group\": -10.550374984741211, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 1, \"draws\": 317, \"mu_intercept_per_group\": -11.876424789428711, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 1, \"draws\": 318, \"mu_intercept_per_group\": -10.929095268249512, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 1, \"draws\": 319, \"mu_intercept_per_group\": -12.96820068359375, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 1, \"draws\": 320, \"mu_intercept_per_group\": -3.8297979831695557, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 1, \"draws\": 321, \"mu_intercept_per_group\": -4.09927225112915, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 1, \"draws\": 322, \"mu_intercept_per_group\": -4.590153217315674, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 1, \"draws\": 323, \"mu_intercept_per_group\": -4.119028091430664, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 1, \"draws\": 324, \"mu_intercept_per_group\": -6.685900688171387, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 1, \"draws\": 325, \"mu_intercept_per_group\": -6.5281524658203125, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 1, \"draws\": 326, \"mu_intercept_per_group\": -6.612931251525879, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 1, \"draws\": 327, \"mu_intercept_per_group\": -6.643036842346191, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 1, \"draws\": 328, \"mu_intercept_per_group\": -7.364760875701904, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 1, \"draws\": 329, \"mu_intercept_per_group\": -7.121610164642334, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 1, \"draws\": 330, \"mu_intercept_per_group\": -7.828948497772217, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 1, \"draws\": 331, \"mu_intercept_per_group\": -8.35095500946045, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 1, \"draws\": 332, \"mu_intercept_per_group\": -8.238360404968262, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 1, \"draws\": 333, \"mu_intercept_per_group\": -8.080526351928711, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 1, \"draws\": 334, \"mu_intercept_per_group\": -7.574469566345215, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 1, \"draws\": 335, \"mu_intercept_per_group\": -7.984649181365967, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 1, \"draws\": 336, \"mu_intercept_per_group\": -7.666357040405273, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 1, \"draws\": 337, \"mu_intercept_per_group\": -7.885285377502441, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 1, \"draws\": 338, \"mu_intercept_per_group\": -13.649304389953613, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 1, \"draws\": 339, \"mu_intercept_per_group\": -11.747048377990723, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 1, \"draws\": 340, \"mu_intercept_per_group\": -12.455309867858887, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 1, \"draws\": 341, \"mu_intercept_per_group\": -11.088165283203125, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 1, \"draws\": 342, \"mu_intercept_per_group\": -10.226978302001953, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 1, \"draws\": 343, \"mu_intercept_per_group\": -10.333722114562988, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 1, \"draws\": 344, \"mu_intercept_per_group\": -12.658970832824707, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 1, \"draws\": 345, \"mu_intercept_per_group\": -17.99748420715332, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 1, \"draws\": 346, \"mu_intercept_per_group\": -11.507952690124512, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 1, \"draws\": 347, \"mu_intercept_per_group\": -8.743481636047363, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 1, \"draws\": 348, \"mu_intercept_per_group\": -8.540989875793457, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 1, \"draws\": 349, \"mu_intercept_per_group\": -8.308331489562988, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 1, \"draws\": 350, \"mu_intercept_per_group\": -10.409808158874512, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 1, \"draws\": 351, \"mu_intercept_per_group\": -10.620538711547852, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 1, \"draws\": 352, \"mu_intercept_per_group\": -11.50767707824707, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 1, \"draws\": 353, \"mu_intercept_per_group\": -13.277064323425293, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 1, \"draws\": 354, \"mu_intercept_per_group\": -6.9937214851379395, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 1, \"draws\": 355, \"mu_intercept_per_group\": -7.777700424194336, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 1, \"draws\": 356, \"mu_intercept_per_group\": -7.282313823699951, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 1, \"draws\": 357, \"mu_intercept_per_group\": -7.079543590545654, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 1, \"draws\": 358, \"mu_intercept_per_group\": -7.220000743865967, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 1, \"draws\": 359, \"mu_intercept_per_group\": -7.683372497558594, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 1, \"draws\": 360, \"mu_intercept_per_group\": -7.039926528930664, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 1, \"draws\": 361, \"mu_intercept_per_group\": -7.488051891326904, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 1, \"draws\": 362, \"mu_intercept_per_group\": -7.797805309295654, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 1, \"draws\": 363, \"mu_intercept_per_group\": -7.752614498138428, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 1, \"draws\": 364, \"mu_intercept_per_group\": -9.179603576660156, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 1, \"draws\": 365, \"mu_intercept_per_group\": -9.563591957092285, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 1, \"draws\": 366, \"mu_intercept_per_group\": -9.184999465942383, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 1, \"draws\": 367, \"mu_intercept_per_group\": -8.46463680267334, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 1, \"draws\": 368, \"mu_intercept_per_group\": -10.848094940185547, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 1, \"draws\": 369, \"mu_intercept_per_group\": -5.596824645996094, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 1, \"draws\": 370, \"mu_intercept_per_group\": -5.436007022857666, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 1, \"draws\": 371, \"mu_intercept_per_group\": -5.630349159240723, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 1, \"draws\": 372, \"mu_intercept_per_group\": -6.366314888000488, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 1, \"draws\": 373, \"mu_intercept_per_group\": -6.2108964920043945, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 1, \"draws\": 374, \"mu_intercept_per_group\": -6.523582935333252, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 1, \"draws\": 375, \"mu_intercept_per_group\": -7.5760955810546875, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 1, \"draws\": 376, \"mu_intercept_per_group\": -9.887060165405273, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 1, \"draws\": 377, \"mu_intercept_per_group\": -6.501410484313965, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 1, \"draws\": 378, \"mu_intercept_per_group\": -6.363732814788818, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 1, \"draws\": 379, \"mu_intercept_per_group\": -6.268908977508545, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 1, \"draws\": 380, \"mu_intercept_per_group\": -6.240509986877441, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 1, \"draws\": 381, \"mu_intercept_per_group\": -8.031135559082031, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 1, \"draws\": 382, \"mu_intercept_per_group\": -6.380482196807861, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 1, \"draws\": 383, \"mu_intercept_per_group\": -6.168534755706787, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 1, \"draws\": 384, \"mu_intercept_per_group\": -11.134572982788086, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 1, \"draws\": 385, \"mu_intercept_per_group\": -10.617363929748535, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 1, \"draws\": 386, \"mu_intercept_per_group\": -10.207976341247559, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 1, \"draws\": 387, \"mu_intercept_per_group\": -10.33414077758789, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 1, \"draws\": 388, \"mu_intercept_per_group\": -10.301100730895996, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 1, \"draws\": 389, \"mu_intercept_per_group\": -10.34332275390625, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 1, \"draws\": 390, \"mu_intercept_per_group\": -11.227458953857422, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 1, \"draws\": 391, \"mu_intercept_per_group\": -10.35970401763916, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 1, \"draws\": 392, \"mu_intercept_per_group\": -10.311380386352539, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 1, \"draws\": 393, \"mu_intercept_per_group\": -9.21191120147705, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 1, \"draws\": 394, \"mu_intercept_per_group\": -9.802841186523438, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 1, \"draws\": 395, \"mu_intercept_per_group\": -9.167405128479004, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 1, \"draws\": 396, \"mu_intercept_per_group\": -9.907194137573242, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 1, \"draws\": 397, \"mu_intercept_per_group\": -9.707542419433594, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 1, \"draws\": 398, \"mu_intercept_per_group\": -10.583898544311523, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 1, \"draws\": 399, \"mu_intercept_per_group\": -8.141343116760254, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 1, \"draws\": 400, \"mu_intercept_per_group\": -8.365325927734375, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 1, \"draws\": 401, \"mu_intercept_per_group\": -7.992537498474121, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 1, \"draws\": 402, \"mu_intercept_per_group\": -8.287038803100586, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 1, \"draws\": 403, \"mu_intercept_per_group\": -7.695856094360352, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 1, \"draws\": 404, \"mu_intercept_per_group\": -10.52297592163086, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 1, \"draws\": 405, \"mu_intercept_per_group\": -9.778302192687988, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 1, \"draws\": 406, \"mu_intercept_per_group\": -10.227386474609375, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 1, \"draws\": 407, \"mu_intercept_per_group\": -9.15649127960205, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 1, \"draws\": 408, \"mu_intercept_per_group\": -8.477409362792969, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 1, \"draws\": 409, \"mu_intercept_per_group\": -9.543404579162598, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 1, \"draws\": 410, \"mu_intercept_per_group\": -9.375753402709961, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 1, \"draws\": 411, \"mu_intercept_per_group\": -7.4569621086120605, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 1, \"draws\": 412, \"mu_intercept_per_group\": -8.041787147521973, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 1, \"draws\": 413, \"mu_intercept_per_group\": -9.744007110595703, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 1, \"draws\": 414, \"mu_intercept_per_group\": -10.0101318359375, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 1, \"draws\": 415, \"mu_intercept_per_group\": -10.217740058898926, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 1, \"draws\": 416, \"mu_intercept_per_group\": -9.67767333984375, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 1, \"draws\": 417, \"mu_intercept_per_group\": -9.037591934204102, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 1, \"draws\": 418, \"mu_intercept_per_group\": -9.875791549682617, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 1, \"draws\": 419, \"mu_intercept_per_group\": -8.751954078674316, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 1, \"draws\": 420, \"mu_intercept_per_group\": -9.460350036621094, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 1, \"draws\": 421, \"mu_intercept_per_group\": -9.78790283203125, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 1, \"draws\": 422, \"mu_intercept_per_group\": -10.130443572998047, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 1, \"draws\": 423, \"mu_intercept_per_group\": -9.183836936950684, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 1, \"draws\": 424, \"mu_intercept_per_group\": -10.277303695678711, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 1, \"draws\": 425, \"mu_intercept_per_group\": -9.653280258178711, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 1, \"draws\": 426, \"mu_intercept_per_group\": -11.628171920776367, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 1, \"draws\": 427, \"mu_intercept_per_group\": -11.7589750289917, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 1, \"draws\": 428, \"mu_intercept_per_group\": -11.612820625305176, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 1, \"draws\": 429, \"mu_intercept_per_group\": -12.499763488769531, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 1, \"draws\": 430, \"mu_intercept_per_group\": -11.79002571105957, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 1, \"draws\": 431, \"mu_intercept_per_group\": -10.061283111572266, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 1, \"draws\": 432, \"mu_intercept_per_group\": -11.270356178283691, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 1, \"draws\": 433, \"mu_intercept_per_group\": -11.914552688598633, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 1, \"draws\": 434, \"mu_intercept_per_group\": -10.077983856201172, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 1, \"draws\": 435, \"mu_intercept_per_group\": -10.068305969238281, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 1, \"draws\": 436, \"mu_intercept_per_group\": -11.516246795654297, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 1, \"draws\": 437, \"mu_intercept_per_group\": -11.973291397094727, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 1, \"draws\": 438, \"mu_intercept_per_group\": -11.533452987670898, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 1, \"draws\": 439, \"mu_intercept_per_group\": -11.37985610961914, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 1, \"draws\": 440, \"mu_intercept_per_group\": -11.270061492919922, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 1, \"draws\": 441, \"mu_intercept_per_group\": -11.925480842590332, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 1, \"draws\": 442, \"mu_intercept_per_group\": -12.290231704711914, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 1, \"draws\": 443, \"mu_intercept_per_group\": -14.637188911437988, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 1, \"draws\": 444, \"mu_intercept_per_group\": -16.00838851928711, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 1, \"draws\": 445, \"mu_intercept_per_group\": -13.500164031982422, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 1, \"draws\": 446, \"mu_intercept_per_group\": -9.3949556350708, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 1, \"draws\": 447, \"mu_intercept_per_group\": -10.260808944702148, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 1, \"draws\": 448, \"mu_intercept_per_group\": -6.478891849517822, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 1, \"draws\": 449, \"mu_intercept_per_group\": -7.64636754989624, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 1, \"draws\": 450, \"mu_intercept_per_group\": -8.549432754516602, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 1, \"draws\": 451, \"mu_intercept_per_group\": -15.287691116333008, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 1, \"draws\": 452, \"mu_intercept_per_group\": -15.460411071777344, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 1, \"draws\": 453, \"mu_intercept_per_group\": -17.755287170410156, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 1, \"draws\": 454, \"mu_intercept_per_group\": -16.716646194458008, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 1, \"draws\": 455, \"mu_intercept_per_group\": -16.87953758239746, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 1, \"draws\": 456, \"mu_intercept_per_group\": -16.023426055908203, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 1, \"draws\": 457, \"mu_intercept_per_group\": -15.582951545715332, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 1, \"draws\": 458, \"mu_intercept_per_group\": -16.49396324157715, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 1, \"draws\": 459, \"mu_intercept_per_group\": -8.918719291687012, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 1, \"draws\": 460, \"mu_intercept_per_group\": -8.765458106994629, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 1, \"draws\": 461, \"mu_intercept_per_group\": -9.00108814239502, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 1, \"draws\": 462, \"mu_intercept_per_group\": -7.093249797821045, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 1, \"draws\": 463, \"mu_intercept_per_group\": -6.7425007820129395, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 1, \"draws\": 464, \"mu_intercept_per_group\": -7.852930545806885, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 1, \"draws\": 465, \"mu_intercept_per_group\": -7.743824005126953, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 1, \"draws\": 466, \"mu_intercept_per_group\": -7.695345401763916, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 1, \"draws\": 467, \"mu_intercept_per_group\": -7.991128921508789, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 1, \"draws\": 468, \"mu_intercept_per_group\": -8.206735610961914, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 1, \"draws\": 469, \"mu_intercept_per_group\": -8.624382019042969, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 1, \"draws\": 470, \"mu_intercept_per_group\": -8.596165657043457, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 1, \"draws\": 471, \"mu_intercept_per_group\": -8.990116119384766, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 1, \"draws\": 472, \"mu_intercept_per_group\": -9.033246994018555, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 1, \"draws\": 473, \"mu_intercept_per_group\": -12.233370780944824, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 1, \"draws\": 474, \"mu_intercept_per_group\": -13.357138633728027, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 1, \"draws\": 475, \"mu_intercept_per_group\": -12.939226150512695, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 1, \"draws\": 476, \"mu_intercept_per_group\": -13.312416076660156, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 1, \"draws\": 477, \"mu_intercept_per_group\": -12.572054862976074, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 1, \"draws\": 478, \"mu_intercept_per_group\": -13.724356651306152, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 1, \"draws\": 479, \"mu_intercept_per_group\": -13.320147514343262, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 1, \"draws\": 480, \"mu_intercept_per_group\": -10.426800727844238, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 1, \"draws\": 481, \"mu_intercept_per_group\": -10.903331756591797, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 1, \"draws\": 482, \"mu_intercept_per_group\": -9.496400833129883, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 1, \"draws\": 483, \"mu_intercept_per_group\": -10.395065307617188, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 1, \"draws\": 484, \"mu_intercept_per_group\": -9.169426918029785, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 1, \"draws\": 485, \"mu_intercept_per_group\": -8.991691589355469, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 1, \"draws\": 486, \"mu_intercept_per_group\": -8.417693138122559, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 1, \"draws\": 487, \"mu_intercept_per_group\": -8.901578903198242, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 1, \"draws\": 488, \"mu_intercept_per_group\": -7.588583469390869, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 1, \"draws\": 489, \"mu_intercept_per_group\": -8.831604957580566, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 1, \"draws\": 490, \"mu_intercept_per_group\": -7.686142444610596, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 1, \"draws\": 491, \"mu_intercept_per_group\": -7.944189548492432, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 1, \"draws\": 492, \"mu_intercept_per_group\": -8.483185768127441, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 1, \"draws\": 493, \"mu_intercept_per_group\": -7.567653656005859, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 1, \"draws\": 494, \"mu_intercept_per_group\": -11.330217361450195, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 1, \"draws\": 495, \"mu_intercept_per_group\": -11.603011131286621, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 1, \"draws\": 496, \"mu_intercept_per_group\": -10.051122665405273, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 1, \"draws\": 497, \"mu_intercept_per_group\": -10.252095222473145, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 1, \"draws\": 498, \"mu_intercept_per_group\": -10.2603759765625, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 1, \"draws\": 499, \"mu_intercept_per_group\": -9.28430461883545, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 1, \"draws\": 500, \"mu_intercept_per_group\": -10.427631378173828, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 1, \"draws\": 501, \"mu_intercept_per_group\": -11.725006103515625, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 1, \"draws\": 502, \"mu_intercept_per_group\": -10.91124439239502, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 1, \"draws\": 503, \"mu_intercept_per_group\": -10.752559661865234, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 1, \"draws\": 504, \"mu_intercept_per_group\": -11.004341125488281, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 1, \"draws\": 505, \"mu_intercept_per_group\": -10.303412437438965, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 1, \"draws\": 506, \"mu_intercept_per_group\": -9.126507759094238, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 1, \"draws\": 507, \"mu_intercept_per_group\": -9.320602416992188, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 1, \"draws\": 508, \"mu_intercept_per_group\": -12.058330535888672, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 1, \"draws\": 509, \"mu_intercept_per_group\": -13.501537322998047, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 1, \"draws\": 510, \"mu_intercept_per_group\": -10.594620704650879, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 1, \"draws\": 511, \"mu_intercept_per_group\": -14.82206916809082, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 1, \"draws\": 512, \"mu_intercept_per_group\": -14.859207153320312, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 1, \"draws\": 513, \"mu_intercept_per_group\": -12.444636344909668, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 1, \"draws\": 514, \"mu_intercept_per_group\": -11.417515754699707, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 1, \"draws\": 515, \"mu_intercept_per_group\": -11.351978302001953, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 1, \"draws\": 516, \"mu_intercept_per_group\": -10.844133377075195, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 1, \"draws\": 517, \"mu_intercept_per_group\": -10.527763366699219, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 1, \"draws\": 518, \"mu_intercept_per_group\": -10.834626197814941, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 1, \"draws\": 519, \"mu_intercept_per_group\": -12.19316291809082, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 1, \"draws\": 520, \"mu_intercept_per_group\": -9.068493843078613, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 1, \"draws\": 521, \"mu_intercept_per_group\": -9.031841278076172, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 1, \"draws\": 522, \"mu_intercept_per_group\": -8.890425682067871, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 1, \"draws\": 523, \"mu_intercept_per_group\": -8.049285888671875, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 1, \"draws\": 524, \"mu_intercept_per_group\": -6.234132766723633, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 1, \"draws\": 525, \"mu_intercept_per_group\": -6.019498348236084, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 1, \"draws\": 526, \"mu_intercept_per_group\": -6.042847633361816, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 1, \"draws\": 527, \"mu_intercept_per_group\": -9.737372398376465, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 1, \"draws\": 528, \"mu_intercept_per_group\": -8.987885475158691, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 1, \"draws\": 529, \"mu_intercept_per_group\": -10.00374698638916, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 1, \"draws\": 530, \"mu_intercept_per_group\": -8.215415954589844, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 1, \"draws\": 531, \"mu_intercept_per_group\": -8.45422649383545, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 1, \"draws\": 532, \"mu_intercept_per_group\": -8.39857006072998, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 1, \"draws\": 533, \"mu_intercept_per_group\": -9.335271835327148, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 1, \"draws\": 534, \"mu_intercept_per_group\": -9.188724517822266, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 1, \"draws\": 535, \"mu_intercept_per_group\": -8.8259916305542, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 1, \"draws\": 536, \"mu_intercept_per_group\": -9.159540176391602, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 1, \"draws\": 537, \"mu_intercept_per_group\": -5.7754950523376465, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 1, \"draws\": 538, \"mu_intercept_per_group\": -6.398288249969482, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 1, \"draws\": 539, \"mu_intercept_per_group\": -6.005887031555176, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 1, \"draws\": 540, \"mu_intercept_per_group\": -7.583805561065674, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 1, \"draws\": 541, \"mu_intercept_per_group\": -7.6820197105407715, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 1, \"draws\": 542, \"mu_intercept_per_group\": -7.90962553024292, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 1, \"draws\": 543, \"mu_intercept_per_group\": -7.95316743850708, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 1, \"draws\": 544, \"mu_intercept_per_group\": -11.122175216674805, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 1, \"draws\": 545, \"mu_intercept_per_group\": -10.834539413452148, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 1, \"draws\": 546, \"mu_intercept_per_group\": -8.287318229675293, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 1, \"draws\": 547, \"mu_intercept_per_group\": -10.842634201049805, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 1, \"draws\": 548, \"mu_intercept_per_group\": -11.078690528869629, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 1, \"draws\": 549, \"mu_intercept_per_group\": -11.045512199401855, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 1, \"draws\": 550, \"mu_intercept_per_group\": -11.285313606262207, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 1, \"draws\": 551, \"mu_intercept_per_group\": -11.067142486572266, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 1, \"draws\": 552, \"mu_intercept_per_group\": -10.333518028259277, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 1, \"draws\": 553, \"mu_intercept_per_group\": -10.578166961669922, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 1, \"draws\": 554, \"mu_intercept_per_group\": -10.715497016906738, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 1, \"draws\": 555, \"mu_intercept_per_group\": -11.639104843139648, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 1, \"draws\": 556, \"mu_intercept_per_group\": -12.060778617858887, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 1, \"draws\": 557, \"mu_intercept_per_group\": -11.169048309326172, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 1, \"draws\": 558, \"mu_intercept_per_group\": -12.006462097167969, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 1, \"draws\": 559, \"mu_intercept_per_group\": -12.334375381469727, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 1, \"draws\": 560, \"mu_intercept_per_group\": -9.823528289794922, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 1, \"draws\": 561, \"mu_intercept_per_group\": -9.184955596923828, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 1, \"draws\": 562, \"mu_intercept_per_group\": -11.07061767578125, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 1, \"draws\": 563, \"mu_intercept_per_group\": -10.850611686706543, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 1, \"draws\": 564, \"mu_intercept_per_group\": -7.421445846557617, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 1, \"draws\": 565, \"mu_intercept_per_group\": -9.054793357849121, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 1, \"draws\": 566, \"mu_intercept_per_group\": -8.856281280517578, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 1, \"draws\": 567, \"mu_intercept_per_group\": -6.67641544342041, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 1, \"draws\": 568, \"mu_intercept_per_group\": -8.808252334594727, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 1, \"draws\": 569, \"mu_intercept_per_group\": -6.5838541984558105, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 1, \"draws\": 570, \"mu_intercept_per_group\": -7.823910236358643, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 1, \"draws\": 571, \"mu_intercept_per_group\": -7.905125141143799, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 1, \"draws\": 572, \"mu_intercept_per_group\": -8.072981834411621, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 1, \"draws\": 573, \"mu_intercept_per_group\": -9.48575210571289, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 1, \"draws\": 574, \"mu_intercept_per_group\": -10.347667694091797, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 1, \"draws\": 575, \"mu_intercept_per_group\": -11.662759780883789, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 1, \"draws\": 576, \"mu_intercept_per_group\": -12.511637687683105, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 1, \"draws\": 577, \"mu_intercept_per_group\": -14.626730918884277, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 1, \"draws\": 578, \"mu_intercept_per_group\": -14.772651672363281, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 1, \"draws\": 579, \"mu_intercept_per_group\": -16.251832962036133, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 1, \"draws\": 580, \"mu_intercept_per_group\": -14.267406463623047, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 1, \"draws\": 581, \"mu_intercept_per_group\": -11.99155330657959, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 1, \"draws\": 582, \"mu_intercept_per_group\": -12.080535888671875, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 1, \"draws\": 583, \"mu_intercept_per_group\": -12.18567180633545, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 1, \"draws\": 584, \"mu_intercept_per_group\": -11.547022819519043, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 1, \"draws\": 585, \"mu_intercept_per_group\": -13.317028045654297, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 1, \"draws\": 586, \"mu_intercept_per_group\": -14.921419143676758, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 1, \"draws\": 587, \"mu_intercept_per_group\": -12.853697776794434, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 1, \"draws\": 588, \"mu_intercept_per_group\": -15.958690643310547, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 1, \"draws\": 589, \"mu_intercept_per_group\": -14.362780570983887, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 1, \"draws\": 590, \"mu_intercept_per_group\": -13.528738021850586, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 1, \"draws\": 591, \"mu_intercept_per_group\": -13.429788589477539, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 1, \"draws\": 592, \"mu_intercept_per_group\": -15.014694213867188, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 1, \"draws\": 593, \"mu_intercept_per_group\": -16.685443878173828, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 1, \"draws\": 594, \"mu_intercept_per_group\": -14.087014198303223, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 1, \"draws\": 595, \"mu_intercept_per_group\": -15.159664154052734, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 1, \"draws\": 596, \"mu_intercept_per_group\": -15.669918060302734, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 1, \"draws\": 597, \"mu_intercept_per_group\": -15.266392707824707, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 1, \"draws\": 598, \"mu_intercept_per_group\": -16.454748153686523, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 1, \"draws\": 599, \"mu_intercept_per_group\": -15.451108932495117, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 1, \"draws\": 600, \"mu_intercept_per_group\": -15.872716903686523, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 1, \"draws\": 601, \"mu_intercept_per_group\": -16.1271915435791, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 1, \"draws\": 602, \"mu_intercept_per_group\": -16.20937156677246, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 1, \"draws\": 603, \"mu_intercept_per_group\": -15.113572120666504, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 1, \"draws\": 604, \"mu_intercept_per_group\": -16.363231658935547, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 1, \"draws\": 605, \"mu_intercept_per_group\": -14.758134841918945, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 1, \"draws\": 606, \"mu_intercept_per_group\": -16.919519424438477, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 1, \"draws\": 607, \"mu_intercept_per_group\": -13.18451976776123, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 1, \"draws\": 608, \"mu_intercept_per_group\": -8.584428787231445, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 1, \"draws\": 609, \"mu_intercept_per_group\": -8.354183197021484, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 1, \"draws\": 610, \"mu_intercept_per_group\": -7.897542953491211, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 1, \"draws\": 611, \"mu_intercept_per_group\": -9.818014144897461, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 1, \"draws\": 612, \"mu_intercept_per_group\": -7.913071632385254, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 1, \"draws\": 613, \"mu_intercept_per_group\": -8.472869873046875, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 1, \"draws\": 614, \"mu_intercept_per_group\": -7.50337028503418, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 1, \"draws\": 615, \"mu_intercept_per_group\": -9.066357612609863, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 1, \"draws\": 616, \"mu_intercept_per_group\": -8.53838062286377, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 1, \"draws\": 617, \"mu_intercept_per_group\": -8.886520385742188, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 1, \"draws\": 618, \"mu_intercept_per_group\": -15.011272430419922, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 1, \"draws\": 619, \"mu_intercept_per_group\": -14.354790687561035, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 1, \"draws\": 620, \"mu_intercept_per_group\": -14.180647850036621, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 1, \"draws\": 621, \"mu_intercept_per_group\": -13.39687442779541, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 1, \"draws\": 622, \"mu_intercept_per_group\": -12.890908241271973, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 1, \"draws\": 623, \"mu_intercept_per_group\": -14.394158363342285, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 1, \"draws\": 624, \"mu_intercept_per_group\": -15.718833923339844, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 1, \"draws\": 625, \"mu_intercept_per_group\": -13.214241981506348, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 1, \"draws\": 626, \"mu_intercept_per_group\": -14.723939895629883, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 1, \"draws\": 627, \"mu_intercept_per_group\": -12.98116683959961, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 1, \"draws\": 628, \"mu_intercept_per_group\": -14.370396614074707, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 1, \"draws\": 629, \"mu_intercept_per_group\": -7.884150505065918, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 1, \"draws\": 630, \"mu_intercept_per_group\": -7.222442150115967, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 1, \"draws\": 631, \"mu_intercept_per_group\": -7.809812068939209, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 1, \"draws\": 632, \"mu_intercept_per_group\": -8.511399269104004, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 1, \"draws\": 633, \"mu_intercept_per_group\": -8.575699806213379, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 1, \"draws\": 634, \"mu_intercept_per_group\": -10.221336364746094, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 1, \"draws\": 635, \"mu_intercept_per_group\": -9.742719650268555, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 1, \"draws\": 636, \"mu_intercept_per_group\": -9.158608436584473, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 1, \"draws\": 637, \"mu_intercept_per_group\": -7.647387981414795, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 1, \"draws\": 638, \"mu_intercept_per_group\": -7.455506801605225, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 1, \"draws\": 639, \"mu_intercept_per_group\": -8.01889705657959, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 2, \"draws\": 0, \"mu_intercept_per_group\": -7.468222141265869, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 2, \"draws\": 1, \"mu_intercept_per_group\": -7.893853664398193, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 2, \"draws\": 2, \"mu_intercept_per_group\": -8.244715690612793, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 2, \"draws\": 3, \"mu_intercept_per_group\": -8.665383338928223, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 2, \"draws\": 4, \"mu_intercept_per_group\": -9.01965045928955, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 2, \"draws\": 5, \"mu_intercept_per_group\": -8.95269775390625, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 2, \"draws\": 6, \"mu_intercept_per_group\": -8.338408470153809, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 2, \"draws\": 7, \"mu_intercept_per_group\": -8.311362266540527, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 2, \"draws\": 8, \"mu_intercept_per_group\": -7.172788619995117, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 2, \"draws\": 9, \"mu_intercept_per_group\": -7.95962381362915, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 2, \"draws\": 10, \"mu_intercept_per_group\": -8.07254695892334, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 2, \"draws\": 11, \"mu_intercept_per_group\": -7.204686164855957, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 2, \"draws\": 12, \"mu_intercept_per_group\": -11.447648048400879, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 2, \"draws\": 13, \"mu_intercept_per_group\": -12.228047370910645, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 2, \"draws\": 14, \"mu_intercept_per_group\": -11.317634582519531, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 2, \"draws\": 15, \"mu_intercept_per_group\": -10.870038986206055, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 2, \"draws\": 16, \"mu_intercept_per_group\": -12.098483085632324, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 2, \"draws\": 17, \"mu_intercept_per_group\": -11.743831634521484, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 2, \"draws\": 18, \"mu_intercept_per_group\": -12.055479049682617, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 2, \"draws\": 19, \"mu_intercept_per_group\": -11.665326118469238, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 2, \"draws\": 20, \"mu_intercept_per_group\": -10.452956199645996, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 2, \"draws\": 21, \"mu_intercept_per_group\": -9.865130424499512, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 2, \"draws\": 22, \"mu_intercept_per_group\": -11.855265617370605, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 2, \"draws\": 23, \"mu_intercept_per_group\": -11.364409446716309, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 2, \"draws\": 24, \"mu_intercept_per_group\": -11.996438026428223, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 2, \"draws\": 25, \"mu_intercept_per_group\": -12.385367393493652, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 2, \"draws\": 26, \"mu_intercept_per_group\": -10.407864570617676, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 2, \"draws\": 27, \"mu_intercept_per_group\": -12.110824584960938, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 2, \"draws\": 28, \"mu_intercept_per_group\": -12.876176834106445, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 2, \"draws\": 29, \"mu_intercept_per_group\": -15.70751953125, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 2, \"draws\": 30, \"mu_intercept_per_group\": -13.771004676818848, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 2, \"draws\": 31, \"mu_intercept_per_group\": -16.001636505126953, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 2, \"draws\": 32, \"mu_intercept_per_group\": -11.170762062072754, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 2, \"draws\": 33, \"mu_intercept_per_group\": -12.000483512878418, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 2, \"draws\": 34, \"mu_intercept_per_group\": -12.128211975097656, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 2, \"draws\": 35, \"mu_intercept_per_group\": -11.469437599182129, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 2, \"draws\": 36, \"mu_intercept_per_group\": -11.996685981750488, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 2, \"draws\": 37, \"mu_intercept_per_group\": -12.988693237304688, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 2, \"draws\": 38, \"mu_intercept_per_group\": -11.420990943908691, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 2, \"draws\": 39, \"mu_intercept_per_group\": -10.714858055114746, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 2, \"draws\": 40, \"mu_intercept_per_group\": -11.203015327453613, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 2, \"draws\": 41, \"mu_intercept_per_group\": -10.312018394470215, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 2, \"draws\": 42, \"mu_intercept_per_group\": -10.7760009765625, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 2, \"draws\": 43, \"mu_intercept_per_group\": -10.62553596496582, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 2, \"draws\": 44, \"mu_intercept_per_group\": -11.590021133422852, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 2, \"draws\": 45, \"mu_intercept_per_group\": -10.000452995300293, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 2, \"draws\": 46, \"mu_intercept_per_group\": -10.422992706298828, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 2, \"draws\": 47, \"mu_intercept_per_group\": -10.080204963684082, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 2, \"draws\": 48, \"mu_intercept_per_group\": -11.57633113861084, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 2, \"draws\": 49, \"mu_intercept_per_group\": -10.529803276062012, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 2, \"draws\": 50, \"mu_intercept_per_group\": -7.037881851196289, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 2, \"draws\": 51, \"mu_intercept_per_group\": -8.302251815795898, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 2, \"draws\": 52, \"mu_intercept_per_group\": -4.861050605773926, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 2, \"draws\": 53, \"mu_intercept_per_group\": -4.484891891479492, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 2, \"draws\": 54, \"mu_intercept_per_group\": -4.553126811981201, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 2, \"draws\": 55, \"mu_intercept_per_group\": -4.662881374359131, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 2, \"draws\": 56, \"mu_intercept_per_group\": -4.417755603790283, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 2, \"draws\": 57, \"mu_intercept_per_group\": -4.910811901092529, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 2, \"draws\": 58, \"mu_intercept_per_group\": -4.4033122062683105, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 2, \"draws\": 59, \"mu_intercept_per_group\": -3.912036895751953, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 2, \"draws\": 60, \"mu_intercept_per_group\": -3.9549801349639893, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 2, \"draws\": 61, \"mu_intercept_per_group\": -7.208376884460449, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 2, \"draws\": 62, \"mu_intercept_per_group\": -7.706581115722656, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 2, \"draws\": 63, \"mu_intercept_per_group\": -8.447404861450195, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 2, \"draws\": 64, \"mu_intercept_per_group\": -7.7373785972595215, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 2, \"draws\": 65, \"mu_intercept_per_group\": -7.708994388580322, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 2, \"draws\": 66, \"mu_intercept_per_group\": -8.680890083312988, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 2, \"draws\": 67, \"mu_intercept_per_group\": -8.69361686706543, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 2, \"draws\": 68, \"mu_intercept_per_group\": -7.975279331207275, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 2, \"draws\": 69, \"mu_intercept_per_group\": -7.709714889526367, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 2, \"draws\": 70, \"mu_intercept_per_group\": -6.508571147918701, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 2, \"draws\": 71, \"mu_intercept_per_group\": -4.881943702697754, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 2, \"draws\": 72, \"mu_intercept_per_group\": -4.966244697570801, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 2, \"draws\": 73, \"mu_intercept_per_group\": -4.78423547744751, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 2, \"draws\": 74, \"mu_intercept_per_group\": -4.845292568206787, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 2, \"draws\": 75, \"mu_intercept_per_group\": -5.543205738067627, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 2, \"draws\": 76, \"mu_intercept_per_group\": -5.577106952667236, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 2, \"draws\": 77, \"mu_intercept_per_group\": -8.403943061828613, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 2, \"draws\": 78, \"mu_intercept_per_group\": -6.946186542510986, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 2, \"draws\": 79, \"mu_intercept_per_group\": -11.154786109924316, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 2, \"draws\": 80, \"mu_intercept_per_group\": -13.394046783447266, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 2, \"draws\": 81, \"mu_intercept_per_group\": -11.849854469299316, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 2, \"draws\": 82, \"mu_intercept_per_group\": -12.415608406066895, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 2, \"draws\": 83, \"mu_intercept_per_group\": -12.007187843322754, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 2, \"draws\": 84, \"mu_intercept_per_group\": -10.74623966217041, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 2, \"draws\": 85, \"mu_intercept_per_group\": -11.732085227966309, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 2, \"draws\": 86, \"mu_intercept_per_group\": -10.023104667663574, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 2, \"draws\": 87, \"mu_intercept_per_group\": -7.586278915405273, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 2, \"draws\": 88, \"mu_intercept_per_group\": -7.455413341522217, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 2, \"draws\": 89, \"mu_intercept_per_group\": -10.266925811767578, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 2, \"draws\": 90, \"mu_intercept_per_group\": -8.922574043273926, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 2, \"draws\": 91, \"mu_intercept_per_group\": -10.511691093444824, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 2, \"draws\": 92, \"mu_intercept_per_group\": -9.939892768859863, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 2, \"draws\": 93, \"mu_intercept_per_group\": -9.695605278015137, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 2, \"draws\": 94, \"mu_intercept_per_group\": -9.562189102172852, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 2, \"draws\": 95, \"mu_intercept_per_group\": -9.681805610656738, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 2, \"draws\": 96, \"mu_intercept_per_group\": -9.782240867614746, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 2, \"draws\": 97, \"mu_intercept_per_group\": -8.630509376525879, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 2, \"draws\": 98, \"mu_intercept_per_group\": -8.855262756347656, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 2, \"draws\": 99, \"mu_intercept_per_group\": -9.184484481811523, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 2, \"draws\": 100, \"mu_intercept_per_group\": -8.961798667907715, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 2, \"draws\": 101, \"mu_intercept_per_group\": -11.286850929260254, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 2, \"draws\": 102, \"mu_intercept_per_group\": -9.175556182861328, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 2, \"draws\": 103, \"mu_intercept_per_group\": -6.8074164390563965, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 2, \"draws\": 104, \"mu_intercept_per_group\": -8.643304824829102, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 2, \"draws\": 105, \"mu_intercept_per_group\": -8.833028793334961, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 2, \"draws\": 106, \"mu_intercept_per_group\": -9.552534103393555, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 2, \"draws\": 107, \"mu_intercept_per_group\": -10.603963851928711, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 2, \"draws\": 108, \"mu_intercept_per_group\": -10.847040176391602, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 2, \"draws\": 109, \"mu_intercept_per_group\": -16.828893661499023, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 2, \"draws\": 110, \"mu_intercept_per_group\": -18.055946350097656, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 2, \"draws\": 111, \"mu_intercept_per_group\": -12.25049114227295, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 2, \"draws\": 112, \"mu_intercept_per_group\": -12.448899269104004, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 2, \"draws\": 113, \"mu_intercept_per_group\": -12.305310249328613, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 2, \"draws\": 114, \"mu_intercept_per_group\": -14.124710083007812, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 2, \"draws\": 115, \"mu_intercept_per_group\": -12.449019432067871, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 2, \"draws\": 116, \"mu_intercept_per_group\": -11.98206901550293, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 2, \"draws\": 117, \"mu_intercept_per_group\": -11.517051696777344, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 2, \"draws\": 118, \"mu_intercept_per_group\": -12.097792625427246, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 2, \"draws\": 119, \"mu_intercept_per_group\": -12.42745304107666, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 2, \"draws\": 120, \"mu_intercept_per_group\": -14.045775413513184, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 2, \"draws\": 121, \"mu_intercept_per_group\": -13.942665100097656, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 2, \"draws\": 122, \"mu_intercept_per_group\": -12.892756462097168, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 2, \"draws\": 123, \"mu_intercept_per_group\": -13.070834159851074, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 2, \"draws\": 124, \"mu_intercept_per_group\": -11.558881759643555, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 2, \"draws\": 125, \"mu_intercept_per_group\": -10.289420127868652, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 2, \"draws\": 126, \"mu_intercept_per_group\": -9.548531532287598, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 2, \"draws\": 127, \"mu_intercept_per_group\": -9.780393600463867, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 2, \"draws\": 128, \"mu_intercept_per_group\": -9.847517967224121, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 2, \"draws\": 129, \"mu_intercept_per_group\": -8.862573623657227, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 2, \"draws\": 130, \"mu_intercept_per_group\": -8.65005874633789, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 2, \"draws\": 131, \"mu_intercept_per_group\": -9.382956504821777, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 2, \"draws\": 132, \"mu_intercept_per_group\": -9.64990520477295, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 2, \"draws\": 133, \"mu_intercept_per_group\": -9.367914199829102, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 2, \"draws\": 134, \"mu_intercept_per_group\": -8.03258228302002, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 2, \"draws\": 135, \"mu_intercept_per_group\": -8.781704902648926, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 2, \"draws\": 136, \"mu_intercept_per_group\": -8.873079299926758, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 2, \"draws\": 137, \"mu_intercept_per_group\": -8.765074729919434, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 2, \"draws\": 138, \"mu_intercept_per_group\": -8.002171516418457, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 2, \"draws\": 139, \"mu_intercept_per_group\": -8.481122970581055, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 2, \"draws\": 140, \"mu_intercept_per_group\": -9.05484676361084, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 2, \"draws\": 141, \"mu_intercept_per_group\": -9.969876289367676, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 2, \"draws\": 142, \"mu_intercept_per_group\": -11.075017929077148, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 2, \"draws\": 143, \"mu_intercept_per_group\": -5.56382942199707, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 2, \"draws\": 144, \"mu_intercept_per_group\": -6.616144180297852, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 2, \"draws\": 145, \"mu_intercept_per_group\": -6.391448020935059, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 2, \"draws\": 146, \"mu_intercept_per_group\": -6.146801948547363, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 2, \"draws\": 147, \"mu_intercept_per_group\": -5.877919673919678, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 2, \"draws\": 148, \"mu_intercept_per_group\": -8.784939765930176, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 2, \"draws\": 149, \"mu_intercept_per_group\": -9.290788650512695, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 2, \"draws\": 150, \"mu_intercept_per_group\": -10.092151641845703, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 2, \"draws\": 151, \"mu_intercept_per_group\": -9.25985050201416, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 2, \"draws\": 152, \"mu_intercept_per_group\": -7.425848484039307, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 2, \"draws\": 153, \"mu_intercept_per_group\": -6.189228534698486, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 2, \"draws\": 154, \"mu_intercept_per_group\": -7.105620861053467, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 2, \"draws\": 155, \"mu_intercept_per_group\": -7.207167625427246, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 2, \"draws\": 156, \"mu_intercept_per_group\": -7.1179890632629395, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 2, \"draws\": 157, \"mu_intercept_per_group\": -7.336030006408691, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 2, \"draws\": 158, \"mu_intercept_per_group\": -8.53834056854248, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 2, \"draws\": 159, \"mu_intercept_per_group\": -9.108002662658691, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 2, \"draws\": 160, \"mu_intercept_per_group\": -14.830260276794434, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 2, \"draws\": 161, \"mu_intercept_per_group\": -17.185462951660156, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 2, \"draws\": 162, \"mu_intercept_per_group\": -15.373597145080566, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 2, \"draws\": 163, \"mu_intercept_per_group\": -15.05878734588623, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 2, \"draws\": 164, \"mu_intercept_per_group\": -13.237135887145996, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 2, \"draws\": 165, \"mu_intercept_per_group\": -10.521673202514648, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 2, \"draws\": 166, \"mu_intercept_per_group\": -19.459592819213867, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 2, \"draws\": 167, \"mu_intercept_per_group\": -12.77586841583252, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 2, \"draws\": 168, \"mu_intercept_per_group\": -14.612886428833008, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 2, \"draws\": 169, \"mu_intercept_per_group\": -13.912336349487305, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 2, \"draws\": 170, \"mu_intercept_per_group\": -15.386208534240723, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 2, \"draws\": 171, \"mu_intercept_per_group\": -14.496955871582031, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 2, \"draws\": 172, \"mu_intercept_per_group\": -15.616334915161133, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 2, \"draws\": 173, \"mu_intercept_per_group\": -15.343432426452637, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 2, \"draws\": 174, \"mu_intercept_per_group\": -15.57786750793457, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 2, \"draws\": 175, \"mu_intercept_per_group\": -15.244278907775879, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 2, \"draws\": 176, \"mu_intercept_per_group\": -15.373337745666504, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 2, \"draws\": 177, \"mu_intercept_per_group\": -16.510028839111328, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 2, \"draws\": 178, \"mu_intercept_per_group\": -16.063766479492188, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 2, \"draws\": 179, \"mu_intercept_per_group\": -7.434024810791016, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 2, \"draws\": 180, \"mu_intercept_per_group\": -6.359696865081787, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 2, \"draws\": 181, \"mu_intercept_per_group\": -7.023039817810059, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 2, \"draws\": 182, \"mu_intercept_per_group\": -8.45052433013916, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 2, \"draws\": 183, \"mu_intercept_per_group\": -8.50468921661377, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 2, \"draws\": 184, \"mu_intercept_per_group\": -8.317551612854004, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 2, \"draws\": 185, \"mu_intercept_per_group\": -8.842100143432617, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 2, \"draws\": 186, \"mu_intercept_per_group\": -7.829134464263916, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 2, \"draws\": 187, \"mu_intercept_per_group\": -8.443354606628418, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 2, \"draws\": 188, \"mu_intercept_per_group\": -8.528440475463867, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 2, \"draws\": 189, \"mu_intercept_per_group\": -7.433631420135498, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 2, \"draws\": 190, \"mu_intercept_per_group\": -11.366190910339355, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 2, \"draws\": 191, \"mu_intercept_per_group\": -11.487279891967773, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 2, \"draws\": 192, \"mu_intercept_per_group\": -10.873893737792969, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 2, \"draws\": 193, \"mu_intercept_per_group\": -7.953674793243408, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 2, \"draws\": 194, \"mu_intercept_per_group\": -9.043959617614746, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 2, \"draws\": 195, \"mu_intercept_per_group\": -7.571133613586426, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 2, \"draws\": 196, \"mu_intercept_per_group\": -9.167332649230957, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 2, \"draws\": 197, \"mu_intercept_per_group\": -9.22920036315918, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 2, \"draws\": 198, \"mu_intercept_per_group\": -7.749976634979248, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 2, \"draws\": 199, \"mu_intercept_per_group\": -9.485520362854004, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 2, \"draws\": 200, \"mu_intercept_per_group\": -9.558971405029297, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 2, \"draws\": 201, \"mu_intercept_per_group\": -9.242197036743164, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 2, \"draws\": 202, \"mu_intercept_per_group\": -8.389689445495605, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 2, \"draws\": 203, \"mu_intercept_per_group\": -7.986049175262451, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 2, \"draws\": 204, \"mu_intercept_per_group\": -7.939853668212891, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 2, \"draws\": 205, \"mu_intercept_per_group\": -8.025477409362793, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 2, \"draws\": 206, \"mu_intercept_per_group\": -9.798044204711914, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 2, \"draws\": 207, \"mu_intercept_per_group\": -8.910064697265625, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 2, \"draws\": 208, \"mu_intercept_per_group\": -8.644339561462402, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 2, \"draws\": 209, \"mu_intercept_per_group\": -8.47162914276123, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 2, \"draws\": 210, \"mu_intercept_per_group\": -8.992490768432617, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 2, \"draws\": 211, \"mu_intercept_per_group\": -8.70028018951416, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 2, \"draws\": 212, \"mu_intercept_per_group\": -9.042204856872559, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 2, \"draws\": 213, \"mu_intercept_per_group\": -6.897375106811523, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 2, \"draws\": 214, \"mu_intercept_per_group\": -6.253714561462402, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 2, \"draws\": 215, \"mu_intercept_per_group\": -5.731706142425537, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 2, \"draws\": 216, \"mu_intercept_per_group\": -5.1961517333984375, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 2, \"draws\": 217, \"mu_intercept_per_group\": -6.687386989593506, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 2, \"draws\": 218, \"mu_intercept_per_group\": -6.272985458374023, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 2, \"draws\": 219, \"mu_intercept_per_group\": -5.811789512634277, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 2, \"draws\": 220, \"mu_intercept_per_group\": -7.017706394195557, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 2, \"draws\": 221, \"mu_intercept_per_group\": -7.163666248321533, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 2, \"draws\": 222, \"mu_intercept_per_group\": -7.07087516784668, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 2, \"draws\": 223, \"mu_intercept_per_group\": -6.612777233123779, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 2, \"draws\": 224, \"mu_intercept_per_group\": -6.44852352142334, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 2, \"draws\": 225, \"mu_intercept_per_group\": -6.516042232513428, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 2, \"draws\": 226, \"mu_intercept_per_group\": -6.6033549308776855, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 2, \"draws\": 227, \"mu_intercept_per_group\": -6.945231914520264, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 2, \"draws\": 228, \"mu_intercept_per_group\": -6.286407947540283, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 2, \"draws\": 229, \"mu_intercept_per_group\": -5.9532670974731445, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 2, \"draws\": 230, \"mu_intercept_per_group\": -5.793153285980225, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 2, \"draws\": 231, \"mu_intercept_per_group\": -6.8703694343566895, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 2, \"draws\": 232, \"mu_intercept_per_group\": -6.9184794425964355, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 2, \"draws\": 233, \"mu_intercept_per_group\": -6.987246513366699, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 2, \"draws\": 234, \"mu_intercept_per_group\": -7.612975597381592, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 2, \"draws\": 235, \"mu_intercept_per_group\": -7.089613437652588, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 2, \"draws\": 236, \"mu_intercept_per_group\": -5.220559597015381, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 2, \"draws\": 237, \"mu_intercept_per_group\": -6.309560298919678, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 2, \"draws\": 238, \"mu_intercept_per_group\": -6.1052727699279785, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 2, \"draws\": 239, \"mu_intercept_per_group\": -5.923365592956543, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 2, \"draws\": 240, \"mu_intercept_per_group\": -5.6926374435424805, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 2, \"draws\": 241, \"mu_intercept_per_group\": -6.7284955978393555, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 2, \"draws\": 242, \"mu_intercept_per_group\": -6.981760025024414, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 2, \"draws\": 243, \"mu_intercept_per_group\": -7.670392990112305, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 2, \"draws\": 244, \"mu_intercept_per_group\": -8.593595504760742, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 2, \"draws\": 245, \"mu_intercept_per_group\": -9.460906028747559, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 2, \"draws\": 246, \"mu_intercept_per_group\": -7.986255168914795, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 2, \"draws\": 247, \"mu_intercept_per_group\": -8.414737701416016, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 2, \"draws\": 248, \"mu_intercept_per_group\": -8.051430702209473, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 2, \"draws\": 249, \"mu_intercept_per_group\": -6.546506881713867, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 2, \"draws\": 250, \"mu_intercept_per_group\": -6.62329626083374, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 2, \"draws\": 251, \"mu_intercept_per_group\": -7.201033592224121, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 2, \"draws\": 252, \"mu_intercept_per_group\": -6.997493267059326, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 2, \"draws\": 253, \"mu_intercept_per_group\": -7.186775207519531, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 2, \"draws\": 254, \"mu_intercept_per_group\": -7.784112930297852, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 2, \"draws\": 255, \"mu_intercept_per_group\": -7.455981731414795, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 2, \"draws\": 256, \"mu_intercept_per_group\": -9.6963472366333, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 2, \"draws\": 257, \"mu_intercept_per_group\": -9.211112022399902, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 2, \"draws\": 258, \"mu_intercept_per_group\": -8.615071296691895, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 2, \"draws\": 259, \"mu_intercept_per_group\": -8.831884384155273, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 2, \"draws\": 260, \"mu_intercept_per_group\": -8.183555603027344, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 2, \"draws\": 261, \"mu_intercept_per_group\": -6.744656085968018, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 2, \"draws\": 262, \"mu_intercept_per_group\": -6.165415287017822, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 2, \"draws\": 263, \"mu_intercept_per_group\": -7.003814697265625, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 2, \"draws\": 264, \"mu_intercept_per_group\": -7.126833915710449, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 2, \"draws\": 265, \"mu_intercept_per_group\": -7.624880313873291, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 2, \"draws\": 266, \"mu_intercept_per_group\": -5.27862024307251, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 2, \"draws\": 267, \"mu_intercept_per_group\": -5.329865455627441, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 2, \"draws\": 268, \"mu_intercept_per_group\": -4.79013204574585, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 2, \"draws\": 269, \"mu_intercept_per_group\": -15.255629539489746, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 2, \"draws\": 270, \"mu_intercept_per_group\": -13.10225772857666, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 2, \"draws\": 271, \"mu_intercept_per_group\": -13.299938201904297, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 2, \"draws\": 272, \"mu_intercept_per_group\": -10.509306907653809, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 2, \"draws\": 273, \"mu_intercept_per_group\": -11.278899192810059, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 2, \"draws\": 274, \"mu_intercept_per_group\": -13.075965881347656, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 2, \"draws\": 275, \"mu_intercept_per_group\": -13.193696975708008, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 2, \"draws\": 276, \"mu_intercept_per_group\": -12.13432502746582, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 2, \"draws\": 277, \"mu_intercept_per_group\": -11.544530868530273, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 2, \"draws\": 278, \"mu_intercept_per_group\": -12.254440307617188, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 2, \"draws\": 279, \"mu_intercept_per_group\": -11.256677627563477, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 2, \"draws\": 280, \"mu_intercept_per_group\": -9.24073314666748, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 2, \"draws\": 281, \"mu_intercept_per_group\": -13.26752758026123, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 2, \"draws\": 282, \"mu_intercept_per_group\": -11.711874008178711, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 2, \"draws\": 283, \"mu_intercept_per_group\": -12.107666015625, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 2, \"draws\": 284, \"mu_intercept_per_group\": -12.49039077758789, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 2, \"draws\": 285, \"mu_intercept_per_group\": -11.510320663452148, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 2, \"draws\": 286, \"mu_intercept_per_group\": -12.789005279541016, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 2, \"draws\": 287, \"mu_intercept_per_group\": -12.965875625610352, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 2, \"draws\": 288, \"mu_intercept_per_group\": -13.440556526184082, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 2, \"draws\": 289, \"mu_intercept_per_group\": -12.935181617736816, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 2, \"draws\": 290, \"mu_intercept_per_group\": -12.585945129394531, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 2, \"draws\": 291, \"mu_intercept_per_group\": -12.836762428283691, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 2, \"draws\": 292, \"mu_intercept_per_group\": -13.05434513092041, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 2, \"draws\": 293, \"mu_intercept_per_group\": -10.055023193359375, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 2, \"draws\": 294, \"mu_intercept_per_group\": -9.636289596557617, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 2, \"draws\": 295, \"mu_intercept_per_group\": -8.662613868713379, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 2, \"draws\": 296, \"mu_intercept_per_group\": -9.1491117477417, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 2, \"draws\": 297, \"mu_intercept_per_group\": -6.403409004211426, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 2, \"draws\": 298, \"mu_intercept_per_group\": -7.563633441925049, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 2, \"draws\": 299, \"mu_intercept_per_group\": -7.942143440246582, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 2, \"draws\": 300, \"mu_intercept_per_group\": -8.514138221740723, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 2, \"draws\": 301, \"mu_intercept_per_group\": -8.339614868164062, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 2, \"draws\": 302, \"mu_intercept_per_group\": -8.53172492980957, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 2, \"draws\": 303, \"mu_intercept_per_group\": -8.924644470214844, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 2, \"draws\": 304, \"mu_intercept_per_group\": -7.523374080657959, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 2, \"draws\": 305, \"mu_intercept_per_group\": -8.11363410949707, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 2, \"draws\": 306, \"mu_intercept_per_group\": -7.583475112915039, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 2, \"draws\": 307, \"mu_intercept_per_group\": -8.914551734924316, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 2, \"draws\": 308, \"mu_intercept_per_group\": -7.59495210647583, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 2, \"draws\": 309, \"mu_intercept_per_group\": -10.408060073852539, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 2, \"draws\": 310, \"mu_intercept_per_group\": -12.107131004333496, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 2, \"draws\": 311, \"mu_intercept_per_group\": -9.929945945739746, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 2, \"draws\": 312, \"mu_intercept_per_group\": -10.515772819519043, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 2, \"draws\": 313, \"mu_intercept_per_group\": -12.24309253692627, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 2, \"draws\": 314, \"mu_intercept_per_group\": -9.440649032592773, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 2, \"draws\": 315, \"mu_intercept_per_group\": -9.507796287536621, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 2, \"draws\": 316, \"mu_intercept_per_group\": -10.594572067260742, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 2, \"draws\": 317, \"mu_intercept_per_group\": -10.321135520935059, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 2, \"draws\": 318, \"mu_intercept_per_group\": -10.93638801574707, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 2, \"draws\": 319, \"mu_intercept_per_group\": -12.396105766296387, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 2, \"draws\": 320, \"mu_intercept_per_group\": -3.8326284885406494, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 2, \"draws\": 321, \"mu_intercept_per_group\": -3.874495267868042, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 2, \"draws\": 322, \"mu_intercept_per_group\": -4.283148765563965, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 2, \"draws\": 323, \"mu_intercept_per_group\": -4.202067852020264, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 2, \"draws\": 324, \"mu_intercept_per_group\": -6.71360969543457, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 2, \"draws\": 325, \"mu_intercept_per_group\": -6.5928215980529785, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 2, \"draws\": 326, \"mu_intercept_per_group\": -6.649409294128418, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 2, \"draws\": 327, \"mu_intercept_per_group\": -6.632644176483154, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 2, \"draws\": 328, \"mu_intercept_per_group\": -6.9088006019592285, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 2, \"draws\": 329, \"mu_intercept_per_group\": -8.115894317626953, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 2, \"draws\": 330, \"mu_intercept_per_group\": -7.053569316864014, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 2, \"draws\": 331, \"mu_intercept_per_group\": -8.572206497192383, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 2, \"draws\": 332, \"mu_intercept_per_group\": -8.318761825561523, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 2, \"draws\": 333, \"mu_intercept_per_group\": -8.070542335510254, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 2, \"draws\": 334, \"mu_intercept_per_group\": -8.093010902404785, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 2, \"draws\": 335, \"mu_intercept_per_group\": -9.144524574279785, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 2, \"draws\": 336, \"mu_intercept_per_group\": -7.008109092712402, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 2, \"draws\": 337, \"mu_intercept_per_group\": -8.386369705200195, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 2, \"draws\": 338, \"mu_intercept_per_group\": -14.962732315063477, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 2, \"draws\": 339, \"mu_intercept_per_group\": -11.990336418151855, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 2, \"draws\": 340, \"mu_intercept_per_group\": -11.937858581542969, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 2, \"draws\": 341, \"mu_intercept_per_group\": -10.761756896972656, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 2, \"draws\": 342, \"mu_intercept_per_group\": -10.97829818725586, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 2, \"draws\": 343, \"mu_intercept_per_group\": -9.957612991333008, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 2, \"draws\": 344, \"mu_intercept_per_group\": -13.30827808380127, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 2, \"draws\": 345, \"mu_intercept_per_group\": -18.20355224609375, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 2, \"draws\": 346, \"mu_intercept_per_group\": -10.243486404418945, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 2, \"draws\": 347, \"mu_intercept_per_group\": -10.212509155273438, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 2, \"draws\": 348, \"mu_intercept_per_group\": -10.102747917175293, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 2, \"draws\": 349, \"mu_intercept_per_group\": -8.879531860351562, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 2, \"draws\": 350, \"mu_intercept_per_group\": -10.94552230834961, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 2, \"draws\": 351, \"mu_intercept_per_group\": -10.738237380981445, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 2, \"draws\": 352, \"mu_intercept_per_group\": -11.55812931060791, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 2, \"draws\": 353, \"mu_intercept_per_group\": -12.129766464233398, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 2, \"draws\": 354, \"mu_intercept_per_group\": -8.159052848815918, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 2, \"draws\": 355, \"mu_intercept_per_group\": -7.960541725158691, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 2, \"draws\": 356, \"mu_intercept_per_group\": -7.436365127563477, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 2, \"draws\": 357, \"mu_intercept_per_group\": -7.345530986785889, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 2, \"draws\": 358, \"mu_intercept_per_group\": -7.375087261199951, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 2, \"draws\": 359, \"mu_intercept_per_group\": -7.308013916015625, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 2, \"draws\": 360, \"mu_intercept_per_group\": -6.2547607421875, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 2, \"draws\": 361, \"mu_intercept_per_group\": -8.171603202819824, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 2, \"draws\": 362, \"mu_intercept_per_group\": -7.307666301727295, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 2, \"draws\": 363, \"mu_intercept_per_group\": -7.54347562789917, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 2, \"draws\": 364, \"mu_intercept_per_group\": -9.506094932556152, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 2, \"draws\": 365, \"mu_intercept_per_group\": -10.119277000427246, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 2, \"draws\": 366, \"mu_intercept_per_group\": -9.589120864868164, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 2, \"draws\": 367, \"mu_intercept_per_group\": -8.38620376586914, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 2, \"draws\": 368, \"mu_intercept_per_group\": -11.248230934143066, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 2, \"draws\": 369, \"mu_intercept_per_group\": -5.862124919891357, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 2, \"draws\": 370, \"mu_intercept_per_group\": -5.463159561157227, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 2, \"draws\": 371, \"mu_intercept_per_group\": -6.068930625915527, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 2, \"draws\": 372, \"mu_intercept_per_group\": -6.1273674964904785, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 2, \"draws\": 373, \"mu_intercept_per_group\": -6.521869659423828, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 2, \"draws\": 374, \"mu_intercept_per_group\": -6.463087558746338, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 2, \"draws\": 375, \"mu_intercept_per_group\": -7.110462188720703, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 2, \"draws\": 376, \"mu_intercept_per_group\": -9.628852844238281, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 2, \"draws\": 377, \"mu_intercept_per_group\": -7.012094020843506, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 2, \"draws\": 378, \"mu_intercept_per_group\": -6.745218753814697, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 2, \"draws\": 379, \"mu_intercept_per_group\": -6.855048656463623, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 2, \"draws\": 380, \"mu_intercept_per_group\": -5.890373706817627, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 2, \"draws\": 381, \"mu_intercept_per_group\": -8.485527038574219, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 2, \"draws\": 382, \"mu_intercept_per_group\": -6.081881523132324, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 2, \"draws\": 383, \"mu_intercept_per_group\": -6.264965057373047, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 2, \"draws\": 384, \"mu_intercept_per_group\": -11.44893741607666, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 2, \"draws\": 385, \"mu_intercept_per_group\": -10.910845756530762, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 2, \"draws\": 386, \"mu_intercept_per_group\": -10.106712341308594, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 2, \"draws\": 387, \"mu_intercept_per_group\": -10.102458000183105, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 2, \"draws\": 388, \"mu_intercept_per_group\": -9.727493286132812, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 2, \"draws\": 389, \"mu_intercept_per_group\": -11.246182441711426, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 2, \"draws\": 390, \"mu_intercept_per_group\": -10.559623718261719, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 2, \"draws\": 391, \"mu_intercept_per_group\": -10.023141860961914, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 2, \"draws\": 392, \"mu_intercept_per_group\": -10.56458854675293, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 2, \"draws\": 393, \"mu_intercept_per_group\": -9.065013885498047, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 2, \"draws\": 394, \"mu_intercept_per_group\": -9.630987167358398, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 2, \"draws\": 395, \"mu_intercept_per_group\": -9.621627807617188, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 2, \"draws\": 396, \"mu_intercept_per_group\": -9.754430770874023, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 2, \"draws\": 397, \"mu_intercept_per_group\": -9.777823448181152, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 2, \"draws\": 398, \"mu_intercept_per_group\": -9.8089599609375, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 2, \"draws\": 399, \"mu_intercept_per_group\": -9.296844482421875, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 2, \"draws\": 400, \"mu_intercept_per_group\": -9.30306339263916, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 2, \"draws\": 401, \"mu_intercept_per_group\": -8.287066459655762, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 2, \"draws\": 402, \"mu_intercept_per_group\": -8.032702445983887, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 2, \"draws\": 403, \"mu_intercept_per_group\": -7.737759113311768, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 2, \"draws\": 404, \"mu_intercept_per_group\": -10.240459442138672, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 2, \"draws\": 405, \"mu_intercept_per_group\": -9.78650951385498, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 2, \"draws\": 406, \"mu_intercept_per_group\": -10.54364013671875, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 2, \"draws\": 407, \"mu_intercept_per_group\": -9.133692741394043, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 2, \"draws\": 408, \"mu_intercept_per_group\": -8.501397132873535, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 2, \"draws\": 409, \"mu_intercept_per_group\": -9.207874298095703, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 2, \"draws\": 410, \"mu_intercept_per_group\": -9.224843978881836, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 2, \"draws\": 411, \"mu_intercept_per_group\": -7.86361837387085, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 2, \"draws\": 412, \"mu_intercept_per_group\": -7.517457962036133, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 2, \"draws\": 413, \"mu_intercept_per_group\": -10.553731918334961, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 2, \"draws\": 414, \"mu_intercept_per_group\": -10.442585945129395, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 2, \"draws\": 415, \"mu_intercept_per_group\": -10.159224510192871, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 2, \"draws\": 416, \"mu_intercept_per_group\": -9.959710121154785, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 2, \"draws\": 417, \"mu_intercept_per_group\": -9.114307403564453, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 2, \"draws\": 418, \"mu_intercept_per_group\": -9.74736499786377, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 2, \"draws\": 419, \"mu_intercept_per_group\": -9.09874153137207, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 2, \"draws\": 420, \"mu_intercept_per_group\": -9.969940185546875, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 2, \"draws\": 421, \"mu_intercept_per_group\": -8.905924797058105, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 2, \"draws\": 422, \"mu_intercept_per_group\": -10.32229995727539, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 2, \"draws\": 423, \"mu_intercept_per_group\": -10.242536544799805, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 2, \"draws\": 424, \"mu_intercept_per_group\": -9.374312400817871, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 2, \"draws\": 425, \"mu_intercept_per_group\": -10.689253807067871, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 2, \"draws\": 426, \"mu_intercept_per_group\": -10.898482322692871, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 2, \"draws\": 427, \"mu_intercept_per_group\": -11.07215690612793, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 2, \"draws\": 428, \"mu_intercept_per_group\": -12.007759094238281, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 2, \"draws\": 429, \"mu_intercept_per_group\": -11.960660934448242, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 2, \"draws\": 430, \"mu_intercept_per_group\": -12.870683670043945, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 2, \"draws\": 431, \"mu_intercept_per_group\": -11.36689567565918, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 2, \"draws\": 432, \"mu_intercept_per_group\": -10.136443138122559, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 2, \"draws\": 433, \"mu_intercept_per_group\": -11.434286117553711, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 2, \"draws\": 434, \"mu_intercept_per_group\": -10.764805793762207, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 2, \"draws\": 435, \"mu_intercept_per_group\": -10.678425788879395, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 2, \"draws\": 436, \"mu_intercept_per_group\": -11.187084197998047, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 2, \"draws\": 437, \"mu_intercept_per_group\": -11.662741661071777, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 2, \"draws\": 438, \"mu_intercept_per_group\": -12.077077865600586, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 2, \"draws\": 439, \"mu_intercept_per_group\": -11.32813835144043, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 2, \"draws\": 440, \"mu_intercept_per_group\": -10.312041282653809, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 2, \"draws\": 441, \"mu_intercept_per_group\": -10.872803688049316, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 2, \"draws\": 442, \"mu_intercept_per_group\": -13.48287296295166, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 2, \"draws\": 443, \"mu_intercept_per_group\": -15.123278617858887, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 2, \"draws\": 444, \"mu_intercept_per_group\": -16.133203506469727, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 2, \"draws\": 445, \"mu_intercept_per_group\": -13.469136238098145, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 2, \"draws\": 446, \"mu_intercept_per_group\": -10.143458366394043, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 2, \"draws\": 447, \"mu_intercept_per_group\": -9.321259498596191, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 2, \"draws\": 448, \"mu_intercept_per_group\": -7.428215503692627, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 2, \"draws\": 449, \"mu_intercept_per_group\": -7.317838191986084, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 2, \"draws\": 450, \"mu_intercept_per_group\": -8.419309616088867, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 2, \"draws\": 451, \"mu_intercept_per_group\": -16.16616439819336, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 2, \"draws\": 452, \"mu_intercept_per_group\": -15.052878379821777, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 2, \"draws\": 453, \"mu_intercept_per_group\": -17.366073608398438, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 2, \"draws\": 454, \"mu_intercept_per_group\": -17.605560302734375, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 2, \"draws\": 455, \"mu_intercept_per_group\": -17.073806762695312, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 2, \"draws\": 456, \"mu_intercept_per_group\": -16.403608322143555, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 2, \"draws\": 457, \"mu_intercept_per_group\": -15.977180480957031, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 2, \"draws\": 458, \"mu_intercept_per_group\": -15.886157035827637, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 2, \"draws\": 459, \"mu_intercept_per_group\": -8.276000022888184, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 2, \"draws\": 460, \"mu_intercept_per_group\": -9.001201629638672, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 2, \"draws\": 461, \"mu_intercept_per_group\": -8.824300765991211, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 2, \"draws\": 462, \"mu_intercept_per_group\": -6.916149139404297, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 2, \"draws\": 463, \"mu_intercept_per_group\": -6.9543633460998535, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 2, \"draws\": 464, \"mu_intercept_per_group\": -7.3828911781311035, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 2, \"draws\": 465, \"mu_intercept_per_group\": -7.041392803192139, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 2, \"draws\": 466, \"mu_intercept_per_group\": -7.0137434005737305, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 2, \"draws\": 467, \"mu_intercept_per_group\": -7.631060600280762, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 2, \"draws\": 468, \"mu_intercept_per_group\": -8.824135780334473, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 2, \"draws\": 469, \"mu_intercept_per_group\": -8.301162719726562, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 2, \"draws\": 470, \"mu_intercept_per_group\": -8.329082489013672, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 2, \"draws\": 471, \"mu_intercept_per_group\": -8.326737403869629, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 2, \"draws\": 472, \"mu_intercept_per_group\": -8.230084419250488, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 2, \"draws\": 473, \"mu_intercept_per_group\": -11.83926010131836, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 2, \"draws\": 474, \"mu_intercept_per_group\": -14.139296531677246, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 2, \"draws\": 475, \"mu_intercept_per_group\": -14.485081672668457, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 2, \"draws\": 476, \"mu_intercept_per_group\": -14.15733528137207, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 2, \"draws\": 477, \"mu_intercept_per_group\": -12.667623519897461, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 2, \"draws\": 478, \"mu_intercept_per_group\": -13.73106575012207, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 2, \"draws\": 479, \"mu_intercept_per_group\": -13.738646507263184, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 2, \"draws\": 480, \"mu_intercept_per_group\": -11.34078598022461, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 2, \"draws\": 481, \"mu_intercept_per_group\": -10.322614669799805, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 2, \"draws\": 482, \"mu_intercept_per_group\": -10.40048885345459, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 2, \"draws\": 483, \"mu_intercept_per_group\": -10.402188301086426, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 2, \"draws\": 484, \"mu_intercept_per_group\": -9.426457405090332, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 2, \"draws\": 485, \"mu_intercept_per_group\": -8.22807502746582, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 2, \"draws\": 486, \"mu_intercept_per_group\": -8.343188285827637, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 2, \"draws\": 487, \"mu_intercept_per_group\": -8.310812950134277, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 2, \"draws\": 488, \"mu_intercept_per_group\": -7.120408058166504, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 2, \"draws\": 489, \"mu_intercept_per_group\": -9.076619148254395, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 2, \"draws\": 490, \"mu_intercept_per_group\": -7.468583583831787, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 2, \"draws\": 491, \"mu_intercept_per_group\": -7.681987285614014, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 2, \"draws\": 492, \"mu_intercept_per_group\": -8.299936294555664, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 2, \"draws\": 493, \"mu_intercept_per_group\": -7.154465198516846, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 2, \"draws\": 494, \"mu_intercept_per_group\": -11.773426055908203, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 2, \"draws\": 495, \"mu_intercept_per_group\": -12.007054328918457, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 2, \"draws\": 496, \"mu_intercept_per_group\": -9.876861572265625, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 2, \"draws\": 497, \"mu_intercept_per_group\": -10.681716918945312, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 2, \"draws\": 498, \"mu_intercept_per_group\": -10.582509994506836, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 2, \"draws\": 499, \"mu_intercept_per_group\": -9.49457836151123, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 2, \"draws\": 500, \"mu_intercept_per_group\": -10.014411926269531, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 2, \"draws\": 501, \"mu_intercept_per_group\": -12.219635963439941, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 2, \"draws\": 502, \"mu_intercept_per_group\": -11.104462623596191, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 2, \"draws\": 503, \"mu_intercept_per_group\": -11.753150939941406, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 2, \"draws\": 504, \"mu_intercept_per_group\": -10.620562553405762, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 2, \"draws\": 505, \"mu_intercept_per_group\": -10.675411224365234, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 2, \"draws\": 506, \"mu_intercept_per_group\": -9.319618225097656, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 2, \"draws\": 507, \"mu_intercept_per_group\": -9.376197814941406, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 2, \"draws\": 508, \"mu_intercept_per_group\": -12.375014305114746, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 2, \"draws\": 509, \"mu_intercept_per_group\": -13.390501976013184, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 2, \"draws\": 510, \"mu_intercept_per_group\": -11.577620506286621, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 2, \"draws\": 511, \"mu_intercept_per_group\": -15.596985816955566, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 2, \"draws\": 512, \"mu_intercept_per_group\": -14.831947326660156, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 2, \"draws\": 513, \"mu_intercept_per_group\": -12.448200225830078, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 2, \"draws\": 514, \"mu_intercept_per_group\": -11.793540000915527, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 2, \"draws\": 515, \"mu_intercept_per_group\": -11.921236038208008, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 2, \"draws\": 516, \"mu_intercept_per_group\": -11.78522777557373, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 2, \"draws\": 517, \"mu_intercept_per_group\": -11.685782432556152, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 2, \"draws\": 518, \"mu_intercept_per_group\": -11.592490196228027, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 2, \"draws\": 519, \"mu_intercept_per_group\": -11.915972709655762, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 2, \"draws\": 520, \"mu_intercept_per_group\": -10.13662338256836, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 2, \"draws\": 521, \"mu_intercept_per_group\": -8.284628868103027, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 2, \"draws\": 522, \"mu_intercept_per_group\": -8.059141159057617, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 2, \"draws\": 523, \"mu_intercept_per_group\": -8.960013389587402, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 2, \"draws\": 524, \"mu_intercept_per_group\": -7.080596446990967, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 2, \"draws\": 525, \"mu_intercept_per_group\": -6.303857326507568, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 2, \"draws\": 526, \"mu_intercept_per_group\": -6.608936786651611, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 2, \"draws\": 527, \"mu_intercept_per_group\": -9.405355453491211, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 2, \"draws\": 528, \"mu_intercept_per_group\": -9.529542922973633, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 2, \"draws\": 529, \"mu_intercept_per_group\": -9.936470985412598, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 2, \"draws\": 530, \"mu_intercept_per_group\": -7.869573593139648, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 2, \"draws\": 531, \"mu_intercept_per_group\": -8.224592208862305, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 2, \"draws\": 532, \"mu_intercept_per_group\": -9.01838493347168, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 2, \"draws\": 533, \"mu_intercept_per_group\": -8.840397834777832, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 2, \"draws\": 534, \"mu_intercept_per_group\": -10.071359634399414, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 2, \"draws\": 535, \"mu_intercept_per_group\": -9.827476501464844, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 2, \"draws\": 536, \"mu_intercept_per_group\": -8.909775733947754, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 2, \"draws\": 537, \"mu_intercept_per_group\": -6.1656694412231445, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 2, \"draws\": 538, \"mu_intercept_per_group\": -6.137988567352295, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 2, \"draws\": 539, \"mu_intercept_per_group\": -6.142375946044922, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 2, \"draws\": 540, \"mu_intercept_per_group\": -8.370516777038574, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 2, \"draws\": 541, \"mu_intercept_per_group\": -8.485040664672852, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 2, \"draws\": 542, \"mu_intercept_per_group\": -8.634536743164062, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 2, \"draws\": 543, \"mu_intercept_per_group\": -8.922847747802734, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 2, \"draws\": 544, \"mu_intercept_per_group\": -11.329963684082031, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 2, \"draws\": 545, \"mu_intercept_per_group\": -10.41037654876709, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 2, \"draws\": 546, \"mu_intercept_per_group\": -9.030210494995117, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 2, \"draws\": 547, \"mu_intercept_per_group\": -10.961108207702637, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 2, \"draws\": 548, \"mu_intercept_per_group\": -10.738873481750488, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 2, \"draws\": 549, \"mu_intercept_per_group\": -10.448390007019043, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 2, \"draws\": 550, \"mu_intercept_per_group\": -12.320303916931152, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 2, \"draws\": 551, \"mu_intercept_per_group\": -12.359390258789062, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 2, \"draws\": 552, \"mu_intercept_per_group\": -11.412613868713379, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 2, \"draws\": 553, \"mu_intercept_per_group\": -9.842954635620117, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 2, \"draws\": 554, \"mu_intercept_per_group\": -11.933849334716797, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 2, \"draws\": 555, \"mu_intercept_per_group\": -12.076140403747559, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 2, \"draws\": 556, \"mu_intercept_per_group\": -12.01351261138916, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 2, \"draws\": 557, \"mu_intercept_per_group\": -11.671770095825195, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 2, \"draws\": 558, \"mu_intercept_per_group\": -11.557403564453125, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 2, \"draws\": 559, \"mu_intercept_per_group\": -11.777539253234863, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 2, \"draws\": 560, \"mu_intercept_per_group\": -9.364644050598145, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 2, \"draws\": 561, \"mu_intercept_per_group\": -9.928903579711914, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 2, \"draws\": 562, \"mu_intercept_per_group\": -10.752791404724121, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 2, \"draws\": 563, \"mu_intercept_per_group\": -10.886780738830566, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 2, \"draws\": 564, \"mu_intercept_per_group\": -7.5234551429748535, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 2, \"draws\": 565, \"mu_intercept_per_group\": -8.985288619995117, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 2, \"draws\": 566, \"mu_intercept_per_group\": -8.50300121307373, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 2, \"draws\": 567, \"mu_intercept_per_group\": -7.083637714385986, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 2, \"draws\": 568, \"mu_intercept_per_group\": -8.643061637878418, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 2, \"draws\": 569, \"mu_intercept_per_group\": -6.8666582107543945, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 2, \"draws\": 570, \"mu_intercept_per_group\": -7.759244441986084, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 2, \"draws\": 571, \"mu_intercept_per_group\": -7.9635820388793945, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 2, \"draws\": 572, \"mu_intercept_per_group\": -7.987215995788574, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 2, \"draws\": 573, \"mu_intercept_per_group\": -11.043526649475098, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 2, \"draws\": 574, \"mu_intercept_per_group\": -9.830126762390137, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 2, \"draws\": 575, \"mu_intercept_per_group\": -12.431546211242676, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 2, \"draws\": 576, \"mu_intercept_per_group\": -12.19079875946045, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 2, \"draws\": 577, \"mu_intercept_per_group\": -15.233949661254883, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 2, \"draws\": 578, \"mu_intercept_per_group\": -15.479727745056152, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 2, \"draws\": 579, \"mu_intercept_per_group\": -15.646200180053711, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 2, \"draws\": 580, \"mu_intercept_per_group\": -15.127071380615234, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 2, \"draws\": 581, \"mu_intercept_per_group\": -12.892071723937988, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 2, \"draws\": 582, \"mu_intercept_per_group\": -12.360160827636719, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 2, \"draws\": 583, \"mu_intercept_per_group\": -11.626749992370605, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 2, \"draws\": 584, \"mu_intercept_per_group\": -11.596542358398438, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 2, \"draws\": 585, \"mu_intercept_per_group\": -13.3951416015625, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 2, \"draws\": 586, \"mu_intercept_per_group\": -15.18194580078125, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 2, \"draws\": 587, \"mu_intercept_per_group\": -15.689735412597656, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 2, \"draws\": 588, \"mu_intercept_per_group\": -15.701537132263184, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 2, \"draws\": 589, \"mu_intercept_per_group\": -15.073882102966309, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 2, \"draws\": 590, \"mu_intercept_per_group\": -15.855364799499512, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 2, \"draws\": 591, \"mu_intercept_per_group\": -15.906293869018555, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 2, \"draws\": 592, \"mu_intercept_per_group\": -14.969801902770996, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 2, \"draws\": 593, \"mu_intercept_per_group\": -17.006940841674805, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 2, \"draws\": 594, \"mu_intercept_per_group\": -14.886451721191406, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 2, \"draws\": 595, \"mu_intercept_per_group\": -14.95926570892334, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 2, \"draws\": 596, \"mu_intercept_per_group\": -16.011926651000977, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 2, \"draws\": 597, \"mu_intercept_per_group\": -15.588326454162598, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 2, \"draws\": 598, \"mu_intercept_per_group\": -16.279985427856445, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 2, \"draws\": 599, \"mu_intercept_per_group\": -15.884343147277832, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 2, \"draws\": 600, \"mu_intercept_per_group\": -16.029590606689453, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 2, \"draws\": 601, \"mu_intercept_per_group\": -16.253360748291016, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 2, \"draws\": 602, \"mu_intercept_per_group\": -16.31010627746582, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 2, \"draws\": 603, \"mu_intercept_per_group\": -16.84382438659668, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 2, \"draws\": 604, \"mu_intercept_per_group\": -15.93847370147705, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 2, \"draws\": 605, \"mu_intercept_per_group\": -15.683954238891602, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 2, \"draws\": 606, \"mu_intercept_per_group\": -16.20218849182129, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 2, \"draws\": 607, \"mu_intercept_per_group\": -13.951407432556152, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 2, \"draws\": 608, \"mu_intercept_per_group\": -8.75363826751709, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 2, \"draws\": 609, \"mu_intercept_per_group\": -8.744316101074219, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 2, \"draws\": 610, \"mu_intercept_per_group\": -8.781010627746582, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 2, \"draws\": 611, \"mu_intercept_per_group\": -8.544942855834961, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 2, \"draws\": 612, \"mu_intercept_per_group\": -9.33665657043457, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 2, \"draws\": 613, \"mu_intercept_per_group\": -7.621401309967041, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 2, \"draws\": 614, \"mu_intercept_per_group\": -8.66136360168457, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 2, \"draws\": 615, \"mu_intercept_per_group\": -8.32052230834961, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 2, \"draws\": 616, \"mu_intercept_per_group\": -9.993941307067871, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 2, \"draws\": 617, \"mu_intercept_per_group\": -9.50870132446289, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 2, \"draws\": 618, \"mu_intercept_per_group\": -14.80935001373291, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 2, \"draws\": 619, \"mu_intercept_per_group\": -14.161215782165527, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 2, \"draws\": 620, \"mu_intercept_per_group\": -14.226594924926758, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 2, \"draws\": 621, \"mu_intercept_per_group\": -13.713505744934082, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 2, \"draws\": 622, \"mu_intercept_per_group\": -14.307723999023438, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 2, \"draws\": 623, \"mu_intercept_per_group\": -12.872706413269043, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 2, \"draws\": 624, \"mu_intercept_per_group\": -14.137105941772461, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 2, \"draws\": 625, \"mu_intercept_per_group\": -14.612154960632324, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 2, \"draws\": 626, \"mu_intercept_per_group\": -13.960301399230957, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 2, \"draws\": 627, \"mu_intercept_per_group\": -14.099410057067871, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 2, \"draws\": 628, \"mu_intercept_per_group\": -13.366686820983887, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 2, \"draws\": 629, \"mu_intercept_per_group\": -7.014652729034424, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 2, \"draws\": 630, \"mu_intercept_per_group\": -7.747760772705078, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 2, \"draws\": 631, \"mu_intercept_per_group\": -8.05859661102295, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 2, \"draws\": 632, \"mu_intercept_per_group\": -8.971078872680664, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 2, \"draws\": 633, \"mu_intercept_per_group\": -8.350561141967773, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 2, \"draws\": 634, \"mu_intercept_per_group\": -10.822115898132324, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 2, \"draws\": 635, \"mu_intercept_per_group\": -10.446824073791504, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 2, \"draws\": 636, \"mu_intercept_per_group\": -10.161876678466797, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 2, \"draws\": 637, \"mu_intercept_per_group\": -8.346480369567871, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 2, \"draws\": 638, \"mu_intercept_per_group\": -8.221733093261719, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 2, \"draws\": 639, \"mu_intercept_per_group\": -7.4953460693359375, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 3, \"draws\": 0, \"mu_intercept_per_group\": -4.4651947021484375, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 3, \"draws\": 1, \"mu_intercept_per_group\": -4.071032524108887, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 3, \"draws\": 2, \"mu_intercept_per_group\": -4.878485679626465, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 3, \"draws\": 3, \"mu_intercept_per_group\": -4.495409965515137, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 3, \"draws\": 4, \"mu_intercept_per_group\": -4.778892993927002, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 3, \"draws\": 5, \"mu_intercept_per_group\": -3.8636436462402344, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 3, \"draws\": 6, \"mu_intercept_per_group\": -4.732561111450195, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 3, \"draws\": 7, \"mu_intercept_per_group\": -4.077816963195801, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 3, \"draws\": 8, \"mu_intercept_per_group\": -3.7448761463165283, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 3, \"draws\": 9, \"mu_intercept_per_group\": -4.527496814727783, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 3, \"draws\": 10, \"mu_intercept_per_group\": -4.548728942871094, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 3, \"draws\": 11, \"mu_intercept_per_group\": -3.3851613998413086, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 3, \"draws\": 12, \"mu_intercept_per_group\": -6.2507758140563965, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 3, \"draws\": 13, \"mu_intercept_per_group\": -7.577321529388428, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 3, \"draws\": 14, \"mu_intercept_per_group\": -6.278017044067383, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 3, \"draws\": 15, \"mu_intercept_per_group\": -5.624145030975342, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 3, \"draws\": 16, \"mu_intercept_per_group\": -7.045640468597412, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 3, \"draws\": 17, \"mu_intercept_per_group\": -6.753748893737793, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 3, \"draws\": 18, \"mu_intercept_per_group\": -6.607899188995361, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 3, \"draws\": 19, \"mu_intercept_per_group\": -6.524211406707764, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 3, \"draws\": 20, \"mu_intercept_per_group\": -5.996279716491699, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 3, \"draws\": 21, \"mu_intercept_per_group\": -4.832637786865234, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 3, \"draws\": 22, \"mu_intercept_per_group\": -6.423463821411133, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 3, \"draws\": 23, \"mu_intercept_per_group\": -6.617916584014893, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 3, \"draws\": 24, \"mu_intercept_per_group\": -6.688039779663086, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 3, \"draws\": 25, \"mu_intercept_per_group\": -7.313354969024658, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 3, \"draws\": 26, \"mu_intercept_per_group\": -5.787234783172607, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 3, \"draws\": 27, \"mu_intercept_per_group\": -7.268190860748291, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 3, \"draws\": 28, \"mu_intercept_per_group\": -7.4051337242126465, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 3, \"draws\": 29, \"mu_intercept_per_group\": -8.752531051635742, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 3, \"draws\": 30, \"mu_intercept_per_group\": -7.847912788391113, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 3, \"draws\": 31, \"mu_intercept_per_group\": -8.558843612670898, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 3, \"draws\": 32, \"mu_intercept_per_group\": -5.585297107696533, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 3, \"draws\": 33, \"mu_intercept_per_group\": -7.092940330505371, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 3, \"draws\": 34, \"mu_intercept_per_group\": -7.2682271003723145, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 3, \"draws\": 35, \"mu_intercept_per_group\": -6.954495429992676, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 3, \"draws\": 36, \"mu_intercept_per_group\": -6.8048224449157715, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 3, \"draws\": 37, \"mu_intercept_per_group\": -7.040626049041748, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 3, \"draws\": 38, \"mu_intercept_per_group\": -5.6131463050842285, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 3, \"draws\": 39, \"mu_intercept_per_group\": -6.398091793060303, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 3, \"draws\": 40, \"mu_intercept_per_group\": -5.328056812286377, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 3, \"draws\": 41, \"mu_intercept_per_group\": -5.954373359680176, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 3, \"draws\": 42, \"mu_intercept_per_group\": -6.407882213592529, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 3, \"draws\": 43, \"mu_intercept_per_group\": -6.220874786376953, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 3, \"draws\": 44, \"mu_intercept_per_group\": -6.226785659790039, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 3, \"draws\": 45, \"mu_intercept_per_group\": -5.535874843597412, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 3, \"draws\": 46, \"mu_intercept_per_group\": -5.384990215301514, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 3, \"draws\": 47, \"mu_intercept_per_group\": -5.60226583480835, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 3, \"draws\": 48, \"mu_intercept_per_group\": -5.7768025398254395, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 3, \"draws\": 49, \"mu_intercept_per_group\": -6.769672870635986, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 3, \"draws\": 50, \"mu_intercept_per_group\": -3.6471774578094482, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 3, \"draws\": 51, \"mu_intercept_per_group\": -4.2124104499816895, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 3, \"draws\": 52, \"mu_intercept_per_group\": -2.531613349914551, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 3, \"draws\": 53, \"mu_intercept_per_group\": -2.9643988609313965, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 3, \"draws\": 54, \"mu_intercept_per_group\": -2.481722116470337, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 3, \"draws\": 55, \"mu_intercept_per_group\": -2.857008934020996, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 3, \"draws\": 56, \"mu_intercept_per_group\": -2.3027243614196777, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 3, \"draws\": 57, \"mu_intercept_per_group\": -2.369565963745117, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 3, \"draws\": 58, \"mu_intercept_per_group\": -2.1467344760894775, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 3, \"draws\": 59, \"mu_intercept_per_group\": -2.1540892124176025, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 3, \"draws\": 60, \"mu_intercept_per_group\": -2.3781323432922363, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 3, \"draws\": 61, \"mu_intercept_per_group\": -4.650877952575684, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 3, \"draws\": 62, \"mu_intercept_per_group\": -4.7508087158203125, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 3, \"draws\": 63, \"mu_intercept_per_group\": -4.603630065917969, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 3, \"draws\": 64, \"mu_intercept_per_group\": -4.141909122467041, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 3, \"draws\": 65, \"mu_intercept_per_group\": -4.706629753112793, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 3, \"draws\": 66, \"mu_intercept_per_group\": -4.546579360961914, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 3, \"draws\": 67, \"mu_intercept_per_group\": -4.705005168914795, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 3, \"draws\": 68, \"mu_intercept_per_group\": -4.543768882751465, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 3, \"draws\": 69, \"mu_intercept_per_group\": -4.5500807762146, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 3, \"draws\": 70, \"mu_intercept_per_group\": -3.425657272338867, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 3, \"draws\": 71, \"mu_intercept_per_group\": -2.453583002090454, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 3, \"draws\": 72, \"mu_intercept_per_group\": -2.401217222213745, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 3, \"draws\": 73, \"mu_intercept_per_group\": -2.5824670791625977, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 3, \"draws\": 74, \"mu_intercept_per_group\": -2.7619118690490723, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 3, \"draws\": 75, \"mu_intercept_per_group\": -3.1059117317199707, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 3, \"draws\": 76, \"mu_intercept_per_group\": -3.103563070297241, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 3, \"draws\": 77, \"mu_intercept_per_group\": -4.900404453277588, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 3, \"draws\": 78, \"mu_intercept_per_group\": -4.009464740753174, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 3, \"draws\": 79, \"mu_intercept_per_group\": -5.505279064178467, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 3, \"draws\": 80, \"mu_intercept_per_group\": -7.005808353424072, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 3, \"draws\": 81, \"mu_intercept_per_group\": -6.255640029907227, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 3, \"draws\": 82, \"mu_intercept_per_group\": -7.323478698730469, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 3, \"draws\": 83, \"mu_intercept_per_group\": -6.700334548950195, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 3, \"draws\": 84, \"mu_intercept_per_group\": -7.200850009918213, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 3, \"draws\": 85, \"mu_intercept_per_group\": -5.683073043823242, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 3, \"draws\": 86, \"mu_intercept_per_group\": -5.6137566566467285, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 3, \"draws\": 87, \"mu_intercept_per_group\": -4.254715442657471, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 3, \"draws\": 88, \"mu_intercept_per_group\": -4.335273742675781, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 3, \"draws\": 89, \"mu_intercept_per_group\": -5.090284824371338, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 3, \"draws\": 90, \"mu_intercept_per_group\": -5.8007283210754395, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 3, \"draws\": 91, \"mu_intercept_per_group\": -5.0847697257995605, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 3, \"draws\": 92, \"mu_intercept_per_group\": -5.251226425170898, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 3, \"draws\": 93, \"mu_intercept_per_group\": -5.472654342651367, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 3, \"draws\": 94, \"mu_intercept_per_group\": -5.4119038581848145, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 3, \"draws\": 95, \"mu_intercept_per_group\": -5.108021259307861, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 3, \"draws\": 96, \"mu_intercept_per_group\": -5.113678455352783, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 3, \"draws\": 97, \"mu_intercept_per_group\": -4.742451190948486, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 3, \"draws\": 98, \"mu_intercept_per_group\": -5.608653545379639, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 3, \"draws\": 99, \"mu_intercept_per_group\": -5.657304286956787, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 3, \"draws\": 100, \"mu_intercept_per_group\": -5.004990577697754, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 3, \"draws\": 101, \"mu_intercept_per_group\": -6.146199703216553, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 3, \"draws\": 102, \"mu_intercept_per_group\": -5.456408500671387, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 3, \"draws\": 103, \"mu_intercept_per_group\": -3.4926717281341553, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 3, \"draws\": 104, \"mu_intercept_per_group\": -4.152259349822998, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 3, \"draws\": 105, \"mu_intercept_per_group\": -4.634077548980713, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 3, \"draws\": 106, \"mu_intercept_per_group\": -5.980301380157471, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 3, \"draws\": 107, \"mu_intercept_per_group\": -5.953535556793213, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 3, \"draws\": 108, \"mu_intercept_per_group\": -5.683080196380615, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 3, \"draws\": 109, \"mu_intercept_per_group\": -8.457954406738281, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 3, \"draws\": 110, \"mu_intercept_per_group\": -7.343505382537842, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 3, \"draws\": 111, \"mu_intercept_per_group\": -6.680629730224609, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 3, \"draws\": 112, \"mu_intercept_per_group\": -7.830854892730713, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 3, \"draws\": 113, \"mu_intercept_per_group\": -7.475622177124023, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 3, \"draws\": 114, \"mu_intercept_per_group\": -7.479725360870361, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 3, \"draws\": 115, \"mu_intercept_per_group\": -7.275534152984619, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 3, \"draws\": 116, \"mu_intercept_per_group\": -6.3264007568359375, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 3, \"draws\": 117, \"mu_intercept_per_group\": -6.733271598815918, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 3, \"draws\": 118, \"mu_intercept_per_group\": -5.3663482666015625, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 3, \"draws\": 119, \"mu_intercept_per_group\": -6.757221221923828, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 3, \"draws\": 120, \"mu_intercept_per_group\": -7.079226016998291, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 3, \"draws\": 121, \"mu_intercept_per_group\": -7.052643775939941, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 3, \"draws\": 122, \"mu_intercept_per_group\": -7.670816421508789, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 3, \"draws\": 123, \"mu_intercept_per_group\": -7.831424713134766, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 3, \"draws\": 124, \"mu_intercept_per_group\": -5.673741340637207, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 3, \"draws\": 125, \"mu_intercept_per_group\": -5.2887115478515625, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 3, \"draws\": 126, \"mu_intercept_per_group\": -4.82011604309082, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 3, \"draws\": 127, \"mu_intercept_per_group\": -4.735052585601807, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 3, \"draws\": 128, \"mu_intercept_per_group\": -5.177676677703857, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 3, \"draws\": 129, \"mu_intercept_per_group\": -4.185025215148926, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 3, \"draws\": 130, \"mu_intercept_per_group\": -5.281758785247803, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 3, \"draws\": 131, \"mu_intercept_per_group\": -5.053088188171387, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 3, \"draws\": 132, \"mu_intercept_per_group\": -4.987194538116455, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 3, \"draws\": 133, \"mu_intercept_per_group\": -5.692770481109619, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 3, \"draws\": 134, \"mu_intercept_per_group\": -5.078647136688232, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 3, \"draws\": 135, \"mu_intercept_per_group\": -4.434950351715088, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 3, \"draws\": 136, \"mu_intercept_per_group\": -4.468170166015625, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 3, \"draws\": 137, \"mu_intercept_per_group\": -4.615714073181152, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 3, \"draws\": 138, \"mu_intercept_per_group\": -5.045149803161621, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 3, \"draws\": 139, \"mu_intercept_per_group\": -4.091817378997803, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 3, \"draws\": 140, \"mu_intercept_per_group\": -5.403796195983887, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 3, \"draws\": 141, \"mu_intercept_per_group\": -5.977889060974121, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 3, \"draws\": 142, \"mu_intercept_per_group\": -5.573631286621094, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 3, \"draws\": 143, \"mu_intercept_per_group\": -3.144230365753174, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 3, \"draws\": 144, \"mu_intercept_per_group\": -3.297851800918579, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 3, \"draws\": 145, \"mu_intercept_per_group\": -3.50142502784729, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 3, \"draws\": 146, \"mu_intercept_per_group\": -2.9383795261383057, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 3, \"draws\": 147, \"mu_intercept_per_group\": -3.321011543273926, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 3, \"draws\": 148, \"mu_intercept_per_group\": -4.739062786102295, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 3, \"draws\": 149, \"mu_intercept_per_group\": -5.362175464630127, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 3, \"draws\": 150, \"mu_intercept_per_group\": -5.294633388519287, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 3, \"draws\": 151, \"mu_intercept_per_group\": -5.487259387969971, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 3, \"draws\": 152, \"mu_intercept_per_group\": -3.8401553630828857, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 3, \"draws\": 153, \"mu_intercept_per_group\": -3.4172585010528564, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 3, \"draws\": 154, \"mu_intercept_per_group\": -3.7148146629333496, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 3, \"draws\": 155, \"mu_intercept_per_group\": -3.4519717693328857, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 3, \"draws\": 156, \"mu_intercept_per_group\": -4.468782901763916, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 3, \"draws\": 157, \"mu_intercept_per_group\": -3.7090020179748535, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 3, \"draws\": 158, \"mu_intercept_per_group\": -5.17562198638916, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 3, \"draws\": 159, \"mu_intercept_per_group\": -4.791464805603027, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 3, \"draws\": 160, \"mu_intercept_per_group\": -8.469317436218262, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 3, \"draws\": 161, \"mu_intercept_per_group\": -8.951935768127441, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 3, \"draws\": 162, \"mu_intercept_per_group\": -8.752230644226074, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 3, \"draws\": 163, \"mu_intercept_per_group\": -8.525711059570312, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 3, \"draws\": 164, \"mu_intercept_per_group\": -7.594056129455566, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 3, \"draws\": 165, \"mu_intercept_per_group\": -5.4420342445373535, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 3, \"draws\": 166, \"mu_intercept_per_group\": -11.442623138427734, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 3, \"draws\": 167, \"mu_intercept_per_group\": -7.05925989151001, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 3, \"draws\": 168, \"mu_intercept_per_group\": -9.009539604187012, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 3, \"draws\": 169, \"mu_intercept_per_group\": -8.0965576171875, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 3, \"draws\": 170, \"mu_intercept_per_group\": -8.548924446105957, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 3, \"draws\": 171, \"mu_intercept_per_group\": -7.576032638549805, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 3, \"draws\": 172, \"mu_intercept_per_group\": -8.297035217285156, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 3, \"draws\": 173, \"mu_intercept_per_group\": -8.929366111755371, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 3, \"draws\": 174, \"mu_intercept_per_group\": -7.948174476623535, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 3, \"draws\": 175, \"mu_intercept_per_group\": -8.475569725036621, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 3, \"draws\": 176, \"mu_intercept_per_group\": -8.841524124145508, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 3, \"draws\": 177, \"mu_intercept_per_group\": -7.693042278289795, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 3, \"draws\": 178, \"mu_intercept_per_group\": -8.059242248535156, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 3, \"draws\": 179, \"mu_intercept_per_group\": -3.7619149684906006, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 3, \"draws\": 180, \"mu_intercept_per_group\": -3.969062089920044, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 3, \"draws\": 181, \"mu_intercept_per_group\": -4.336879730224609, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 3, \"draws\": 182, \"mu_intercept_per_group\": -4.833128452301025, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 3, \"draws\": 183, \"mu_intercept_per_group\": -4.606860160827637, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 3, \"draws\": 184, \"mu_intercept_per_group\": -4.693568229675293, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 3, \"draws\": 185, \"mu_intercept_per_group\": -5.345755577087402, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 3, \"draws\": 186, \"mu_intercept_per_group\": -4.091735363006592, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 3, \"draws\": 187, \"mu_intercept_per_group\": -4.516643047332764, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 3, \"draws\": 188, \"mu_intercept_per_group\": -4.434087753295898, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 3, \"draws\": 189, \"mu_intercept_per_group\": -5.195588111877441, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 3, \"draws\": 190, \"mu_intercept_per_group\": -6.797750473022461, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 3, \"draws\": 191, \"mu_intercept_per_group\": -7.116320610046387, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 3, \"draws\": 192, \"mu_intercept_per_group\": -5.192755222320557, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 3, \"draws\": 193, \"mu_intercept_per_group\": -5.172474384307861, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 3, \"draws\": 194, \"mu_intercept_per_group\": -4.087462425231934, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 3, \"draws\": 195, \"mu_intercept_per_group\": -4.653280735015869, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 3, \"draws\": 196, \"mu_intercept_per_group\": -5.5943708419799805, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 3, \"draws\": 197, \"mu_intercept_per_group\": -5.343291282653809, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 3, \"draws\": 198, \"mu_intercept_per_group\": -4.048859596252441, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 3, \"draws\": 199, \"mu_intercept_per_group\": -4.82941198348999, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 3, \"draws\": 200, \"mu_intercept_per_group\": -4.736727237701416, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 3, \"draws\": 201, \"mu_intercept_per_group\": -5.886011123657227, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 3, \"draws\": 202, \"mu_intercept_per_group\": -4.211130142211914, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 3, \"draws\": 203, \"mu_intercept_per_group\": -4.9919352531433105, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 3, \"draws\": 204, \"mu_intercept_per_group\": -4.928150653839111, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 3, \"draws\": 205, \"mu_intercept_per_group\": -3.9328155517578125, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 3, \"draws\": 206, \"mu_intercept_per_group\": -4.747169017791748, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 3, \"draws\": 207, \"mu_intercept_per_group\": -5.454480171203613, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 3, \"draws\": 208, \"mu_intercept_per_group\": -5.448852062225342, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 3, \"draws\": 209, \"mu_intercept_per_group\": -5.141651153564453, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 3, \"draws\": 210, \"mu_intercept_per_group\": -5.015182018280029, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 3, \"draws\": 211, \"mu_intercept_per_group\": -5.151602268218994, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 3, \"draws\": 212, \"mu_intercept_per_group\": -5.232419013977051, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 3, \"draws\": 213, \"mu_intercept_per_group\": -3.1104226112365723, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 3, \"draws\": 214, \"mu_intercept_per_group\": -3.852212905883789, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 3, \"draws\": 215, \"mu_intercept_per_group\": -3.480557918548584, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 3, \"draws\": 216, \"mu_intercept_per_group\": -3.2880685329437256, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 3, \"draws\": 217, \"mu_intercept_per_group\": -4.155666351318359, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 3, \"draws\": 218, \"mu_intercept_per_group\": -3.9214439392089844, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 3, \"draws\": 219, \"mu_intercept_per_group\": -3.0718629360198975, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 3, \"draws\": 220, \"mu_intercept_per_group\": -4.028192043304443, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 3, \"draws\": 221, \"mu_intercept_per_group\": -4.15199613571167, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 3, \"draws\": 222, \"mu_intercept_per_group\": -3.8369364738464355, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 3, \"draws\": 223, \"mu_intercept_per_group\": -3.7850348949432373, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 3, \"draws\": 224, \"mu_intercept_per_group\": -3.7293596267700195, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 3, \"draws\": 225, \"mu_intercept_per_group\": -4.001599311828613, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 3, \"draws\": 226, \"mu_intercept_per_group\": -3.771817922592163, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 3, \"draws\": 227, \"mu_intercept_per_group\": -4.2409281730651855, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 3, \"draws\": 228, \"mu_intercept_per_group\": -3.376891613006592, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 3, \"draws\": 229, \"mu_intercept_per_group\": -3.2043914794921875, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 3, \"draws\": 230, \"mu_intercept_per_group\": -3.917228937149048, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 3, \"draws\": 231, \"mu_intercept_per_group\": -3.683015823364258, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 3, \"draws\": 232, \"mu_intercept_per_group\": -3.3007078170776367, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 3, \"draws\": 233, \"mu_intercept_per_group\": -3.756033420562744, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 3, \"draws\": 234, \"mu_intercept_per_group\": -3.5576651096343994, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 3, \"draws\": 235, \"mu_intercept_per_group\": -3.608534812927246, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 3, \"draws\": 236, \"mu_intercept_per_group\": -2.9610366821289062, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 3, \"draws\": 237, \"mu_intercept_per_group\": -3.5294759273529053, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 3, \"draws\": 238, \"mu_intercept_per_group\": -3.6959989070892334, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 3, \"draws\": 239, \"mu_intercept_per_group\": -3.4683854579925537, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 3, \"draws\": 240, \"mu_intercept_per_group\": -3.475247383117676, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 3, \"draws\": 241, \"mu_intercept_per_group\": -3.73671293258667, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 3, \"draws\": 242, \"mu_intercept_per_group\": -3.441636562347412, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 3, \"draws\": 243, \"mu_intercept_per_group\": -4.364984512329102, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 3, \"draws\": 244, \"mu_intercept_per_group\": -5.160479545593262, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 3, \"draws\": 245, \"mu_intercept_per_group\": -4.852465629577637, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 3, \"draws\": 246, \"mu_intercept_per_group\": -4.386254787445068, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 3, \"draws\": 247, \"mu_intercept_per_group\": -4.661422252655029, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 3, \"draws\": 248, \"mu_intercept_per_group\": -4.219639301300049, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 3, \"draws\": 249, \"mu_intercept_per_group\": -2.8732542991638184, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 3, \"draws\": 250, \"mu_intercept_per_group\": -4.018141746520996, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 3, \"draws\": 251, \"mu_intercept_per_group\": -3.6744465827941895, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 3, \"draws\": 252, \"mu_intercept_per_group\": -4.111606597900391, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 3, \"draws\": 253, \"mu_intercept_per_group\": -4.165467739105225, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 3, \"draws\": 254, \"mu_intercept_per_group\": -3.509472608566284, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 3, \"draws\": 255, \"mu_intercept_per_group\": -3.3874385356903076, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 3, \"draws\": 256, \"mu_intercept_per_group\": -5.2424235343933105, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 3, \"draws\": 257, \"mu_intercept_per_group\": -4.875796318054199, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 3, \"draws\": 258, \"mu_intercept_per_group\": -4.0063581466674805, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 3, \"draws\": 259, \"mu_intercept_per_group\": -3.840270757675171, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 3, \"draws\": 260, \"mu_intercept_per_group\": -4.166221618652344, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 3, \"draws\": 261, \"mu_intercept_per_group\": -3.791804313659668, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 3, \"draws\": 262, \"mu_intercept_per_group\": -3.3116302490234375, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 3, \"draws\": 263, \"mu_intercept_per_group\": -3.767601728439331, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 3, \"draws\": 264, \"mu_intercept_per_group\": -4.398008346557617, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 3, \"draws\": 265, \"mu_intercept_per_group\": -4.605267524719238, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 3, \"draws\": 266, \"mu_intercept_per_group\": -3.2276647090911865, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 3, \"draws\": 267, \"mu_intercept_per_group\": -3.4993104934692383, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 3, \"draws\": 268, \"mu_intercept_per_group\": -2.5941312313079834, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 3, \"draws\": 269, \"mu_intercept_per_group\": -8.700529098510742, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 3, \"draws\": 270, \"mu_intercept_per_group\": -6.00996732711792, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 3, \"draws\": 271, \"mu_intercept_per_group\": -6.587067604064941, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 3, \"draws\": 272, \"mu_intercept_per_group\": -5.673789978027344, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 3, \"draws\": 273, \"mu_intercept_per_group\": -6.77787446975708, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 3, \"draws\": 274, \"mu_intercept_per_group\": -6.601485252380371, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 3, \"draws\": 275, \"mu_intercept_per_group\": -7.057787895202637, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 3, \"draws\": 276, \"mu_intercept_per_group\": -7.349900722503662, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 3, \"draws\": 277, \"mu_intercept_per_group\": -5.885043144226074, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 3, \"draws\": 278, \"mu_intercept_per_group\": -5.862990856170654, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 3, \"draws\": 279, \"mu_intercept_per_group\": -6.146670341491699, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 3, \"draws\": 280, \"mu_intercept_per_group\": -6.463149547576904, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 3, \"draws\": 281, \"mu_intercept_per_group\": -6.034718990325928, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 3, \"draws\": 282, \"mu_intercept_per_group\": -7.240029811859131, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 3, \"draws\": 283, \"mu_intercept_per_group\": -7.270077705383301, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 3, \"draws\": 284, \"mu_intercept_per_group\": -6.3339433670043945, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 3, \"draws\": 285, \"mu_intercept_per_group\": -6.072902202606201, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 3, \"draws\": 286, \"mu_intercept_per_group\": -7.342334747314453, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 3, \"draws\": 287, \"mu_intercept_per_group\": -7.594297885894775, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 3, \"draws\": 288, \"mu_intercept_per_group\": -7.503993034362793, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 3, \"draws\": 289, \"mu_intercept_per_group\": -7.999755859375, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 3, \"draws\": 290, \"mu_intercept_per_group\": -6.995380878448486, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 3, \"draws\": 291, \"mu_intercept_per_group\": -6.451685428619385, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 3, \"draws\": 292, \"mu_intercept_per_group\": -6.3102898597717285, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 3, \"draws\": 293, \"mu_intercept_per_group\": -6.024908542633057, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 3, \"draws\": 294, \"mu_intercept_per_group\": -5.531137943267822, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 3, \"draws\": 295, \"mu_intercept_per_group\": -4.802505970001221, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 3, \"draws\": 296, \"mu_intercept_per_group\": -4.660428047180176, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 3, \"draws\": 297, \"mu_intercept_per_group\": -3.46517014503479, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 3, \"draws\": 298, \"mu_intercept_per_group\": -4.236396789550781, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 3, \"draws\": 299, \"mu_intercept_per_group\": -4.348811149597168, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 3, \"draws\": 300, \"mu_intercept_per_group\": -4.817853927612305, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 3, \"draws\": 301, \"mu_intercept_per_group\": -4.66499137878418, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 3, \"draws\": 302, \"mu_intercept_per_group\": -4.789389610290527, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 3, \"draws\": 303, \"mu_intercept_per_group\": -5.150897026062012, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 3, \"draws\": 304, \"mu_intercept_per_group\": -4.222580909729004, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 3, \"draws\": 305, \"mu_intercept_per_group\": -4.473111152648926, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 3, \"draws\": 306, \"mu_intercept_per_group\": -4.082411766052246, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 3, \"draws\": 307, \"mu_intercept_per_group\": -4.620270729064941, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 3, \"draws\": 308, \"mu_intercept_per_group\": -4.000030040740967, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 3, \"draws\": 309, \"mu_intercept_per_group\": -6.269591808319092, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 3, \"draws\": 310, \"mu_intercept_per_group\": -6.80250358581543, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 3, \"draws\": 311, \"mu_intercept_per_group\": -6.0629472732543945, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 3, \"draws\": 312, \"mu_intercept_per_group\": -6.364255428314209, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 3, \"draws\": 313, \"mu_intercept_per_group\": -7.006587982177734, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 3, \"draws\": 314, \"mu_intercept_per_group\": -4.763122081756592, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 3, \"draws\": 315, \"mu_intercept_per_group\": -4.742313385009766, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 3, \"draws\": 316, \"mu_intercept_per_group\": -6.326752662658691, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 3, \"draws\": 317, \"mu_intercept_per_group\": -6.503209114074707, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 3, \"draws\": 318, \"mu_intercept_per_group\": -6.400110244750977, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 3, \"draws\": 319, \"mu_intercept_per_group\": -6.574813365936279, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 3, \"draws\": 320, \"mu_intercept_per_group\": -2.554067373275757, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 3, \"draws\": 321, \"mu_intercept_per_group\": -1.9594141244888306, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 3, \"draws\": 322, \"mu_intercept_per_group\": -2.626640558242798, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 3, \"draws\": 323, \"mu_intercept_per_group\": -2.1319119930267334, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 3, \"draws\": 324, \"mu_intercept_per_group\": -3.72029185295105, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 3, \"draws\": 325, \"mu_intercept_per_group\": -3.5649983882904053, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 3, \"draws\": 326, \"mu_intercept_per_group\": -3.8354148864746094, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 3, \"draws\": 327, \"mu_intercept_per_group\": -3.3434596061706543, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 3, \"draws\": 328, \"mu_intercept_per_group\": -4.069168567657471, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 3, \"draws\": 329, \"mu_intercept_per_group\": -4.230885028839111, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 3, \"draws\": 330, \"mu_intercept_per_group\": -4.287948131561279, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 3, \"draws\": 331, \"mu_intercept_per_group\": -4.548680305480957, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 3, \"draws\": 332, \"mu_intercept_per_group\": -4.4285149574279785, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 3, \"draws\": 333, \"mu_intercept_per_group\": -4.72823429107666, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 3, \"draws\": 334, \"mu_intercept_per_group\": -4.634169101715088, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 3, \"draws\": 335, \"mu_intercept_per_group\": -4.29194974899292, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 3, \"draws\": 336, \"mu_intercept_per_group\": -4.360034465789795, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 3, \"draws\": 337, \"mu_intercept_per_group\": -4.511038780212402, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 3, \"draws\": 338, \"mu_intercept_per_group\": -7.288619041442871, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 3, \"draws\": 339, \"mu_intercept_per_group\": -7.369436740875244, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 3, \"draws\": 340, \"mu_intercept_per_group\": -6.983633041381836, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 3, \"draws\": 341, \"mu_intercept_per_group\": -5.9416890144348145, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 3, \"draws\": 342, \"mu_intercept_per_group\": -5.42965841293335, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 3, \"draws\": 343, \"mu_intercept_per_group\": -5.640103340148926, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 3, \"draws\": 344, \"mu_intercept_per_group\": -7.137578010559082, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 3, \"draws\": 345, \"mu_intercept_per_group\": -10.397228240966797, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 3, \"draws\": 346, \"mu_intercept_per_group\": -5.313264846801758, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 3, \"draws\": 347, \"mu_intercept_per_group\": -4.296082496643066, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 3, \"draws\": 348, \"mu_intercept_per_group\": -4.797342300415039, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 3, \"draws\": 349, \"mu_intercept_per_group\": -5.18768835067749, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 3, \"draws\": 350, \"mu_intercept_per_group\": -6.084588527679443, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 3, \"draws\": 351, \"mu_intercept_per_group\": -5.776798248291016, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 3, \"draws\": 352, \"mu_intercept_per_group\": -6.369850158691406, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 3, \"draws\": 353, \"mu_intercept_per_group\": -6.9111247062683105, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 3, \"draws\": 354, \"mu_intercept_per_group\": -4.479602813720703, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 3, \"draws\": 355, \"mu_intercept_per_group\": -3.8752877712249756, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 3, \"draws\": 356, \"mu_intercept_per_group\": -4.473843574523926, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 3, \"draws\": 357, \"mu_intercept_per_group\": -4.335937023162842, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 3, \"draws\": 358, \"mu_intercept_per_group\": -4.242465972900391, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 3, \"draws\": 359, \"mu_intercept_per_group\": -3.667379856109619, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 3, \"draws\": 360, \"mu_intercept_per_group\": -4.132870674133301, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 3, \"draws\": 361, \"mu_intercept_per_group\": -3.9678637981414795, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 3, \"draws\": 362, \"mu_intercept_per_group\": -4.754471778869629, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 3, \"draws\": 363, \"mu_intercept_per_group\": -4.793647289276123, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 3, \"draws\": 364, \"mu_intercept_per_group\": -5.408947467803955, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 3, \"draws\": 365, \"mu_intercept_per_group\": -5.492337703704834, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 3, \"draws\": 366, \"mu_intercept_per_group\": -5.385361671447754, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 3, \"draws\": 367, \"mu_intercept_per_group\": -5.552547454833984, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 3, \"draws\": 368, \"mu_intercept_per_group\": -6.60469388961792, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 3, \"draws\": 369, \"mu_intercept_per_group\": -2.847346305847168, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 3, \"draws\": 370, \"mu_intercept_per_group\": -3.1153645515441895, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 3, \"draws\": 371, \"mu_intercept_per_group\": -3.0109503269195557, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 3, \"draws\": 372, \"mu_intercept_per_group\": -3.448930025100708, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 3, \"draws\": 373, \"mu_intercept_per_group\": -3.5146026611328125, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 3, \"draws\": 374, \"mu_intercept_per_group\": -3.773453950881958, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 3, \"draws\": 375, \"mu_intercept_per_group\": -4.4434027671813965, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 3, \"draws\": 376, \"mu_intercept_per_group\": -5.845037937164307, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 3, \"draws\": 377, \"mu_intercept_per_group\": -3.3439273834228516, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 3, \"draws\": 378, \"mu_intercept_per_group\": -3.5143988132476807, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 3, \"draws\": 379, \"mu_intercept_per_group\": -3.529521942138672, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 3, \"draws\": 380, \"mu_intercept_per_group\": -3.46156644821167, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 3, \"draws\": 381, \"mu_intercept_per_group\": -4.211008548736572, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 3, \"draws\": 382, \"mu_intercept_per_group\": -2.815542459487915, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 3, \"draws\": 383, \"mu_intercept_per_group\": -3.5889859199523926, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 3, \"draws\": 384, \"mu_intercept_per_group\": -6.4818925857543945, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 3, \"draws\": 385, \"mu_intercept_per_group\": -6.270923137664795, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 3, \"draws\": 386, \"mu_intercept_per_group\": -5.858028888702393, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 3, \"draws\": 387, \"mu_intercept_per_group\": -6.083117961883545, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 3, \"draws\": 388, \"mu_intercept_per_group\": -6.2024126052856445, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 3, \"draws\": 389, \"mu_intercept_per_group\": -5.751458644866943, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 3, \"draws\": 390, \"mu_intercept_per_group\": -5.70267391204834, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 3, \"draws\": 391, \"mu_intercept_per_group\": -6.360776901245117, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 3, \"draws\": 392, \"mu_intercept_per_group\": -5.672219276428223, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 3, \"draws\": 393, \"mu_intercept_per_group\": -5.162337303161621, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 3, \"draws\": 394, \"mu_intercept_per_group\": -4.87339973449707, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 3, \"draws\": 395, \"mu_intercept_per_group\": -5.855421543121338, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 3, \"draws\": 396, \"mu_intercept_per_group\": -5.377645015716553, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 3, \"draws\": 397, \"mu_intercept_per_group\": -5.572293758392334, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 3, \"draws\": 398, \"mu_intercept_per_group\": -5.058868885040283, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 3, \"draws\": 399, \"mu_intercept_per_group\": -4.13148832321167, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 3, \"draws\": 400, \"mu_intercept_per_group\": -4.470322608947754, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 3, \"draws\": 401, \"mu_intercept_per_group\": -5.044578552246094, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 3, \"draws\": 402, \"mu_intercept_per_group\": -5.050568103790283, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 3, \"draws\": 403, \"mu_intercept_per_group\": -3.8862462043762207, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 3, \"draws\": 404, \"mu_intercept_per_group\": -5.687005519866943, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 3, \"draws\": 405, \"mu_intercept_per_group\": -5.778645038604736, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 3, \"draws\": 406, \"mu_intercept_per_group\": -5.130939960479736, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 3, \"draws\": 407, \"mu_intercept_per_group\": -4.4524617195129395, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 3, \"draws\": 408, \"mu_intercept_per_group\": -4.798315525054932, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 3, \"draws\": 409, \"mu_intercept_per_group\": -4.788690567016602, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 3, \"draws\": 410, \"mu_intercept_per_group\": -4.805228233337402, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 3, \"draws\": 411, \"mu_intercept_per_group\": -3.708239793777466, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 3, \"draws\": 412, \"mu_intercept_per_group\": -4.496054172515869, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 3, \"draws\": 413, \"mu_intercept_per_group\": -6.2481303215026855, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 3, \"draws\": 414, \"mu_intercept_per_group\": -6.208493232727051, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 3, \"draws\": 415, \"mu_intercept_per_group\": -5.638308048248291, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 3, \"draws\": 416, \"mu_intercept_per_group\": -6.6094889640808105, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 3, \"draws\": 417, \"mu_intercept_per_group\": -5.940882682800293, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 3, \"draws\": 418, \"mu_intercept_per_group\": -4.870668411254883, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 3, \"draws\": 419, \"mu_intercept_per_group\": -5.392248153686523, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 3, \"draws\": 420, \"mu_intercept_per_group\": -4.93410062789917, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 3, \"draws\": 421, \"mu_intercept_per_group\": -5.3558454513549805, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 3, \"draws\": 422, \"mu_intercept_per_group\": -5.8303117752075195, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 3, \"draws\": 423, \"mu_intercept_per_group\": -4.998587131500244, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 3, \"draws\": 424, \"mu_intercept_per_group\": -5.831279277801514, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 3, \"draws\": 425, \"mu_intercept_per_group\": -5.6341962814331055, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 3, \"draws\": 426, \"mu_intercept_per_group\": -5.602822303771973, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 3, \"draws\": 427, \"mu_intercept_per_group\": -5.743920803070068, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 3, \"draws\": 428, \"mu_intercept_per_group\": -6.048460960388184, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 3, \"draws\": 429, \"mu_intercept_per_group\": -6.953797817230225, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 3, \"draws\": 430, \"mu_intercept_per_group\": -7.3769378662109375, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 3, \"draws\": 431, \"mu_intercept_per_group\": -6.297316551208496, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 3, \"draws\": 432, \"mu_intercept_per_group\": -5.606019496917725, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 3, \"draws\": 433, \"mu_intercept_per_group\": -6.783804416656494, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 3, \"draws\": 434, \"mu_intercept_per_group\": -5.462093353271484, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 3, \"draws\": 435, \"mu_intercept_per_group\": -5.811466693878174, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 3, \"draws\": 436, \"mu_intercept_per_group\": -5.856975555419922, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 3, \"draws\": 437, \"mu_intercept_per_group\": -7.0012030601501465, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 3, \"draws\": 438, \"mu_intercept_per_group\": -6.664778232574463, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 3, \"draws\": 439, \"mu_intercept_per_group\": -5.5683722496032715, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 3, \"draws\": 440, \"mu_intercept_per_group\": -5.612614154815674, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 3, \"draws\": 441, \"mu_intercept_per_group\": -5.096993446350098, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 3, \"draws\": 442, \"mu_intercept_per_group\": -7.468817710876465, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 3, \"draws\": 443, \"mu_intercept_per_group\": -8.645752906799316, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 3, \"draws\": 444, \"mu_intercept_per_group\": -9.103045463562012, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 3, \"draws\": 445, \"mu_intercept_per_group\": -6.341405391693115, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 3, \"draws\": 446, \"mu_intercept_per_group\": -4.796304702758789, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 3, \"draws\": 447, \"mu_intercept_per_group\": -5.666258811950684, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 3, \"draws\": 448, \"mu_intercept_per_group\": -3.9581050872802734, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 3, \"draws\": 449, \"mu_intercept_per_group\": -3.8193132877349854, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 3, \"draws\": 450, \"mu_intercept_per_group\": -5.151919841766357, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 3, \"draws\": 451, \"mu_intercept_per_group\": -9.32603931427002, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 3, \"draws\": 452, \"mu_intercept_per_group\": -6.951363563537598, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 3, \"draws\": 453, \"mu_intercept_per_group\": -12.172569274902344, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 3, \"draws\": 454, \"mu_intercept_per_group\": -9.620279312133789, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 3, \"draws\": 455, \"mu_intercept_per_group\": -9.069825172424316, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 3, \"draws\": 456, \"mu_intercept_per_group\": -10.371658325195312, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 3, \"draws\": 457, \"mu_intercept_per_group\": -10.157044410705566, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 3, \"draws\": 458, \"mu_intercept_per_group\": -8.461028099060059, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 3, \"draws\": 459, \"mu_intercept_per_group\": -5.2941179275512695, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 3, \"draws\": 460, \"mu_intercept_per_group\": -5.488392353057861, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 3, \"draws\": 461, \"mu_intercept_per_group\": -5.164551734924316, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 3, \"draws\": 462, \"mu_intercept_per_group\": -3.824673891067505, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 3, \"draws\": 463, \"mu_intercept_per_group\": -3.709726572036743, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 3, \"draws\": 464, \"mu_intercept_per_group\": -4.032395362854004, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 3, \"draws\": 465, \"mu_intercept_per_group\": -4.077763557434082, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 3, \"draws\": 466, \"mu_intercept_per_group\": -4.130234718322754, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 3, \"draws\": 467, \"mu_intercept_per_group\": -4.836045742034912, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 3, \"draws\": 468, \"mu_intercept_per_group\": -4.883211612701416, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 3, \"draws\": 469, \"mu_intercept_per_group\": -4.449584484100342, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 3, \"draws\": 470, \"mu_intercept_per_group\": -4.417517185211182, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 3, \"draws\": 471, \"mu_intercept_per_group\": -5.168157577514648, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 3, \"draws\": 472, \"mu_intercept_per_group\": -5.363668441772461, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 3, \"draws\": 473, \"mu_intercept_per_group\": -7.311577796936035, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 3, \"draws\": 474, \"mu_intercept_per_group\": -7.1391448974609375, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 3, \"draws\": 475, \"mu_intercept_per_group\": -7.777771949768066, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 3, \"draws\": 476, \"mu_intercept_per_group\": -7.579893589019775, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 3, \"draws\": 477, \"mu_intercept_per_group\": -7.161425590515137, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 3, \"draws\": 478, \"mu_intercept_per_group\": -7.199687957763672, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 3, \"draws\": 479, \"mu_intercept_per_group\": -7.910067081451416, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 3, \"draws\": 480, \"mu_intercept_per_group\": -6.49989128112793, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 3, \"draws\": 481, \"mu_intercept_per_group\": -6.26507568359375, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 3, \"draws\": 482, \"mu_intercept_per_group\": -6.267812728881836, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 3, \"draws\": 483, \"mu_intercept_per_group\": -6.0630903244018555, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 3, \"draws\": 484, \"mu_intercept_per_group\": -4.299042224884033, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 3, \"draws\": 485, \"mu_intercept_per_group\": -5.233388423919678, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 3, \"draws\": 486, \"mu_intercept_per_group\": -5.236589431762695, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 3, \"draws\": 487, \"mu_intercept_per_group\": -4.967183589935303, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 3, \"draws\": 488, \"mu_intercept_per_group\": -4.1031174659729, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 3, \"draws\": 489, \"mu_intercept_per_group\": -4.816502571105957, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 3, \"draws\": 490, \"mu_intercept_per_group\": -4.26674222946167, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 3, \"draws\": 491, \"mu_intercept_per_group\": -4.637521743774414, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 3, \"draws\": 492, \"mu_intercept_per_group\": -4.783592224121094, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 3, \"draws\": 493, \"mu_intercept_per_group\": -3.6830286979675293, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 3, \"draws\": 494, \"mu_intercept_per_group\": -6.446967601776123, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 3, \"draws\": 495, \"mu_intercept_per_group\": -5.9991230964660645, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 3, \"draws\": 496, \"mu_intercept_per_group\": -5.274527072906494, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 3, \"draws\": 497, \"mu_intercept_per_group\": -5.592042922973633, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 3, \"draws\": 498, \"mu_intercept_per_group\": -5.668954372406006, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 3, \"draws\": 499, \"mu_intercept_per_group\": -5.521432876586914, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 3, \"draws\": 500, \"mu_intercept_per_group\": -5.4170002937316895, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 3, \"draws\": 501, \"mu_intercept_per_group\": -7.1148152351379395, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 3, \"draws\": 502, \"mu_intercept_per_group\": -6.796136379241943, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 3, \"draws\": 503, \"mu_intercept_per_group\": -6.508797645568848, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 3, \"draws\": 504, \"mu_intercept_per_group\": -5.995060920715332, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 3, \"draws\": 505, \"mu_intercept_per_group\": -6.6115875244140625, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 3, \"draws\": 506, \"mu_intercept_per_group\": -5.552478790283203, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 3, \"draws\": 507, \"mu_intercept_per_group\": -4.320967197418213, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 3, \"draws\": 508, \"mu_intercept_per_group\": -6.113180160522461, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 3, \"draws\": 509, \"mu_intercept_per_group\": -6.288466930389404, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 3, \"draws\": 510, \"mu_intercept_per_group\": -5.017216682434082, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 3, \"draws\": 511, \"mu_intercept_per_group\": -9.61325740814209, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 3, \"draws\": 512, \"mu_intercept_per_group\": -7.690115451812744, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 3, \"draws\": 513, \"mu_intercept_per_group\": -7.30750846862793, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 3, \"draws\": 514, \"mu_intercept_per_group\": -6.420309543609619, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 3, \"draws\": 515, \"mu_intercept_per_group\": -6.748944282531738, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 3, \"draws\": 516, \"mu_intercept_per_group\": -6.273843765258789, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 3, \"draws\": 517, \"mu_intercept_per_group\": -6.1579413414001465, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 3, \"draws\": 518, \"mu_intercept_per_group\": -6.24082612991333, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 3, \"draws\": 519, \"mu_intercept_per_group\": -6.266751766204834, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 3, \"draws\": 520, \"mu_intercept_per_group\": -5.317060470581055, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 3, \"draws\": 521, \"mu_intercept_per_group\": -4.2370734214782715, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 3, \"draws\": 522, \"mu_intercept_per_group\": -4.830300331115723, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 3, \"draws\": 523, \"mu_intercept_per_group\": -4.441035747528076, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 3, \"draws\": 524, \"mu_intercept_per_group\": -3.520125389099121, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 3, \"draws\": 525, \"mu_intercept_per_group\": -3.9427051544189453, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 3, \"draws\": 526, \"mu_intercept_per_group\": -4.164914608001709, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 3, \"draws\": 527, \"mu_intercept_per_group\": -4.633415699005127, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 3, \"draws\": 528, \"mu_intercept_per_group\": -5.012077331542969, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 3, \"draws\": 529, \"mu_intercept_per_group\": -5.577658176422119, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 3, \"draws\": 530, \"mu_intercept_per_group\": -3.8646767139434814, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 3, \"draws\": 531, \"mu_intercept_per_group\": -4.515129089355469, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 3, \"draws\": 532, \"mu_intercept_per_group\": -5.002838611602783, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 3, \"draws\": 533, \"mu_intercept_per_group\": -5.152456283569336, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 3, \"draws\": 534, \"mu_intercept_per_group\": -5.427723407745361, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 3, \"draws\": 535, \"mu_intercept_per_group\": -5.226616859436035, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 3, \"draws\": 536, \"mu_intercept_per_group\": -5.29499626159668, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 3, \"draws\": 537, \"mu_intercept_per_group\": -3.3291478157043457, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 3, \"draws\": 538, \"mu_intercept_per_group\": -3.8070168495178223, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 3, \"draws\": 539, \"mu_intercept_per_group\": -3.4469172954559326, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 3, \"draws\": 540, \"mu_intercept_per_group\": -4.125557899475098, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 3, \"draws\": 541, \"mu_intercept_per_group\": -4.617308139801025, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 3, \"draws\": 542, \"mu_intercept_per_group\": -4.619353294372559, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 3, \"draws\": 543, \"mu_intercept_per_group\": -4.595637321472168, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 3, \"draws\": 544, \"mu_intercept_per_group\": -5.592173099517822, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 3, \"draws\": 545, \"mu_intercept_per_group\": -6.122406005859375, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 3, \"draws\": 546, \"mu_intercept_per_group\": -5.069957256317139, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 3, \"draws\": 547, \"mu_intercept_per_group\": -6.05607271194458, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 3, \"draws\": 548, \"mu_intercept_per_group\": -6.322469234466553, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 3, \"draws\": 549, \"mu_intercept_per_group\": -6.183130264282227, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 3, \"draws\": 550, \"mu_intercept_per_group\": -6.353452682495117, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 3, \"draws\": 551, \"mu_intercept_per_group\": -6.412219047546387, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 3, \"draws\": 552, \"mu_intercept_per_group\": -6.161712646484375, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 3, \"draws\": 553, \"mu_intercept_per_group\": -6.204931735992432, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 3, \"draws\": 554, \"mu_intercept_per_group\": -6.2284321784973145, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 3, \"draws\": 555, \"mu_intercept_per_group\": -6.438796520233154, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 3, \"draws\": 556, \"mu_intercept_per_group\": -5.868676662445068, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 3, \"draws\": 557, \"mu_intercept_per_group\": -7.194488048553467, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 3, \"draws\": 558, \"mu_intercept_per_group\": -5.932461261749268, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 3, \"draws\": 559, \"mu_intercept_per_group\": -6.6272172927856445, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 3, \"draws\": 560, \"mu_intercept_per_group\": -6.1236042976379395, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 3, \"draws\": 561, \"mu_intercept_per_group\": -5.268127918243408, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 3, \"draws\": 562, \"mu_intercept_per_group\": -6.21993350982666, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 3, \"draws\": 563, \"mu_intercept_per_group\": -6.140072822570801, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 3, \"draws\": 564, \"mu_intercept_per_group\": -4.146174430847168, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 3, \"draws\": 565, \"mu_intercept_per_group\": -4.991800785064697, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 3, \"draws\": 566, \"mu_intercept_per_group\": -5.379293441772461, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 3, \"draws\": 567, \"mu_intercept_per_group\": -4.453949451446533, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 3, \"draws\": 568, \"mu_intercept_per_group\": -4.017897129058838, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 3, \"draws\": 569, \"mu_intercept_per_group\": -3.918119192123413, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 3, \"draws\": 570, \"mu_intercept_per_group\": -4.097125053405762, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 3, \"draws\": 571, \"mu_intercept_per_group\": -4.330342769622803, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 3, \"draws\": 572, \"mu_intercept_per_group\": -4.840630531311035, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 3, \"draws\": 573, \"mu_intercept_per_group\": -6.543200969696045, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 3, \"draws\": 574, \"mu_intercept_per_group\": -6.119840621948242, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 3, \"draws\": 575, \"mu_intercept_per_group\": -6.264693737030029, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 3, \"draws\": 576, \"mu_intercept_per_group\": -6.909795761108398, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 3, \"draws\": 577, \"mu_intercept_per_group\": -7.568028926849365, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 3, \"draws\": 578, \"mu_intercept_per_group\": -7.527130126953125, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 3, \"draws\": 579, \"mu_intercept_per_group\": -8.825040817260742, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 3, \"draws\": 580, \"mu_intercept_per_group\": -7.597271919250488, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 3, \"draws\": 581, \"mu_intercept_per_group\": -6.911983966827393, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 3, \"draws\": 582, \"mu_intercept_per_group\": -6.568662643432617, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 3, \"draws\": 583, \"mu_intercept_per_group\": -6.650530815124512, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 3, \"draws\": 584, \"mu_intercept_per_group\": -6.667719841003418, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 3, \"draws\": 585, \"mu_intercept_per_group\": -8.108125686645508, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 3, \"draws\": 586, \"mu_intercept_per_group\": -8.893248558044434, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 3, \"draws\": 587, \"mu_intercept_per_group\": -8.63908576965332, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 3, \"draws\": 588, \"mu_intercept_per_group\": -8.130635261535645, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 3, \"draws\": 589, \"mu_intercept_per_group\": -8.704039573669434, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 3, \"draws\": 590, \"mu_intercept_per_group\": -8.556929588317871, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 3, \"draws\": 591, \"mu_intercept_per_group\": -8.520505905151367, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 3, \"draws\": 592, \"mu_intercept_per_group\": -8.32738971710205, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 3, \"draws\": 593, \"mu_intercept_per_group\": -10.016140937805176, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 3, \"draws\": 594, \"mu_intercept_per_group\": -7.751852512359619, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 3, \"draws\": 595, \"mu_intercept_per_group\": -9.002931594848633, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 3, \"draws\": 596, \"mu_intercept_per_group\": -7.567327976226807, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 3, \"draws\": 597, \"mu_intercept_per_group\": -8.434462547302246, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 3, \"draws\": 598, \"mu_intercept_per_group\": -9.005170822143555, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 3, \"draws\": 599, \"mu_intercept_per_group\": -10.244596481323242, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 3, \"draws\": 600, \"mu_intercept_per_group\": -9.000879287719727, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 3, \"draws\": 601, \"mu_intercept_per_group\": -10.177730560302734, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 3, \"draws\": 602, \"mu_intercept_per_group\": -8.664528846740723, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 3, \"draws\": 603, \"mu_intercept_per_group\": -8.363438606262207, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 3, \"draws\": 604, \"mu_intercept_per_group\": -8.822105407714844, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 3, \"draws\": 605, \"mu_intercept_per_group\": -8.257913589477539, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 3, \"draws\": 606, \"mu_intercept_per_group\": -8.396563529968262, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 3, \"draws\": 607, \"mu_intercept_per_group\": -8.717286109924316, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 3, \"draws\": 608, \"mu_intercept_per_group\": -4.1521501541137695, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 3, \"draws\": 609, \"mu_intercept_per_group\": -4.381858825683594, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 3, \"draws\": 610, \"mu_intercept_per_group\": -5.459375858306885, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 3, \"draws\": 611, \"mu_intercept_per_group\": -4.552024841308594, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 3, \"draws\": 612, \"mu_intercept_per_group\": -5.423214435577393, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 3, \"draws\": 613, \"mu_intercept_per_group\": -4.1766839027404785, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 3, \"draws\": 614, \"mu_intercept_per_group\": -4.247849941253662, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 3, \"draws\": 615, \"mu_intercept_per_group\": -5.131702899932861, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 3, \"draws\": 616, \"mu_intercept_per_group\": -4.8990254402160645, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 3, \"draws\": 617, \"mu_intercept_per_group\": -4.823692321777344, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 3, \"draws\": 618, \"mu_intercept_per_group\": -7.7395477294921875, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 3, \"draws\": 619, \"mu_intercept_per_group\": -9.042439460754395, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 3, \"draws\": 620, \"mu_intercept_per_group\": -8.67538070678711, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 3, \"draws\": 621, \"mu_intercept_per_group\": -8.017312049865723, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 3, \"draws\": 622, \"mu_intercept_per_group\": -8.628585815429688, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 3, \"draws\": 623, \"mu_intercept_per_group\": -8.104585647583008, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 3, \"draws\": 624, \"mu_intercept_per_group\": -9.071730613708496, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 3, \"draws\": 625, \"mu_intercept_per_group\": -8.939050674438477, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 3, \"draws\": 626, \"mu_intercept_per_group\": -7.127598285675049, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 3, \"draws\": 627, \"mu_intercept_per_group\": -8.139835357666016, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 3, \"draws\": 628, \"mu_intercept_per_group\": -8.309562683105469, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 3, \"draws\": 629, \"mu_intercept_per_group\": -4.132501602172852, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 3, \"draws\": 630, \"mu_intercept_per_group\": -3.9787166118621826, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 3, \"draws\": 631, \"mu_intercept_per_group\": -4.509105205535889, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 3, \"draws\": 632, \"mu_intercept_per_group\": -4.776891231536865, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 3, \"draws\": 633, \"mu_intercept_per_group\": -4.711182117462158, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 3, \"draws\": 634, \"mu_intercept_per_group\": -5.634485721588135, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 3, \"draws\": 635, \"mu_intercept_per_group\": -5.543056011199951, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 3, \"draws\": 636, \"mu_intercept_per_group\": -4.933659553527832, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 3, \"draws\": 637, \"mu_intercept_per_group\": -4.653660297393799, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 3, \"draws\": 638, \"mu_intercept_per_group\": -4.540064334869385, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 3, \"draws\": 639, \"mu_intercept_per_group\": -4.322659969329834, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 4, \"draws\": 0, \"mu_intercept_per_group\": -3.2160682678222656, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 4, \"draws\": 1, \"mu_intercept_per_group\": -3.1503524780273438, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 4, \"draws\": 2, \"mu_intercept_per_group\": -3.154973030090332, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 4, \"draws\": 3, \"mu_intercept_per_group\": -3.6993825435638428, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 4, \"draws\": 4, \"mu_intercept_per_group\": -3.5863540172576904, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 4, \"draws\": 5, \"mu_intercept_per_group\": -3.6957690715789795, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 4, \"draws\": 6, \"mu_intercept_per_group\": -3.0974276065826416, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 4, \"draws\": 7, \"mu_intercept_per_group\": -3.471959352493286, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 4, \"draws\": 8, \"mu_intercept_per_group\": -3.2102572917938232, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 4, \"draws\": 9, \"mu_intercept_per_group\": -2.8224105834960938, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 4, \"draws\": 10, \"mu_intercept_per_group\": -2.695841073989868, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 4, \"draws\": 11, \"mu_intercept_per_group\": -3.2250771522521973, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 4, \"draws\": 12, \"mu_intercept_per_group\": -4.391496181488037, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 4, \"draws\": 13, \"mu_intercept_per_group\": -4.2693257331848145, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 4, \"draws\": 14, \"mu_intercept_per_group\": -5.523819446563721, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 4, \"draws\": 15, \"mu_intercept_per_group\": -4.7754011154174805, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 4, \"draws\": 16, \"mu_intercept_per_group\": -4.798484802246094, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 4, \"draws\": 17, \"mu_intercept_per_group\": -4.897063255310059, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 4, \"draws\": 18, \"mu_intercept_per_group\": -5.103401184082031, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 4, \"draws\": 19, \"mu_intercept_per_group\": -4.573517799377441, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 4, \"draws\": 20, \"mu_intercept_per_group\": -4.7928290367126465, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 4, \"draws\": 21, \"mu_intercept_per_group\": -3.387516498565674, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 4, \"draws\": 22, \"mu_intercept_per_group\": -5.246242046356201, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 4, \"draws\": 23, \"mu_intercept_per_group\": -4.365924835205078, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 4, \"draws\": 24, \"mu_intercept_per_group\": -4.70215368270874, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 4, \"draws\": 25, \"mu_intercept_per_group\": -5.150832176208496, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 4, \"draws\": 26, \"mu_intercept_per_group\": -4.720948696136475, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 4, \"draws\": 27, \"mu_intercept_per_group\": -5.241862773895264, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 4, \"draws\": 28, \"mu_intercept_per_group\": -5.436944007873535, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 4, \"draws\": 29, \"mu_intercept_per_group\": -5.250262260437012, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 4, \"draws\": 30, \"mu_intercept_per_group\": -5.867660045623779, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 4, \"draws\": 31, \"mu_intercept_per_group\": -6.199116230010986, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 4, \"draws\": 32, \"mu_intercept_per_group\": -5.454075336456299, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 4, \"draws\": 33, \"mu_intercept_per_group\": -5.099089622497559, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 4, \"draws\": 34, \"mu_intercept_per_group\": -4.9395341873168945, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 4, \"draws\": 35, \"mu_intercept_per_group\": -5.1202826499938965, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 4, \"draws\": 36, \"mu_intercept_per_group\": -5.292822360992432, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 4, \"draws\": 37, \"mu_intercept_per_group\": -5.066089630126953, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 4, \"draws\": 38, \"mu_intercept_per_group\": -4.443789005279541, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 4, \"draws\": 39, \"mu_intercept_per_group\": -3.829704999923706, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 4, \"draws\": 40, \"mu_intercept_per_group\": -4.451542854309082, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 4, \"draws\": 41, \"mu_intercept_per_group\": -4.943082809448242, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 4, \"draws\": 42, \"mu_intercept_per_group\": -4.021325588226318, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 4, \"draws\": 43, \"mu_intercept_per_group\": -5.21320104598999, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 4, \"draws\": 44, \"mu_intercept_per_group\": -4.182582378387451, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 4, \"draws\": 45, \"mu_intercept_per_group\": -3.070464849472046, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 4, \"draws\": 46, \"mu_intercept_per_group\": -4.925419807434082, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 4, \"draws\": 47, \"mu_intercept_per_group\": -5.190820693969727, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 4, \"draws\": 48, \"mu_intercept_per_group\": -4.0811567306518555, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 4, \"draws\": 49, \"mu_intercept_per_group\": -4.749053001403809, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 4, \"draws\": 50, \"mu_intercept_per_group\": -2.8098151683807373, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 4, \"draws\": 51, \"mu_intercept_per_group\": -3.033369541168213, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 4, \"draws\": 52, \"mu_intercept_per_group\": -2.0070154666900635, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 4, \"draws\": 53, \"mu_intercept_per_group\": -1.8347281217575073, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 4, \"draws\": 54, \"mu_intercept_per_group\": -2.144105911254883, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 4, \"draws\": 55, \"mu_intercept_per_group\": -2.353419780731201, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 4, \"draws\": 56, \"mu_intercept_per_group\": -1.6818358898162842, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 4, \"draws\": 57, \"mu_intercept_per_group\": -1.6209059953689575, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 4, \"draws\": 58, \"mu_intercept_per_group\": -1.7081159353256226, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 4, \"draws\": 59, \"mu_intercept_per_group\": -1.4941926002502441, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 4, \"draws\": 60, \"mu_intercept_per_group\": -1.5644822120666504, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 4, \"draws\": 61, \"mu_intercept_per_group\": -3.5098400115966797, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 4, \"draws\": 62, \"mu_intercept_per_group\": -3.209838628768921, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 4, \"draws\": 63, \"mu_intercept_per_group\": -3.4945502281188965, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 4, \"draws\": 64, \"mu_intercept_per_group\": -3.415635347366333, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 4, \"draws\": 65, \"mu_intercept_per_group\": -3.4234721660614014, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 4, \"draws\": 66, \"mu_intercept_per_group\": -3.2571933269500732, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 4, \"draws\": 67, \"mu_intercept_per_group\": -3.1588056087493896, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 4, \"draws\": 68, \"mu_intercept_per_group\": -2.9789884090423584, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 4, \"draws\": 69, \"mu_intercept_per_group\": -2.9133501052856445, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 4, \"draws\": 70, \"mu_intercept_per_group\": -2.3872969150543213, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 4, \"draws\": 71, \"mu_intercept_per_group\": -2.3875670433044434, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 4, \"draws\": 72, \"mu_intercept_per_group\": -2.324662923812866, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 4, \"draws\": 73, \"mu_intercept_per_group\": -2.291844606399536, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 4, \"draws\": 74, \"mu_intercept_per_group\": -2.2619130611419678, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 4, \"draws\": 75, \"mu_intercept_per_group\": -2.1550426483154297, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 4, \"draws\": 76, \"mu_intercept_per_group\": -2.2293331623077393, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 4, \"draws\": 77, \"mu_intercept_per_group\": -3.6478919982910156, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 4, \"draws\": 78, \"mu_intercept_per_group\": -3.381657838821411, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 4, \"draws\": 79, \"mu_intercept_per_group\": -4.8553385734558105, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 4, \"draws\": 80, \"mu_intercept_per_group\": -5.972522735595703, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 4, \"draws\": 81, \"mu_intercept_per_group\": -4.222433090209961, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 4, \"draws\": 82, \"mu_intercept_per_group\": -5.179210186004639, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 4, \"draws\": 83, \"mu_intercept_per_group\": -5.0110321044921875, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 4, \"draws\": 84, \"mu_intercept_per_group\": -4.753268718719482, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 4, \"draws\": 85, \"mu_intercept_per_group\": -4.381407737731934, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 4, \"draws\": 86, \"mu_intercept_per_group\": -4.4969377517700195, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 4, \"draws\": 87, \"mu_intercept_per_group\": -2.741515874862671, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 4, \"draws\": 88, \"mu_intercept_per_group\": -2.770547866821289, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 4, \"draws\": 89, \"mu_intercept_per_group\": -3.370682716369629, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 4, \"draws\": 90, \"mu_intercept_per_group\": -3.4866318702697754, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 4, \"draws\": 91, \"mu_intercept_per_group\": -4.463639259338379, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 4, \"draws\": 92, \"mu_intercept_per_group\": -4.5936760902404785, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 4, \"draws\": 93, \"mu_intercept_per_group\": -4.369146823883057, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 4, \"draws\": 94, \"mu_intercept_per_group\": -4.232141971588135, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 4, \"draws\": 95, \"mu_intercept_per_group\": -3.986844539642334, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 4, \"draws\": 96, \"mu_intercept_per_group\": -4.245208740234375, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 4, \"draws\": 97, \"mu_intercept_per_group\": -4.060065269470215, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 4, \"draws\": 98, \"mu_intercept_per_group\": -3.383484363555908, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 4, \"draws\": 99, \"mu_intercept_per_group\": -3.3818578720092773, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 4, \"draws\": 100, \"mu_intercept_per_group\": -4.560321807861328, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 4, \"draws\": 101, \"mu_intercept_per_group\": -3.8793609142303467, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 4, \"draws\": 102, \"mu_intercept_per_group\": -4.104524612426758, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 4, \"draws\": 103, \"mu_intercept_per_group\": -3.0438332557678223, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 4, \"draws\": 104, \"mu_intercept_per_group\": -3.7577364444732666, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 4, \"draws\": 105, \"mu_intercept_per_group\": -3.836346387863159, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 4, \"draws\": 106, \"mu_intercept_per_group\": -4.417436122894287, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 4, \"draws\": 107, \"mu_intercept_per_group\": -4.598402500152588, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 4, \"draws\": 108, \"mu_intercept_per_group\": -4.273797512054443, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 4, \"draws\": 109, \"mu_intercept_per_group\": -5.948584079742432, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 4, \"draws\": 110, \"mu_intercept_per_group\": -5.523548126220703, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 4, \"draws\": 111, \"mu_intercept_per_group\": -5.334526538848877, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 4, \"draws\": 112, \"mu_intercept_per_group\": -6.16411828994751, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 4, \"draws\": 113, \"mu_intercept_per_group\": -6.291115760803223, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 4, \"draws\": 114, \"mu_intercept_per_group\": -5.488147735595703, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 4, \"draws\": 115, \"mu_intercept_per_group\": -6.084145545959473, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 4, \"draws\": 116, \"mu_intercept_per_group\": -5.468303203582764, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 4, \"draws\": 117, \"mu_intercept_per_group\": -4.3605499267578125, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 4, \"draws\": 118, \"mu_intercept_per_group\": -5.810192584991455, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 4, \"draws\": 119, \"mu_intercept_per_group\": -5.80193567276001, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 4, \"draws\": 120, \"mu_intercept_per_group\": -4.695533752441406, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 4, \"draws\": 121, \"mu_intercept_per_group\": -4.761996746063232, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 4, \"draws\": 122, \"mu_intercept_per_group\": -6.156547546386719, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 4, \"draws\": 123, \"mu_intercept_per_group\": -6.265928268432617, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 4, \"draws\": 124, \"mu_intercept_per_group\": -3.905517339706421, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 4, \"draws\": 125, \"mu_intercept_per_group\": -4.674711227416992, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 4, \"draws\": 126, \"mu_intercept_per_group\": -4.404232978820801, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 4, \"draws\": 127, \"mu_intercept_per_group\": -4.414945125579834, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 4, \"draws\": 128, \"mu_intercept_per_group\": -3.6202003955841064, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 4, \"draws\": 129, \"mu_intercept_per_group\": -3.5070831775665283, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 4, \"draws\": 130, \"mu_intercept_per_group\": -3.8916783332824707, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 4, \"draws\": 131, \"mu_intercept_per_group\": -3.474385976791382, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 4, \"draws\": 132, \"mu_intercept_per_group\": -3.839395523071289, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 4, \"draws\": 133, \"mu_intercept_per_group\": -4.073233127593994, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 4, \"draws\": 134, \"mu_intercept_per_group\": -3.0155794620513916, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 4, \"draws\": 135, \"mu_intercept_per_group\": -3.951336622238159, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 4, \"draws\": 136, \"mu_intercept_per_group\": -3.9323551654815674, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 4, \"draws\": 137, \"mu_intercept_per_group\": -3.5236833095550537, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 4, \"draws\": 138, \"mu_intercept_per_group\": -2.9192757606506348, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 4, \"draws\": 139, \"mu_intercept_per_group\": -3.9267947673797607, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 4, \"draws\": 140, \"mu_intercept_per_group\": -3.6702234745025635, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 4, \"draws\": 141, \"mu_intercept_per_group\": -4.596139430999756, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 4, \"draws\": 142, \"mu_intercept_per_group\": -4.236914157867432, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 4, \"draws\": 143, \"mu_intercept_per_group\": -2.5385448932647705, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 4, \"draws\": 144, \"mu_intercept_per_group\": -2.6649394035339355, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 4, \"draws\": 145, \"mu_intercept_per_group\": -2.6408231258392334, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 4, \"draws\": 146, \"mu_intercept_per_group\": -2.3756258487701416, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 4, \"draws\": 147, \"mu_intercept_per_group\": -2.5461554527282715, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 4, \"draws\": 148, \"mu_intercept_per_group\": -3.197763442993164, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 4, \"draws\": 149, \"mu_intercept_per_group\": -3.8799164295196533, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 4, \"draws\": 150, \"mu_intercept_per_group\": -3.4827263355255127, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 4, \"draws\": 151, \"mu_intercept_per_group\": -3.24053955078125, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 4, \"draws\": 152, \"mu_intercept_per_group\": -2.2780933380126953, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 4, \"draws\": 153, \"mu_intercept_per_group\": -3.25518536567688, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 4, \"draws\": 154, \"mu_intercept_per_group\": -2.9563307762145996, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 4, \"draws\": 155, \"mu_intercept_per_group\": -2.7817699909210205, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 4, \"draws\": 156, \"mu_intercept_per_group\": -2.500922203063965, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 4, \"draws\": 157, \"mu_intercept_per_group\": -3.527482271194458, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 4, \"draws\": 158, \"mu_intercept_per_group\": -2.9213085174560547, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 4, \"draws\": 159, \"mu_intercept_per_group\": -3.6521008014678955, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 4, \"draws\": 160, \"mu_intercept_per_group\": -6.641815185546875, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 4, \"draws\": 161, \"mu_intercept_per_group\": -6.895459175109863, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 4, \"draws\": 162, \"mu_intercept_per_group\": -6.3789496421813965, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 4, \"draws\": 163, \"mu_intercept_per_group\": -6.216711044311523, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 4, \"draws\": 164, \"mu_intercept_per_group\": -5.817533016204834, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 4, \"draws\": 165, \"mu_intercept_per_group\": -5.039096832275391, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 4, \"draws\": 166, \"mu_intercept_per_group\": -7.664427280426025, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 4, \"draws\": 167, \"mu_intercept_per_group\": -6.759448528289795, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 4, \"draws\": 168, \"mu_intercept_per_group\": -5.945134162902832, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 4, \"draws\": 169, \"mu_intercept_per_group\": -7.0006818771362305, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 4, \"draws\": 170, \"mu_intercept_per_group\": -6.461031913757324, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 4, \"draws\": 171, \"mu_intercept_per_group\": -7.2749552726745605, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 4, \"draws\": 172, \"mu_intercept_per_group\": -6.960305213928223, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 4, \"draws\": 173, \"mu_intercept_per_group\": -7.136066913604736, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 4, \"draws\": 174, \"mu_intercept_per_group\": -5.193940162658691, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 4, \"draws\": 175, \"mu_intercept_per_group\": -5.051795959472656, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 4, \"draws\": 176, \"mu_intercept_per_group\": -5.784646034240723, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 4, \"draws\": 177, \"mu_intercept_per_group\": -6.329106330871582, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 4, \"draws\": 178, \"mu_intercept_per_group\": -6.040773868560791, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 4, \"draws\": 179, \"mu_intercept_per_group\": -2.9474081993103027, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 4, \"draws\": 180, \"mu_intercept_per_group\": -3.0106089115142822, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 4, \"draws\": 181, \"mu_intercept_per_group\": -3.045865774154663, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 4, \"draws\": 182, \"mu_intercept_per_group\": -3.2070584297180176, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 4, \"draws\": 183, \"mu_intercept_per_group\": -3.271054267883301, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 4, \"draws\": 184, \"mu_intercept_per_group\": -3.307243824005127, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 4, \"draws\": 185, \"mu_intercept_per_group\": -3.289296865463257, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 4, \"draws\": 186, \"mu_intercept_per_group\": -3.477045774459839, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 4, \"draws\": 187, \"mu_intercept_per_group\": -4.032845973968506, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 4, \"draws\": 188, \"mu_intercept_per_group\": -4.0605082511901855, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 4, \"draws\": 189, \"mu_intercept_per_group\": -3.5073561668395996, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 4, \"draws\": 190, \"mu_intercept_per_group\": -5.079497337341309, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 4, \"draws\": 191, \"mu_intercept_per_group\": -4.988544940948486, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 4, \"draws\": 192, \"mu_intercept_per_group\": -3.9411513805389404, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 4, \"draws\": 193, \"mu_intercept_per_group\": -3.8062539100646973, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 4, \"draws\": 194, \"mu_intercept_per_group\": -3.3497555255889893, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 4, \"draws\": 195, \"mu_intercept_per_group\": -3.569349765777588, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 4, \"draws\": 196, \"mu_intercept_per_group\": -3.9238440990448, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 4, \"draws\": 197, \"mu_intercept_per_group\": -3.978806495666504, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 4, \"draws\": 198, \"mu_intercept_per_group\": -3.0066308975219727, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 4, \"draws\": 199, \"mu_intercept_per_group\": -3.926762342453003, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 4, \"draws\": 200, \"mu_intercept_per_group\": -4.322369575500488, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 4, \"draws\": 201, \"mu_intercept_per_group\": -3.5430142879486084, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 4, \"draws\": 202, \"mu_intercept_per_group\": -3.8352396488189697, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 4, \"draws\": 203, \"mu_intercept_per_group\": -3.8052420616149902, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 4, \"draws\": 204, \"mu_intercept_per_group\": -3.8384222984313965, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 4, \"draws\": 205, \"mu_intercept_per_group\": -2.632709503173828, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 4, \"draws\": 206, \"mu_intercept_per_group\": -4.114975452423096, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 4, \"draws\": 207, \"mu_intercept_per_group\": -4.2314534187316895, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 4, \"draws\": 208, \"mu_intercept_per_group\": -4.404394626617432, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 4, \"draws\": 209, \"mu_intercept_per_group\": -3.6645560264587402, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 4, \"draws\": 210, \"mu_intercept_per_group\": -3.5687692165374756, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 4, \"draws\": 211, \"mu_intercept_per_group\": -3.662562608718872, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 4, \"draws\": 212, \"mu_intercept_per_group\": -3.6080362796783447, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 4, \"draws\": 213, \"mu_intercept_per_group\": -2.4620444774627686, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 4, \"draws\": 214, \"mu_intercept_per_group\": -2.0879948139190674, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 4, \"draws\": 215, \"mu_intercept_per_group\": -2.149364709854126, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 4, \"draws\": 216, \"mu_intercept_per_group\": -2.4797139167785645, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 4, \"draws\": 217, \"mu_intercept_per_group\": -3.0565314292907715, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 4, \"draws\": 218, \"mu_intercept_per_group\": -2.3406660556793213, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 4, \"draws\": 219, \"mu_intercept_per_group\": -2.400101661682129, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 4, \"draws\": 220, \"mu_intercept_per_group\": -2.7424070835113525, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 4, \"draws\": 221, \"mu_intercept_per_group\": -3.213590621948242, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 4, \"draws\": 222, \"mu_intercept_per_group\": -2.88499116897583, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 4, \"draws\": 223, \"mu_intercept_per_group\": -3.038557291030884, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 4, \"draws\": 224, \"mu_intercept_per_group\": -2.664194345474243, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 4, \"draws\": 225, \"mu_intercept_per_group\": -2.8238189220428467, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 4, \"draws\": 226, \"mu_intercept_per_group\": -2.760932445526123, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 4, \"draws\": 227, \"mu_intercept_per_group\": -3.1783807277679443, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 4, \"draws\": 228, \"mu_intercept_per_group\": -2.640887975692749, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 4, \"draws\": 229, \"mu_intercept_per_group\": -2.7908642292022705, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 4, \"draws\": 230, \"mu_intercept_per_group\": -2.524254560470581, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 4, \"draws\": 231, \"mu_intercept_per_group\": -2.4667599201202393, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 4, \"draws\": 232, \"mu_intercept_per_group\": -2.347156524658203, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 4, \"draws\": 233, \"mu_intercept_per_group\": -2.3926002979278564, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 4, \"draws\": 234, \"mu_intercept_per_group\": -2.289705991744995, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 4, \"draws\": 235, \"mu_intercept_per_group\": -2.6834497451782227, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 4, \"draws\": 236, \"mu_intercept_per_group\": -2.1849350929260254, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 4, \"draws\": 237, \"mu_intercept_per_group\": -2.509713888168335, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 4, \"draws\": 238, \"mu_intercept_per_group\": -2.352776050567627, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 4, \"draws\": 239, \"mu_intercept_per_group\": -2.4423108100891113, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 4, \"draws\": 240, \"mu_intercept_per_group\": -2.516552209854126, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 4, \"draws\": 241, \"mu_intercept_per_group\": -2.89945650100708, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 4, \"draws\": 242, \"mu_intercept_per_group\": -3.098738670349121, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 4, \"draws\": 243, \"mu_intercept_per_group\": -3.6454076766967773, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 4, \"draws\": 244, \"mu_intercept_per_group\": -4.265998363494873, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 4, \"draws\": 245, \"mu_intercept_per_group\": -4.327999114990234, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 4, \"draws\": 246, \"mu_intercept_per_group\": -3.932969331741333, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 4, \"draws\": 247, \"mu_intercept_per_group\": -3.6663167476654053, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 4, \"draws\": 248, \"mu_intercept_per_group\": -3.165194272994995, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 4, \"draws\": 249, \"mu_intercept_per_group\": -2.572188377380371, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 4, \"draws\": 250, \"mu_intercept_per_group\": -3.1041557788848877, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 4, \"draws\": 251, \"mu_intercept_per_group\": -2.875343084335327, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 4, \"draws\": 252, \"mu_intercept_per_group\": -3.109771728515625, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 4, \"draws\": 253, \"mu_intercept_per_group\": -3.232915163040161, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 4, \"draws\": 254, \"mu_intercept_per_group\": -2.988302230834961, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 4, \"draws\": 255, \"mu_intercept_per_group\": -3.1662814617156982, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 4, \"draws\": 256, \"mu_intercept_per_group\": -3.4214487075805664, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 4, \"draws\": 257, \"mu_intercept_per_group\": -4.101804733276367, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 4, \"draws\": 258, \"mu_intercept_per_group\": -3.743385076522827, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 4, \"draws\": 259, \"mu_intercept_per_group\": -3.8181614875793457, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 4, \"draws\": 260, \"mu_intercept_per_group\": -3.5863101482391357, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 4, \"draws\": 261, \"mu_intercept_per_group\": -3.108229875564575, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 4, \"draws\": 262, \"mu_intercept_per_group\": -2.706930160522461, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 4, \"draws\": 263, \"mu_intercept_per_group\": -3.1580193042755127, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 4, \"draws\": 264, \"mu_intercept_per_group\": -2.788930654525757, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 4, \"draws\": 265, \"mu_intercept_per_group\": -3.2309956550598145, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 4, \"draws\": 266, \"mu_intercept_per_group\": -1.9728314876556396, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 4, \"draws\": 267, \"mu_intercept_per_group\": -2.3518455028533936, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 4, \"draws\": 268, \"mu_intercept_per_group\": -2.473067283630371, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 4, \"draws\": 269, \"mu_intercept_per_group\": -5.332357406616211, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 4, \"draws\": 270, \"mu_intercept_per_group\": -5.381455421447754, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 4, \"draws\": 271, \"mu_intercept_per_group\": -4.615597248077393, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 4, \"draws\": 272, \"mu_intercept_per_group\": -4.889718055725098, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 4, \"draws\": 273, \"mu_intercept_per_group\": -4.4609832763671875, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 4, \"draws\": 274, \"mu_intercept_per_group\": -5.806756973266602, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 4, \"draws\": 275, \"mu_intercept_per_group\": -5.286625385284424, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 4, \"draws\": 276, \"mu_intercept_per_group\": -5.524487018585205, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 4, \"draws\": 277, \"mu_intercept_per_group\": -4.521651268005371, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 4, \"draws\": 278, \"mu_intercept_per_group\": -5.12087869644165, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 4, \"draws\": 279, \"mu_intercept_per_group\": -4.983374118804932, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 4, \"draws\": 280, \"mu_intercept_per_group\": -4.846686363220215, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 4, \"draws\": 281, \"mu_intercept_per_group\": -4.549624919891357, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 4, \"draws\": 282, \"mu_intercept_per_group\": -4.8745832443237305, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 4, \"draws\": 283, \"mu_intercept_per_group\": -4.427802562713623, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 4, \"draws\": 284, \"mu_intercept_per_group\": -4.724285125732422, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 4, \"draws\": 285, \"mu_intercept_per_group\": -4.929312229156494, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 4, \"draws\": 286, \"mu_intercept_per_group\": -5.307123184204102, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 4, \"draws\": 287, \"mu_intercept_per_group\": -5.964105129241943, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 4, \"draws\": 288, \"mu_intercept_per_group\": -5.6698174476623535, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 4, \"draws\": 289, \"mu_intercept_per_group\": -4.639018535614014, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 4, \"draws\": 290, \"mu_intercept_per_group\": -5.195610523223877, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 4, \"draws\": 291, \"mu_intercept_per_group\": -4.9866557121276855, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 4, \"draws\": 292, \"mu_intercept_per_group\": -5.252693176269531, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 4, \"draws\": 293, \"mu_intercept_per_group\": -4.868904113769531, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 4, \"draws\": 294, \"mu_intercept_per_group\": -3.7882955074310303, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 4, \"draws\": 295, \"mu_intercept_per_group\": -3.7022202014923096, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 4, \"draws\": 296, \"mu_intercept_per_group\": -3.5920870304107666, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 4, \"draws\": 297, \"mu_intercept_per_group\": -2.960514783859253, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 4, \"draws\": 298, \"mu_intercept_per_group\": -3.0206875801086426, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 4, \"draws\": 299, \"mu_intercept_per_group\": -3.43034291267395, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 4, \"draws\": 300, \"mu_intercept_per_group\": -3.2613840103149414, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 4, \"draws\": 301, \"mu_intercept_per_group\": -3.61409330368042, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 4, \"draws\": 302, \"mu_intercept_per_group\": -3.643528699874878, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 4, \"draws\": 303, \"mu_intercept_per_group\": -3.2535321712493896, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 4, \"draws\": 304, \"mu_intercept_per_group\": -3.8252780437469482, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 4, \"draws\": 305, \"mu_intercept_per_group\": -2.8267228603363037, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 4, \"draws\": 306, \"mu_intercept_per_group\": -3.782644748687744, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 4, \"draws\": 307, \"mu_intercept_per_group\": -3.2677431106567383, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 4, \"draws\": 308, \"mu_intercept_per_group\": -2.7394590377807617, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 4, \"draws\": 309, \"mu_intercept_per_group\": -4.586507797241211, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 4, \"draws\": 310, \"mu_intercept_per_group\": -4.732074737548828, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 4, \"draws\": 311, \"mu_intercept_per_group\": -4.968839645385742, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 4, \"draws\": 312, \"mu_intercept_per_group\": -4.675271034240723, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 4, \"draws\": 313, \"mu_intercept_per_group\": -4.870193004608154, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 4, \"draws\": 314, \"mu_intercept_per_group\": -3.9732182025909424, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 4, \"draws\": 315, \"mu_intercept_per_group\": -3.564786434173584, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 4, \"draws\": 316, \"mu_intercept_per_group\": -5.132424831390381, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 4, \"draws\": 317, \"mu_intercept_per_group\": -5.385344505310059, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 4, \"draws\": 318, \"mu_intercept_per_group\": -5.661250591278076, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 4, \"draws\": 319, \"mu_intercept_per_group\": -4.237105846405029, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 4, \"draws\": 320, \"mu_intercept_per_group\": -1.5702146291732788, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 4, \"draws\": 321, \"mu_intercept_per_group\": -1.7159725427627563, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 4, \"draws\": 322, \"mu_intercept_per_group\": -1.6724237203598022, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 4, \"draws\": 323, \"mu_intercept_per_group\": -2.0121443271636963, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 4, \"draws\": 324, \"mu_intercept_per_group\": -2.938324451446533, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 4, \"draws\": 325, \"mu_intercept_per_group\": -2.7914986610412598, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 4, \"draws\": 326, \"mu_intercept_per_group\": -2.8377532958984375, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 4, \"draws\": 327, \"mu_intercept_per_group\": -2.627164125442505, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 4, \"draws\": 328, \"mu_intercept_per_group\": -3.2317397594451904, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 4, \"draws\": 329, \"mu_intercept_per_group\": -2.8942012786865234, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 4, \"draws\": 330, \"mu_intercept_per_group\": -3.293412685394287, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 4, \"draws\": 331, \"mu_intercept_per_group\": -3.8311445713043213, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 4, \"draws\": 332, \"mu_intercept_per_group\": -3.7580695152282715, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 4, \"draws\": 333, \"mu_intercept_per_group\": -3.092212200164795, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 4, \"draws\": 334, \"mu_intercept_per_group\": -2.8050055503845215, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 4, \"draws\": 335, \"mu_intercept_per_group\": -4.064183235168457, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 4, \"draws\": 336, \"mu_intercept_per_group\": -3.645002841949463, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 4, \"draws\": 337, \"mu_intercept_per_group\": -3.076366901397705, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 4, \"draws\": 338, \"mu_intercept_per_group\": -6.792789459228516, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 4, \"draws\": 339, \"mu_intercept_per_group\": -4.6451897621154785, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 4, \"draws\": 340, \"mu_intercept_per_group\": -5.35081672668457, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 4, \"draws\": 341, \"mu_intercept_per_group\": -4.651253700256348, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 4, \"draws\": 342, \"mu_intercept_per_group\": -4.434096336364746, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 4, \"draws\": 343, \"mu_intercept_per_group\": -4.811375141143799, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 4, \"draws\": 344, \"mu_intercept_per_group\": -5.682912349700928, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 4, \"draws\": 345, \"mu_intercept_per_group\": -7.590211391448975, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 4, \"draws\": 346, \"mu_intercept_per_group\": -4.6606292724609375, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 4, \"draws\": 347, \"mu_intercept_per_group\": -3.5575826168060303, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 4, \"draws\": 348, \"mu_intercept_per_group\": -3.7162833213806152, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 4, \"draws\": 349, \"mu_intercept_per_group\": -3.779306173324585, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 4, \"draws\": 350, \"mu_intercept_per_group\": -4.743076801300049, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 4, \"draws\": 351, \"mu_intercept_per_group\": -4.450291633605957, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 4, \"draws\": 352, \"mu_intercept_per_group\": -4.985365390777588, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 4, \"draws\": 353, \"mu_intercept_per_group\": -5.02490234375, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 4, \"draws\": 354, \"mu_intercept_per_group\": -2.75164532661438, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 4, \"draws\": 355, \"mu_intercept_per_group\": -3.2992801666259766, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 4, \"draws\": 356, \"mu_intercept_per_group\": -2.7618889808654785, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 4, \"draws\": 357, \"mu_intercept_per_group\": -2.561657190322876, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 4, \"draws\": 358, \"mu_intercept_per_group\": -2.5778698921203613, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 4, \"draws\": 359, \"mu_intercept_per_group\": -2.048013925552368, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 4, \"draws\": 360, \"mu_intercept_per_group\": -3.668407678604126, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 4, \"draws\": 361, \"mu_intercept_per_group\": -2.402118444442749, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 4, \"draws\": 362, \"mu_intercept_per_group\": -3.1823861598968506, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 4, \"draws\": 363, \"mu_intercept_per_group\": -3.261369466781616, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 4, \"draws\": 364, \"mu_intercept_per_group\": -3.910154342651367, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 4, \"draws\": 365, \"mu_intercept_per_group\": -3.923431396484375, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 4, \"draws\": 366, \"mu_intercept_per_group\": -4.29631233215332, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 4, \"draws\": 367, \"mu_intercept_per_group\": -3.8419671058654785, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 4, \"draws\": 368, \"mu_intercept_per_group\": -5.084696292877197, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 4, \"draws\": 369, \"mu_intercept_per_group\": -2.3924612998962402, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 4, \"draws\": 370, \"mu_intercept_per_group\": -2.0784921646118164, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 4, \"draws\": 371, \"mu_intercept_per_group\": -2.356757164001465, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 4, \"draws\": 372, \"mu_intercept_per_group\": -3.1755475997924805, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 4, \"draws\": 373, \"mu_intercept_per_group\": -3.189838409423828, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 4, \"draws\": 374, \"mu_intercept_per_group\": -2.32490873336792, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 4, \"draws\": 375, \"mu_intercept_per_group\": -2.7461585998535156, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 4, \"draws\": 376, \"mu_intercept_per_group\": -4.324718475341797, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 4, \"draws\": 377, \"mu_intercept_per_group\": -2.423102617263794, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 4, \"draws\": 378, \"mu_intercept_per_group\": -2.4673519134521484, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 4, \"draws\": 379, \"mu_intercept_per_group\": -2.4462523460388184, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 4, \"draws\": 380, \"mu_intercept_per_group\": -2.630737066268921, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 4, \"draws\": 381, \"mu_intercept_per_group\": -3.705571174621582, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 4, \"draws\": 382, \"mu_intercept_per_group\": -2.0518798828125, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 4, \"draws\": 383, \"mu_intercept_per_group\": -2.238481044769287, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 4, \"draws\": 384, \"mu_intercept_per_group\": -4.5069732666015625, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 4, \"draws\": 385, \"mu_intercept_per_group\": -4.775793552398682, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 4, \"draws\": 386, \"mu_intercept_per_group\": -4.211631774902344, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 4, \"draws\": 387, \"mu_intercept_per_group\": -4.166933536529541, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 4, \"draws\": 388, \"mu_intercept_per_group\": -4.3499064445495605, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 4, \"draws\": 389, \"mu_intercept_per_group\": -4.7391815185546875, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 4, \"draws\": 390, \"mu_intercept_per_group\": -4.608121395111084, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 4, \"draws\": 391, \"mu_intercept_per_group\": -4.532625198364258, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 4, \"draws\": 392, \"mu_intercept_per_group\": -4.210813999176025, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 4, \"draws\": 393, \"mu_intercept_per_group\": -3.9007232189178467, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 4, \"draws\": 394, \"mu_intercept_per_group\": -3.6870005130767822, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 4, \"draws\": 395, \"mu_intercept_per_group\": -3.8026609420776367, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 4, \"draws\": 396, \"mu_intercept_per_group\": -4.258692264556885, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 4, \"draws\": 397, \"mu_intercept_per_group\": -4.513071537017822, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 4, \"draws\": 398, \"mu_intercept_per_group\": -3.5466809272766113, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 4, \"draws\": 399, \"mu_intercept_per_group\": -3.189875841140747, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 4, \"draws\": 400, \"mu_intercept_per_group\": -3.130948781967163, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 4, \"draws\": 401, \"mu_intercept_per_group\": -3.3508801460266113, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 4, \"draws\": 402, \"mu_intercept_per_group\": -3.2309508323669434, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 4, \"draws\": 403, \"mu_intercept_per_group\": -3.6773369312286377, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 4, \"draws\": 404, \"mu_intercept_per_group\": -3.764237880706787, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 4, \"draws\": 405, \"mu_intercept_per_group\": -4.597661972045898, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 4, \"draws\": 406, \"mu_intercept_per_group\": -4.337717056274414, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 4, \"draws\": 407, \"mu_intercept_per_group\": -3.167217493057251, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 4, \"draws\": 408, \"mu_intercept_per_group\": -3.907944440841675, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 4, \"draws\": 409, \"mu_intercept_per_group\": -3.430443048477173, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 4, \"draws\": 410, \"mu_intercept_per_group\": -3.634525775909424, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 4, \"draws\": 411, \"mu_intercept_per_group\": -2.508734703063965, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 4, \"draws\": 412, \"mu_intercept_per_group\": -3.0726072788238525, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 4, \"draws\": 413, \"mu_intercept_per_group\": -4.056229591369629, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 4, \"draws\": 414, \"mu_intercept_per_group\": -4.0263261795043945, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 4, \"draws\": 415, \"mu_intercept_per_group\": -4.596679210662842, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 4, \"draws\": 416, \"mu_intercept_per_group\": -4.5367350578308105, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 4, \"draws\": 417, \"mu_intercept_per_group\": -3.896312713623047, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 4, \"draws\": 418, \"mu_intercept_per_group\": -4.317710876464844, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 4, \"draws\": 419, \"mu_intercept_per_group\": -4.3585968017578125, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 4, \"draws\": 420, \"mu_intercept_per_group\": -3.373908519744873, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 4, \"draws\": 421, \"mu_intercept_per_group\": -4.021493434906006, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 4, \"draws\": 422, \"mu_intercept_per_group\": -4.3133440017700195, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 4, \"draws\": 423, \"mu_intercept_per_group\": -4.013141632080078, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 4, \"draws\": 424, \"mu_intercept_per_group\": -4.388591766357422, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 4, \"draws\": 425, \"mu_intercept_per_group\": -4.437829494476318, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 4, \"draws\": 426, \"mu_intercept_per_group\": -4.567445278167725, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 4, \"draws\": 427, \"mu_intercept_per_group\": -4.853612422943115, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 4, \"draws\": 428, \"mu_intercept_per_group\": -4.11179256439209, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 4, \"draws\": 429, \"mu_intercept_per_group\": -4.661942005157471, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 4, \"draws\": 430, \"mu_intercept_per_group\": -6.344722270965576, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 4, \"draws\": 431, \"mu_intercept_per_group\": -3.9799797534942627, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 4, \"draws\": 432, \"mu_intercept_per_group\": -4.599727630615234, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 4, \"draws\": 433, \"mu_intercept_per_group\": -5.223723888397217, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 4, \"draws\": 434, \"mu_intercept_per_group\": -3.9218454360961914, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 4, \"draws\": 435, \"mu_intercept_per_group\": -3.711454153060913, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 4, \"draws\": 436, \"mu_intercept_per_group\": -4.266801357269287, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 4, \"draws\": 437, \"mu_intercept_per_group\": -5.6389689445495605, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 4, \"draws\": 438, \"mu_intercept_per_group\": -5.074189186096191, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 4, \"draws\": 439, \"mu_intercept_per_group\": -4.804760456085205, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 4, \"draws\": 440, \"mu_intercept_per_group\": -4.506194114685059, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 4, \"draws\": 441, \"mu_intercept_per_group\": -4.417525768280029, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 4, \"draws\": 442, \"mu_intercept_per_group\": -4.978493690490723, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 4, \"draws\": 443, \"mu_intercept_per_group\": -6.543245792388916, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 4, \"draws\": 444, \"mu_intercept_per_group\": -6.004430294036865, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 4, \"draws\": 445, \"mu_intercept_per_group\": -5.752226829528809, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 4, \"draws\": 446, \"mu_intercept_per_group\": -4.472527980804443, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 4, \"draws\": 447, \"mu_intercept_per_group\": -4.127964973449707, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 4, \"draws\": 448, \"mu_intercept_per_group\": -2.4681849479675293, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 4, \"draws\": 449, \"mu_intercept_per_group\": -2.899723768234253, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 4, \"draws\": 450, \"mu_intercept_per_group\": -3.469630479812622, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 4, \"draws\": 451, \"mu_intercept_per_group\": -6.732649803161621, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 4, \"draws\": 452, \"mu_intercept_per_group\": -7.628556251525879, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 4, \"draws\": 453, \"mu_intercept_per_group\": -7.007566452026367, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 4, \"draws\": 454, \"mu_intercept_per_group\": -7.510087966918945, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 4, \"draws\": 455, \"mu_intercept_per_group\": -7.596124172210693, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 4, \"draws\": 456, \"mu_intercept_per_group\": -6.759806156158447, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 4, \"draws\": 457, \"mu_intercept_per_group\": -6.572453498840332, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 4, \"draws\": 458, \"mu_intercept_per_group\": -7.216283321380615, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 4, \"draws\": 459, \"mu_intercept_per_group\": -3.394761085510254, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 4, \"draws\": 460, \"mu_intercept_per_group\": -3.5830938816070557, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 4, \"draws\": 461, \"mu_intercept_per_group\": -3.972700357437134, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 4, \"draws\": 462, \"mu_intercept_per_group\": -2.687992811203003, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 4, \"draws\": 463, \"mu_intercept_per_group\": -2.640437602996826, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 4, \"draws\": 464, \"mu_intercept_per_group\": -2.6268911361694336, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 4, \"draws\": 465, \"mu_intercept_per_group\": -3.1473395824432373, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 4, \"draws\": 466, \"mu_intercept_per_group\": -3.3164284229278564, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 4, \"draws\": 467, \"mu_intercept_per_group\": -3.1227779388427734, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 4, \"draws\": 468, \"mu_intercept_per_group\": -3.5324432849884033, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 4, \"draws\": 469, \"mu_intercept_per_group\": -3.489243745803833, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 4, \"draws\": 470, \"mu_intercept_per_group\": -3.5340919494628906, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 4, \"draws\": 471, \"mu_intercept_per_group\": -3.3475990295410156, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 4, \"draws\": 472, \"mu_intercept_per_group\": -3.4157185554504395, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 4, \"draws\": 473, \"mu_intercept_per_group\": -5.84027099609375, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 4, \"draws\": 474, \"mu_intercept_per_group\": -5.2672905921936035, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 4, \"draws\": 475, \"mu_intercept_per_group\": -4.948997974395752, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 4, \"draws\": 476, \"mu_intercept_per_group\": -4.900701522827148, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 4, \"draws\": 477, \"mu_intercept_per_group\": -5.157842636108398, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 4, \"draws\": 478, \"mu_intercept_per_group\": -4.902860164642334, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 4, \"draws\": 479, \"mu_intercept_per_group\": -5.401073932647705, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 4, \"draws\": 480, \"mu_intercept_per_group\": -3.591236114501953, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 4, \"draws\": 481, \"mu_intercept_per_group\": -3.6667087078094482, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 4, \"draws\": 482, \"mu_intercept_per_group\": -4.798236846923828, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 4, \"draws\": 483, \"mu_intercept_per_group\": -4.659868240356445, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 4, \"draws\": 484, \"mu_intercept_per_group\": -3.2778127193450928, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 4, \"draws\": 485, \"mu_intercept_per_group\": -3.623180627822876, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 4, \"draws\": 486, \"mu_intercept_per_group\": -3.568042278289795, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 4, \"draws\": 487, \"mu_intercept_per_group\": -3.634218454360962, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 4, \"draws\": 488, \"mu_intercept_per_group\": -3.0686845779418945, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 4, \"draws\": 489, \"mu_intercept_per_group\": -3.514482259750366, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 4, \"draws\": 490, \"mu_intercept_per_group\": -3.2363946437835693, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 4, \"draws\": 491, \"mu_intercept_per_group\": -2.9840352535247803, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 4, \"draws\": 492, \"mu_intercept_per_group\": -3.7173821926116943, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 4, \"draws\": 493, \"mu_intercept_per_group\": -2.7388837337493896, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 4, \"draws\": 494, \"mu_intercept_per_group\": -5.413711071014404, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 4, \"draws\": 495, \"mu_intercept_per_group\": -4.079289436340332, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 4, \"draws\": 496, \"mu_intercept_per_group\": -3.775406837463379, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 4, \"draws\": 497, \"mu_intercept_per_group\": -3.903639554977417, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 4, \"draws\": 498, \"mu_intercept_per_group\": -3.9414424896240234, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 4, \"draws\": 499, \"mu_intercept_per_group\": -4.3830718994140625, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 4, \"draws\": 500, \"mu_intercept_per_group\": -3.5963191986083984, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 4, \"draws\": 501, \"mu_intercept_per_group\": -4.528805255889893, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 4, \"draws\": 502, \"mu_intercept_per_group\": -4.785755634307861, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 4, \"draws\": 503, \"mu_intercept_per_group\": -4.740671157836914, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 4, \"draws\": 504, \"mu_intercept_per_group\": -4.571068286895752, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 4, \"draws\": 505, \"mu_intercept_per_group\": -4.587764263153076, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 4, \"draws\": 506, \"mu_intercept_per_group\": -4.0866522789001465, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 4, \"draws\": 507, \"mu_intercept_per_group\": -3.407818078994751, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 4, \"draws\": 508, \"mu_intercept_per_group\": -5.464204788208008, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 4, \"draws\": 509, \"mu_intercept_per_group\": -5.632685661315918, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 4, \"draws\": 510, \"mu_intercept_per_group\": -4.239137649536133, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 4, \"draws\": 511, \"mu_intercept_per_group\": -7.8659186363220215, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 4, \"draws\": 512, \"mu_intercept_per_group\": -5.434419631958008, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 4, \"draws\": 513, \"mu_intercept_per_group\": -5.407713890075684, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 4, \"draws\": 514, \"mu_intercept_per_group\": -6.021812915802002, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 4, \"draws\": 515, \"mu_intercept_per_group\": -6.029812335968018, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 4, \"draws\": 516, \"mu_intercept_per_group\": -5.301197528839111, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 4, \"draws\": 517, \"mu_intercept_per_group\": -5.334539890289307, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 4, \"draws\": 518, \"mu_intercept_per_group\": -5.26688814163208, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 4, \"draws\": 519, \"mu_intercept_per_group\": -4.240052223205566, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 4, \"draws\": 520, \"mu_intercept_per_group\": -4.368261337280273, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 4, \"draws\": 521, \"mu_intercept_per_group\": -3.18776273727417, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 4, \"draws\": 522, \"mu_intercept_per_group\": -3.5277905464172363, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 4, \"draws\": 523, \"mu_intercept_per_group\": -3.6785292625427246, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 4, \"draws\": 524, \"mu_intercept_per_group\": -2.5285444259643555, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 4, \"draws\": 525, \"mu_intercept_per_group\": -2.9731125831604004, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 4, \"draws\": 526, \"mu_intercept_per_group\": -2.829897880554199, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 4, \"draws\": 527, \"mu_intercept_per_group\": -4.158510208129883, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 4, \"draws\": 528, \"mu_intercept_per_group\": -4.003491401672363, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 4, \"draws\": 529, \"mu_intercept_per_group\": -3.814572334289551, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 4, \"draws\": 530, \"mu_intercept_per_group\": -3.232607841491699, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 4, \"draws\": 531, \"mu_intercept_per_group\": -3.3436439037323, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 4, \"draws\": 532, \"mu_intercept_per_group\": -4.358837604522705, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 4, \"draws\": 533, \"mu_intercept_per_group\": -4.363704681396484, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 4, \"draws\": 534, \"mu_intercept_per_group\": -4.069090843200684, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 4, \"draws\": 535, \"mu_intercept_per_group\": -3.9309959411621094, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 4, \"draws\": 536, \"mu_intercept_per_group\": -4.411968231201172, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 4, \"draws\": 537, \"mu_intercept_per_group\": -2.548729419708252, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 4, \"draws\": 538, \"mu_intercept_per_group\": -2.49269962310791, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 4, \"draws\": 539, \"mu_intercept_per_group\": -2.437382221221924, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 4, \"draws\": 540, \"mu_intercept_per_group\": -2.942302942276001, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 4, \"draws\": 541, \"mu_intercept_per_group\": -3.8632140159606934, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 4, \"draws\": 542, \"mu_intercept_per_group\": -3.9833905696868896, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 4, \"draws\": 543, \"mu_intercept_per_group\": -2.968825101852417, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 4, \"draws\": 544, \"mu_intercept_per_group\": -4.591165065765381, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 4, \"draws\": 545, \"mu_intercept_per_group\": -4.5309038162231445, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 4, \"draws\": 546, \"mu_intercept_per_group\": -3.943223237991333, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 4, \"draws\": 547, \"mu_intercept_per_group\": -4.770256996154785, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 4, \"draws\": 548, \"mu_intercept_per_group\": -4.093761444091797, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 4, \"draws\": 549, \"mu_intercept_per_group\": -3.8612608909606934, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 4, \"draws\": 550, \"mu_intercept_per_group\": -4.252291202545166, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 4, \"draws\": 551, \"mu_intercept_per_group\": -4.2185258865356445, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 4, \"draws\": 552, \"mu_intercept_per_group\": -5.181571960449219, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 4, \"draws\": 553, \"mu_intercept_per_group\": -4.663662910461426, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 4, \"draws\": 554, \"mu_intercept_per_group\": -4.433403015136719, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 4, \"draws\": 555, \"mu_intercept_per_group\": -5.282678604125977, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 4, \"draws\": 556, \"mu_intercept_per_group\": -5.20654821395874, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 4, \"draws\": 557, \"mu_intercept_per_group\": -4.824530601501465, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 4, \"draws\": 558, \"mu_intercept_per_group\": -5.099240779876709, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 4, \"draws\": 559, \"mu_intercept_per_group\": -4.2522687911987305, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 4, \"draws\": 560, \"mu_intercept_per_group\": -4.258301258087158, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 4, \"draws\": 561, \"mu_intercept_per_group\": -3.9566400051116943, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 4, \"draws\": 562, \"mu_intercept_per_group\": -4.13801908493042, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 4, \"draws\": 563, \"mu_intercept_per_group\": -4.612829685211182, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 4, \"draws\": 564, \"mu_intercept_per_group\": -2.847416877746582, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 4, \"draws\": 565, \"mu_intercept_per_group\": -3.4255168437957764, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 4, \"draws\": 566, \"mu_intercept_per_group\": -3.2269604206085205, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 4, \"draws\": 567, \"mu_intercept_per_group\": -2.788729429244995, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 4, \"draws\": 568, \"mu_intercept_per_group\": -2.824359893798828, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 4, \"draws\": 569, \"mu_intercept_per_group\": -3.052668333053589, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 4, \"draws\": 570, \"mu_intercept_per_group\": -3.418741464614868, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 4, \"draws\": 571, \"mu_intercept_per_group\": -3.387570381164551, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 4, \"draws\": 572, \"mu_intercept_per_group\": -3.9114391803741455, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 4, \"draws\": 573, \"mu_intercept_per_group\": -4.065336227416992, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 4, \"draws\": 574, \"mu_intercept_per_group\": -4.3415327072143555, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 4, \"draws\": 575, \"mu_intercept_per_group\": -5.4453349113464355, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 4, \"draws\": 576, \"mu_intercept_per_group\": -5.5228962898254395, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 4, \"draws\": 577, \"mu_intercept_per_group\": -5.544732093811035, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 4, \"draws\": 578, \"mu_intercept_per_group\": -5.4729461669921875, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 4, \"draws\": 579, \"mu_intercept_per_group\": -6.660963535308838, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 4, \"draws\": 580, \"mu_intercept_per_group\": -6.4763922691345215, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 4, \"draws\": 581, \"mu_intercept_per_group\": -4.478976249694824, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 4, \"draws\": 582, \"mu_intercept_per_group\": -4.907191753387451, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 4, \"draws\": 583, \"mu_intercept_per_group\": -5.86683988571167, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 4, \"draws\": 584, \"mu_intercept_per_group\": -4.188579082489014, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 4, \"draws\": 585, \"mu_intercept_per_group\": -5.674649238586426, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 4, \"draws\": 586, \"mu_intercept_per_group\": -5.717710018157959, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 4, \"draws\": 587, \"mu_intercept_per_group\": -6.036621570587158, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 4, \"draws\": 588, \"mu_intercept_per_group\": -5.85478401184082, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 4, \"draws\": 589, \"mu_intercept_per_group\": -5.709803581237793, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 4, \"draws\": 590, \"mu_intercept_per_group\": -5.727370738983154, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 4, \"draws\": 591, \"mu_intercept_per_group\": -6.035646438598633, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 4, \"draws\": 592, \"mu_intercept_per_group\": -6.362344741821289, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 4, \"draws\": 593, \"mu_intercept_per_group\": -6.7093424797058105, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 4, \"draws\": 594, \"mu_intercept_per_group\": -7.108487129211426, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 4, \"draws\": 595, \"mu_intercept_per_group\": -5.4198808670043945, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 4, \"draws\": 596, \"mu_intercept_per_group\": -6.380059242248535, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 4, \"draws\": 597, \"mu_intercept_per_group\": -6.642141819000244, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 4, \"draws\": 598, \"mu_intercept_per_group\": -7.352542877197266, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 4, \"draws\": 599, \"mu_intercept_per_group\": -6.631113529205322, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 4, \"draws\": 600, \"mu_intercept_per_group\": -7.120119094848633, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 4, \"draws\": 601, \"mu_intercept_per_group\": -6.907416820526123, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 4, \"draws\": 602, \"mu_intercept_per_group\": -7.215344429016113, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 4, \"draws\": 603, \"mu_intercept_per_group\": -6.971077919006348, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 4, \"draws\": 604, \"mu_intercept_per_group\": -6.897181987762451, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 4, \"draws\": 605, \"mu_intercept_per_group\": -7.283603668212891, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 4, \"draws\": 606, \"mu_intercept_per_group\": -6.49800443649292, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 4, \"draws\": 607, \"mu_intercept_per_group\": -5.1211724281311035, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 4, \"draws\": 608, \"mu_intercept_per_group\": -3.6746926307678223, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 4, \"draws\": 609, \"mu_intercept_per_group\": -3.4845449924468994, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 4, \"draws\": 610, \"mu_intercept_per_group\": -3.575435161590576, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 4, \"draws\": 611, \"mu_intercept_per_group\": -3.6247293949127197, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 4, \"draws\": 612, \"mu_intercept_per_group\": -2.869335412979126, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 4, \"draws\": 613, \"mu_intercept_per_group\": -3.906411647796631, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 4, \"draws\": 614, \"mu_intercept_per_group\": -3.589778423309326, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 4, \"draws\": 615, \"mu_intercept_per_group\": -3.0932862758636475, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 4, \"draws\": 616, \"mu_intercept_per_group\": -3.6840925216674805, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 4, \"draws\": 617, \"mu_intercept_per_group\": -3.7941360473632812, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 4, \"draws\": 618, \"mu_intercept_per_group\": -6.279681205749512, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 4, \"draws\": 619, \"mu_intercept_per_group\": -5.739294528961182, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 4, \"draws\": 620, \"mu_intercept_per_group\": -6.042718410491943, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 4, \"draws\": 621, \"mu_intercept_per_group\": -5.980036735534668, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 4, \"draws\": 622, \"mu_intercept_per_group\": -5.620779991149902, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 4, \"draws\": 623, \"mu_intercept_per_group\": -5.187619209289551, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 4, \"draws\": 624, \"mu_intercept_per_group\": -6.674992084503174, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 4, \"draws\": 625, \"mu_intercept_per_group\": -6.819550037384033, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 4, \"draws\": 626, \"mu_intercept_per_group\": -6.114410877227783, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 4, \"draws\": 627, \"mu_intercept_per_group\": -5.5620951652526855, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 4, \"draws\": 628, \"mu_intercept_per_group\": -5.536381721496582, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 4, \"draws\": 629, \"mu_intercept_per_group\": -3.0471675395965576, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 4, \"draws\": 630, \"mu_intercept_per_group\": -2.9261879920959473, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 4, \"draws\": 631, \"mu_intercept_per_group\": -3.1725387573242188, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 4, \"draws\": 632, \"mu_intercept_per_group\": -3.752673864364624, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 4, \"draws\": 633, \"mu_intercept_per_group\": -3.8568577766418457, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 4, \"draws\": 634, \"mu_intercept_per_group\": -4.942365646362305, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 4, \"draws\": 635, \"mu_intercept_per_group\": -3.1797034740448, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 4, \"draws\": 636, \"mu_intercept_per_group\": -3.2032883167266846, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 4, \"draws\": 637, \"mu_intercept_per_group\": -3.29259991645813, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 4, \"draws\": 638, \"mu_intercept_per_group\": -3.0837907791137695, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 4, \"draws\": 639, \"mu_intercept_per_group\": -2.9839587211608887, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 5, \"draws\": 0, \"mu_intercept_per_group\": -1.5793304443359375, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 5, \"draws\": 1, \"mu_intercept_per_group\": -0.3386399745941162, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 5, \"draws\": 2, \"mu_intercept_per_group\": -0.6066361665725708, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 5, \"draws\": 3, \"mu_intercept_per_group\": -1.1273313760757446, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 5, \"draws\": 4, \"mu_intercept_per_group\": -1.139746069908142, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 5, \"draws\": 5, \"mu_intercept_per_group\": -0.8700952529907227, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 5, \"draws\": 6, \"mu_intercept_per_group\": -1.3974287509918213, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 5, \"draws\": 7, \"mu_intercept_per_group\": -1.1432844400405884, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 5, \"draws\": 8, \"mu_intercept_per_group\": -1.0779393911361694, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 5, \"draws\": 9, \"mu_intercept_per_group\": -0.8921818137168884, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 5, \"draws\": 10, \"mu_intercept_per_group\": -0.9124529957771301, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 5, \"draws\": 11, \"mu_intercept_per_group\": -0.6906599402427673, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 5, \"draws\": 12, \"mu_intercept_per_group\": -1.468015193939209, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 5, \"draws\": 13, \"mu_intercept_per_group\": -1.774086356163025, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 5, \"draws\": 14, \"mu_intercept_per_group\": -1.6288797855377197, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 5, \"draws\": 15, \"mu_intercept_per_group\": -0.7182140350341797, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 5, \"draws\": 16, \"mu_intercept_per_group\": -1.4240251779556274, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 5, \"draws\": 17, \"mu_intercept_per_group\": -1.5990158319473267, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 5, \"draws\": 18, \"mu_intercept_per_group\": -2.260577917098999, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 5, \"draws\": 19, \"mu_intercept_per_group\": -1.4570704698562622, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 5, \"draws\": 20, \"mu_intercept_per_group\": -0.7702620029449463, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 5, \"draws\": 21, \"mu_intercept_per_group\": -2.093247175216675, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 5, \"draws\": 22, \"mu_intercept_per_group\": -1.460252285003662, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 5, \"draws\": 23, \"mu_intercept_per_group\": -1.5284886360168457, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 5, \"draws\": 24, \"mu_intercept_per_group\": -1.7178409099578857, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 5, \"draws\": 25, \"mu_intercept_per_group\": -1.849600911140442, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 5, \"draws\": 26, \"mu_intercept_per_group\": -1.5821080207824707, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 5, \"draws\": 27, \"mu_intercept_per_group\": -1.5546361207962036, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 5, \"draws\": 28, \"mu_intercept_per_group\": -2.485996723175049, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 5, \"draws\": 29, \"mu_intercept_per_group\": -1.959211826324463, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 5, \"draws\": 30, \"mu_intercept_per_group\": -2.1365835666656494, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 5, \"draws\": 31, \"mu_intercept_per_group\": -2.3494980335235596, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 5, \"draws\": 32, \"mu_intercept_per_group\": -1.414552927017212, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 5, \"draws\": 33, \"mu_intercept_per_group\": -1.3385727405548096, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 5, \"draws\": 34, \"mu_intercept_per_group\": -1.3192826509475708, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 5, \"draws\": 35, \"mu_intercept_per_group\": -1.3542405366897583, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 5, \"draws\": 36, \"mu_intercept_per_group\": -1.2869433164596558, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 5, \"draws\": 37, \"mu_intercept_per_group\": -2.1492984294891357, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 5, \"draws\": 38, \"mu_intercept_per_group\": -0.2042546570301056, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 5, \"draws\": 39, \"mu_intercept_per_group\": -0.6039175391197205, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 5, \"draws\": 40, \"mu_intercept_per_group\": -1.4348515272140503, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 5, \"draws\": 41, \"mu_intercept_per_group\": -0.7525573372840881, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 5, \"draws\": 42, \"mu_intercept_per_group\": -1.740633249282837, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 5, \"draws\": 43, \"mu_intercept_per_group\": -2.3854494094848633, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 5, \"draws\": 44, \"mu_intercept_per_group\": -2.030940532684326, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 5, \"draws\": 45, \"mu_intercept_per_group\": -0.9836751818656921, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 5, \"draws\": 46, \"mu_intercept_per_group\": -1.2793201208114624, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 5, \"draws\": 47, \"mu_intercept_per_group\": -1.2328218221664429, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 5, \"draws\": 48, \"mu_intercept_per_group\": -1.6185036897659302, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 5, \"draws\": 49, \"mu_intercept_per_group\": -1.5202380418777466, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 5, \"draws\": 50, \"mu_intercept_per_group\": -0.9224631786346436, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 5, \"draws\": 51, \"mu_intercept_per_group\": -0.6605522036552429, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 5, \"draws\": 52, \"mu_intercept_per_group\": -0.8635042905807495, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 5, \"draws\": 53, \"mu_intercept_per_group\": -0.7943082451820374, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 5, \"draws\": 54, \"mu_intercept_per_group\": -0.8728619813919067, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 5, \"draws\": 55, \"mu_intercept_per_group\": -0.7869472503662109, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 5, \"draws\": 56, \"mu_intercept_per_group\": -0.17961649596691132, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 5, \"draws\": 57, \"mu_intercept_per_group\": -0.30677372217178345, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 5, \"draws\": 58, \"mu_intercept_per_group\": -0.3844347298145294, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 5, \"draws\": 59, \"mu_intercept_per_group\": -0.47244492173194885, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 5, \"draws\": 60, \"mu_intercept_per_group\": -0.5176213979721069, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 5, \"draws\": 61, \"mu_intercept_per_group\": -1.193021297454834, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 5, \"draws\": 62, \"mu_intercept_per_group\": -1.5825754404067993, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 5, \"draws\": 63, \"mu_intercept_per_group\": -1.656615138053894, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 5, \"draws\": 64, \"mu_intercept_per_group\": -1.6231993436813354, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 5, \"draws\": 65, \"mu_intercept_per_group\": -1.6169003248214722, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 5, \"draws\": 66, \"mu_intercept_per_group\": -1.7128803730010986, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 5, \"draws\": 67, \"mu_intercept_per_group\": -1.599549412727356, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 5, \"draws\": 68, \"mu_intercept_per_group\": -1.5501813888549805, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 5, \"draws\": 69, \"mu_intercept_per_group\": -1.5531164407730103, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 5, \"draws\": 70, \"mu_intercept_per_group\": -0.5559641122817993, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 5, \"draws\": 71, \"mu_intercept_per_group\": -0.5147886276245117, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 5, \"draws\": 72, \"mu_intercept_per_group\": -0.48789647221565247, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 5, \"draws\": 73, \"mu_intercept_per_group\": -0.6109480261802673, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 5, \"draws\": 74, \"mu_intercept_per_group\": -0.5583378076553345, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 5, \"draws\": 75, \"mu_intercept_per_group\": -0.5488558411598206, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 5, \"draws\": 76, \"mu_intercept_per_group\": -0.5581833720207214, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 5, \"draws\": 77, \"mu_intercept_per_group\": -1.4750500917434692, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 5, \"draws\": 78, \"mu_intercept_per_group\": -1.0945720672607422, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 5, \"draws\": 79, \"mu_intercept_per_group\": -0.9208037853240967, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 5, \"draws\": 80, \"mu_intercept_per_group\": -2.634246587753296, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 5, \"draws\": 81, \"mu_intercept_per_group\": -1.0617647171020508, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 5, \"draws\": 82, \"mu_intercept_per_group\": -0.9755017757415771, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 5, \"draws\": 83, \"mu_intercept_per_group\": -0.8871098160743713, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 5, \"draws\": 84, \"mu_intercept_per_group\": -2.1612138748168945, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 5, \"draws\": 85, \"mu_intercept_per_group\": -1.959204912185669, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 5, \"draws\": 86, \"mu_intercept_per_group\": -1.7251263856887817, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 5, \"draws\": 87, \"mu_intercept_per_group\": -0.9083702564239502, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 5, \"draws\": 88, \"mu_intercept_per_group\": -0.9043962359428406, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 5, \"draws\": 89, \"mu_intercept_per_group\": -0.795539140701294, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 5, \"draws\": 90, \"mu_intercept_per_group\": -1.005604863166809, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 5, \"draws\": 91, \"mu_intercept_per_group\": -0.5135535597801208, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 5, \"draws\": 92, \"mu_intercept_per_group\": -1.041568398475647, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 5, \"draws\": 93, \"mu_intercept_per_group\": -0.43796899914741516, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 5, \"draws\": 94, \"mu_intercept_per_group\": -0.4092741310596466, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 5, \"draws\": 95, \"mu_intercept_per_group\": -0.39452773332595825, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 5, \"draws\": 96, \"mu_intercept_per_group\": -0.5989896655082703, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 5, \"draws\": 97, \"mu_intercept_per_group\": -0.4781475365161896, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 5, \"draws\": 98, \"mu_intercept_per_group\": -1.2757444381713867, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 5, \"draws\": 99, \"mu_intercept_per_group\": -1.3071010112762451, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 5, \"draws\": 100, \"mu_intercept_per_group\": -1.4424288272857666, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 5, \"draws\": 101, \"mu_intercept_per_group\": -0.7024034261703491, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 5, \"draws\": 102, \"mu_intercept_per_group\": -1.3886243104934692, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 5, \"draws\": 103, \"mu_intercept_per_group\": -0.6554731726646423, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 5, \"draws\": 104, \"mu_intercept_per_group\": -1.3257298469543457, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 5, \"draws\": 105, \"mu_intercept_per_group\": -1.3706328868865967, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 5, \"draws\": 106, \"mu_intercept_per_group\": -1.6659761667251587, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 5, \"draws\": 107, \"mu_intercept_per_group\": -1.8181687593460083, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 5, \"draws\": 108, \"mu_intercept_per_group\": -2.0179829597473145, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 5, \"draws\": 109, \"mu_intercept_per_group\": -1.406087875366211, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 5, \"draws\": 110, \"mu_intercept_per_group\": -1.0864651203155518, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 5, \"draws\": 111, \"mu_intercept_per_group\": -2.1734182834625244, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 5, \"draws\": 112, \"mu_intercept_per_group\": -1.8220123052597046, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 5, \"draws\": 113, \"mu_intercept_per_group\": -1.6228489875793457, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 5, \"draws\": 114, \"mu_intercept_per_group\": -1.2134534120559692, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 5, \"draws\": 115, \"mu_intercept_per_group\": -0.9925497770309448, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 5, \"draws\": 116, \"mu_intercept_per_group\": -1.258803367614746, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 5, \"draws\": 117, \"mu_intercept_per_group\": -1.4048693180084229, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 5, \"draws\": 118, \"mu_intercept_per_group\": -1.2095900774002075, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 5, \"draws\": 119, \"mu_intercept_per_group\": -0.7187108397483826, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 5, \"draws\": 120, \"mu_intercept_per_group\": -2.2112927436828613, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 5, \"draws\": 121, \"mu_intercept_per_group\": -2.2117886543273926, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 5, \"draws\": 122, \"mu_intercept_per_group\": -1.924555778503418, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 5, \"draws\": 123, \"mu_intercept_per_group\": -1.9193533658981323, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 5, \"draws\": 124, \"mu_intercept_per_group\": -1.7649424076080322, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 5, \"draws\": 125, \"mu_intercept_per_group\": -1.8945544958114624, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 5, \"draws\": 126, \"mu_intercept_per_group\": -1.9902231693267822, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 5, \"draws\": 127, \"mu_intercept_per_group\": -2.00016713142395, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 5, \"draws\": 128, \"mu_intercept_per_group\": -1.4538748264312744, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 5, \"draws\": 129, \"mu_intercept_per_group\": -1.0874958038330078, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 5, \"draws\": 130, \"mu_intercept_per_group\": -1.1027657985687256, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 5, \"draws\": 131, \"mu_intercept_per_group\": -0.8530477285385132, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 5, \"draws\": 132, \"mu_intercept_per_group\": -1.0660871267318726, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 5, \"draws\": 133, \"mu_intercept_per_group\": -1.3925387859344482, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 5, \"draws\": 134, \"mu_intercept_per_group\": -1.6132956743240356, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 5, \"draws\": 135, \"mu_intercept_per_group\": -1.685394525527954, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 5, \"draws\": 136, \"mu_intercept_per_group\": -1.6273133754730225, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 5, \"draws\": 137, \"mu_intercept_per_group\": -1.569743037223816, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 5, \"draws\": 138, \"mu_intercept_per_group\": -1.0141254663467407, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 5, \"draws\": 139, \"mu_intercept_per_group\": -1.2763803005218506, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 5, \"draws\": 140, \"mu_intercept_per_group\": -1.2423560619354248, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 5, \"draws\": 141, \"mu_intercept_per_group\": -1.409285068511963, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 5, \"draws\": 142, \"mu_intercept_per_group\": -1.8523666858673096, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 5, \"draws\": 143, \"mu_intercept_per_group\": -0.630407452583313, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 5, \"draws\": 144, \"mu_intercept_per_group\": -1.2426462173461914, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 5, \"draws\": 145, \"mu_intercept_per_group\": -1.19795823097229, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 5, \"draws\": 146, \"mu_intercept_per_group\": -0.7800688147544861, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 5, \"draws\": 147, \"mu_intercept_per_group\": -0.5423478484153748, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 5, \"draws\": 148, \"mu_intercept_per_group\": -1.1780658960342407, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 5, \"draws\": 149, \"mu_intercept_per_group\": -1.181146264076233, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 5, \"draws\": 150, \"mu_intercept_per_group\": -0.9817159175872803, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 5, \"draws\": 151, \"mu_intercept_per_group\": -0.9313755035400391, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 5, \"draws\": 152, \"mu_intercept_per_group\": -0.9490402936935425, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 5, \"draws\": 153, \"mu_intercept_per_group\": -0.8036763072013855, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 5, \"draws\": 154, \"mu_intercept_per_group\": -1.26613187789917, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 5, \"draws\": 155, \"mu_intercept_per_group\": -0.8601390719413757, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 5, \"draws\": 156, \"mu_intercept_per_group\": -0.8201642036437988, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 5, \"draws\": 157, \"mu_intercept_per_group\": -0.5648239850997925, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 5, \"draws\": 158, \"mu_intercept_per_group\": -1.3028912544250488, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 5, \"draws\": 159, \"mu_intercept_per_group\": -1.2925969362258911, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 5, \"draws\": 160, \"mu_intercept_per_group\": -3.579207420349121, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 5, \"draws\": 161, \"mu_intercept_per_group\": -1.7752635478973389, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 5, \"draws\": 162, \"mu_intercept_per_group\": -2.7721197605133057, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 5, \"draws\": 163, \"mu_intercept_per_group\": -0.83809494972229, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 5, \"draws\": 164, \"mu_intercept_per_group\": -1.651466965675354, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 5, \"draws\": 165, \"mu_intercept_per_group\": -1.4543590545654297, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 5, \"draws\": 166, \"mu_intercept_per_group\": -2.081183433532715, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 5, \"draws\": 167, \"mu_intercept_per_group\": -2.2773990631103516, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 5, \"draws\": 168, \"mu_intercept_per_group\": -2.692565679550171, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 5, \"draws\": 169, \"mu_intercept_per_group\": -1.6770504713058472, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 5, \"draws\": 170, \"mu_intercept_per_group\": -1.5986809730529785, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 5, \"draws\": 171, \"mu_intercept_per_group\": -2.257812976837158, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 5, \"draws\": 172, \"mu_intercept_per_group\": -2.227414131164551, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 5, \"draws\": 173, \"mu_intercept_per_group\": -2.062645673751831, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 5, \"draws\": 174, \"mu_intercept_per_group\": -2.1379172801971436, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 5, \"draws\": 175, \"mu_intercept_per_group\": -1.982905626296997, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 5, \"draws\": 176, \"mu_intercept_per_group\": -1.619933843612671, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 5, \"draws\": 177, \"mu_intercept_per_group\": -1.43576979637146, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 5, \"draws\": 178, \"mu_intercept_per_group\": -1.947229027748108, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 5, \"draws\": 179, \"mu_intercept_per_group\": -1.2781716585159302, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 5, \"draws\": 180, \"mu_intercept_per_group\": -0.6059046387672424, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 5, \"draws\": 181, \"mu_intercept_per_group\": -1.1831443309783936, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 5, \"draws\": 182, \"mu_intercept_per_group\": -0.3439643681049347, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 5, \"draws\": 183, \"mu_intercept_per_group\": -0.3802606165409088, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 5, \"draws\": 184, \"mu_intercept_per_group\": -1.5765905380249023, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 5, \"draws\": 185, \"mu_intercept_per_group\": -1.5360254049301147, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 5, \"draws\": 186, \"mu_intercept_per_group\": -1.588009238243103, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 5, \"draws\": 187, \"mu_intercept_per_group\": -1.4076342582702637, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 5, \"draws\": 188, \"mu_intercept_per_group\": -1.331429362297058, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 5, \"draws\": 189, \"mu_intercept_per_group\": -1.5125035047531128, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 5, \"draws\": 190, \"mu_intercept_per_group\": -1.175573706626892, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 5, \"draws\": 191, \"mu_intercept_per_group\": -1.4759044647216797, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 5, \"draws\": 192, \"mu_intercept_per_group\": -1.777660608291626, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 5, \"draws\": 193, \"mu_intercept_per_group\": -0.7045328617095947, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 5, \"draws\": 194, \"mu_intercept_per_group\": -0.8186622858047485, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 5, \"draws\": 195, \"mu_intercept_per_group\": -0.7953992486000061, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 5, \"draws\": 196, \"mu_intercept_per_group\": -1.9781798124313354, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 5, \"draws\": 197, \"mu_intercept_per_group\": -2.040315628051758, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 5, \"draws\": 198, \"mu_intercept_per_group\": -0.666896402835846, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 5, \"draws\": 199, \"mu_intercept_per_group\": -1.6265122890472412, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 5, \"draws\": 200, \"mu_intercept_per_group\": -1.8275490999221802, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 5, \"draws\": 201, \"mu_intercept_per_group\": -1.355084776878357, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 5, \"draws\": 202, \"mu_intercept_per_group\": -0.5356783866882324, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 5, \"draws\": 203, \"mu_intercept_per_group\": -0.9541614651679993, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 5, \"draws\": 204, \"mu_intercept_per_group\": -1.0470136404037476, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 5, \"draws\": 205, \"mu_intercept_per_group\": -0.38598668575286865, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 5, \"draws\": 206, \"mu_intercept_per_group\": -2.0536797046661377, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 5, \"draws\": 207, \"mu_intercept_per_group\": -2.166334390640259, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 5, \"draws\": 208, \"mu_intercept_per_group\": -2.1086857318878174, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 5, \"draws\": 209, \"mu_intercept_per_group\": -1.0443857908248901, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 5, \"draws\": 210, \"mu_intercept_per_group\": -1.5650837421417236, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 5, \"draws\": 211, \"mu_intercept_per_group\": -1.616254448890686, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 5, \"draws\": 212, \"mu_intercept_per_group\": -1.8000385761260986, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 5, \"draws\": 213, \"mu_intercept_per_group\": 0.08724179863929749, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 5, \"draws\": 214, \"mu_intercept_per_group\": -0.32694634795188904, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 5, \"draws\": 215, \"mu_intercept_per_group\": -1.1668390035629272, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 5, \"draws\": 216, \"mu_intercept_per_group\": -1.1467140913009644, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 5, \"draws\": 217, \"mu_intercept_per_group\": -1.2304414510726929, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 5, \"draws\": 218, \"mu_intercept_per_group\": -0.28019747138023376, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 5, \"draws\": 219, \"mu_intercept_per_group\": -0.7151187062263489, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 5, \"draws\": 220, \"mu_intercept_per_group\": -0.5330749154090881, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 5, \"draws\": 221, \"mu_intercept_per_group\": -0.7170394659042358, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 5, \"draws\": 222, \"mu_intercept_per_group\": -0.7086692452430725, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 5, \"draws\": 223, \"mu_intercept_per_group\": -0.5447890162467957, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 5, \"draws\": 224, \"mu_intercept_per_group\": -0.8425978422164917, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 5, \"draws\": 225, \"mu_intercept_per_group\": -0.7691192626953125, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 5, \"draws\": 226, \"mu_intercept_per_group\": -0.7283124923706055, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 5, \"draws\": 227, \"mu_intercept_per_group\": -1.035970687866211, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 5, \"draws\": 228, \"mu_intercept_per_group\": -1.0237685441970825, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 5, \"draws\": 229, \"mu_intercept_per_group\": -1.0436331033706665, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 5, \"draws\": 230, \"mu_intercept_per_group\": -0.9203091263771057, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 5, \"draws\": 231, \"mu_intercept_per_group\": -0.8533544540405273, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 5, \"draws\": 232, \"mu_intercept_per_group\": -0.37059545516967773, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 5, \"draws\": 233, \"mu_intercept_per_group\": -0.30060404539108276, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 5, \"draws\": 234, \"mu_intercept_per_group\": -0.531226634979248, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 5, \"draws\": 235, \"mu_intercept_per_group\": -0.4825955033302307, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 5, \"draws\": 236, \"mu_intercept_per_group\": -0.6969283223152161, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 5, \"draws\": 237, \"mu_intercept_per_group\": -0.8991882801055908, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 5, \"draws\": 238, \"mu_intercept_per_group\": -0.8116040229797363, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 5, \"draws\": 239, \"mu_intercept_per_group\": -0.8294022679328918, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 5, \"draws\": 240, \"mu_intercept_per_group\": -0.8432760834693909, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 5, \"draws\": 241, \"mu_intercept_per_group\": -1.1694259643554688, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 5, \"draws\": 242, \"mu_intercept_per_group\": -0.8039877414703369, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 5, \"draws\": 243, \"mu_intercept_per_group\": -0.787101686000824, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 5, \"draws\": 244, \"mu_intercept_per_group\": -1.7842700481414795, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 5, \"draws\": 245, \"mu_intercept_per_group\": -1.7787739038467407, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 5, \"draws\": 246, \"mu_intercept_per_group\": -0.7393859624862671, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 5, \"draws\": 247, \"mu_intercept_per_group\": -0.47591856122016907, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 5, \"draws\": 248, \"mu_intercept_per_group\": -0.8940849304199219, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 5, \"draws\": 249, \"mu_intercept_per_group\": -0.8242979645729065, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 5, \"draws\": 250, \"mu_intercept_per_group\": -0.7360490560531616, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 5, \"draws\": 251, \"mu_intercept_per_group\": -1.048547625541687, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 5, \"draws\": 252, \"mu_intercept_per_group\": -1.2236298322677612, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 5, \"draws\": 253, \"mu_intercept_per_group\": -1.2562119960784912, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 5, \"draws\": 254, \"mu_intercept_per_group\": -0.8217189908027649, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 5, \"draws\": 255, \"mu_intercept_per_group\": -0.7889475226402283, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 5, \"draws\": 256, \"mu_intercept_per_group\": -0.9303635954856873, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 5, \"draws\": 257, \"mu_intercept_per_group\": -1.3767677545547485, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 5, \"draws\": 258, \"mu_intercept_per_group\": -0.9082226753234863, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 5, \"draws\": 259, \"mu_intercept_per_group\": -0.8722160458564758, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 5, \"draws\": 260, \"mu_intercept_per_group\": -0.946395993232727, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 5, \"draws\": 261, \"mu_intercept_per_group\": -0.7337520122528076, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 5, \"draws\": 262, \"mu_intercept_per_group\": -0.7785698771476746, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 5, \"draws\": 263, \"mu_intercept_per_group\": -0.8139783143997192, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 5, \"draws\": 264, \"mu_intercept_per_group\": -1.0860705375671387, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 5, \"draws\": 265, \"mu_intercept_per_group\": -1.166969895362854, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 5, \"draws\": 266, \"mu_intercept_per_group\": -0.6989108324050903, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 5, \"draws\": 267, \"mu_intercept_per_group\": -0.5923544764518738, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 5, \"draws\": 268, \"mu_intercept_per_group\": -0.4918759763240814, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 5, \"draws\": 269, \"mu_intercept_per_group\": -1.1514378786087036, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 5, \"draws\": 270, \"mu_intercept_per_group\": -0.9468256235122681, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 5, \"draws\": 271, \"mu_intercept_per_group\": -0.8423957228660583, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 5, \"draws\": 272, \"mu_intercept_per_group\": -1.3712998628616333, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 5, \"draws\": 273, \"mu_intercept_per_group\": -0.7293978929519653, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 5, \"draws\": 274, \"mu_intercept_per_group\": -1.507312536239624, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 5, \"draws\": 275, \"mu_intercept_per_group\": -1.626999020576477, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 5, \"draws\": 276, \"mu_intercept_per_group\": -1.2152295112609863, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 5, \"draws\": 277, \"mu_intercept_per_group\": -1.5028148889541626, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 5, \"draws\": 278, \"mu_intercept_per_group\": -1.337175726890564, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 5, \"draws\": 279, \"mu_intercept_per_group\": -1.137499213218689, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 5, \"draws\": 280, \"mu_intercept_per_group\": -1.3662246465682983, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 5, \"draws\": 281, \"mu_intercept_per_group\": -2.0934667587280273, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 5, \"draws\": 282, \"mu_intercept_per_group\": -1.9115415811538696, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 5, \"draws\": 283, \"mu_intercept_per_group\": -2.006162643432617, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 5, \"draws\": 284, \"mu_intercept_per_group\": -1.9136282205581665, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 5, \"draws\": 285, \"mu_intercept_per_group\": -2.0810935497283936, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 5, \"draws\": 286, \"mu_intercept_per_group\": -2.0864152908325195, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 5, \"draws\": 287, \"mu_intercept_per_group\": -1.831087350845337, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 5, \"draws\": 288, \"mu_intercept_per_group\": -1.9696316719055176, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 5, \"draws\": 289, \"mu_intercept_per_group\": -2.1387741565704346, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 5, \"draws\": 290, \"mu_intercept_per_group\": -2.5705578327178955, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 5, \"draws\": 291, \"mu_intercept_per_group\": -2.068910598754883, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 5, \"draws\": 292, \"mu_intercept_per_group\": -2.0467514991760254, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 5, \"draws\": 293, \"mu_intercept_per_group\": -0.8598767518997192, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 5, \"draws\": 294, \"mu_intercept_per_group\": -1.1387608051300049, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 5, \"draws\": 295, \"mu_intercept_per_group\": -1.3851009607315063, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 5, \"draws\": 296, \"mu_intercept_per_group\": -1.0754187107086182, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 5, \"draws\": 297, \"mu_intercept_per_group\": -1.063109278678894, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 5, \"draws\": 298, \"mu_intercept_per_group\": -1.449560523033142, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 5, \"draws\": 299, \"mu_intercept_per_group\": -1.0850414037704468, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 5, \"draws\": 300, \"mu_intercept_per_group\": -1.336409330368042, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 5, \"draws\": 301, \"mu_intercept_per_group\": -1.1986602544784546, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 5, \"draws\": 302, \"mu_intercept_per_group\": -0.6825391054153442, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 5, \"draws\": 303, \"mu_intercept_per_group\": -0.6786816716194153, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 5, \"draws\": 304, \"mu_intercept_per_group\": -1.236074447631836, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 5, \"draws\": 305, \"mu_intercept_per_group\": -0.6231013536453247, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 5, \"draws\": 306, \"mu_intercept_per_group\": -0.463207483291626, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 5, \"draws\": 307, \"mu_intercept_per_group\": -0.6072850823402405, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 5, \"draws\": 308, \"mu_intercept_per_group\": -1.0374064445495605, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 5, \"draws\": 309, \"mu_intercept_per_group\": -2.1740801334381104, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 5, \"draws\": 310, \"mu_intercept_per_group\": -1.8932750225067139, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 5, \"draws\": 311, \"mu_intercept_per_group\": -1.8794344663619995, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 5, \"draws\": 312, \"mu_intercept_per_group\": -1.9947861433029175, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 5, \"draws\": 313, \"mu_intercept_per_group\": -1.5080268383026123, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 5, \"draws\": 314, \"mu_intercept_per_group\": -1.5660001039505005, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 5, \"draws\": 315, \"mu_intercept_per_group\": -1.3381221294403076, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 5, \"draws\": 316, \"mu_intercept_per_group\": -2.2366812229156494, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 5, \"draws\": 317, \"mu_intercept_per_group\": -2.2404003143310547, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 5, \"draws\": 318, \"mu_intercept_per_group\": -2.2413597106933594, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 5, \"draws\": 319, \"mu_intercept_per_group\": -1.8062713146209717, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 5, \"draws\": 320, \"mu_intercept_per_group\": -0.7263314127922058, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 5, \"draws\": 321, \"mu_intercept_per_group\": -0.7975068092346191, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 5, \"draws\": 322, \"mu_intercept_per_group\": -0.7957483530044556, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 5, \"draws\": 323, \"mu_intercept_per_group\": -0.7118898034095764, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 5, \"draws\": 324, \"mu_intercept_per_group\": -0.7321929931640625, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 5, \"draws\": 325, \"mu_intercept_per_group\": -0.7853003144264221, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 5, \"draws\": 326, \"mu_intercept_per_group\": -0.7524705529212952, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 5, \"draws\": 327, \"mu_intercept_per_group\": -0.49633389711380005, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 5, \"draws\": 328, \"mu_intercept_per_group\": -0.9018470048904419, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 5, \"draws\": 329, \"mu_intercept_per_group\": -0.8959497213363647, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 5, \"draws\": 330, \"mu_intercept_per_group\": -0.9241054058074951, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 5, \"draws\": 331, \"mu_intercept_per_group\": -1.198999047279358, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 5, \"draws\": 332, \"mu_intercept_per_group\": -1.0940786600112915, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 5, \"draws\": 333, \"mu_intercept_per_group\": -0.2030409872531891, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 5, \"draws\": 334, \"mu_intercept_per_group\": -1.1595209836959839, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 5, \"draws\": 335, \"mu_intercept_per_group\": -0.8241695761680603, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 5, \"draws\": 336, \"mu_intercept_per_group\": -0.5313515067100525, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 5, \"draws\": 337, \"mu_intercept_per_group\": -1.1857420206069946, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 5, \"draws\": 338, \"mu_intercept_per_group\": -2.24733567237854, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 5, \"draws\": 339, \"mu_intercept_per_group\": -1.7090815305709839, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 5, \"draws\": 340, \"mu_intercept_per_group\": -1.7544888257980347, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 5, \"draws\": 341, \"mu_intercept_per_group\": -2.4426357746124268, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 5, \"draws\": 342, \"mu_intercept_per_group\": -1.2136198282241821, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 5, \"draws\": 343, \"mu_intercept_per_group\": -0.6513227224349976, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 5, \"draws\": 344, \"mu_intercept_per_group\": -2.5740435123443604, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 5, \"draws\": 345, \"mu_intercept_per_group\": -3.206010580062866, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 5, \"draws\": 346, \"mu_intercept_per_group\": -0.6772065758705139, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 5, \"draws\": 347, \"mu_intercept_per_group\": -1.7722936868667603, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 5, \"draws\": 348, \"mu_intercept_per_group\": -1.067476511001587, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 5, \"draws\": 349, \"mu_intercept_per_group\": -1.0568757057189941, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 5, \"draws\": 350, \"mu_intercept_per_group\": -1.032668113708496, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 5, \"draws\": 351, \"mu_intercept_per_group\": -1.4348303079605103, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 5, \"draws\": 352, \"mu_intercept_per_group\": -1.563767671585083, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 5, \"draws\": 353, \"mu_intercept_per_group\": -1.7050107717514038, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 5, \"draws\": 354, \"mu_intercept_per_group\": -1.2523306608200073, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 5, \"draws\": 355, \"mu_intercept_per_group\": -0.9818125367164612, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 5, \"draws\": 356, \"mu_intercept_per_group\": -0.6945610046386719, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 5, \"draws\": 357, \"mu_intercept_per_group\": -0.6241200566291809, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 5, \"draws\": 358, \"mu_intercept_per_group\": -0.6277928948402405, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 5, \"draws\": 359, \"mu_intercept_per_group\": -0.943081796169281, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 5, \"draws\": 360, \"mu_intercept_per_group\": -0.6452227234840393, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 5, \"draws\": 361, \"mu_intercept_per_group\": -0.8966981768608093, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 5, \"draws\": 362, \"mu_intercept_per_group\": -0.7916486859321594, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 5, \"draws\": 363, \"mu_intercept_per_group\": -0.7835677862167358, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 5, \"draws\": 364, \"mu_intercept_per_group\": -1.3107515573501587, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 5, \"draws\": 365, \"mu_intercept_per_group\": -1.0993295907974243, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 5, \"draws\": 366, \"mu_intercept_per_group\": -1.8770077228546143, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 5, \"draws\": 367, \"mu_intercept_per_group\": -1.8487263917922974, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 5, \"draws\": 368, \"mu_intercept_per_group\": -1.9059489965438843, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 5, \"draws\": 369, \"mu_intercept_per_group\": -0.23495134711265564, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 5, \"draws\": 370, \"mu_intercept_per_group\": -0.7346991300582886, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 5, \"draws\": 371, \"mu_intercept_per_group\": -0.6860364675521851, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 5, \"draws\": 372, \"mu_intercept_per_group\": -0.7511520981788635, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 5, \"draws\": 373, \"mu_intercept_per_group\": -0.8476157188415527, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 5, \"draws\": 374, \"mu_intercept_per_group\": -1.2829341888427734, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 5, \"draws\": 375, \"mu_intercept_per_group\": -0.7268734574317932, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 5, \"draws\": 376, \"mu_intercept_per_group\": -2.0280601978302, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 5, \"draws\": 377, \"mu_intercept_per_group\": -0.6003614068031311, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 5, \"draws\": 378, \"mu_intercept_per_group\": -0.19366997480392456, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 5, \"draws\": 379, \"mu_intercept_per_group\": -0.7375174760818481, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 5, \"draws\": 380, \"mu_intercept_per_group\": -0.7599180340766907, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 5, \"draws\": 381, \"mu_intercept_per_group\": -0.9997471570968628, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 5, \"draws\": 382, \"mu_intercept_per_group\": -0.7191975712776184, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 5, \"draws\": 383, \"mu_intercept_per_group\": -0.8507235646247864, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 5, \"draws\": 384, \"mu_intercept_per_group\": -1.813844919204712, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 5, \"draws\": 385, \"mu_intercept_per_group\": -1.9269781112670898, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 5, \"draws\": 386, \"mu_intercept_per_group\": -1.6688692569732666, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 5, \"draws\": 387, \"mu_intercept_per_group\": -1.6972726583480835, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 5, \"draws\": 388, \"mu_intercept_per_group\": -1.6687583923339844, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 5, \"draws\": 389, \"mu_intercept_per_group\": -0.9452236890792847, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 5, \"draws\": 390, \"mu_intercept_per_group\": -1.3404637575149536, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 5, \"draws\": 391, \"mu_intercept_per_group\": -1.5771164894104004, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 5, \"draws\": 392, \"mu_intercept_per_group\": -1.3309500217437744, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 5, \"draws\": 393, \"mu_intercept_per_group\": -1.1251492500305176, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 5, \"draws\": 394, \"mu_intercept_per_group\": -1.192922830581665, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 5, \"draws\": 395, \"mu_intercept_per_group\": -1.333432674407959, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 5, \"draws\": 396, \"mu_intercept_per_group\": -1.1278433799743652, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 5, \"draws\": 397, \"mu_intercept_per_group\": -1.084143042564392, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 5, \"draws\": 398, \"mu_intercept_per_group\": -1.2883034944534302, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 5, \"draws\": 399, \"mu_intercept_per_group\": -0.5458956360816956, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 5, \"draws\": 400, \"mu_intercept_per_group\": -0.5883055329322815, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 5, \"draws\": 401, \"mu_intercept_per_group\": -1.4416223764419556, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 5, \"draws\": 402, \"mu_intercept_per_group\": -1.354504108428955, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 5, \"draws\": 403, \"mu_intercept_per_group\": -1.3765846490859985, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 5, \"draws\": 404, \"mu_intercept_per_group\": -1.4383494853973389, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 5, \"draws\": 405, \"mu_intercept_per_group\": -1.3342781066894531, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 5, \"draws\": 406, \"mu_intercept_per_group\": -1.3334842920303345, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 5, \"draws\": 407, \"mu_intercept_per_group\": -0.23088467121124268, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 5, \"draws\": 408, \"mu_intercept_per_group\": -0.2701609432697296, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 5, \"draws\": 409, \"mu_intercept_per_group\": -0.966873824596405, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 5, \"draws\": 410, \"mu_intercept_per_group\": -1.2145929336547852, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 5, \"draws\": 411, \"mu_intercept_per_group\": -0.4861750304698944, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 5, \"draws\": 412, \"mu_intercept_per_group\": -0.462912380695343, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 5, \"draws\": 413, \"mu_intercept_per_group\": -1.2776682376861572, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 5, \"draws\": 414, \"mu_intercept_per_group\": -1.3254425525665283, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 5, \"draws\": 415, \"mu_intercept_per_group\": -1.5401476621627808, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 5, \"draws\": 416, \"mu_intercept_per_group\": -1.594929575920105, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 5, \"draws\": 417, \"mu_intercept_per_group\": -1.7677198648452759, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 5, \"draws\": 418, \"mu_intercept_per_group\": -1.4388046264648438, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 5, \"draws\": 419, \"mu_intercept_per_group\": -1.4498974084854126, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 5, \"draws\": 420, \"mu_intercept_per_group\": -1.0218411684036255, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 5, \"draws\": 421, \"mu_intercept_per_group\": -1.2970685958862305, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 5, \"draws\": 422, \"mu_intercept_per_group\": -1.3577823638916016, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 5, \"draws\": 423, \"mu_intercept_per_group\": -0.25416600704193115, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 5, \"draws\": 424, \"mu_intercept_per_group\": -0.7554976344108582, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 5, \"draws\": 425, \"mu_intercept_per_group\": -1.0868221521377563, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 5, \"draws\": 426, \"mu_intercept_per_group\": -2.2906394004821777, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 5, \"draws\": 427, \"mu_intercept_per_group\": -2.378765821456909, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 5, \"draws\": 428, \"mu_intercept_per_group\": -2.5859439373016357, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 5, \"draws\": 429, \"mu_intercept_per_group\": -2.1249704360961914, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 5, \"draws\": 430, \"mu_intercept_per_group\": -1.6778484582901, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 5, \"draws\": 431, \"mu_intercept_per_group\": -2.277637004852295, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 5, \"draws\": 432, \"mu_intercept_per_group\": -1.9305877685546875, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 5, \"draws\": 433, \"mu_intercept_per_group\": -1.7422462701797485, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 5, \"draws\": 434, \"mu_intercept_per_group\": -2.014101505279541, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 5, \"draws\": 435, \"mu_intercept_per_group\": -1.9917324781417847, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 5, \"draws\": 436, \"mu_intercept_per_group\": -1.2047291994094849, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 5, \"draws\": 437, \"mu_intercept_per_group\": -2.077045202255249, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 5, \"draws\": 438, \"mu_intercept_per_group\": -1.653107762336731, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 5, \"draws\": 439, \"mu_intercept_per_group\": -1.5376180410385132, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 5, \"draws\": 440, \"mu_intercept_per_group\": -1.4543657302856445, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 5, \"draws\": 441, \"mu_intercept_per_group\": -1.5344308614730835, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 5, \"draws\": 442, \"mu_intercept_per_group\": -0.553213894367218, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 5, \"draws\": 443, \"mu_intercept_per_group\": -1.7032865285873413, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 5, \"draws\": 444, \"mu_intercept_per_group\": -1.5616077184677124, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 5, \"draws\": 445, \"mu_intercept_per_group\": -0.9944790005683899, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 5, \"draws\": 446, \"mu_intercept_per_group\": -1.905419111251831, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 5, \"draws\": 447, \"mu_intercept_per_group\": -1.9244791269302368, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 5, \"draws\": 448, \"mu_intercept_per_group\": -0.7353504300117493, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 5, \"draws\": 449, \"mu_intercept_per_group\": -1.112964391708374, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 5, \"draws\": 450, \"mu_intercept_per_group\": -0.8417492508888245, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 5, \"draws\": 451, \"mu_intercept_per_group\": -2.4756593704223633, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 5, \"draws\": 452, \"mu_intercept_per_group\": -2.687723159790039, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 5, \"draws\": 453, \"mu_intercept_per_group\": -2.790431022644043, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 5, \"draws\": 454, \"mu_intercept_per_group\": -2.8153600692749023, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 5, \"draws\": 455, \"mu_intercept_per_group\": -3.1138272285461426, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 5, \"draws\": 456, \"mu_intercept_per_group\": -2.2507729530334473, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 5, \"draws\": 457, \"mu_intercept_per_group\": -2.919771194458008, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 5, \"draws\": 458, \"mu_intercept_per_group\": -1.5954054594039917, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 5, \"draws\": 459, \"mu_intercept_per_group\": -1.065798282623291, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 5, \"draws\": 460, \"mu_intercept_per_group\": -1.1142011880874634, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 5, \"draws\": 461, \"mu_intercept_per_group\": -1.1895217895507812, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 5, \"draws\": 462, \"mu_intercept_per_group\": -0.7141769528388977, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 5, \"draws\": 463, \"mu_intercept_per_group\": -0.5605641603469849, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 5, \"draws\": 464, \"mu_intercept_per_group\": -0.9276348352432251, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 5, \"draws\": 465, \"mu_intercept_per_group\": -0.9833197593688965, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 5, \"draws\": 466, \"mu_intercept_per_group\": -0.9504334926605225, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 5, \"draws\": 467, \"mu_intercept_per_group\": -1.2587393522262573, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 5, \"draws\": 468, \"mu_intercept_per_group\": -1.7300000190734863, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 5, \"draws\": 469, \"mu_intercept_per_group\": -1.88367760181427, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 5, \"draws\": 470, \"mu_intercept_per_group\": -1.8614481687545776, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 5, \"draws\": 471, \"mu_intercept_per_group\": -1.1292585134506226, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 5, \"draws\": 472, \"mu_intercept_per_group\": -1.1820170879364014, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 5, \"draws\": 473, \"mu_intercept_per_group\": -2.3315131664276123, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 5, \"draws\": 474, \"mu_intercept_per_group\": -2.017615556716919, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 5, \"draws\": 475, \"mu_intercept_per_group\": -2.0742287635803223, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 5, \"draws\": 476, \"mu_intercept_per_group\": -1.877847671508789, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 5, \"draws\": 477, \"mu_intercept_per_group\": -1.979557752609253, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 5, \"draws\": 478, \"mu_intercept_per_group\": -1.7299554347991943, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 5, \"draws\": 479, \"mu_intercept_per_group\": -2.2394981384277344, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 5, \"draws\": 480, \"mu_intercept_per_group\": -1.6015499830245972, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 5, \"draws\": 481, \"mu_intercept_per_group\": -1.3728324174880981, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 5, \"draws\": 482, \"mu_intercept_per_group\": -1.137937307357788, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 5, \"draws\": 483, \"mu_intercept_per_group\": -1.2004764080047607, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 5, \"draws\": 484, \"mu_intercept_per_group\": -1.4159290790557861, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 5, \"draws\": 485, \"mu_intercept_per_group\": -1.4189338684082031, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 5, \"draws\": 486, \"mu_intercept_per_group\": -1.4090567827224731, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 5, \"draws\": 487, \"mu_intercept_per_group\": -1.4107979536056519, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 5, \"draws\": 488, \"mu_intercept_per_group\": -0.4066404700279236, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 5, \"draws\": 489, \"mu_intercept_per_group\": -1.389673113822937, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 5, \"draws\": 490, \"mu_intercept_per_group\": -1.1020009517669678, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 5, \"draws\": 491, \"mu_intercept_per_group\": -1.0727314949035645, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 5, \"draws\": 492, \"mu_intercept_per_group\": -1.1451019048690796, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 5, \"draws\": 493, \"mu_intercept_per_group\": -1.0572686195373535, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 5, \"draws\": 494, \"mu_intercept_per_group\": -2.1062779426574707, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 5, \"draws\": 495, \"mu_intercept_per_group\": -1.6030666828155518, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 5, \"draws\": 496, \"mu_intercept_per_group\": -1.0114842653274536, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 5, \"draws\": 497, \"mu_intercept_per_group\": -0.9377049803733826, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 5, \"draws\": 498, \"mu_intercept_per_group\": -0.9836239814758301, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 5, \"draws\": 499, \"mu_intercept_per_group\": -1.28663969039917, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 5, \"draws\": 500, \"mu_intercept_per_group\": -1.1798229217529297, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 5, \"draws\": 501, \"mu_intercept_per_group\": -1.2984422445297241, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 5, \"draws\": 502, \"mu_intercept_per_group\": -1.204878330230713, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 5, \"draws\": 503, \"mu_intercept_per_group\": -1.1810373067855835, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 5, \"draws\": 504, \"mu_intercept_per_group\": -1.2803964614868164, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 5, \"draws\": 505, \"mu_intercept_per_group\": -1.2376000881195068, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 5, \"draws\": 506, \"mu_intercept_per_group\": -1.5662354230880737, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 5, \"draws\": 507, \"mu_intercept_per_group\": -1.8467607498168945, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 5, \"draws\": 508, \"mu_intercept_per_group\": -1.099025011062622, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 5, \"draws\": 509, \"mu_intercept_per_group\": -1.55122971534729, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 5, \"draws\": 510, \"mu_intercept_per_group\": -1.7043029069900513, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 5, \"draws\": 511, \"mu_intercept_per_group\": -2.004977226257324, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 5, \"draws\": 512, \"mu_intercept_per_group\": -2.2644708156585693, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 5, \"draws\": 513, \"mu_intercept_per_group\": -1.1932313442230225, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 5, \"draws\": 514, \"mu_intercept_per_group\": -0.9867665767669678, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 5, \"draws\": 515, \"mu_intercept_per_group\": -0.918413519859314, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 5, \"draws\": 516, \"mu_intercept_per_group\": -2.0863423347473145, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 5, \"draws\": 517, \"mu_intercept_per_group\": -2.14388370513916, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 5, \"draws\": 518, \"mu_intercept_per_group\": -2.146881103515625, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 5, \"draws\": 519, \"mu_intercept_per_group\": -1.9218058586120605, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 5, \"draws\": 520, \"mu_intercept_per_group\": -1.8001434803009033, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 5, \"draws\": 521, \"mu_intercept_per_group\": -0.9418633580207825, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 5, \"draws\": 522, \"mu_intercept_per_group\": -1.3270677328109741, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 5, \"draws\": 523, \"mu_intercept_per_group\": -0.99443519115448, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 5, \"draws\": 524, \"mu_intercept_per_group\": -1.134224534034729, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 5, \"draws\": 525, \"mu_intercept_per_group\": -1.3806407451629639, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 5, \"draws\": 526, \"mu_intercept_per_group\": -0.47156664729118347, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 5, \"draws\": 527, \"mu_intercept_per_group\": -1.3198784589767456, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 5, \"draws\": 528, \"mu_intercept_per_group\": -0.9727766513824463, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 5, \"draws\": 529, \"mu_intercept_per_group\": -0.712227463722229, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 5, \"draws\": 530, \"mu_intercept_per_group\": -1.2042841911315918, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 5, \"draws\": 531, \"mu_intercept_per_group\": -1.30672025680542, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 5, \"draws\": 532, \"mu_intercept_per_group\": -1.7680153846740723, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 5, \"draws\": 533, \"mu_intercept_per_group\": -1.8652113676071167, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 5, \"draws\": 534, \"mu_intercept_per_group\": -0.9121977686882019, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 5, \"draws\": 535, \"mu_intercept_per_group\": -1.7785627841949463, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 5, \"draws\": 536, \"mu_intercept_per_group\": -1.4213629961013794, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 5, \"draws\": 537, \"mu_intercept_per_group\": -0.8279338479042053, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 5, \"draws\": 538, \"mu_intercept_per_group\": -0.7687971591949463, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 5, \"draws\": 539, \"mu_intercept_per_group\": -0.8542805910110474, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 5, \"draws\": 540, \"mu_intercept_per_group\": -0.819174587726593, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 5, \"draws\": 541, \"mu_intercept_per_group\": -1.3057807683944702, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 5, \"draws\": 542, \"mu_intercept_per_group\": -1.2841225862503052, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 5, \"draws\": 543, \"mu_intercept_per_group\": -0.6265795230865479, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 5, \"draws\": 544, \"mu_intercept_per_group\": -1.8401150703430176, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 5, \"draws\": 545, \"mu_intercept_per_group\": -1.3862075805664062, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 5, \"draws\": 546, \"mu_intercept_per_group\": -1.6940453052520752, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 5, \"draws\": 547, \"mu_intercept_per_group\": -1.4079958200454712, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 5, \"draws\": 548, \"mu_intercept_per_group\": -1.5120048522949219, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 5, \"draws\": 549, \"mu_intercept_per_group\": -1.5034242868423462, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 5, \"draws\": 550, \"mu_intercept_per_group\": -1.1250765323638916, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 5, \"draws\": 551, \"mu_intercept_per_group\": -1.1370294094085693, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 5, \"draws\": 552, \"mu_intercept_per_group\": -1.4609625339508057, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 5, \"draws\": 553, \"mu_intercept_per_group\": -1.3878421783447266, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 5, \"draws\": 554, \"mu_intercept_per_group\": -1.32957923412323, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 5, \"draws\": 555, \"mu_intercept_per_group\": -1.3149738311767578, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 5, \"draws\": 556, \"mu_intercept_per_group\": -1.1686830520629883, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 5, \"draws\": 557, \"mu_intercept_per_group\": -0.7331857681274414, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 5, \"draws\": 558, \"mu_intercept_per_group\": -0.6091421842575073, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 5, \"draws\": 559, \"mu_intercept_per_group\": -1.4375454187393188, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 5, \"draws\": 560, \"mu_intercept_per_group\": -1.3129926919937134, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 5, \"draws\": 561, \"mu_intercept_per_group\": -1.4415607452392578, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 5, \"draws\": 562, \"mu_intercept_per_group\": -0.6036281585693359, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 5, \"draws\": 563, \"mu_intercept_per_group\": -1.4913184642791748, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 5, \"draws\": 564, \"mu_intercept_per_group\": -1.3650431632995605, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 5, \"draws\": 565, \"mu_intercept_per_group\": -1.0206013917922974, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 5, \"draws\": 566, \"mu_intercept_per_group\": -0.9081404209136963, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 5, \"draws\": 567, \"mu_intercept_per_group\": -1.5527735948562622, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 5, \"draws\": 568, \"mu_intercept_per_group\": -1.1987990140914917, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 5, \"draws\": 569, \"mu_intercept_per_group\": -1.086661696434021, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 5, \"draws\": 570, \"mu_intercept_per_group\": -0.9421762228012085, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 5, \"draws\": 571, \"mu_intercept_per_group\": -0.9798345565795898, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 5, \"draws\": 572, \"mu_intercept_per_group\": -1.1713215112686157, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 5, \"draws\": 573, \"mu_intercept_per_group\": -1.4503273963928223, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 5, \"draws\": 574, \"mu_intercept_per_group\": -1.2748398780822754, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 5, \"draws\": 575, \"mu_intercept_per_group\": -1.7251726388931274, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 5, \"draws\": 576, \"mu_intercept_per_group\": -1.90568208694458, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 5, \"draws\": 577, \"mu_intercept_per_group\": -1.7606265544891357, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 5, \"draws\": 578, \"mu_intercept_per_group\": -0.29791513085365295, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 5, \"draws\": 579, \"mu_intercept_per_group\": -4.2716755867004395, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 5, \"draws\": 580, \"mu_intercept_per_group\": -1.6680243015289307, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 5, \"draws\": 581, \"mu_intercept_per_group\": -2.2965054512023926, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 5, \"draws\": 582, \"mu_intercept_per_group\": -1.0968902111053467, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 5, \"draws\": 583, \"mu_intercept_per_group\": -1.5245212316513062, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 5, \"draws\": 584, \"mu_intercept_per_group\": -1.230912208557129, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 5, \"draws\": 585, \"mu_intercept_per_group\": -1.9569684267044067, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 5, \"draws\": 586, \"mu_intercept_per_group\": -2.143126964569092, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 5, \"draws\": 587, \"mu_intercept_per_group\": -1.9057914018630981, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 5, \"draws\": 588, \"mu_intercept_per_group\": -1.9545046091079712, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 5, \"draws\": 589, \"mu_intercept_per_group\": -2.1852407455444336, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 5, \"draws\": 590, \"mu_intercept_per_group\": -2.1063785552978516, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 5, \"draws\": 591, \"mu_intercept_per_group\": -2.018118143081665, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 5, \"draws\": 592, \"mu_intercept_per_group\": -2.3353257179260254, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 5, \"draws\": 593, \"mu_intercept_per_group\": -2.7735626697540283, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 5, \"draws\": 594, \"mu_intercept_per_group\": -2.036341428756714, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 5, \"draws\": 595, \"mu_intercept_per_group\": -1.949866533279419, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 5, \"draws\": 596, \"mu_intercept_per_group\": -2.4541397094726562, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 5, \"draws\": 597, \"mu_intercept_per_group\": -2.3564720153808594, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 5, \"draws\": 598, \"mu_intercept_per_group\": -2.262061595916748, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 5, \"draws\": 599, \"mu_intercept_per_group\": -2.3837432861328125, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 5, \"draws\": 600, \"mu_intercept_per_group\": -2.694272518157959, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 5, \"draws\": 601, \"mu_intercept_per_group\": -1.0280643701553345, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 5, \"draws\": 602, \"mu_intercept_per_group\": -1.5657631158828735, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 5, \"draws\": 603, \"mu_intercept_per_group\": -1.5768442153930664, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 5, \"draws\": 604, \"mu_intercept_per_group\": -1.6732062101364136, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 5, \"draws\": 605, \"mu_intercept_per_group\": -1.8823237419128418, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 5, \"draws\": 606, \"mu_intercept_per_group\": -2.0594394207000732, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 5, \"draws\": 607, \"mu_intercept_per_group\": -1.6474961042404175, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 5, \"draws\": 608, \"mu_intercept_per_group\": -1.6091055870056152, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 5, \"draws\": 609, \"mu_intercept_per_group\": -1.4945740699768066, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 5, \"draws\": 610, \"mu_intercept_per_group\": -1.0027194023132324, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 5, \"draws\": 611, \"mu_intercept_per_group\": -0.8738247156143188, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 5, \"draws\": 612, \"mu_intercept_per_group\": -0.8441886901855469, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 5, \"draws\": 613, \"mu_intercept_per_group\": -0.8196900486946106, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 5, \"draws\": 614, \"mu_intercept_per_group\": -1.0549908876419067, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 5, \"draws\": 615, \"mu_intercept_per_group\": -1.150259017944336, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 5, \"draws\": 616, \"mu_intercept_per_group\": -1.2988754510879517, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 5, \"draws\": 617, \"mu_intercept_per_group\": -1.2661845684051514, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 5, \"draws\": 618, \"mu_intercept_per_group\": -2.148043155670166, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 5, \"draws\": 619, \"mu_intercept_per_group\": -2.4858853816986084, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 5, \"draws\": 620, \"mu_intercept_per_group\": -2.454902172088623, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 5, \"draws\": 621, \"mu_intercept_per_group\": -2.189439058303833, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 5, \"draws\": 622, \"mu_intercept_per_group\": -2.1197290420532227, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 5, \"draws\": 623, \"mu_intercept_per_group\": -1.3636078834533691, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 5, \"draws\": 624, \"mu_intercept_per_group\": -2.370382785797119, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 5, \"draws\": 625, \"mu_intercept_per_group\": -2.1345653533935547, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 5, \"draws\": 626, \"mu_intercept_per_group\": -1.6626505851745605, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 5, \"draws\": 627, \"mu_intercept_per_group\": -1.8472392559051514, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 5, \"draws\": 628, \"mu_intercept_per_group\": -2.360694646835327, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 5, \"draws\": 629, \"mu_intercept_per_group\": -0.6291685104370117, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 5, \"draws\": 630, \"mu_intercept_per_group\": -0.7307078242301941, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 5, \"draws\": 631, \"mu_intercept_per_group\": -1.1867907047271729, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 5, \"draws\": 632, \"mu_intercept_per_group\": -1.1127946376800537, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 5, \"draws\": 633, \"mu_intercept_per_group\": -1.049731731414795, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 5, \"draws\": 634, \"mu_intercept_per_group\": -1.2533459663391113, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 5, \"draws\": 635, \"mu_intercept_per_group\": -0.7303784489631653, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 5, \"draws\": 636, \"mu_intercept_per_group\": -0.7168490290641785, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 5, \"draws\": 637, \"mu_intercept_per_group\": -0.5208616256713867, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 5, \"draws\": 638, \"mu_intercept_per_group\": -0.8286248445510864, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 5, \"draws\": 639, \"mu_intercept_per_group\": -1.0105972290039062, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 6, \"draws\": 0, \"mu_intercept_per_group\": 6.44242525100708, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 6, \"draws\": 1, \"mu_intercept_per_group\": 7.119933128356934, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 6, \"draws\": 2, \"mu_intercept_per_group\": 7.0878586769104, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 6, \"draws\": 3, \"mu_intercept_per_group\": 6.75143575668335, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 6, \"draws\": 4, \"mu_intercept_per_group\": 7.646886825561523, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 6, \"draws\": 5, \"mu_intercept_per_group\": 7.599708080291748, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 6, \"draws\": 6, \"mu_intercept_per_group\": 6.78194522857666, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 6, \"draws\": 7, \"mu_intercept_per_group\": 6.350749492645264, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 6, \"draws\": 8, \"mu_intercept_per_group\": 6.363409519195557, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 6, \"draws\": 9, \"mu_intercept_per_group\": 5.933447360992432, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 6, \"draws\": 10, \"mu_intercept_per_group\": 5.853187561035156, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 6, \"draws\": 11, \"mu_intercept_per_group\": 6.542262554168701, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 6, \"draws\": 12, \"mu_intercept_per_group\": 10.160593032836914, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 6, \"draws\": 13, \"mu_intercept_per_group\": 8.65396499633789, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 6, \"draws\": 14, \"mu_intercept_per_group\": 8.961529731750488, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 6, \"draws\": 15, \"mu_intercept_per_group\": 10.434885025024414, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 6, \"draws\": 16, \"mu_intercept_per_group\": 9.038124084472656, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 6, \"draws\": 17, \"mu_intercept_per_group\": 9.4014310836792, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 6, \"draws\": 18, \"mu_intercept_per_group\": 9.322399139404297, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 6, \"draws\": 19, \"mu_intercept_per_group\": 9.3804292678833, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 6, \"draws\": 20, \"mu_intercept_per_group\": 9.130976676940918, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 6, \"draws\": 21, \"mu_intercept_per_group\": 8.232771873474121, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 6, \"draws\": 22, \"mu_intercept_per_group\": 9.134203910827637, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 6, \"draws\": 23, \"mu_intercept_per_group\": 8.617166519165039, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 6, \"draws\": 24, \"mu_intercept_per_group\": 8.790091514587402, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 6, \"draws\": 25, \"mu_intercept_per_group\": 9.15243148803711, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 6, \"draws\": 26, \"mu_intercept_per_group\": 9.096107482910156, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 6, \"draws\": 27, \"mu_intercept_per_group\": 8.670356750488281, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 6, \"draws\": 28, \"mu_intercept_per_group\": 11.807844161987305, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 6, \"draws\": 29, \"mu_intercept_per_group\": 11.304010391235352, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 6, \"draws\": 30, \"mu_intercept_per_group\": 11.720206260681152, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 6, \"draws\": 31, \"mu_intercept_per_group\": 11.0661039352417, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 6, \"draws\": 32, \"mu_intercept_per_group\": 10.297859191894531, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 6, \"draws\": 33, \"mu_intercept_per_group\": 9.616209983825684, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 6, \"draws\": 34, \"mu_intercept_per_group\": 10.214313507080078, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 6, \"draws\": 35, \"mu_intercept_per_group\": 9.734882354736328, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 6, \"draws\": 36, \"mu_intercept_per_group\": 10.050962448120117, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 6, \"draws\": 37, \"mu_intercept_per_group\": 10.531621932983398, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 6, \"draws\": 38, \"mu_intercept_per_group\": 9.262715339660645, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 6, \"draws\": 39, \"mu_intercept_per_group\": 9.040542602539062, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 6, \"draws\": 40, \"mu_intercept_per_group\": 9.38218879699707, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 6, \"draws\": 41, \"mu_intercept_per_group\": 8.908907890319824, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 6, \"draws\": 42, \"mu_intercept_per_group\": 9.480887413024902, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 6, \"draws\": 43, \"mu_intercept_per_group\": 8.625937461853027, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 6, \"draws\": 44, \"mu_intercept_per_group\": 8.439367294311523, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 6, \"draws\": 45, \"mu_intercept_per_group\": 8.332025527954102, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 6, \"draws\": 46, \"mu_intercept_per_group\": 8.197508811950684, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 6, \"draws\": 47, \"mu_intercept_per_group\": 9.362689971923828, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 6, \"draws\": 48, \"mu_intercept_per_group\": 8.541336059570312, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 6, \"draws\": 49, \"mu_intercept_per_group\": 9.307796478271484, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 6, \"draws\": 50, \"mu_intercept_per_group\": 5.951233386993408, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 6, \"draws\": 51, \"mu_intercept_per_group\": 7.334356784820557, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 6, \"draws\": 52, \"mu_intercept_per_group\": 3.441554546356201, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 6, \"draws\": 53, \"mu_intercept_per_group\": 3.300849199295044, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 6, \"draws\": 54, \"mu_intercept_per_group\": 3.2934024333953857, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 6, \"draws\": 55, \"mu_intercept_per_group\": 3.7783255577087402, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 6, \"draws\": 56, \"mu_intercept_per_group\": 3.935070037841797, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 6, \"draws\": 57, \"mu_intercept_per_group\": 4.069378852844238, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 6, \"draws\": 58, \"mu_intercept_per_group\": 3.716883420944214, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 6, \"draws\": 59, \"mu_intercept_per_group\": 3.746779203414917, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 6, \"draws\": 60, \"mu_intercept_per_group\": 3.510507822036743, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 6, \"draws\": 61, \"mu_intercept_per_group\": 5.755338191986084, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 6, \"draws\": 62, \"mu_intercept_per_group\": 6.816492080688477, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 6, \"draws\": 63, \"mu_intercept_per_group\": 6.112684726715088, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 6, \"draws\": 64, \"mu_intercept_per_group\": 6.285821914672852, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 6, \"draws\": 65, \"mu_intercept_per_group\": 5.922773838043213, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 6, \"draws\": 66, \"mu_intercept_per_group\": 6.711319446563721, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 6, \"draws\": 67, \"mu_intercept_per_group\": 6.064018726348877, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 6, \"draws\": 68, \"mu_intercept_per_group\": 6.776413440704346, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 6, \"draws\": 69, \"mu_intercept_per_group\": 6.8418073654174805, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 6, \"draws\": 70, \"mu_intercept_per_group\": 5.3042988777160645, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 6, \"draws\": 71, \"mu_intercept_per_group\": 4.150613784790039, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 6, \"draws\": 72, \"mu_intercept_per_group\": 4.161302089691162, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 6, \"draws\": 73, \"mu_intercept_per_group\": 4.496865749359131, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 6, \"draws\": 74, \"mu_intercept_per_group\": 4.090243339538574, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 6, \"draws\": 75, \"mu_intercept_per_group\": 4.55704927444458, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 6, \"draws\": 76, \"mu_intercept_per_group\": 4.461277961730957, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 6, \"draws\": 77, \"mu_intercept_per_group\": 5.868112087249756, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 6, \"draws\": 78, \"mu_intercept_per_group\": 5.99063777923584, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 6, \"draws\": 79, \"mu_intercept_per_group\": 8.52448558807373, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 6, \"draws\": 80, \"mu_intercept_per_group\": 10.493786811828613, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 6, \"draws\": 81, \"mu_intercept_per_group\": 10.167278289794922, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 6, \"draws\": 82, \"mu_intercept_per_group\": 9.832326889038086, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 6, \"draws\": 83, \"mu_intercept_per_group\": 10.711143493652344, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 6, \"draws\": 84, \"mu_intercept_per_group\": 8.819849967956543, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 6, \"draws\": 85, \"mu_intercept_per_group\": 8.912633895874023, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 6, \"draws\": 86, \"mu_intercept_per_group\": 7.799365997314453, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 6, \"draws\": 87, \"mu_intercept_per_group\": 6.33791446685791, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 6, \"draws\": 88, \"mu_intercept_per_group\": 6.37909460067749, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 6, \"draws\": 89, \"mu_intercept_per_group\": 8.133611679077148, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 6, \"draws\": 90, \"mu_intercept_per_group\": 7.808767318725586, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 6, \"draws\": 91, \"mu_intercept_per_group\": 9.09640884399414, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 6, \"draws\": 92, \"mu_intercept_per_group\": 9.279224395751953, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 6, \"draws\": 93, \"mu_intercept_per_group\": 8.12138843536377, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 6, \"draws\": 94, \"mu_intercept_per_group\": 7.908900260925293, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 6, \"draws\": 95, \"mu_intercept_per_group\": 8.650402069091797, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 6, \"draws\": 96, \"mu_intercept_per_group\": 8.575915336608887, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 6, \"draws\": 97, \"mu_intercept_per_group\": 7.963813304901123, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 6, \"draws\": 98, \"mu_intercept_per_group\": 8.189574241638184, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 6, \"draws\": 99, \"mu_intercept_per_group\": 8.077909469604492, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 6, \"draws\": 100, \"mu_intercept_per_group\": 7.635969161987305, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 6, \"draws\": 101, \"mu_intercept_per_group\": 8.57835865020752, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 6, \"draws\": 102, \"mu_intercept_per_group\": 9.099989891052246, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 6, \"draws\": 103, \"mu_intercept_per_group\": 4.646775722503662, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 6, \"draws\": 104, \"mu_intercept_per_group\": 6.7272844314575195, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 6, \"draws\": 105, \"mu_intercept_per_group\": 7.051004409790039, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 6, \"draws\": 106, \"mu_intercept_per_group\": 7.874227523803711, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 6, \"draws\": 107, \"mu_intercept_per_group\": 8.037461280822754, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 6, \"draws\": 108, \"mu_intercept_per_group\": 7.502870559692383, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 6, \"draws\": 109, \"mu_intercept_per_group\": 13.849235534667969, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 6, \"draws\": 110, \"mu_intercept_per_group\": 14.555395126342773, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 6, \"draws\": 111, \"mu_intercept_per_group\": 10.024314880371094, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 6, \"draws\": 112, \"mu_intercept_per_group\": 9.102640151977539, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 6, \"draws\": 113, \"mu_intercept_per_group\": 9.062414169311523, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 6, \"draws\": 114, \"mu_intercept_per_group\": 10.54573917388916, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 6, \"draws\": 115, \"mu_intercept_per_group\": 9.662028312683105, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 6, \"draws\": 116, \"mu_intercept_per_group\": 9.06899642944336, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 6, \"draws\": 117, \"mu_intercept_per_group\": 10.745865821838379, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 6, \"draws\": 118, \"mu_intercept_per_group\": 9.776222229003906, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 6, \"draws\": 119, \"mu_intercept_per_group\": 10.970254898071289, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 6, \"draws\": 120, \"mu_intercept_per_group\": 11.96401309967041, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 6, \"draws\": 121, \"mu_intercept_per_group\": 11.819497108459473, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 6, \"draws\": 122, \"mu_intercept_per_group\": 10.018353462219238, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 6, \"draws\": 123, \"mu_intercept_per_group\": 9.855454444885254, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 6, \"draws\": 124, \"mu_intercept_per_group\": 8.792333602905273, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 6, \"draws\": 125, \"mu_intercept_per_group\": 7.454135417938232, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 6, \"draws\": 126, \"mu_intercept_per_group\": 8.417159080505371, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 6, \"draws\": 127, \"mu_intercept_per_group\": 8.611626625061035, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 6, \"draws\": 128, \"mu_intercept_per_group\": 6.239546775817871, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 6, \"draws\": 129, \"mu_intercept_per_group\": 7.452734470367432, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 6, \"draws\": 130, \"mu_intercept_per_group\": 7.50393533706665, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 6, \"draws\": 131, \"mu_intercept_per_group\": 8.455405235290527, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 6, \"draws\": 132, \"mu_intercept_per_group\": 7.529179096221924, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 6, \"draws\": 133, \"mu_intercept_per_group\": 7.229579925537109, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 6, \"draws\": 134, \"mu_intercept_per_group\": 6.525679588317871, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 6, \"draws\": 135, \"mu_intercept_per_group\": 7.389513969421387, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 6, \"draws\": 136, \"mu_intercept_per_group\": 7.169402599334717, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 6, \"draws\": 137, \"mu_intercept_per_group\": 6.796781539916992, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 6, \"draws\": 138, \"mu_intercept_per_group\": 7.173099517822266, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 6, \"draws\": 139, \"mu_intercept_per_group\": 6.562859058380127, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 6, \"draws\": 140, \"mu_intercept_per_group\": 7.2335100173950195, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 6, \"draws\": 141, \"mu_intercept_per_group\": 7.369751453399658, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 6, \"draws\": 142, \"mu_intercept_per_group\": 8.221086502075195, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 6, \"draws\": 143, \"mu_intercept_per_group\": 4.627559661865234, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 6, \"draws\": 144, \"mu_intercept_per_group\": 5.113148212432861, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 6, \"draws\": 145, \"mu_intercept_per_group\": 5.001250743865967, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 6, \"draws\": 146, \"mu_intercept_per_group\": 4.953166961669922, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 6, \"draws\": 147, \"mu_intercept_per_group\": 4.870550632476807, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 6, \"draws\": 148, \"mu_intercept_per_group\": 6.696098327636719, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 6, \"draws\": 149, \"mu_intercept_per_group\": 8.15292739868164, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 6, \"draws\": 150, \"mu_intercept_per_group\": 8.938582420349121, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 6, \"draws\": 151, \"mu_intercept_per_group\": 8.223645210266113, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 6, \"draws\": 152, \"mu_intercept_per_group\": 5.709514617919922, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 6, \"draws\": 153, \"mu_intercept_per_group\": 4.716357231140137, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 6, \"draws\": 154, \"mu_intercept_per_group\": 5.730381488800049, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 6, \"draws\": 155, \"mu_intercept_per_group\": 5.989377021789551, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 6, \"draws\": 156, \"mu_intercept_per_group\": 5.813709259033203, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 6, \"draws\": 157, \"mu_intercept_per_group\": 5.983046531677246, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 6, \"draws\": 158, \"mu_intercept_per_group\": 6.9822869300842285, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 6, \"draws\": 159, \"mu_intercept_per_group\": 7.143868446350098, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 6, \"draws\": 160, \"mu_intercept_per_group\": 12.603129386901855, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 6, \"draws\": 161, \"mu_intercept_per_group\": 13.318949699401855, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 6, \"draws\": 162, \"mu_intercept_per_group\": 14.398468017578125, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 6, \"draws\": 163, \"mu_intercept_per_group\": 12.56020450592041, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 6, \"draws\": 164, \"mu_intercept_per_group\": 11.881718635559082, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 6, \"draws\": 165, \"mu_intercept_per_group\": 10.041082382202148, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 6, \"draws\": 166, \"mu_intercept_per_group\": 15.112136840820312, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 6, \"draws\": 167, \"mu_intercept_per_group\": 10.072324752807617, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 6, \"draws\": 168, \"mu_intercept_per_group\": 12.215296745300293, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 6, \"draws\": 169, \"mu_intercept_per_group\": 13.262344360351562, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 6, \"draws\": 170, \"mu_intercept_per_group\": 11.681585311889648, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 6, \"draws\": 171, \"mu_intercept_per_group\": 12.267688751220703, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 6, \"draws\": 172, \"mu_intercept_per_group\": 11.200095176696777, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 6, \"draws\": 173, \"mu_intercept_per_group\": 13.316904067993164, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 6, \"draws\": 174, \"mu_intercept_per_group\": 11.860135078430176, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 6, \"draws\": 175, \"mu_intercept_per_group\": 13.34777545928955, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 6, \"draws\": 176, \"mu_intercept_per_group\": 12.337682723999023, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 6, \"draws\": 177, \"mu_intercept_per_group\": 13.658371925354004, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 6, \"draws\": 178, \"mu_intercept_per_group\": 13.182790756225586, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 6, \"draws\": 179, \"mu_intercept_per_group\": 5.588159561157227, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 6, \"draws\": 180, \"mu_intercept_per_group\": 5.5253496170043945, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 6, \"draws\": 181, \"mu_intercept_per_group\": 5.918810844421387, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 6, \"draws\": 182, \"mu_intercept_per_group\": 7.770699501037598, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 6, \"draws\": 183, \"mu_intercept_per_group\": 7.8333563804626465, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 6, \"draws\": 184, \"mu_intercept_per_group\": 6.336348056793213, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 6, \"draws\": 185, \"mu_intercept_per_group\": 6.174731731414795, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 6, \"draws\": 186, \"mu_intercept_per_group\": 7.269944667816162, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 6, \"draws\": 187, \"mu_intercept_per_group\": 6.351038932800293, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 6, \"draws\": 188, \"mu_intercept_per_group\": 6.33950662612915, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 6, \"draws\": 189, \"mu_intercept_per_group\": 6.419040203094482, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 6, \"draws\": 190, \"mu_intercept_per_group\": 8.586856842041016, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 6, \"draws\": 191, \"mu_intercept_per_group\": 10.861992835998535, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 6, \"draws\": 192, \"mu_intercept_per_group\": 9.917713165283203, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 6, \"draws\": 193, \"mu_intercept_per_group\": 5.787021636962891, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 6, \"draws\": 194, \"mu_intercept_per_group\": 6.693829536437988, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 6, \"draws\": 195, \"mu_intercept_per_group\": 6.5373735427856445, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 6, \"draws\": 196, \"mu_intercept_per_group\": 6.018726348876953, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 6, \"draws\": 197, \"mu_intercept_per_group\": 5.741212844848633, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 6, \"draws\": 198, \"mu_intercept_per_group\": 5.311969757080078, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 6, \"draws\": 199, \"mu_intercept_per_group\": 7.759718418121338, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 6, \"draws\": 200, \"mu_intercept_per_group\": 6.36519718170166, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 6, \"draws\": 201, \"mu_intercept_per_group\": 5.80181884765625, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 6, \"draws\": 202, \"mu_intercept_per_group\": 6.205177307128906, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 6, \"draws\": 203, \"mu_intercept_per_group\": 6.555182933807373, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 6, \"draws\": 204, \"mu_intercept_per_group\": 7.000260829925537, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 6, \"draws\": 205, \"mu_intercept_per_group\": 6.809412479400635, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 6, \"draws\": 206, \"mu_intercept_per_group\": 7.5207600593566895, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 6, \"draws\": 207, \"mu_intercept_per_group\": 6.041316032409668, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 6, \"draws\": 208, \"mu_intercept_per_group\": 5.883327960968018, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 6, \"draws\": 209, \"mu_intercept_per_group\": 6.839687347412109, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 6, \"draws\": 210, \"mu_intercept_per_group\": 6.217465877532959, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 6, \"draws\": 211, \"mu_intercept_per_group\": 5.955320835113525, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 6, \"draws\": 212, \"mu_intercept_per_group\": 6.888370513916016, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 6, \"draws\": 213, \"mu_intercept_per_group\": 5.873354911804199, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 6, \"draws\": 214, \"mu_intercept_per_group\": 5.6609649658203125, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 6, \"draws\": 215, \"mu_intercept_per_group\": 4.788509368896484, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 6, \"draws\": 216, \"mu_intercept_per_group\": 4.332564353942871, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 6, \"draws\": 217, \"mu_intercept_per_group\": 5.441709041595459, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 6, \"draws\": 218, \"mu_intercept_per_group\": 5.527358531951904, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 6, \"draws\": 219, \"mu_intercept_per_group\": 5.228763580322266, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 6, \"draws\": 220, \"mu_intercept_per_group\": 5.9253740310668945, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 6, \"draws\": 221, \"mu_intercept_per_group\": 5.4029011726379395, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 6, \"draws\": 222, \"mu_intercept_per_group\": 5.944394588470459, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 6, \"draws\": 223, \"mu_intercept_per_group\": 5.360775947570801, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 6, \"draws\": 224, \"mu_intercept_per_group\": 5.563313961029053, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 6, \"draws\": 225, \"mu_intercept_per_group\": 5.347412109375, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 6, \"draws\": 226, \"mu_intercept_per_group\": 5.707730293273926, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 6, \"draws\": 227, \"mu_intercept_per_group\": 5.9847331047058105, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 6, \"draws\": 228, \"mu_intercept_per_group\": 4.589234828948975, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 6, \"draws\": 229, \"mu_intercept_per_group\": 4.597904682159424, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 6, \"draws\": 230, \"mu_intercept_per_group\": 4.9350199699401855, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 6, \"draws\": 231, \"mu_intercept_per_group\": 5.081120491027832, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 6, \"draws\": 232, \"mu_intercept_per_group\": 6.6459174156188965, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 6, \"draws\": 233, \"mu_intercept_per_group\": 6.509714603424072, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 6, \"draws\": 234, \"mu_intercept_per_group\": 6.557188034057617, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 6, \"draws\": 235, \"mu_intercept_per_group\": 5.8516998291015625, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 6, \"draws\": 236, \"mu_intercept_per_group\": 4.778357028961182, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 6, \"draws\": 237, \"mu_intercept_per_group\": 4.554792881011963, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 6, \"draws\": 238, \"mu_intercept_per_group\": 4.9315080642700195, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 6, \"draws\": 239, \"mu_intercept_per_group\": 5.116124629974365, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 6, \"draws\": 240, \"mu_intercept_per_group\": 5.141764163970947, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 6, \"draws\": 241, \"mu_intercept_per_group\": 4.61113977432251, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 6, \"draws\": 242, \"mu_intercept_per_group\": 5.955816268920898, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 6, \"draws\": 243, \"mu_intercept_per_group\": 6.014526844024658, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 6, \"draws\": 244, \"mu_intercept_per_group\": 6.595561981201172, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 6, \"draws\": 245, \"mu_intercept_per_group\": 7.24875020980835, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 6, \"draws\": 246, \"mu_intercept_per_group\": 6.798802852630615, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 6, \"draws\": 247, \"mu_intercept_per_group\": 7.02449893951416, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 6, \"draws\": 248, \"mu_intercept_per_group\": 6.75741720199585, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 6, \"draws\": 249, \"mu_intercept_per_group\": 4.89534330368042, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 6, \"draws\": 250, \"mu_intercept_per_group\": 4.854712009429932, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 6, \"draws\": 251, \"mu_intercept_per_group\": 5.248372554779053, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 6, \"draws\": 252, \"mu_intercept_per_group\": 5.4784159660339355, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 6, \"draws\": 253, \"mu_intercept_per_group\": 5.148327350616455, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 6, \"draws\": 254, \"mu_intercept_per_group\": 5.844515800476074, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 6, \"draws\": 255, \"mu_intercept_per_group\": 5.94085693359375, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 6, \"draws\": 256, \"mu_intercept_per_group\": 7.710791110992432, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 6, \"draws\": 257, \"mu_intercept_per_group\": 7.136485576629639, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 6, \"draws\": 258, \"mu_intercept_per_group\": 7.1948676109313965, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 6, \"draws\": 259, \"mu_intercept_per_group\": 7.068617820739746, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 6, \"draws\": 260, \"mu_intercept_per_group\": 7.0412726402282715, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 6, \"draws\": 261, \"mu_intercept_per_group\": 5.577961444854736, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 6, \"draws\": 262, \"mu_intercept_per_group\": 6.063137054443359, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 6, \"draws\": 263, \"mu_intercept_per_group\": 6.08484411239624, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 6, \"draws\": 264, \"mu_intercept_per_group\": 5.061281204223633, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 6, \"draws\": 265, \"mu_intercept_per_group\": 5.277675151824951, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 6, \"draws\": 266, \"mu_intercept_per_group\": 4.835519790649414, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 6, \"draws\": 267, \"mu_intercept_per_group\": 4.051097869873047, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 6, \"draws\": 268, \"mu_intercept_per_group\": 4.234492301940918, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 6, \"draws\": 269, \"mu_intercept_per_group\": 13.54055404663086, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 6, \"draws\": 270, \"mu_intercept_per_group\": 12.169087409973145, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 6, \"draws\": 271, \"mu_intercept_per_group\": 11.858327865600586, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 6, \"draws\": 272, \"mu_intercept_per_group\": 8.562613487243652, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 6, \"draws\": 273, \"mu_intercept_per_group\": 9.596062660217285, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 6, \"draws\": 274, \"mu_intercept_per_group\": 11.716014862060547, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 6, \"draws\": 275, \"mu_intercept_per_group\": 10.148331642150879, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 6, \"draws\": 276, \"mu_intercept_per_group\": 11.377574920654297, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 6, \"draws\": 277, \"mu_intercept_per_group\": 10.052515029907227, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 6, \"draws\": 278, \"mu_intercept_per_group\": 9.619640350341797, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 6, \"draws\": 279, \"mu_intercept_per_group\": 10.12104320526123, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 6, \"draws\": 280, \"mu_intercept_per_group\": 7.71097469329834, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 6, \"draws\": 281, \"mu_intercept_per_group\": 10.455362319946289, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 6, \"draws\": 282, \"mu_intercept_per_group\": 9.480401039123535, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 6, \"draws\": 283, \"mu_intercept_per_group\": 8.835434913635254, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 6, \"draws\": 284, \"mu_intercept_per_group\": 10.35590648651123, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 6, \"draws\": 285, \"mu_intercept_per_group\": 9.454895973205566, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 6, \"draws\": 286, \"mu_intercept_per_group\": 9.522154808044434, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 6, \"draws\": 287, \"mu_intercept_per_group\": 10.69210433959961, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 6, \"draws\": 288, \"mu_intercept_per_group\": 9.89820384979248, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 6, \"draws\": 289, \"mu_intercept_per_group\": 10.385075569152832, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 6, \"draws\": 290, \"mu_intercept_per_group\": 9.640055656433105, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 6, \"draws\": 291, \"mu_intercept_per_group\": 11.137589454650879, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 6, \"draws\": 292, \"mu_intercept_per_group\": 10.630555152893066, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 6, \"draws\": 293, \"mu_intercept_per_group\": 8.652636528015137, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 6, \"draws\": 294, \"mu_intercept_per_group\": 7.972969055175781, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 6, \"draws\": 295, \"mu_intercept_per_group\": 7.905138969421387, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 6, \"draws\": 296, \"mu_intercept_per_group\": 7.219156742095947, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 6, \"draws\": 297, \"mu_intercept_per_group\": 4.805926322937012, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 6, \"draws\": 298, \"mu_intercept_per_group\": 5.998935699462891, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 6, \"draws\": 299, \"mu_intercept_per_group\": 6.304920196533203, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 6, \"draws\": 300, \"mu_intercept_per_group\": 6.693556308746338, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 6, \"draws\": 301, \"mu_intercept_per_group\": 7.294597625732422, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 6, \"draws\": 302, \"mu_intercept_per_group\": 7.1022515296936035, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 6, \"draws\": 303, \"mu_intercept_per_group\": 7.9989399909973145, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 6, \"draws\": 304, \"mu_intercept_per_group\": 7.282175064086914, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 6, \"draws\": 305, \"mu_intercept_per_group\": 6.3523077964782715, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 6, \"draws\": 306, \"mu_intercept_per_group\": 6.280169486999512, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 6, \"draws\": 307, \"mu_intercept_per_group\": 7.244989395141602, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 6, \"draws\": 308, \"mu_intercept_per_group\": 6.345453262329102, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 6, \"draws\": 309, \"mu_intercept_per_group\": 8.540804862976074, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 6, \"draws\": 310, \"mu_intercept_per_group\": 8.607023239135742, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 6, \"draws\": 311, \"mu_intercept_per_group\": 7.57801628112793, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 6, \"draws\": 312, \"mu_intercept_per_group\": 7.548185348510742, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 6, \"draws\": 313, \"mu_intercept_per_group\": 10.406472206115723, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 6, \"draws\": 314, \"mu_intercept_per_group\": 6.508364200592041, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 6, \"draws\": 315, \"mu_intercept_per_group\": 6.934550762176514, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 6, \"draws\": 316, \"mu_intercept_per_group\": 8.719722747802734, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 6, \"draws\": 317, \"mu_intercept_per_group\": 8.32511043548584, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 6, \"draws\": 318, \"mu_intercept_per_group\": 8.030926704406738, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 6, \"draws\": 319, \"mu_intercept_per_group\": 9.917937278747559, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 6, \"draws\": 320, \"mu_intercept_per_group\": 3.0378055572509766, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 6, \"draws\": 321, \"mu_intercept_per_group\": 3.4540836811065674, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 6, \"draws\": 322, \"mu_intercept_per_group\": 3.886277198791504, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 6, \"draws\": 323, \"mu_intercept_per_group\": 3.4497852325439453, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 6, \"draws\": 324, \"mu_intercept_per_group\": 5.634133338928223, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 6, \"draws\": 325, \"mu_intercept_per_group\": 5.176501274108887, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 6, \"draws\": 326, \"mu_intercept_per_group\": 5.658136367797852, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 6, \"draws\": 327, \"mu_intercept_per_group\": 6.040293216705322, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 6, \"draws\": 328, \"mu_intercept_per_group\": 7.010168075561523, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 6, \"draws\": 329, \"mu_intercept_per_group\": 5.627787113189697, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 6, \"draws\": 330, \"mu_intercept_per_group\": 6.835237503051758, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 6, \"draws\": 331, \"mu_intercept_per_group\": 6.047579288482666, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 6, \"draws\": 332, \"mu_intercept_per_group\": 6.360288619995117, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 6, \"draws\": 333, \"mu_intercept_per_group\": 6.499030590057373, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 6, \"draws\": 334, \"mu_intercept_per_group\": 6.444857597351074, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 6, \"draws\": 335, \"mu_intercept_per_group\": 6.178199291229248, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 6, \"draws\": 336, \"mu_intercept_per_group\": 5.760493278503418, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 6, \"draws\": 337, \"mu_intercept_per_group\": 6.602076530456543, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 6, \"draws\": 338, \"mu_intercept_per_group\": 11.737799644470215, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 6, \"draws\": 339, \"mu_intercept_per_group\": 9.446699142456055, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 6, \"draws\": 340, \"mu_intercept_per_group\": 9.271122932434082, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 6, \"draws\": 341, \"mu_intercept_per_group\": 8.458904266357422, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 6, \"draws\": 342, \"mu_intercept_per_group\": 8.216804504394531, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 6, \"draws\": 343, \"mu_intercept_per_group\": 8.339337348937988, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 6, \"draws\": 344, \"mu_intercept_per_group\": 11.396873474121094, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 6, \"draws\": 345, \"mu_intercept_per_group\": 13.146418571472168, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 6, \"draws\": 346, \"mu_intercept_per_group\": 9.120341300964355, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 6, \"draws\": 347, \"mu_intercept_per_group\": 7.542057991027832, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 6, \"draws\": 348, \"mu_intercept_per_group\": 6.612941741943359, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 6, \"draws\": 349, \"mu_intercept_per_group\": 7.144115924835205, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 6, \"draws\": 350, \"mu_intercept_per_group\": 8.564892768859863, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 6, \"draws\": 351, \"mu_intercept_per_group\": 8.30569076538086, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 6, \"draws\": 352, \"mu_intercept_per_group\": 8.717899322509766, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 6, \"draws\": 353, \"mu_intercept_per_group\": 10.7899169921875, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 6, \"draws\": 354, \"mu_intercept_per_group\": 5.776623725891113, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 6, \"draws\": 355, \"mu_intercept_per_group\": 6.6342573165893555, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 6, \"draws\": 356, \"mu_intercept_per_group\": 6.428171157836914, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 6, \"draws\": 357, \"mu_intercept_per_group\": 6.43193244934082, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 6, \"draws\": 358, \"mu_intercept_per_group\": 6.259112358093262, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 6, \"draws\": 359, \"mu_intercept_per_group\": 6.5758538246154785, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 6, \"draws\": 360, \"mu_intercept_per_group\": 5.506444454193115, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 6, \"draws\": 361, \"mu_intercept_per_group\": 6.3477959632873535, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 6, \"draws\": 362, \"mu_intercept_per_group\": 6.1728129386901855, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 6, \"draws\": 363, \"mu_intercept_per_group\": 6.343296527862549, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 6, \"draws\": 364, \"mu_intercept_per_group\": 8.123056411743164, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 6, \"draws\": 365, \"mu_intercept_per_group\": 8.212301254272461, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 6, \"draws\": 366, \"mu_intercept_per_group\": 7.309240818023682, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 6, \"draws\": 367, \"mu_intercept_per_group\": 6.520120143890381, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 6, \"draws\": 368, \"mu_intercept_per_group\": 8.738837242126465, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 6, \"draws\": 369, \"mu_intercept_per_group\": 5.494771480560303, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 6, \"draws\": 370, \"mu_intercept_per_group\": 5.228726387023926, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 6, \"draws\": 371, \"mu_intercept_per_group\": 5.386542797088623, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 6, \"draws\": 372, \"mu_intercept_per_group\": 5.221736431121826, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 6, \"draws\": 373, \"mu_intercept_per_group\": 4.91135835647583, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 6, \"draws\": 374, \"mu_intercept_per_group\": 5.129876613616943, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 6, \"draws\": 375, \"mu_intercept_per_group\": 6.467576026916504, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 6, \"draws\": 376, \"mu_intercept_per_group\": 6.78586483001709, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 6, \"draws\": 377, \"mu_intercept_per_group\": 5.894855499267578, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 6, \"draws\": 378, \"mu_intercept_per_group\": 6.256791591644287, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 6, \"draws\": 379, \"mu_intercept_per_group\": 5.770027160644531, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 6, \"draws\": 380, \"mu_intercept_per_group\": 5.016124248504639, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 6, \"draws\": 381, \"mu_intercept_per_group\": 6.512770175933838, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 6, \"draws\": 382, \"mu_intercept_per_group\": 5.377038478851318, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 6, \"draws\": 383, \"mu_intercept_per_group\": 4.671774387359619, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 6, \"draws\": 384, \"mu_intercept_per_group\": 9.381853103637695, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 6, \"draws\": 385, \"mu_intercept_per_group\": 8.205405235290527, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 6, \"draws\": 386, \"mu_intercept_per_group\": 7.49556827545166, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 6, \"draws\": 387, \"mu_intercept_per_group\": 7.3695831298828125, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 6, \"draws\": 388, \"mu_intercept_per_group\": 7.504415512084961, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 6, \"draws\": 389, \"mu_intercept_per_group\": 8.773069381713867, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 6, \"draws\": 390, \"mu_intercept_per_group\": 8.396282196044922, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 6, \"draws\": 391, \"mu_intercept_per_group\": 7.213515758514404, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 6, \"draws\": 392, \"mu_intercept_per_group\": 8.378059387207031, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 6, \"draws\": 393, \"mu_intercept_per_group\": 8.653185844421387, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 6, \"draws\": 394, \"mu_intercept_per_group\": 7.6507086753845215, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 6, \"draws\": 395, \"mu_intercept_per_group\": 7.640504837036133, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 6, \"draws\": 396, \"mu_intercept_per_group\": 8.275436401367188, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 6, \"draws\": 397, \"mu_intercept_per_group\": 7.91212797164917, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 6, \"draws\": 398, \"mu_intercept_per_group\": 8.251493453979492, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 6, \"draws\": 399, \"mu_intercept_per_group\": 7.766905784606934, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 6, \"draws\": 400, \"mu_intercept_per_group\": 7.664503574371338, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 6, \"draws\": 401, \"mu_intercept_per_group\": 6.081905841827393, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 6, \"draws\": 402, \"mu_intercept_per_group\": 6.450358867645264, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 6, \"draws\": 403, \"mu_intercept_per_group\": 5.78774356842041, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 6, \"draws\": 404, \"mu_intercept_per_group\": 8.115100860595703, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 6, \"draws\": 405, \"mu_intercept_per_group\": 8.393680572509766, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 6, \"draws\": 406, \"mu_intercept_per_group\": 8.888397216796875, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 6, \"draws\": 407, \"mu_intercept_per_group\": 8.50220775604248, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 6, \"draws\": 408, \"mu_intercept_per_group\": 7.62954568862915, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 6, \"draws\": 409, \"mu_intercept_per_group\": 7.329501628875732, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 6, \"draws\": 410, \"mu_intercept_per_group\": 7.118637561798096, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 6, \"draws\": 411, \"mu_intercept_per_group\": 6.446343898773193, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 6, \"draws\": 412, \"mu_intercept_per_group\": 7.15817928314209, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 6, \"draws\": 413, \"mu_intercept_per_group\": 8.638924598693848, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 6, \"draws\": 414, \"mu_intercept_per_group\": 8.744651794433594, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 6, \"draws\": 415, \"mu_intercept_per_group\": 9.004300117492676, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 6, \"draws\": 416, \"mu_intercept_per_group\": 7.582159996032715, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 6, \"draws\": 417, \"mu_intercept_per_group\": 7.16995096206665, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 6, \"draws\": 418, \"mu_intercept_per_group\": 8.094589233398438, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 6, \"draws\": 419, \"mu_intercept_per_group\": 8.173418998718262, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 6, \"draws\": 420, \"mu_intercept_per_group\": 7.786073207855225, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 6, \"draws\": 421, \"mu_intercept_per_group\": 7.542136192321777, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 6, \"draws\": 422, \"mu_intercept_per_group\": 9.262347221374512, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 6, \"draws\": 423, \"mu_intercept_per_group\": 8.472554206848145, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 6, \"draws\": 424, \"mu_intercept_per_group\": 8.396621704101562, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 6, \"draws\": 425, \"mu_intercept_per_group\": 7.448306560516357, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 6, \"draws\": 426, \"mu_intercept_per_group\": 9.599287033081055, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 6, \"draws\": 427, \"mu_intercept_per_group\": 9.6124267578125, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 6, \"draws\": 428, \"mu_intercept_per_group\": 10.75981616973877, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 6, \"draws\": 429, \"mu_intercept_per_group\": 9.809743881225586, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 6, \"draws\": 430, \"mu_intercept_per_group\": 9.578779220581055, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 6, \"draws\": 431, \"mu_intercept_per_group\": 8.749266624450684, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 6, \"draws\": 432, \"mu_intercept_per_group\": 9.265604972839355, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 6, \"draws\": 433, \"mu_intercept_per_group\": 8.716691970825195, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 6, \"draws\": 434, \"mu_intercept_per_group\": 8.401588439941406, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 6, \"draws\": 435, \"mu_intercept_per_group\": 7.894198417663574, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 6, \"draws\": 436, \"mu_intercept_per_group\": 9.121498107910156, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 6, \"draws\": 437, \"mu_intercept_per_group\": 8.73010540008545, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 6, \"draws\": 438, \"mu_intercept_per_group\": 9.707252502441406, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 6, \"draws\": 439, \"mu_intercept_per_group\": 9.032855033874512, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 6, \"draws\": 440, \"mu_intercept_per_group\": 10.13469409942627, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 6, \"draws\": 441, \"mu_intercept_per_group\": 9.839611053466797, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 6, \"draws\": 442, \"mu_intercept_per_group\": 11.05491828918457, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 6, \"draws\": 443, \"mu_intercept_per_group\": 13.115935325622559, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 6, \"draws\": 444, \"mu_intercept_per_group\": 12.38604736328125, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 6, \"draws\": 445, \"mu_intercept_per_group\": 11.210824966430664, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 6, \"draws\": 446, \"mu_intercept_per_group\": 7.949946880340576, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 6, \"draws\": 447, \"mu_intercept_per_group\": 7.453067779541016, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 6, \"draws\": 448, \"mu_intercept_per_group\": 6.420390605926514, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 6, \"draws\": 449, \"mu_intercept_per_group\": 6.397250175476074, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 6, \"draws\": 450, \"mu_intercept_per_group\": 7.119836330413818, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 6, \"draws\": 451, \"mu_intercept_per_group\": 13.327613830566406, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 6, \"draws\": 452, \"mu_intercept_per_group\": 12.316282272338867, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 6, \"draws\": 453, \"mu_intercept_per_group\": 13.807828903198242, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 6, \"draws\": 454, \"mu_intercept_per_group\": 14.341822624206543, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 6, \"draws\": 455, \"mu_intercept_per_group\": 11.986412048339844, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 6, \"draws\": 456, \"mu_intercept_per_group\": 13.454182624816895, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 6, \"draws\": 457, \"mu_intercept_per_group\": 12.272390365600586, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 6, \"draws\": 458, \"mu_intercept_per_group\": 13.51424789428711, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 6, \"draws\": 459, \"mu_intercept_per_group\": 7.534616470336914, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 6, \"draws\": 460, \"mu_intercept_per_group\": 6.95334529876709, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 6, \"draws\": 461, \"mu_intercept_per_group\": 6.58003044128418, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 6, \"draws\": 462, \"mu_intercept_per_group\": 6.370406150817871, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 6, \"draws\": 463, \"mu_intercept_per_group\": 6.196560382843018, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 6, \"draws\": 464, \"mu_intercept_per_group\": 6.947127342224121, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 6, \"draws\": 465, \"mu_intercept_per_group\": 6.14371395111084, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 6, \"draws\": 466, \"mu_intercept_per_group\": 6.077942848205566, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 6, \"draws\": 467, \"mu_intercept_per_group\": 6.546658039093018, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 6, \"draws\": 468, \"mu_intercept_per_group\": 6.809438228607178, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 6, \"draws\": 469, \"mu_intercept_per_group\": 6.651566982269287, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 6, \"draws\": 470, \"mu_intercept_per_group\": 6.584951877593994, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 6, \"draws\": 471, \"mu_intercept_per_group\": 7.917222499847412, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 6, \"draws\": 472, \"mu_intercept_per_group\": 8.109935760498047, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 6, \"draws\": 473, \"mu_intercept_per_group\": 8.196521759033203, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 6, \"draws\": 474, \"mu_intercept_per_group\": 10.529877662658691, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 6, \"draws\": 475, \"mu_intercept_per_group\": 11.544147491455078, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 6, \"draws\": 476, \"mu_intercept_per_group\": 11.828389167785645, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 6, \"draws\": 477, \"mu_intercept_per_group\": 10.63341999053955, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 6, \"draws\": 478, \"mu_intercept_per_group\": 11.072500228881836, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 6, \"draws\": 479, \"mu_intercept_per_group\": 10.423125267028809, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 6, \"draws\": 480, \"mu_intercept_per_group\": 8.992118835449219, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 6, \"draws\": 481, \"mu_intercept_per_group\": 8.325664520263672, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 6, \"draws\": 482, \"mu_intercept_per_group\": 7.849891185760498, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 6, \"draws\": 483, \"mu_intercept_per_group\": 7.363802909851074, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 6, \"draws\": 484, \"mu_intercept_per_group\": 7.216925144195557, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 6, \"draws\": 485, \"mu_intercept_per_group\": 7.056357383728027, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 6, \"draws\": 486, \"mu_intercept_per_group\": 7.232532978057861, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 6, \"draws\": 487, \"mu_intercept_per_group\": 7.127587795257568, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 6, \"draws\": 488, \"mu_intercept_per_group\": 6.342020511627197, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 6, \"draws\": 489, \"mu_intercept_per_group\": 7.160610198974609, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 6, \"draws\": 490, \"mu_intercept_per_group\": 6.107128143310547, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 6, \"draws\": 491, \"mu_intercept_per_group\": 6.145669937133789, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 6, \"draws\": 492, \"mu_intercept_per_group\": 7.111682891845703, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 6, \"draws\": 493, \"mu_intercept_per_group\": 6.072910308837891, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 6, \"draws\": 494, \"mu_intercept_per_group\": 10.38752269744873, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 6, \"draws\": 495, \"mu_intercept_per_group\": 9.405823707580566, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 6, \"draws\": 496, \"mu_intercept_per_group\": 8.136987686157227, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 6, \"draws\": 497, \"mu_intercept_per_group\": 8.295087814331055, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 6, \"draws\": 498, \"mu_intercept_per_group\": 8.015007972717285, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 6, \"draws\": 499, \"mu_intercept_per_group\": 7.715789318084717, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 6, \"draws\": 500, \"mu_intercept_per_group\": 8.484610557556152, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 6, \"draws\": 501, \"mu_intercept_per_group\": 9.49968147277832, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 6, \"draws\": 502, \"mu_intercept_per_group\": 8.772159576416016, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 6, \"draws\": 503, \"mu_intercept_per_group\": 8.810076713562012, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 6, \"draws\": 504, \"mu_intercept_per_group\": 9.422101020812988, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 6, \"draws\": 505, \"mu_intercept_per_group\": 8.773214340209961, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 6, \"draws\": 506, \"mu_intercept_per_group\": 7.799867630004883, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 6, \"draws\": 507, \"mu_intercept_per_group\": 8.123867988586426, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 6, \"draws\": 508, \"mu_intercept_per_group\": 8.721755981445312, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 6, \"draws\": 509, \"mu_intercept_per_group\": 10.22288703918457, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 6, \"draws\": 510, \"mu_intercept_per_group\": 9.164045333862305, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 6, \"draws\": 511, \"mu_intercept_per_group\": 11.509112358093262, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 6, \"draws\": 512, \"mu_intercept_per_group\": 12.715229988098145, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 6, \"draws\": 513, \"mu_intercept_per_group\": 10.288811683654785, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 6, \"draws\": 514, \"mu_intercept_per_group\": 9.621590614318848, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 6, \"draws\": 515, \"mu_intercept_per_group\": 10.064018249511719, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 6, \"draws\": 516, \"mu_intercept_per_group\": 9.560905456542969, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 6, \"draws\": 517, \"mu_intercept_per_group\": 9.443747520446777, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 6, \"draws\": 518, \"mu_intercept_per_group\": 9.246569633483887, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 6, \"draws\": 519, \"mu_intercept_per_group\": 10.02010726928711, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 6, \"draws\": 520, \"mu_intercept_per_group\": 6.724331855773926, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 6, \"draws\": 521, \"mu_intercept_per_group\": 7.8802385330200195, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 6, \"draws\": 522, \"mu_intercept_per_group\": 7.443273067474365, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 6, \"draws\": 523, \"mu_intercept_per_group\": 7.819050312042236, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 6, \"draws\": 524, \"mu_intercept_per_group\": 5.0905632972717285, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 6, \"draws\": 525, \"mu_intercept_per_group\": 5.180716037750244, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 6, \"draws\": 526, \"mu_intercept_per_group\": 5.335208415985107, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 6, \"draws\": 527, \"mu_intercept_per_group\": 7.521187782287598, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 6, \"draws\": 528, \"mu_intercept_per_group\": 7.990299224853516, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 6, \"draws\": 529, \"mu_intercept_per_group\": 7.368868827819824, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 6, \"draws\": 530, \"mu_intercept_per_group\": 7.028357028961182, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 6, \"draws\": 531, \"mu_intercept_per_group\": 6.496448040008545, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 6, \"draws\": 532, \"mu_intercept_per_group\": 6.549635410308838, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 6, \"draws\": 533, \"mu_intercept_per_group\": 6.86488676071167, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 6, \"draws\": 534, \"mu_intercept_per_group\": 8.43232250213623, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 6, \"draws\": 535, \"mu_intercept_per_group\": 7.825453281402588, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 6, \"draws\": 536, \"mu_intercept_per_group\": 7.35949182510376, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 6, \"draws\": 537, \"mu_intercept_per_group\": 5.520208358764648, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 6, \"draws\": 538, \"mu_intercept_per_group\": 4.91188383102417, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 6, \"draws\": 539, \"mu_intercept_per_group\": 5.286657333374023, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 6, \"draws\": 540, \"mu_intercept_per_group\": 6.930163860321045, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 6, \"draws\": 541, \"mu_intercept_per_group\": 6.360686302185059, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 6, \"draws\": 542, \"mu_intercept_per_group\": 6.513362884521484, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 6, \"draws\": 543, \"mu_intercept_per_group\": 7.297323226928711, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 6, \"draws\": 544, \"mu_intercept_per_group\": 8.539663314819336, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 6, \"draws\": 545, \"mu_intercept_per_group\": 8.901529312133789, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 6, \"draws\": 546, \"mu_intercept_per_group\": 7.2059502601623535, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 6, \"draws\": 547, \"mu_intercept_per_group\": 8.735586166381836, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 6, \"draws\": 548, \"mu_intercept_per_group\": 8.106321334838867, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 6, \"draws\": 549, \"mu_intercept_per_group\": 8.984590530395508, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 6, \"draws\": 550, \"mu_intercept_per_group\": 8.53218936920166, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 6, \"draws\": 551, \"mu_intercept_per_group\": 8.71702766418457, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 6, \"draws\": 552, \"mu_intercept_per_group\": 8.729817390441895, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 6, \"draws\": 553, \"mu_intercept_per_group\": 8.97480297088623, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 6, \"draws\": 554, \"mu_intercept_per_group\": 8.807027816772461, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 6, \"draws\": 555, \"mu_intercept_per_group\": 9.317878723144531, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 6, \"draws\": 556, \"mu_intercept_per_group\": 11.190193176269531, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 6, \"draws\": 557, \"mu_intercept_per_group\": 10.322629928588867, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 6, \"draws\": 558, \"mu_intercept_per_group\": 10.049152374267578, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 6, \"draws\": 559, \"mu_intercept_per_group\": 10.764819145202637, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 6, \"draws\": 560, \"mu_intercept_per_group\": 8.090039253234863, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 6, \"draws\": 561, \"mu_intercept_per_group\": 7.6282830238342285, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 6, \"draws\": 562, \"mu_intercept_per_group\": 9.552068710327148, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 6, \"draws\": 563, \"mu_intercept_per_group\": 8.701016426086426, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 6, \"draws\": 564, \"mu_intercept_per_group\": 6.308617115020752, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 6, \"draws\": 565, \"mu_intercept_per_group\": 6.649825096130371, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 6, \"draws\": 566, \"mu_intercept_per_group\": 5.87125825881958, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 6, \"draws\": 567, \"mu_intercept_per_group\": 5.823843955993652, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 6, \"draws\": 568, \"mu_intercept_per_group\": 6.828389644622803, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 6, \"draws\": 569, \"mu_intercept_per_group\": 6.3411455154418945, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 6, \"draws\": 570, \"mu_intercept_per_group\": 6.211709022521973, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 6, \"draws\": 571, \"mu_intercept_per_group\": 6.140937805175781, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 6, \"draws\": 572, \"mu_intercept_per_group\": 5.988331317901611, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 6, \"draws\": 573, \"mu_intercept_per_group\": 9.219610214233398, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 6, \"draws\": 574, \"mu_intercept_per_group\": 8.404141426086426, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 6, \"draws\": 575, \"mu_intercept_per_group\": 9.733304977416992, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 6, \"draws\": 576, \"mu_intercept_per_group\": 10.323922157287598, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 6, \"draws\": 577, \"mu_intercept_per_group\": 12.470230102539062, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 6, \"draws\": 578, \"mu_intercept_per_group\": 12.656524658203125, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 6, \"draws\": 579, \"mu_intercept_per_group\": 12.382938385009766, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 6, \"draws\": 580, \"mu_intercept_per_group\": 10.457259178161621, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 6, \"draws\": 581, \"mu_intercept_per_group\": 9.89118480682373, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 6, \"draws\": 582, \"mu_intercept_per_group\": 9.103690147399902, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 6, \"draws\": 583, \"mu_intercept_per_group\": 9.936705589294434, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 6, \"draws\": 584, \"mu_intercept_per_group\": 9.260136604309082, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 6, \"draws\": 585, \"mu_intercept_per_group\": 12.350250244140625, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 6, \"draws\": 586, \"mu_intercept_per_group\": 11.197752952575684, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 6, \"draws\": 587, \"mu_intercept_per_group\": 12.077271461486816, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 6, \"draws\": 588, \"mu_intercept_per_group\": 12.11439037322998, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 6, \"draws\": 589, \"mu_intercept_per_group\": 12.137679100036621, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 6, \"draws\": 590, \"mu_intercept_per_group\": 12.568549156188965, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 6, \"draws\": 591, \"mu_intercept_per_group\": 12.59296989440918, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 6, \"draws\": 592, \"mu_intercept_per_group\": 12.61994457244873, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 6, \"draws\": 593, \"mu_intercept_per_group\": 13.75624942779541, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 6, \"draws\": 594, \"mu_intercept_per_group\": 12.995519638061523, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 6, \"draws\": 595, \"mu_intercept_per_group\": 12.715022087097168, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 6, \"draws\": 596, \"mu_intercept_per_group\": 12.58169174194336, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 6, \"draws\": 597, \"mu_intercept_per_group\": 13.586897850036621, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 6, \"draws\": 598, \"mu_intercept_per_group\": 11.938750267028809, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 6, \"draws\": 599, \"mu_intercept_per_group\": 13.606650352478027, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 6, \"draws\": 600, \"mu_intercept_per_group\": 11.192628860473633, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 6, \"draws\": 601, \"mu_intercept_per_group\": 11.908283233642578, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 6, \"draws\": 602, \"mu_intercept_per_group\": 13.234382629394531, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 6, \"draws\": 603, \"mu_intercept_per_group\": 13.134452819824219, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 6, \"draws\": 604, \"mu_intercept_per_group\": 12.159107208251953, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 6, \"draws\": 605, \"mu_intercept_per_group\": 14.019562721252441, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 6, \"draws\": 606, \"mu_intercept_per_group\": 13.090171813964844, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 6, \"draws\": 607, \"mu_intercept_per_group\": 12.800149917602539, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 6, \"draws\": 608, \"mu_intercept_per_group\": 7.402369499206543, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 6, \"draws\": 609, \"mu_intercept_per_group\": 6.842586517333984, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 6, \"draws\": 610, \"mu_intercept_per_group\": 6.986385345458984, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 6, \"draws\": 611, \"mu_intercept_per_group\": 7.476758003234863, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 6, \"draws\": 612, \"mu_intercept_per_group\": 6.49592399597168, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 6, \"draws\": 613, \"mu_intercept_per_group\": 6.018400192260742, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 6, \"draws\": 614, \"mu_intercept_per_group\": 7.325270652770996, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 6, \"draws\": 615, \"mu_intercept_per_group\": 8.079042434692383, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 6, \"draws\": 616, \"mu_intercept_per_group\": 7.734365940093994, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 6, \"draws\": 617, \"mu_intercept_per_group\": 7.277247905731201, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 6, \"draws\": 618, \"mu_intercept_per_group\": 10.899203300476074, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 6, \"draws\": 619, \"mu_intercept_per_group\": 11.419858932495117, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 6, \"draws\": 620, \"mu_intercept_per_group\": 10.695928573608398, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 6, \"draws\": 621, \"mu_intercept_per_group\": 11.180797576904297, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 6, \"draws\": 622, \"mu_intercept_per_group\": 10.426112174987793, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 6, \"draws\": 623, \"mu_intercept_per_group\": 12.719986915588379, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 6, \"draws\": 624, \"mu_intercept_per_group\": 11.186307907104492, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 6, \"draws\": 625, \"mu_intercept_per_group\": 11.689884185791016, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 6, \"draws\": 626, \"mu_intercept_per_group\": 11.111427307128906, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 6, \"draws\": 627, \"mu_intercept_per_group\": 10.560688972473145, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 6, \"draws\": 628, \"mu_intercept_per_group\": 10.19147777557373, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 6, \"draws\": 629, \"mu_intercept_per_group\": 6.237336158752441, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 6, \"draws\": 630, \"mu_intercept_per_group\": 6.605474472045898, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 6, \"draws\": 631, \"mu_intercept_per_group\": 5.980112075805664, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 6, \"draws\": 632, \"mu_intercept_per_group\": 7.268651962280273, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 6, \"draws\": 633, \"mu_intercept_per_group\": 7.508934020996094, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 6, \"draws\": 634, \"mu_intercept_per_group\": 8.009002685546875, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 6, \"draws\": 635, \"mu_intercept_per_group\": 8.484498977661133, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 6, \"draws\": 636, \"mu_intercept_per_group\": 9.157941818237305, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 6, \"draws\": 637, \"mu_intercept_per_group\": 8.21286678314209, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 6, \"draws\": 638, \"mu_intercept_per_group\": 6.970890998840332, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 6, \"draws\": 639, \"mu_intercept_per_group\": 6.187521934509277, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}, {\"mouse\": 7, \"draws\": 0, \"mu_intercept_per_group\": 9.213627815246582, \"sigma_intercept_per_group\": 0.02567276917397976, \"sigma_obs\": 0.0035865597892552614, \"slope\": 0.1862485706806183, \"chain\": 0, \"draw\": 0}, {\"mouse\": 7, \"draws\": 1, \"mu_intercept_per_group\": 9.834117889404297, \"sigma_intercept_per_group\": 0.024225503206253052, \"sigma_obs\": 0.0036130575463175774, \"slope\": 0.18214517831802368, \"chain\": 0, \"draw\": 1}, {\"mouse\": 7, \"draws\": 2, \"mu_intercept_per_group\": 9.729364395141602, \"sigma_intercept_per_group\": 0.02399633079767227, \"sigma_obs\": 0.0036158461589366198, \"slope\": 0.18422828614711761, \"chain\": 0, \"draw\": 2}, {\"mouse\": 7, \"draws\": 3, \"mu_intercept_per_group\": 9.672246932983398, \"sigma_intercept_per_group\": 0.02385750412940979, \"sigma_obs\": 0.0035955787170678377, \"slope\": 0.18956609070301056, \"chain\": 0, \"draw\": 3}, {\"mouse\": 7, \"draws\": 4, \"mu_intercept_per_group\": 10.909956932067871, \"sigma_intercept_per_group\": 0.021697938442230225, \"sigma_obs\": 0.0036303235683590174, \"slope\": 0.1905411034822464, \"chain\": 0, \"draw\": 4}, {\"mouse\": 7, \"draws\": 5, \"mu_intercept_per_group\": 10.370231628417969, \"sigma_intercept_per_group\": 0.022660940885543823, \"sigma_obs\": 0.0036386908032000065, \"slope\": 0.19301852583885193, \"chain\": 0, \"draw\": 5}, {\"mouse\": 7, \"draws\": 6, \"mu_intercept_per_group\": 9.904123306274414, \"sigma_intercept_per_group\": 0.024262966588139534, \"sigma_obs\": 0.003628139616921544, \"slope\": 0.19114845991134644, \"chain\": 0, \"draw\": 6}, {\"mouse\": 7, \"draws\": 7, \"mu_intercept_per_group\": 8.957792282104492, \"sigma_intercept_per_group\": 0.025719182565808296, \"sigma_obs\": 0.00359806208871305, \"slope\": 0.19086617231369019, \"chain\": 0, \"draw\": 7}, {\"mouse\": 7, \"draws\": 8, \"mu_intercept_per_group\": 8.40782356262207, \"sigma_intercept_per_group\": 0.02690105326473713, \"sigma_obs\": 0.003606146899983287, \"slope\": 0.19048477709293365, \"chain\": 0, \"draw\": 8}, {\"mouse\": 7, \"draws\": 9, \"mu_intercept_per_group\": 8.692178726196289, \"sigma_intercept_per_group\": 0.026805421337485313, \"sigma_obs\": 0.003603233490139246, \"slope\": 0.1860472857952118, \"chain\": 0, \"draw\": 9}, {\"mouse\": 7, \"draws\": 10, \"mu_intercept_per_group\": 8.433756828308105, \"sigma_intercept_per_group\": 0.02552388422191143, \"sigma_obs\": 0.003605497069656849, \"slope\": 0.18604068458080292, \"chain\": 0, \"draw\": 10}, {\"mouse\": 7, \"draws\": 11, \"mu_intercept_per_group\": 8.968855857849121, \"sigma_intercept_per_group\": 0.026902848854660988, \"sigma_obs\": 0.003592956345528364, \"slope\": 0.18669074773788452, \"chain\": 0, \"draw\": 11}, {\"mouse\": 7, \"draws\": 12, \"mu_intercept_per_group\": 13.960990905761719, \"sigma_intercept_per_group\": 0.01704244688153267, \"sigma_obs\": 0.0036010402254760265, \"slope\": 0.19155021011829376, \"chain\": 0, \"draw\": 12}, {\"mouse\": 7, \"draws\": 13, \"mu_intercept_per_group\": 13.406194686889648, \"sigma_intercept_per_group\": 0.017292048782110214, \"sigma_obs\": 0.003606520127505064, \"slope\": 0.194507896900177, \"chain\": 0, \"draw\": 13}, {\"mouse\": 7, \"draws\": 14, \"mu_intercept_per_group\": 12.736788749694824, \"sigma_intercept_per_group\": 0.017483489587903023, \"sigma_obs\": 0.0035947849974036217, \"slope\": 0.1969202160835266, \"chain\": 0, \"draw\": 14}, {\"mouse\": 7, \"draws\": 15, \"mu_intercept_per_group\": 13.955178260803223, \"sigma_intercept_per_group\": 0.016756728291511536, \"sigma_obs\": 0.003621509298682213, \"slope\": 0.17872914671897888, \"chain\": 0, \"draw\": 15}, {\"mouse\": 7, \"draws\": 16, \"mu_intercept_per_group\": 13.107860565185547, \"sigma_intercept_per_group\": 0.017391743138432503, \"sigma_obs\": 0.0035808710381388664, \"slope\": 0.19179464876651764, \"chain\": 0, \"draw\": 16}, {\"mouse\": 7, \"draws\": 17, \"mu_intercept_per_group\": 13.100902557373047, \"sigma_intercept_per_group\": 0.016798529773950577, \"sigma_obs\": 0.0035752253606915474, \"slope\": 0.1918923705816269, \"chain\": 0, \"draw\": 17}, {\"mouse\": 7, \"draws\": 18, \"mu_intercept_per_group\": 13.665458679199219, \"sigma_intercept_per_group\": 0.01680074818432331, \"sigma_obs\": 0.0036042560823261738, \"slope\": 0.1868363618850708, \"chain\": 0, \"draw\": 18}, {\"mouse\": 7, \"draws\": 19, \"mu_intercept_per_group\": 13.348406791687012, \"sigma_intercept_per_group\": 0.016946686431765556, \"sigma_obs\": 0.0036075436510145664, \"slope\": 0.1927732676267624, \"chain\": 0, \"draw\": 19}, {\"mouse\": 7, \"draws\": 20, \"mu_intercept_per_group\": 13.394099235534668, \"sigma_intercept_per_group\": 0.01788945496082306, \"sigma_obs\": 0.003618058981373906, \"slope\": 0.18616291880607605, \"chain\": 0, \"draw\": 20}, {\"mouse\": 7, \"draws\": 21, \"mu_intercept_per_group\": 11.303171157836914, \"sigma_intercept_per_group\": 0.020151978358626366, \"sigma_obs\": 0.0035976057406514883, \"slope\": 0.18452736735343933, \"chain\": 0, \"draw\": 21}, {\"mouse\": 7, \"draws\": 22, \"mu_intercept_per_group\": 12.553191184997559, \"sigma_intercept_per_group\": 0.0172649584710598, \"sigma_obs\": 0.003568237414583564, \"slope\": 0.19352282583713531, \"chain\": 0, \"draw\": 22}, {\"mouse\": 7, \"draws\": 23, \"mu_intercept_per_group\": 12.651515007019043, \"sigma_intercept_per_group\": 0.01746990531682968, \"sigma_obs\": 0.00356018147431314, \"slope\": 0.1938650757074356, \"chain\": 0, \"draw\": 23}, {\"mouse\": 7, \"draws\": 24, \"mu_intercept_per_group\": 12.478144645690918, \"sigma_intercept_per_group\": 0.017467832192778587, \"sigma_obs\": 0.0035675805993378162, \"slope\": 0.1930655986070633, \"chain\": 0, \"draw\": 24}, {\"mouse\": 7, \"draws\": 25, \"mu_intercept_per_group\": 13.423978805541992, \"sigma_intercept_per_group\": 0.016812961548566818, \"sigma_obs\": 0.0035814533475786448, \"slope\": 0.19506731629371643, \"chain\": 0, \"draw\": 25}, {\"mouse\": 7, \"draws\": 26, \"mu_intercept_per_group\": 12.812862396240234, \"sigma_intercept_per_group\": 0.01826082170009613, \"sigma_obs\": 0.003596050199121237, \"slope\": 0.18712331354618073, \"chain\": 0, \"draw\": 26}, {\"mouse\": 7, \"draws\": 27, \"mu_intercept_per_group\": 12.730733871459961, \"sigma_intercept_per_group\": 0.017227204516530037, \"sigma_obs\": 0.0035779522731900215, \"slope\": 0.1966174989938736, \"chain\": 0, \"draw\": 27}, {\"mouse\": 7, \"draws\": 28, \"mu_intercept_per_group\": 16.500648498535156, \"sigma_intercept_per_group\": 0.013904055580496788, \"sigma_obs\": 0.0036053836811333895, \"slope\": 0.1855842024087906, \"chain\": 0, \"draw\": 28}, {\"mouse\": 7, \"draws\": 29, \"mu_intercept_per_group\": 16.81934356689453, \"sigma_intercept_per_group\": 0.013682653196156025, \"sigma_obs\": 0.0036072854418307543, \"slope\": 0.19379311800003052, \"chain\": 0, \"draw\": 29}, {\"mouse\": 7, \"draws\": 30, \"mu_intercept_per_group\": 15.435750007629395, \"sigma_intercept_per_group\": 0.01445866096764803, \"sigma_obs\": 0.0035984928254038095, \"slope\": 0.19644460082054138, \"chain\": 0, \"draw\": 30}, {\"mouse\": 7, \"draws\": 31, \"mu_intercept_per_group\": 16.746749877929688, \"sigma_intercept_per_group\": 0.01340528018772602, \"sigma_obs\": 0.0035804561339318752, \"slope\": 0.1955338567495346, \"chain\": 0, \"draw\": 31}, {\"mouse\": 7, \"draws\": 32, \"mu_intercept_per_group\": 15.079421997070312, \"sigma_intercept_per_group\": 0.015800658613443375, \"sigma_obs\": 0.0036212727427482605, \"slope\": 0.18520775437355042, \"chain\": 0, \"draw\": 32}, {\"mouse\": 7, \"draws\": 33, \"mu_intercept_per_group\": 14.319287300109863, \"sigma_intercept_per_group\": 0.01633341982960701, \"sigma_obs\": 0.00361210317350924, \"slope\": 0.1928042322397232, \"chain\": 0, \"draw\": 33}, {\"mouse\": 7, \"draws\": 34, \"mu_intercept_per_group\": 12.707924842834473, \"sigma_intercept_per_group\": 0.016766231507062912, \"sigma_obs\": 0.003612394444644451, \"slope\": 0.19086000323295593, \"chain\": 0, \"draw\": 34}, {\"mouse\": 7, \"draws\": 35, \"mu_intercept_per_group\": 14.636408805847168, \"sigma_intercept_per_group\": 0.016147801652550697, \"sigma_obs\": 0.003612380474805832, \"slope\": 0.18992188572883606, \"chain\": 0, \"draw\": 35}, {\"mouse\": 7, \"draws\": 36, \"mu_intercept_per_group\": 13.334298133850098, \"sigma_intercept_per_group\": 0.01625576801598072, \"sigma_obs\": 0.0035918138455599546, \"slope\": 0.1862964928150177, \"chain\": 0, \"draw\": 36}, {\"mouse\": 7, \"draws\": 37, \"mu_intercept_per_group\": 14.044265747070312, \"sigma_intercept_per_group\": 0.015555276535451412, \"sigma_obs\": 0.003593510016798973, \"slope\": 0.1830633282661438, \"chain\": 0, \"draw\": 37}, {\"mouse\": 7, \"draws\": 38, \"mu_intercept_per_group\": 14.274371147155762, \"sigma_intercept_per_group\": 0.016940344125032425, \"sigma_obs\": 0.0036348290741443634, \"slope\": 0.1858898252248764, \"chain\": 0, \"draw\": 38}, {\"mouse\": 7, \"draws\": 39, \"mu_intercept_per_group\": 14.010676383972168, \"sigma_intercept_per_group\": 0.01736862026154995, \"sigma_obs\": 0.0036129679065197706, \"slope\": 0.18206816911697388, \"chain\": 0, \"draw\": 39}, {\"mouse\": 7, \"draws\": 40, \"mu_intercept_per_group\": 13.74808120727539, \"sigma_intercept_per_group\": 0.017338410019874573, \"sigma_obs\": 0.0036145844496786594, \"slope\": 0.18744051456451416, \"chain\": 0, \"draw\": 40}, {\"mouse\": 7, \"draws\": 41, \"mu_intercept_per_group\": 13.67876148223877, \"sigma_intercept_per_group\": 0.017185991629958153, \"sigma_obs\": 0.003581687342375517, \"slope\": 0.17807823419570923, \"chain\": 0, \"draw\": 41}, {\"mouse\": 7, \"draws\": 42, \"mu_intercept_per_group\": 12.22245979309082, \"sigma_intercept_per_group\": 0.01777239330112934, \"sigma_obs\": 0.0035894664470106363, \"slope\": 0.18890836834907532, \"chain\": 0, \"draw\": 42}, {\"mouse\": 7, \"draws\": 43, \"mu_intercept_per_group\": 11.113139152526855, \"sigma_intercept_per_group\": 0.019074106588959694, \"sigma_obs\": 0.0035865153186023235, \"slope\": 0.20086956024169922, \"chain\": 0, \"draw\": 43}, {\"mouse\": 7, \"draws\": 44, \"mu_intercept_per_group\": 12.065282821655273, \"sigma_intercept_per_group\": 0.01836521178483963, \"sigma_obs\": 0.0035957861691713333, \"slope\": 0.19394491612911224, \"chain\": 0, \"draw\": 44}, {\"mouse\": 7, \"draws\": 45, \"mu_intercept_per_group\": 11.848932266235352, \"sigma_intercept_per_group\": 0.01972019299864769, \"sigma_obs\": 0.0035895658656954765, \"slope\": 0.18302036821842194, \"chain\": 0, \"draw\": 45}, {\"mouse\": 7, \"draws\": 46, \"mu_intercept_per_group\": 12.413116455078125, \"sigma_intercept_per_group\": 0.018794434145092964, \"sigma_obs\": 0.003591034794226289, \"slope\": 0.17740820348262787, \"chain\": 0, \"draw\": 46}, {\"mouse\": 7, \"draws\": 47, \"mu_intercept_per_group\": 12.429065704345703, \"sigma_intercept_per_group\": 0.01929295063018799, \"sigma_obs\": 0.003587320912629366, \"slope\": 0.17922011017799377, \"chain\": 0, \"draw\": 47}, {\"mouse\": 7, \"draws\": 48, \"mu_intercept_per_group\": 13.095636367797852, \"sigma_intercept_per_group\": 0.018546247854828835, \"sigma_obs\": 0.003569454187527299, \"slope\": 0.18277129530906677, \"chain\": 0, \"draw\": 48}, {\"mouse\": 7, \"draws\": 49, \"mu_intercept_per_group\": 12.541633605957031, \"sigma_intercept_per_group\": 0.01774284988641739, \"sigma_obs\": 0.0035763848572969437, \"slope\": 0.18289095163345337, \"chain\": 0, \"draw\": 49}, {\"mouse\": 7, \"draws\": 50, \"mu_intercept_per_group\": 8.320059776306152, \"sigma_intercept_per_group\": 0.02875550277531147, \"sigma_obs\": 0.0036165618803352118, \"slope\": 0.19487632811069489, \"chain\": 0, \"draw\": 50}, {\"mouse\": 7, \"draws\": 51, \"mu_intercept_per_group\": 9.778614044189453, \"sigma_intercept_per_group\": 0.02357609197497368, \"sigma_obs\": 0.003612680360674858, \"slope\": 0.18027754127979279, \"chain\": 0, \"draw\": 51}, {\"mouse\": 7, \"draws\": 52, \"mu_intercept_per_group\": 5.030928134918213, \"sigma_intercept_per_group\": 0.04416833445429802, \"sigma_obs\": 0.0035796230658888817, \"slope\": 0.19808143377304077, \"chain\": 0, \"draw\": 52}, {\"mouse\": 7, \"draws\": 53, \"mu_intercept_per_group\": 4.664797306060791, \"sigma_intercept_per_group\": 0.04594124108552933, \"sigma_obs\": 0.0035753720439970493, \"slope\": 0.19831471145153046, \"chain\": 0, \"draw\": 53}, {\"mouse\": 7, \"draws\": 54, \"mu_intercept_per_group\": 4.608709812164307, \"sigma_intercept_per_group\": 0.04666163772344589, \"sigma_obs\": 0.003573541296645999, \"slope\": 0.19822140038013458, \"chain\": 0, \"draw\": 54}, {\"mouse\": 7, \"draws\": 55, \"mu_intercept_per_group\": 5.176743984222412, \"sigma_intercept_per_group\": 0.04200543835759163, \"sigma_obs\": 0.0035628019832074642, \"slope\": 0.1994291990995407, \"chain\": 0, \"draw\": 55}, {\"mouse\": 7, \"draws\": 56, \"mu_intercept_per_group\": 5.524876117706299, \"sigma_intercept_per_group\": 0.045365288853645325, \"sigma_obs\": 0.0036489421036094427, \"slope\": 0.18349230289459229, \"chain\": 0, \"draw\": 56}, {\"mouse\": 7, \"draws\": 57, \"mu_intercept_per_group\": 5.531571865081787, \"sigma_intercept_per_group\": 0.04220767319202423, \"sigma_obs\": 0.003633167129009962, \"slope\": 0.18557313084602356, \"chain\": 0, \"draw\": 57}, {\"mouse\": 7, \"draws\": 58, \"mu_intercept_per_group\": 5.082027912139893, \"sigma_intercept_per_group\": 0.04622257500886917, \"sigma_obs\": 0.0036298129707574844, \"slope\": 0.1824798434972763, \"chain\": 0, \"draw\": 58}, {\"mouse\": 7, \"draws\": 59, \"mu_intercept_per_group\": 5.238330364227295, \"sigma_intercept_per_group\": 0.04599187150597572, \"sigma_obs\": 0.003627542871981859, \"slope\": 0.18291348218917847, \"chain\": 0, \"draw\": 59}, {\"mouse\": 7, \"draws\": 60, \"mu_intercept_per_group\": 5.1273040771484375, \"sigma_intercept_per_group\": 0.04597925394773483, \"sigma_obs\": 0.0036262855865061283, \"slope\": 0.1828322559595108, \"chain\": 0, \"draw\": 60}, {\"mouse\": 7, \"draws\": 61, \"mu_intercept_per_group\": 8.060755729675293, \"sigma_intercept_per_group\": 0.02791447378695011, \"sigma_obs\": 0.003573422087356448, \"slope\": 0.19430845975875854, \"chain\": 0, \"draw\": 61}, {\"mouse\": 7, \"draws\": 62, \"mu_intercept_per_group\": 9.402769088745117, \"sigma_intercept_per_group\": 0.024111580103635788, \"sigma_obs\": 0.0035985615104436874, \"slope\": 0.19080160558223724, \"chain\": 0, \"draw\": 62}, {\"mouse\": 7, \"draws\": 63, \"mu_intercept_per_group\": 9.09987735748291, \"sigma_intercept_per_group\": 0.025329796597361565, \"sigma_obs\": 0.003604766447097063, \"slope\": 0.1913401335477829, \"chain\": 0, \"draw\": 63}, {\"mouse\": 7, \"draws\": 64, \"mu_intercept_per_group\": 9.3138427734375, \"sigma_intercept_per_group\": 0.024736803025007248, \"sigma_obs\": 0.0036002176348119974, \"slope\": 0.19178242981433868, \"chain\": 0, \"draw\": 64}, {\"mouse\": 7, \"draws\": 65, \"mu_intercept_per_group\": 9.066337585449219, \"sigma_intercept_per_group\": 0.025850770995020866, \"sigma_obs\": 0.0036024192813783884, \"slope\": 0.1962258517742157, \"chain\": 0, \"draw\": 65}, {\"mouse\": 7, \"draws\": 66, \"mu_intercept_per_group\": 9.208731651306152, \"sigma_intercept_per_group\": 0.024632738903164864, \"sigma_obs\": 0.003607894526794553, \"slope\": 0.1964886635541916, \"chain\": 0, \"draw\": 66}, {\"mouse\": 7, \"draws\": 67, \"mu_intercept_per_group\": 9.222782135009766, \"sigma_intercept_per_group\": 0.02409014105796814, \"sigma_obs\": 0.0036020532716065645, \"slope\": 0.19585992395877838, \"chain\": 0, \"draw\": 67}, {\"mouse\": 7, \"draws\": 68, \"mu_intercept_per_group\": 9.138355255126953, \"sigma_intercept_per_group\": 0.024955550208687782, \"sigma_obs\": 0.003598148003220558, \"slope\": 0.19365131855010986, \"chain\": 0, \"draw\": 68}, {\"mouse\": 7, \"draws\": 69, \"mu_intercept_per_group\": 9.563375473022461, \"sigma_intercept_per_group\": 0.024058297276496887, \"sigma_obs\": 0.003599637420848012, \"slope\": 0.19344431161880493, \"chain\": 0, \"draw\": 69}, {\"mouse\": 7, \"draws\": 70, \"mu_intercept_per_group\": 7.112536430358887, \"sigma_intercept_per_group\": 0.03206897899508476, \"sigma_obs\": 0.0035939759109169245, \"slope\": 0.19261164963245392, \"chain\": 0, \"draw\": 70}, {\"mouse\": 7, \"draws\": 71, \"mu_intercept_per_group\": 6.145611763000488, \"sigma_intercept_per_group\": 0.038460321724414825, \"sigma_obs\": 0.003608661936596036, \"slope\": 0.18565791845321655, \"chain\": 0, \"draw\": 71}, {\"mouse\": 7, \"draws\": 72, \"mu_intercept_per_group\": 6.3184309005737305, \"sigma_intercept_per_group\": 0.03801451250910759, \"sigma_obs\": 0.003611581400036812, \"slope\": 0.18579472601413727, \"chain\": 0, \"draw\": 72}, {\"mouse\": 7, \"draws\": 73, \"mu_intercept_per_group\": 6.203390598297119, \"sigma_intercept_per_group\": 0.03839884325861931, \"sigma_obs\": 0.0036139225121587515, \"slope\": 0.18577516078948975, \"chain\": 0, \"draw\": 73}, {\"mouse\": 7, \"draws\": 74, \"mu_intercept_per_group\": 5.786012649536133, \"sigma_intercept_per_group\": 0.038481712341308594, \"sigma_obs\": 0.0036147756036370993, \"slope\": 0.1862640529870987, \"chain\": 0, \"draw\": 74}, {\"mouse\": 7, \"draws\": 75, \"mu_intercept_per_group\": 6.408137798309326, \"sigma_intercept_per_group\": 0.036341141909360886, \"sigma_obs\": 0.0035873858723789454, \"slope\": 0.17818708717823029, \"chain\": 0, \"draw\": 75}, {\"mouse\": 7, \"draws\": 76, \"mu_intercept_per_group\": 6.436429500579834, \"sigma_intercept_per_group\": 0.03610263392329216, \"sigma_obs\": 0.0035860654897987843, \"slope\": 0.17831146717071533, \"chain\": 0, \"draw\": 76}, {\"mouse\": 7, \"draws\": 77, \"mu_intercept_per_group\": 8.718072891235352, \"sigma_intercept_per_group\": 0.02563287876546383, \"sigma_obs\": 0.0035905553959310055, \"slope\": 0.2000746726989746, \"chain\": 0, \"draw\": 77}, {\"mouse\": 7, \"draws\": 78, \"mu_intercept_per_group\": 8.073888778686523, \"sigma_intercept_per_group\": 0.0282643623650074, \"sigma_obs\": 0.003587758867070079, \"slope\": 0.18813511729240417, \"chain\": 0, \"draw\": 78}, {\"mouse\": 7, \"draws\": 79, \"mu_intercept_per_group\": 12.50383472442627, \"sigma_intercept_per_group\": 0.018341688439249992, \"sigma_obs\": 0.003619021736085415, \"slope\": 0.1897200495004654, \"chain\": 0, \"draw\": 79}, {\"mouse\": 7, \"draws\": 80, \"mu_intercept_per_group\": 14.6437349319458, \"sigma_intercept_per_group\": 0.015620038844645023, \"sigma_obs\": 0.0035633472725749016, \"slope\": 0.1851406693458557, \"chain\": 0, \"draw\": 80}, {\"mouse\": 7, \"draws\": 81, \"mu_intercept_per_group\": 13.905681610107422, \"sigma_intercept_per_group\": 0.01692698895931244, \"sigma_obs\": 0.0036110493820160627, \"slope\": 0.18626567721366882, \"chain\": 0, \"draw\": 81}, {\"mouse\": 7, \"draws\": 82, \"mu_intercept_per_group\": 14.383466720581055, \"sigma_intercept_per_group\": 0.01605873741209507, \"sigma_obs\": 0.0035963915288448334, \"slope\": 0.1873772293329239, \"chain\": 0, \"draw\": 82}, {\"mouse\": 7, \"draws\": 83, \"mu_intercept_per_group\": 14.96165657043457, \"sigma_intercept_per_group\": 0.015859119594097137, \"sigma_obs\": 0.003595168935135007, \"slope\": 0.18047231435775757, \"chain\": 0, \"draw\": 83}, {\"mouse\": 7, \"draws\": 84, \"mu_intercept_per_group\": 12.443949699401855, \"sigma_intercept_per_group\": 0.017832376062870026, \"sigma_obs\": 0.003581094555556774, \"slope\": 0.1933223307132721, \"chain\": 0, \"draw\": 84}, {\"mouse\": 7, \"draws\": 85, \"mu_intercept_per_group\": 12.591570854187012, \"sigma_intercept_per_group\": 0.018247460946440697, \"sigma_obs\": 0.0035741105675697327, \"slope\": 0.1917574107646942, \"chain\": 0, \"draw\": 85}, {\"mouse\": 7, \"draws\": 86, \"mu_intercept_per_group\": 11.093611717224121, \"sigma_intercept_per_group\": 0.020516803488135338, \"sigma_obs\": 0.0035931244492530823, \"slope\": 0.19252188503742218, \"chain\": 0, \"draw\": 86}, {\"mouse\": 7, \"draws\": 87, \"mu_intercept_per_group\": 9.042926788330078, \"sigma_intercept_per_group\": 0.026219544932246208, \"sigma_obs\": 0.0036158806178718805, \"slope\": 0.18666358292102814, \"chain\": 0, \"draw\": 87}, {\"mouse\": 7, \"draws\": 88, \"mu_intercept_per_group\": 8.879538536071777, \"sigma_intercept_per_group\": 0.027031399309635162, \"sigma_obs\": 0.003613055916503072, \"slope\": 0.18657955527305603, \"chain\": 0, \"draw\": 88}, {\"mouse\": 7, \"draws\": 89, \"mu_intercept_per_group\": 11.699110984802246, \"sigma_intercept_per_group\": 0.02028581127524376, \"sigma_obs\": 0.0036249717231839895, \"slope\": 0.18866576254367828, \"chain\": 0, \"draw\": 89}, {\"mouse\": 7, \"draws\": 90, \"mu_intercept_per_group\": 11.002934455871582, \"sigma_intercept_per_group\": 0.0206430796533823, \"sigma_obs\": 0.0036159565206617117, \"slope\": 0.19140881299972534, \"chain\": 0, \"draw\": 90}, {\"mouse\": 7, \"draws\": 91, \"mu_intercept_per_group\": 13.15277099609375, \"sigma_intercept_per_group\": 0.018172958865761757, \"sigma_obs\": 0.0036074782256036997, \"slope\": 0.17802299559116364, \"chain\": 0, \"draw\": 91}, {\"mouse\": 7, \"draws\": 92, \"mu_intercept_per_group\": 12.102582931518555, \"sigma_intercept_per_group\": 0.019296912476420403, \"sigma_obs\": 0.0036112903617322445, \"slope\": 0.1814308762550354, \"chain\": 0, \"draw\": 92}, {\"mouse\": 7, \"draws\": 93, \"mu_intercept_per_group\": 12.63425350189209, \"sigma_intercept_per_group\": 0.019298817962408066, \"sigma_obs\": 0.0036549167707562447, \"slope\": 0.20035187900066376, \"chain\": 0, \"draw\": 93}, {\"mouse\": 7, \"draws\": 94, \"mu_intercept_per_group\": 12.645500183105469, \"sigma_intercept_per_group\": 0.019013110548257828, \"sigma_obs\": 0.0036567908246070147, \"slope\": 0.20102527737617493, \"chain\": 0, \"draw\": 94}, {\"mouse\": 7, \"draws\": 95, \"mu_intercept_per_group\": 12.180895805358887, \"sigma_intercept_per_group\": 0.019301049411296844, \"sigma_obs\": 0.0036643976345658302, \"slope\": 0.20038112998008728, \"chain\": 0, \"draw\": 95}, {\"mouse\": 7, \"draws\": 96, \"mu_intercept_per_group\": 11.41718578338623, \"sigma_intercept_per_group\": 0.02070239745080471, \"sigma_obs\": 0.0036765073891729116, \"slope\": 0.19795894622802734, \"chain\": 0, \"draw\": 96}, {\"mouse\": 7, \"draws\": 97, \"mu_intercept_per_group\": 11.626137733459473, \"sigma_intercept_per_group\": 0.020868554711341858, \"sigma_obs\": 0.0036651648115366697, \"slope\": 0.1966148316860199, \"chain\": 0, \"draw\": 97}, {\"mouse\": 7, \"draws\": 98, \"mu_intercept_per_group\": 11.092533111572266, \"sigma_intercept_per_group\": 0.020952319726347923, \"sigma_obs\": 0.003630997147411108, \"slope\": 0.1940213292837143, \"chain\": 0, \"draw\": 98}, {\"mouse\": 7, \"draws\": 99, \"mu_intercept_per_group\": 11.016407012939453, \"sigma_intercept_per_group\": 0.020602568984031677, \"sigma_obs\": 0.003629937767982483, \"slope\": 0.19363313913345337, \"chain\": 0, \"draw\": 99}, {\"mouse\": 7, \"draws\": 100, \"mu_intercept_per_group\": 11.056938171386719, \"sigma_intercept_per_group\": 0.02095814421772957, \"sigma_obs\": 0.003613800276070833, \"slope\": 0.19754108786582947, \"chain\": 0, \"draw\": 100}, {\"mouse\": 7, \"draws\": 101, \"mu_intercept_per_group\": 12.859992980957031, \"sigma_intercept_per_group\": 0.01851489767432213, \"sigma_obs\": 0.003609646111726761, \"slope\": 0.18494030833244324, \"chain\": 0, \"draw\": 101}, {\"mouse\": 7, \"draws\": 102, \"mu_intercept_per_group\": 12.762211799621582, \"sigma_intercept_per_group\": 0.018786553293466568, \"sigma_obs\": 0.003632607636973262, \"slope\": 0.18858161568641663, \"chain\": 0, \"draw\": 102}, {\"mouse\": 7, \"draws\": 103, \"mu_intercept_per_group\": 7.210906028747559, \"sigma_intercept_per_group\": 0.03228265792131424, \"sigma_obs\": 0.0035999619867652655, \"slope\": 0.19256488978862762, \"chain\": 0, \"draw\": 103}, {\"mouse\": 7, \"draws\": 104, \"mu_intercept_per_group\": 10.110258102416992, \"sigma_intercept_per_group\": 0.02372453548014164, \"sigma_obs\": 0.0036139036528766155, \"slope\": 0.18907195329666138, \"chain\": 0, \"draw\": 104}, {\"mouse\": 7, \"draws\": 105, \"mu_intercept_per_group\": 9.963737487792969, \"sigma_intercept_per_group\": 0.022215858101844788, \"sigma_obs\": 0.0035493180621415377, \"slope\": 0.18118156492710114, \"chain\": 0, \"draw\": 105}, {\"mouse\": 7, \"draws\": 106, \"mu_intercept_per_group\": 10.98570728302002, \"sigma_intercept_per_group\": 0.020380254834890366, \"sigma_obs\": 0.003612824948504567, \"slope\": 0.1975925862789154, \"chain\": 0, \"draw\": 106}, {\"mouse\": 7, \"draws\": 107, \"mu_intercept_per_group\": 11.430583000183105, \"sigma_intercept_per_group\": 0.01963503658771515, \"sigma_obs\": 0.0035745331551879644, \"slope\": 0.19700098037719727, \"chain\": 0, \"draw\": 107}, {\"mouse\": 7, \"draws\": 108, \"mu_intercept_per_group\": 11.19536304473877, \"sigma_intercept_per_group\": 0.01983003132045269, \"sigma_obs\": 0.0035808435641229153, \"slope\": 0.19766771793365479, \"chain\": 0, \"draw\": 108}, {\"mouse\": 7, \"draws\": 109, \"mu_intercept_per_group\": 19.51195526123047, \"sigma_intercept_per_group\": 0.011968192644417286, \"sigma_obs\": 0.003602941520512104, \"slope\": 0.17744509875774384, \"chain\": 0, \"draw\": 109}, {\"mouse\": 7, \"draws\": 110, \"mu_intercept_per_group\": 20.299570083618164, \"sigma_intercept_per_group\": 0.011746767908334732, \"sigma_obs\": 0.003614079440012574, \"slope\": 0.17911460995674133, \"chain\": 0, \"draw\": 110}, {\"mouse\": 7, \"draws\": 111, \"mu_intercept_per_group\": 13.546540260314941, \"sigma_intercept_per_group\": 0.016061387956142426, \"sigma_obs\": 0.00358179141767323, \"slope\": 0.19672614336013794, \"chain\": 0, \"draw\": 111}, {\"mouse\": 7, \"draws\": 112, \"mu_intercept_per_group\": 12.784123420715332, \"sigma_intercept_per_group\": 0.01698175258934498, \"sigma_obs\": 0.0035904627293348312, \"slope\": 0.19764505326747894, \"chain\": 0, \"draw\": 112}, {\"mouse\": 7, \"draws\": 113, \"mu_intercept_per_group\": 13.257153511047363, \"sigma_intercept_per_group\": 0.01667170599102974, \"sigma_obs\": 0.0035894373431801796, \"slope\": 0.19650930166244507, \"chain\": 0, \"draw\": 113}, {\"mouse\": 7, \"draws\": 114, \"mu_intercept_per_group\": 14.41031551361084, \"sigma_intercept_per_group\": 0.014817258343100548, \"sigma_obs\": 0.0035617758985608816, \"slope\": 0.1950979381799698, \"chain\": 0, \"draw\": 114}, {\"mouse\": 7, \"draws\": 115, \"mu_intercept_per_group\": 14.123627662658691, \"sigma_intercept_per_group\": 0.016119007021188736, \"sigma_obs\": 0.0035785238724201918, \"slope\": 0.1908784657716751, \"chain\": 0, \"draw\": 115}, {\"mouse\": 7, \"draws\": 116, \"mu_intercept_per_group\": 13.036506652832031, \"sigma_intercept_per_group\": 0.017227524891495705, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.19327199459075928, \"chain\": 0, \"draw\": 116}, {\"mouse\": 7, \"draws\": 117, \"mu_intercept_per_group\": 14.61015796661377, \"sigma_intercept_per_group\": 0.016069354489445686, \"sigma_obs\": 0.003623983124271035, \"slope\": 0.18090713024139404, \"chain\": 0, \"draw\": 117}, {\"mouse\": 7, \"draws\": 118, \"mu_intercept_per_group\": 14.42878246307373, \"sigma_intercept_per_group\": 0.016661960631608963, \"sigma_obs\": 0.0036060181446373463, \"slope\": 0.18571484088897705, \"chain\": 0, \"draw\": 118}, {\"mouse\": 7, \"draws\": 119, \"mu_intercept_per_group\": 14.399157524108887, \"sigma_intercept_per_group\": 0.0160249974578619, \"sigma_obs\": 0.003611174877732992, \"slope\": 0.1818389594554901, \"chain\": 0, \"draw\": 119}, {\"mouse\": 7, \"draws\": 120, \"mu_intercept_per_group\": 16.9290828704834, \"sigma_intercept_per_group\": 0.013900257647037506, \"sigma_obs\": 0.0036060421261936426, \"slope\": 0.18610714375972748, \"chain\": 0, \"draw\": 120}, {\"mouse\": 7, \"draws\": 121, \"mu_intercept_per_group\": 16.628997802734375, \"sigma_intercept_per_group\": 0.013676273636519909, \"sigma_obs\": 0.003605756675824523, \"slope\": 0.18679741024971008, \"chain\": 0, \"draw\": 121}, {\"mouse\": 7, \"draws\": 122, \"mu_intercept_per_group\": 14.44288158416748, \"sigma_intercept_per_group\": 0.016544047743082047, \"sigma_obs\": 0.003607669146731496, \"slope\": 0.2000032514333725, \"chain\": 0, \"draw\": 122}, {\"mouse\": 7, \"draws\": 123, \"mu_intercept_per_group\": 14.6681489944458, \"sigma_intercept_per_group\": 0.016036661341786385, \"sigma_obs\": 0.0036080614663660526, \"slope\": 0.19929790496826172, \"chain\": 0, \"draw\": 123}, {\"mouse\": 7, \"draws\": 124, \"mu_intercept_per_group\": 12.307303428649902, \"sigma_intercept_per_group\": 0.01818889193236828, \"sigma_obs\": 0.0036028074100613594, \"slope\": 0.1915874481201172, \"chain\": 0, \"draw\": 124}, {\"mouse\": 7, \"draws\": 125, \"mu_intercept_per_group\": 10.730957984924316, \"sigma_intercept_per_group\": 0.020860694348812103, \"sigma_obs\": 0.0036017373204231262, \"slope\": 0.18938902020454407, \"chain\": 0, \"draw\": 125}, {\"mouse\": 7, \"draws\": 126, \"mu_intercept_per_group\": 11.716023445129395, \"sigma_intercept_per_group\": 0.0199438389390707, \"sigma_obs\": 0.003601866075769067, \"slope\": 0.18829345703125, \"chain\": 0, \"draw\": 126}, {\"mouse\": 7, \"draws\": 127, \"mu_intercept_per_group\": 11.298872947692871, \"sigma_intercept_per_group\": 0.020486239343881607, \"sigma_obs\": 0.003600772237405181, \"slope\": 0.18793553113937378, \"chain\": 0, \"draw\": 127}, {\"mouse\": 7, \"draws\": 128, \"mu_intercept_per_group\": 9.422407150268555, \"sigma_intercept_per_group\": 0.02252143993973732, \"sigma_obs\": 0.003601912409067154, \"slope\": 0.20723757147789001, \"chain\": 0, \"draw\": 128}, {\"mouse\": 7, \"draws\": 129, \"mu_intercept_per_group\": 10.2095308303833, \"sigma_intercept_per_group\": 0.02253081277012825, \"sigma_obs\": 0.0035895623732358217, \"slope\": 0.18534018099308014, \"chain\": 0, \"draw\": 129}, {\"mouse\": 7, \"draws\": 130, \"mu_intercept_per_group\": 10.915311813354492, \"sigma_intercept_per_group\": 0.021927472203969955, \"sigma_obs\": 0.0036170482635498047, \"slope\": 0.18110224604606628, \"chain\": 0, \"draw\": 130}, {\"mouse\": 7, \"draws\": 131, \"mu_intercept_per_group\": 11.465434074401855, \"sigma_intercept_per_group\": 0.020473377779126167, \"sigma_obs\": 0.003620235249400139, \"slope\": 0.18117056787014008, \"chain\": 0, \"draw\": 131}, {\"mouse\": 7, \"draws\": 132, \"mu_intercept_per_group\": 10.02987003326416, \"sigma_intercept_per_group\": 0.02198585867881775, \"sigma_obs\": 0.0036092710215598345, \"slope\": 0.193137064576149, \"chain\": 0, \"draw\": 132}, {\"mouse\": 7, \"draws\": 133, \"mu_intercept_per_group\": 10.669035911560059, \"sigma_intercept_per_group\": 0.021905839443206787, \"sigma_obs\": 0.0035686474293470383, \"slope\": 0.192082941532135, \"chain\": 0, \"draw\": 133}, {\"mouse\": 7, \"draws\": 134, \"mu_intercept_per_group\": 10.48486328125, \"sigma_intercept_per_group\": 0.022731443867087364, \"sigma_obs\": 0.0035918892826884985, \"slope\": 0.1807270497083664, \"chain\": 0, \"draw\": 134}, {\"mouse\": 7, \"draws\": 135, \"mu_intercept_per_group\": 9.880863189697266, \"sigma_intercept_per_group\": 0.023484647274017334, \"sigma_obs\": 0.003596683032810688, \"slope\": 0.1872601956129074, \"chain\": 0, \"draw\": 135}, {\"mouse\": 7, \"draws\": 136, \"mu_intercept_per_group\": 9.725358963012695, \"sigma_intercept_per_group\": 0.023313302546739578, \"sigma_obs\": 0.0035981221590191126, \"slope\": 0.1878470927476883, \"chain\": 0, \"draw\": 136}, {\"mouse\": 7, \"draws\": 137, \"mu_intercept_per_group\": 10.35915756225586, \"sigma_intercept_per_group\": 0.022554997354745865, \"sigma_obs\": 0.0035985030699521303, \"slope\": 0.18680056929588318, \"chain\": 0, \"draw\": 137}, {\"mouse\": 7, \"draws\": 138, \"mu_intercept_per_group\": 9.679999351501465, \"sigma_intercept_per_group\": 0.024417677894234657, \"sigma_obs\": 0.003608384868130088, \"slope\": 0.188721165060997, \"chain\": 0, \"draw\": 138}, {\"mouse\": 7, \"draws\": 139, \"mu_intercept_per_group\": 9.510231971740723, \"sigma_intercept_per_group\": 0.02442983165383339, \"sigma_obs\": 0.0036089543718844652, \"slope\": 0.19020330905914307, \"chain\": 0, \"draw\": 139}, {\"mouse\": 7, \"draws\": 140, \"mu_intercept_per_group\": 10.098800659179688, \"sigma_intercept_per_group\": 0.02289554849267006, \"sigma_obs\": 0.003599973861128092, \"slope\": 0.1888386756181717, \"chain\": 0, \"draw\": 140}, {\"mouse\": 7, \"draws\": 141, \"mu_intercept_per_group\": 11.089457511901855, \"sigma_intercept_per_group\": 0.0203307643532753, \"sigma_obs\": 0.003585292724892497, \"slope\": 0.19351564347743988, \"chain\": 0, \"draw\": 141}, {\"mouse\": 7, \"draws\": 142, \"mu_intercept_per_group\": 12.32906723022461, \"sigma_intercept_per_group\": 0.018698884174227715, \"sigma_obs\": 0.003600040916353464, \"slope\": 0.19241292774677277, \"chain\": 0, \"draw\": 142}, {\"mouse\": 7, \"draws\": 143, \"mu_intercept_per_group\": 6.986202716827393, \"sigma_intercept_per_group\": 0.03265602886676788, \"sigma_obs\": 0.0035830948036164045, \"slope\": 0.1883404552936554, \"chain\": 0, \"draw\": 143}, {\"mouse\": 7, \"draws\": 144, \"mu_intercept_per_group\": 7.250833988189697, \"sigma_intercept_per_group\": 0.031937140971422195, \"sigma_obs\": 0.0036011242773383856, \"slope\": 0.19460025429725647, \"chain\": 0, \"draw\": 144}, {\"mouse\": 7, \"draws\": 145, \"mu_intercept_per_group\": 7.04548978805542, \"sigma_intercept_per_group\": 0.030996454879641533, \"sigma_obs\": 0.003602932905778289, \"slope\": 0.1950591504573822, \"chain\": 0, \"draw\": 145}, {\"mouse\": 7, \"draws\": 146, \"mu_intercept_per_group\": 6.986104488372803, \"sigma_intercept_per_group\": 0.03399500995874405, \"sigma_obs\": 0.003575835609808564, \"slope\": 0.17983709275722504, \"chain\": 0, \"draw\": 146}, {\"mouse\": 7, \"draws\": 147, \"mu_intercept_per_group\": 7.013962268829346, \"sigma_intercept_per_group\": 0.03322315961122513, \"sigma_obs\": 0.0035736504942178726, \"slope\": 0.18200606107711792, \"chain\": 0, \"draw\": 147}, {\"mouse\": 7, \"draws\": 148, \"mu_intercept_per_group\": 9.223431587219238, \"sigma_intercept_per_group\": 0.02448478899896145, \"sigma_obs\": 0.003572437446564436, \"slope\": 0.18880906701087952, \"chain\": 0, \"draw\": 148}, {\"mouse\": 7, \"draws\": 149, \"mu_intercept_per_group\": 11.426567077636719, \"sigma_intercept_per_group\": 0.020491162315011024, \"sigma_obs\": 0.003631147788837552, \"slope\": 0.188320130109787, \"chain\": 0, \"draw\": 149}, {\"mouse\": 7, \"draws\": 150, \"mu_intercept_per_group\": 11.302207946777344, \"sigma_intercept_per_group\": 0.019927004352211952, \"sigma_obs\": 0.003643689677119255, \"slope\": 0.194557324051857, \"chain\": 0, \"draw\": 150}, {\"mouse\": 7, \"draws\": 151, \"mu_intercept_per_group\": 11.74538516998291, \"sigma_intercept_per_group\": 0.020315751433372498, \"sigma_obs\": 0.003644440323114395, \"slope\": 0.19448786973953247, \"chain\": 0, \"draw\": 151}, {\"mouse\": 7, \"draws\": 152, \"mu_intercept_per_group\": 8.104558944702148, \"sigma_intercept_per_group\": 0.0283373836427927, \"sigma_obs\": 0.003588687861338258, \"slope\": 0.18584749102592468, \"chain\": 0, \"draw\": 152}, {\"mouse\": 7, \"draws\": 153, \"mu_intercept_per_group\": 7.035085201263428, \"sigma_intercept_per_group\": 0.033604830503463745, \"sigma_obs\": 0.003571025561541319, \"slope\": 0.1892658919095993, \"chain\": 0, \"draw\": 153}, {\"mouse\": 7, \"draws\": 154, \"mu_intercept_per_group\": 8.313529014587402, \"sigma_intercept_per_group\": 0.02906806766986847, \"sigma_obs\": 0.003588652005419135, \"slope\": 0.18151970207691193, \"chain\": 0, \"draw\": 154}, {\"mouse\": 7, \"draws\": 155, \"mu_intercept_per_group\": 8.5067777633667, \"sigma_intercept_per_group\": 0.02846369333565235, \"sigma_obs\": 0.0035850652493536472, \"slope\": 0.17839443683624268, \"chain\": 0, \"draw\": 155}, {\"mouse\": 7, \"draws\": 156, \"mu_intercept_per_group\": 8.43693733215332, \"sigma_intercept_per_group\": 0.028211472555994987, \"sigma_obs\": 0.0035758833400905132, \"slope\": 0.18105851113796234, \"chain\": 0, \"draw\": 156}, {\"mouse\": 7, \"draws\": 157, \"mu_intercept_per_group\": 8.399803161621094, \"sigma_intercept_per_group\": 0.0263617392629385, \"sigma_obs\": 0.003567880019545555, \"slope\": 0.18105627596378326, \"chain\": 0, \"draw\": 157}, {\"mouse\": 7, \"draws\": 158, \"mu_intercept_per_group\": 10.22137451171875, \"sigma_intercept_per_group\": 0.023340266197919846, \"sigma_obs\": 0.0036346609704196453, \"slope\": 0.20020967721939087, \"chain\": 0, \"draw\": 158}, {\"mouse\": 7, \"draws\": 159, \"mu_intercept_per_group\": 9.824759483337402, \"sigma_intercept_per_group\": 0.023124273866415024, \"sigma_obs\": 0.003630993654951453, \"slope\": 0.19910287857055664, \"chain\": 0, \"draw\": 159}, {\"mouse\": 7, \"draws\": 160, \"mu_intercept_per_group\": 16.846460342407227, \"sigma_intercept_per_group\": 0.013495417311787605, \"sigma_obs\": 0.003589608706533909, \"slope\": 0.18908926844596863, \"chain\": 1, \"draw\": 0}, {\"mouse\": 7, \"draws\": 161, \"mu_intercept_per_group\": 18.349695205688477, \"sigma_intercept_per_group\": 0.012619039043784142, \"sigma_obs\": 0.003594008507207036, \"slope\": 0.18995319306850433, \"chain\": 1, \"draw\": 1}, {\"mouse\": 7, \"draws\": 162, \"mu_intercept_per_group\": 19.47640037536621, \"sigma_intercept_per_group\": 0.0118672214448452, \"sigma_obs\": 0.0035959063097834587, \"slope\": 0.1807488352060318, \"chain\": 1, \"draw\": 2}, {\"mouse\": 7, \"draws\": 163, \"mu_intercept_per_group\": 17.065519332885742, \"sigma_intercept_per_group\": 0.013119803741574287, \"sigma_obs\": 0.00359418336302042, \"slope\": 0.18733204901218414, \"chain\": 1, \"draw\": 3}, {\"mouse\": 7, \"draws\": 164, \"mu_intercept_per_group\": 16.75712776184082, \"sigma_intercept_per_group\": 0.014109361916780472, \"sigma_obs\": 0.003596561262384057, \"slope\": 0.18163777887821198, \"chain\": 1, \"draw\": 4}, {\"mouse\": 7, \"draws\": 165, \"mu_intercept_per_group\": 14.039481163024902, \"sigma_intercept_per_group\": 0.017380790784955025, \"sigma_obs\": 0.003609709907323122, \"slope\": 0.17965982854366302, \"chain\": 1, \"draw\": 5}, {\"mouse\": 7, \"draws\": 166, \"mu_intercept_per_group\": 22.547077178955078, \"sigma_intercept_per_group\": 0.010208469815552235, \"sigma_obs\": 0.003606318961828947, \"slope\": 0.1962626725435257, \"chain\": 1, \"draw\": 6}, {\"mouse\": 7, \"draws\": 167, \"mu_intercept_per_group\": 14.686722755432129, \"sigma_intercept_per_group\": 0.015670686960220337, \"sigma_obs\": 0.0035895504988729954, \"slope\": 0.19473962485790253, \"chain\": 1, \"draw\": 7}, {\"mouse\": 7, \"draws\": 168, \"mu_intercept_per_group\": 16.801464080810547, \"sigma_intercept_per_group\": 0.01341672707349062, \"sigma_obs\": 0.0035578361712396145, \"slope\": 0.18766678869724274, \"chain\": 1, \"draw\": 8}, {\"mouse\": 7, \"draws\": 169, \"mu_intercept_per_group\": 16.774049758911133, \"sigma_intercept_per_group\": 0.013445630669593811, \"sigma_obs\": 0.003622053423896432, \"slope\": 0.19293776154518127, \"chain\": 1, \"draw\": 9}, {\"mouse\": 7, \"draws\": 170, \"mu_intercept_per_group\": 18.21277618408203, \"sigma_intercept_per_group\": 0.012896601110696793, \"sigma_obs\": 0.0036201057955622673, \"slope\": 0.19370216131210327, \"chain\": 1, \"draw\": 10}, {\"mouse\": 7, \"draws\": 171, \"mu_intercept_per_group\": 17.137020111083984, \"sigma_intercept_per_group\": 0.013679221272468567, \"sigma_obs\": 0.003596062306314707, \"slope\": 0.18726268410682678, \"chain\": 1, \"draw\": 11}, {\"mouse\": 7, \"draws\": 172, \"mu_intercept_per_group\": 17.786558151245117, \"sigma_intercept_per_group\": 0.013358348049223423, \"sigma_obs\": 0.0035915158223360777, \"slope\": 0.18942581117153168, \"chain\": 1, \"draw\": 12}, {\"mouse\": 7, \"draws\": 173, \"mu_intercept_per_group\": 17.626907348632812, \"sigma_intercept_per_group\": 0.012442108243703842, \"sigma_obs\": 0.003594817593693733, \"slope\": 0.18798042833805084, \"chain\": 1, \"draw\": 13}, {\"mouse\": 7, \"draws\": 174, \"mu_intercept_per_group\": 17.509769439697266, \"sigma_intercept_per_group\": 0.013089371845126152, \"sigma_obs\": 0.0036140105221420527, \"slope\": 0.18748636543750763, \"chain\": 1, \"draw\": 14}, {\"mouse\": 7, \"draws\": 175, \"mu_intercept_per_group\": 18.067750930786133, \"sigma_intercept_per_group\": 0.012959800660610199, \"sigma_obs\": 0.0036023419816046953, \"slope\": 0.18768419325351715, \"chain\": 1, \"draw\": 15}, {\"mouse\": 7, \"draws\": 176, \"mu_intercept_per_group\": 18.299070358276367, \"sigma_intercept_per_group\": 0.012820516712963581, \"sigma_obs\": 0.003618386806920171, \"slope\": 0.1876378357410431, \"chain\": 1, \"draw\": 16}, {\"mouse\": 7, \"draws\": 177, \"mu_intercept_per_group\": 19.217119216918945, \"sigma_intercept_per_group\": 0.012195006012916565, \"sigma_obs\": 0.003621371230110526, \"slope\": 0.1883387565612793, \"chain\": 1, \"draw\": 17}, {\"mouse\": 7, \"draws\": 178, \"mu_intercept_per_group\": 17.755247116088867, \"sigma_intercept_per_group\": 0.012546762824058533, \"sigma_obs\": 0.0035969214513897896, \"slope\": 0.18624675273895264, \"chain\": 1, \"draw\": 18}, {\"mouse\": 7, \"draws\": 179, \"mu_intercept_per_group\": 8.556084632873535, \"sigma_intercept_per_group\": 0.026014603674411774, \"sigma_obs\": 0.0035820750053972006, \"slope\": 0.1878061592578888, \"chain\": 1, \"draw\": 19}, {\"mouse\": 7, \"draws\": 180, \"mu_intercept_per_group\": 8.208080291748047, \"sigma_intercept_per_group\": 0.029914526268839836, \"sigma_obs\": 0.0035979077219963074, \"slope\": 0.18526124954223633, \"chain\": 1, \"draw\": 20}, {\"mouse\": 7, \"draws\": 181, \"mu_intercept_per_group\": 8.31843090057373, \"sigma_intercept_per_group\": 0.028429558500647545, \"sigma_obs\": 0.0036267403047531843, \"slope\": 0.1947786659002304, \"chain\": 1, \"draw\": 21}, {\"mouse\": 7, \"draws\": 182, \"mu_intercept_per_group\": 10.522472381591797, \"sigma_intercept_per_group\": 0.02276754565536976, \"sigma_obs\": 0.0036156289279460907, \"slope\": 0.17865560948848724, \"chain\": 1, \"draw\": 22}, {\"mouse\": 7, \"draws\": 183, \"mu_intercept_per_group\": 10.476648330688477, \"sigma_intercept_per_group\": 0.022805124521255493, \"sigma_obs\": 0.0036104293540120125, \"slope\": 0.17775920033454895, \"chain\": 1, \"draw\": 23}, {\"mouse\": 7, \"draws\": 184, \"mu_intercept_per_group\": 9.22039794921875, \"sigma_intercept_per_group\": 0.024595346301794052, \"sigma_obs\": 0.0036187232472002506, \"slope\": 0.19827143847942352, \"chain\": 1, \"draw\": 24}, {\"mouse\": 7, \"draws\": 185, \"mu_intercept_per_group\": 9.400035858154297, \"sigma_intercept_per_group\": 0.024366147816181183, \"sigma_obs\": 0.003622768446803093, \"slope\": 0.19788309931755066, \"chain\": 1, \"draw\": 25}, {\"mouse\": 7, \"draws\": 186, \"mu_intercept_per_group\": 9.675834655761719, \"sigma_intercept_per_group\": 0.023641228675842285, \"sigma_obs\": 0.0036225421354174614, \"slope\": 0.1981201469898224, \"chain\": 1, \"draw\": 26}, {\"mouse\": 7, \"draws\": 187, \"mu_intercept_per_group\": 9.214376449584961, \"sigma_intercept_per_group\": 0.02503485046327114, \"sigma_obs\": 0.003618495538830757, \"slope\": 0.20093238353729248, \"chain\": 1, \"draw\": 27}, {\"mouse\": 7, \"draws\": 188, \"mu_intercept_per_group\": 9.036466598510742, \"sigma_intercept_per_group\": 0.024745173752307892, \"sigma_obs\": 0.0036201539915055037, \"slope\": 0.20115984976291656, \"chain\": 1, \"draw\": 28}, {\"mouse\": 7, \"draws\": 189, \"mu_intercept_per_group\": 9.208574295043945, \"sigma_intercept_per_group\": 0.025150978937745094, \"sigma_obs\": 0.0036270569544285536, \"slope\": 0.19992287456989288, \"chain\": 1, \"draw\": 29}, {\"mouse\": 7, \"draws\": 190, \"mu_intercept_per_group\": 13.298826217651367, \"sigma_intercept_per_group\": 0.017743544653058052, \"sigma_obs\": 0.0035906066186726093, \"slope\": 0.1831652820110321, \"chain\": 1, \"draw\": 30}, {\"mouse\": 7, \"draws\": 191, \"mu_intercept_per_group\": 15.42348861694336, \"sigma_intercept_per_group\": 0.01609397679567337, \"sigma_obs\": 0.0036148170474916697, \"slope\": 0.1832631677389145, \"chain\": 1, \"draw\": 31}, {\"mouse\": 7, \"draws\": 192, \"mu_intercept_per_group\": 13.83507251739502, \"sigma_intercept_per_group\": 0.01751936599612236, \"sigma_obs\": 0.0036051583010703325, \"slope\": 0.1805906891822815, \"chain\": 1, \"draw\": 32}, {\"mouse\": 7, \"draws\": 193, \"mu_intercept_per_group\": 8.707788467407227, \"sigma_intercept_per_group\": 0.026040442287921906, \"sigma_obs\": 0.003605057019740343, \"slope\": 0.19773779809474945, \"chain\": 1, \"draw\": 33}, {\"mouse\": 7, \"draws\": 194, \"mu_intercept_per_group\": 9.251585006713867, \"sigma_intercept_per_group\": 0.024396298453211784, \"sigma_obs\": 0.0035950574092566967, \"slope\": 0.19388923048973083, \"chain\": 1, \"draw\": 34}, {\"mouse\": 7, \"draws\": 195, \"mu_intercept_per_group\": 9.052249908447266, \"sigma_intercept_per_group\": 0.02593887224793434, \"sigma_obs\": 0.0036277053877711296, \"slope\": 0.19406428933143616, \"chain\": 1, \"draw\": 35}, {\"mouse\": 7, \"draws\": 196, \"mu_intercept_per_group\": 9.82917594909668, \"sigma_intercept_per_group\": 0.023239200934767723, \"sigma_obs\": 0.003588766558095813, \"slope\": 0.19684767723083496, \"chain\": 1, \"draw\": 36}, {\"mouse\": 7, \"draws\": 197, \"mu_intercept_per_group\": 9.725754737854004, \"sigma_intercept_per_group\": 0.023446956649422646, \"sigma_obs\": 0.0035895383916795254, \"slope\": 0.19711072742938995, \"chain\": 1, \"draw\": 37}, {\"mouse\": 7, \"draws\": 198, \"mu_intercept_per_group\": 8.806682586669922, \"sigma_intercept_per_group\": 0.02571992389857769, \"sigma_obs\": 0.0035903037060052156, \"slope\": 0.1917983591556549, \"chain\": 1, \"draw\": 38}, {\"mouse\": 7, \"draws\": 199, \"mu_intercept_per_group\": 11.270689964294434, \"sigma_intercept_per_group\": 0.021065320819616318, \"sigma_obs\": 0.0036105550825595856, \"slope\": 0.19888320565223694, \"chain\": 1, \"draw\": 39}, {\"mouse\": 7, \"draws\": 200, \"mu_intercept_per_group\": 10.202579498291016, \"sigma_intercept_per_group\": 0.021812155842781067, \"sigma_obs\": 0.003534796182066202, \"slope\": 0.18865570425987244, \"chain\": 1, \"draw\": 40}, {\"mouse\": 7, \"draws\": 201, \"mu_intercept_per_group\": 9.697301864624023, \"sigma_intercept_per_group\": 0.022939100861549377, \"sigma_obs\": 0.0035685827024281025, \"slope\": 0.19580507278442383, \"chain\": 1, \"draw\": 41}, {\"mouse\": 7, \"draws\": 202, \"mu_intercept_per_group\": 9.532554626464844, \"sigma_intercept_per_group\": 0.024542398750782013, \"sigma_obs\": 0.0035657931584864855, \"slope\": 0.19124570488929749, \"chain\": 1, \"draw\": 42}, {\"mouse\": 7, \"draws\": 203, \"mu_intercept_per_group\": 9.436655044555664, \"sigma_intercept_per_group\": 0.02482583001255989, \"sigma_obs\": 0.0035873721353709698, \"slope\": 0.1852446347475052, \"chain\": 1, \"draw\": 43}, {\"mouse\": 7, \"draws\": 204, \"mu_intercept_per_group\": 9.737995147705078, \"sigma_intercept_per_group\": 0.02359456941485405, \"sigma_obs\": 0.003601720090955496, \"slope\": 0.17935235798358917, \"chain\": 1, \"draw\": 44}, {\"mouse\": 7, \"draws\": 205, \"mu_intercept_per_group\": 9.288839340209961, \"sigma_intercept_per_group\": 0.024154048413038254, \"sigma_obs\": 0.003590598003938794, \"slope\": 0.18412484228610992, \"chain\": 1, \"draw\": 45}, {\"mouse\": 7, \"draws\": 206, \"mu_intercept_per_group\": 10.736775398254395, \"sigma_intercept_per_group\": 0.02027273364365101, \"sigma_obs\": 0.0035661638248711824, \"slope\": 0.18776820600032806, \"chain\": 1, \"draw\": 46}, {\"mouse\": 7, \"draws\": 207, \"mu_intercept_per_group\": 9.34485149383545, \"sigma_intercept_per_group\": 0.0227791927754879, \"sigma_obs\": 0.0035689249634742737, \"slope\": 0.20392516255378723, \"chain\": 1, \"draw\": 47}, {\"mouse\": 7, \"draws\": 208, \"mu_intercept_per_group\": 9.227876663208008, \"sigma_intercept_per_group\": 0.023536868393421173, \"sigma_obs\": 0.0035714649129658937, \"slope\": 0.20256774127483368, \"chain\": 1, \"draw\": 48}, {\"mouse\": 7, \"draws\": 209, \"mu_intercept_per_group\": 9.469313621520996, \"sigma_intercept_per_group\": 0.022969277575612068, \"sigma_obs\": 0.003574923612177372, \"slope\": 0.19704094529151917, \"chain\": 1, \"draw\": 49}, {\"mouse\": 7, \"draws\": 210, \"mu_intercept_per_group\": 9.402536392211914, \"sigma_intercept_per_group\": 0.02344094216823578, \"sigma_obs\": 0.0035892303567379713, \"slope\": 0.19389726221561432, \"chain\": 1, \"draw\": 50}, {\"mouse\": 7, \"draws\": 211, \"mu_intercept_per_group\": 9.817926406860352, \"sigma_intercept_per_group\": 0.02346104383468628, \"sigma_obs\": 0.0035845558159053326, \"slope\": 0.19332727789878845, \"chain\": 1, \"draw\": 51}, {\"mouse\": 7, \"draws\": 212, \"mu_intercept_per_group\": 8.816874504089355, \"sigma_intercept_per_group\": 0.023716550320386887, \"sigma_obs\": 0.003569576656445861, \"slope\": 0.19242306053638458, \"chain\": 1, \"draw\": 52}, {\"mouse\": 7, \"draws\": 213, \"mu_intercept_per_group\": 7.913830757141113, \"sigma_intercept_per_group\": 0.029578518122434616, \"sigma_obs\": 0.003639192320406437, \"slope\": 0.1822797656059265, \"chain\": 1, \"draw\": 53}, {\"mouse\": 7, \"draws\": 214, \"mu_intercept_per_group\": 7.687036514282227, \"sigma_intercept_per_group\": 0.03090851940214634, \"sigma_obs\": 0.003630005056038499, \"slope\": 0.18383662402629852, \"chain\": 1, \"draw\": 54}, {\"mouse\": 7, \"draws\": 215, \"mu_intercept_per_group\": 5.940617084503174, \"sigma_intercept_per_group\": 0.03607262298464775, \"sigma_obs\": 0.0035685182083398104, \"slope\": 0.19432085752487183, \"chain\": 1, \"draw\": 55}, {\"mouse\": 7, \"draws\": 216, \"mu_intercept_per_group\": 6.010695934295654, \"sigma_intercept_per_group\": 0.03672478348016739, \"sigma_obs\": 0.003565546590834856, \"slope\": 0.19427570700645447, \"chain\": 1, \"draw\": 56}, {\"mouse\": 7, \"draws\": 217, \"mu_intercept_per_group\": 7.686226844787598, \"sigma_intercept_per_group\": 0.029585804790258408, \"sigma_obs\": 0.003605698235332966, \"slope\": 0.19221048057079315, \"chain\": 1, \"draw\": 57}, {\"mouse\": 7, \"draws\": 218, \"mu_intercept_per_group\": 7.617751121520996, \"sigma_intercept_per_group\": 0.03191618248820305, \"sigma_obs\": 0.0036128354258835316, \"slope\": 0.18039274215698242, \"chain\": 1, \"draw\": 58}, {\"mouse\": 7, \"draws\": 219, \"mu_intercept_per_group\": 6.943645477294922, \"sigma_intercept_per_group\": 0.032433122396469116, \"sigma_obs\": 0.003592106746509671, \"slope\": 0.18289141356945038, \"chain\": 1, \"draw\": 59}, {\"mouse\": 7, \"draws\": 220, \"mu_intercept_per_group\": 8.945474624633789, \"sigma_intercept_per_group\": 0.02684042789041996, \"sigma_obs\": 0.0036348532885313034, \"slope\": 0.18951909244060516, \"chain\": 1, \"draw\": 60}, {\"mouse\": 7, \"draws\": 221, \"mu_intercept_per_group\": 7.830075263977051, \"sigma_intercept_per_group\": 0.029330702498555183, \"sigma_obs\": 0.00359390233643353, \"slope\": 0.18679074943065643, \"chain\": 1, \"draw\": 61}, {\"mouse\": 7, \"draws\": 222, \"mu_intercept_per_group\": 8.398107528686523, \"sigma_intercept_per_group\": 0.027316970750689507, \"sigma_obs\": 0.003593379631638527, \"slope\": 0.18911536037921906, \"chain\": 1, \"draw\": 62}, {\"mouse\": 7, \"draws\": 223, \"mu_intercept_per_group\": 7.702796459197998, \"sigma_intercept_per_group\": 0.029026862233877182, \"sigma_obs\": 0.003603884717449546, \"slope\": 0.1938406378030777, \"chain\": 1, \"draw\": 63}, {\"mouse\": 7, \"draws\": 224, \"mu_intercept_per_group\": 7.623422145843506, \"sigma_intercept_per_group\": 0.029687589034438133, \"sigma_obs\": 0.0036055915988981724, \"slope\": 0.18622185289859772, \"chain\": 1, \"draw\": 64}, {\"mouse\": 7, \"draws\": 225, \"mu_intercept_per_group\": 8.159574508666992, \"sigma_intercept_per_group\": 0.02875732071697712, \"sigma_obs\": 0.0036067126784473658, \"slope\": 0.18564903736114502, \"chain\": 1, \"draw\": 65}, {\"mouse\": 7, \"draws\": 226, \"mu_intercept_per_group\": 7.408087253570557, \"sigma_intercept_per_group\": 0.029793482273817062, \"sigma_obs\": 0.0036006125155836344, \"slope\": 0.18687556684017181, \"chain\": 1, \"draw\": 66}, {\"mouse\": 7, \"draws\": 227, \"mu_intercept_per_group\": 8.166772842407227, \"sigma_intercept_per_group\": 0.028114119544625282, \"sigma_obs\": 0.003567835781723261, \"slope\": 0.1858779639005661, \"chain\": 1, \"draw\": 67}, {\"mouse\": 7, \"draws\": 228, \"mu_intercept_per_group\": 6.511370658874512, \"sigma_intercept_per_group\": 0.03375045210123062, \"sigma_obs\": 0.003557597054168582, \"slope\": 0.1933600753545761, \"chain\": 1, \"draw\": 68}, {\"mouse\": 7, \"draws\": 229, \"mu_intercept_per_group\": 6.518929958343506, \"sigma_intercept_per_group\": 0.034101735800504684, \"sigma_obs\": 0.0035579651594161987, \"slope\": 0.19352079927921295, \"chain\": 1, \"draw\": 69}, {\"mouse\": 7, \"draws\": 230, \"mu_intercept_per_group\": 6.797684669494629, \"sigma_intercept_per_group\": 0.033420637249946594, \"sigma_obs\": 0.003583902958780527, \"slope\": 0.19176246225833893, \"chain\": 1, \"draw\": 70}, {\"mouse\": 7, \"draws\": 231, \"mu_intercept_per_group\": 7.244635105133057, \"sigma_intercept_per_group\": 0.032293032854795456, \"sigma_obs\": 0.0035975079517811537, \"slope\": 0.19148151576519012, \"chain\": 1, \"draw\": 71}, {\"mouse\": 7, \"draws\": 232, \"mu_intercept_per_group\": 8.963022232055664, \"sigma_intercept_per_group\": 0.02748400717973709, \"sigma_obs\": 0.003638772526755929, \"slope\": 0.17643311619758606, \"chain\": 1, \"draw\": 72}, {\"mouse\": 7, \"draws\": 233, \"mu_intercept_per_group\": 9.203293800354004, \"sigma_intercept_per_group\": 0.025866424664855003, \"sigma_obs\": 0.003633506828919053, \"slope\": 0.1793624609708786, \"chain\": 1, \"draw\": 73}, {\"mouse\": 7, \"draws\": 234, \"mu_intercept_per_group\": 9.164643287658691, \"sigma_intercept_per_group\": 0.02605549618601799, \"sigma_obs\": 0.0036414472851902246, \"slope\": 0.17716525495052338, \"chain\": 1, \"draw\": 74}, {\"mouse\": 7, \"draws\": 235, \"mu_intercept_per_group\": 8.455629348754883, \"sigma_intercept_per_group\": 0.02808169648051262, \"sigma_obs\": 0.003629496321082115, \"slope\": 0.19044409692287445, \"chain\": 1, \"draw\": 75}, {\"mouse\": 7, \"draws\": 236, \"mu_intercept_per_group\": 6.460043430328369, \"sigma_intercept_per_group\": 0.035298705101013184, \"sigma_obs\": 0.0036093019880354404, \"slope\": 0.18283437192440033, \"chain\": 1, \"draw\": 76}, {\"mouse\": 7, \"draws\": 237, \"mu_intercept_per_group\": 7.253722190856934, \"sigma_intercept_per_group\": 0.03267180919647217, \"sigma_obs\": 0.0035989596508443356, \"slope\": 0.1895958036184311, \"chain\": 1, \"draw\": 77}, {\"mouse\": 7, \"draws\": 238, \"mu_intercept_per_group\": 6.924093246459961, \"sigma_intercept_per_group\": 0.032623305916786194, \"sigma_obs\": 0.0035962029360234737, \"slope\": 0.1889989674091339, \"chain\": 1, \"draw\": 78}, {\"mouse\": 7, \"draws\": 239, \"mu_intercept_per_group\": 6.812102317810059, \"sigma_intercept_per_group\": 0.03259528800845146, \"sigma_obs\": 0.0035994264762848616, \"slope\": 0.18922264873981476, \"chain\": 1, \"draw\": 79}, {\"mouse\": 7, \"draws\": 240, \"mu_intercept_per_group\": 6.81666898727417, \"sigma_intercept_per_group\": 0.032995112240314484, \"sigma_obs\": 0.00359840365126729, \"slope\": 0.18915697932243347, \"chain\": 1, \"draw\": 80}, {\"mouse\": 7, \"draws\": 241, \"mu_intercept_per_group\": 6.717197895050049, \"sigma_intercept_per_group\": 0.032946981489658356, \"sigma_obs\": 0.0035581805277615786, \"slope\": 0.19108045101165771, \"chain\": 1, \"draw\": 81}, {\"mouse\": 7, \"draws\": 242, \"mu_intercept_per_group\": 8.326837539672852, \"sigma_intercept_per_group\": 0.028711700811982155, \"sigma_obs\": 0.003599848598241806, \"slope\": 0.1806209832429886, \"chain\": 1, \"draw\": 82}, {\"mouse\": 7, \"draws\": 243, \"mu_intercept_per_group\": 8.827495574951172, \"sigma_intercept_per_group\": 0.026371821761131287, \"sigma_obs\": 0.003613438457250595, \"slope\": 0.19455702602863312, \"chain\": 1, \"draw\": 83}, {\"mouse\": 7, \"draws\": 244, \"mu_intercept_per_group\": 9.544142723083496, \"sigma_intercept_per_group\": 0.02323714643716812, \"sigma_obs\": 0.0035884943790733814, \"slope\": 0.19359053671360016, \"chain\": 1, \"draw\": 84}, {\"mouse\": 7, \"draws\": 245, \"mu_intercept_per_group\": 9.923998832702637, \"sigma_intercept_per_group\": 0.023144759237766266, \"sigma_obs\": 0.003566638333722949, \"slope\": 0.1879860907793045, \"chain\": 1, \"draw\": 85}, {\"mouse\": 7, \"draws\": 246, \"mu_intercept_per_group\": 10.47934627532959, \"sigma_intercept_per_group\": 0.023437757045030594, \"sigma_obs\": 0.0036005901638418436, \"slope\": 0.18582606315612793, \"chain\": 1, \"draw\": 86}, {\"mouse\": 7, \"draws\": 247, \"mu_intercept_per_group\": 8.906576156616211, \"sigma_intercept_per_group\": 0.024363422766327858, \"sigma_obs\": 0.003600411582738161, \"slope\": 0.18181510269641876, \"chain\": 1, \"draw\": 87}, {\"mouse\": 7, \"draws\": 248, \"mu_intercept_per_group\": 10.105539321899414, \"sigma_intercept_per_group\": 0.024317067116498947, \"sigma_obs\": 0.003591156331822276, \"slope\": 0.18364179134368896, \"chain\": 1, \"draw\": 88}, {\"mouse\": 7, \"draws\": 249, \"mu_intercept_per_group\": 6.374002933502197, \"sigma_intercept_per_group\": 0.03454233705997467, \"sigma_obs\": 0.0036078807897865772, \"slope\": 0.1902647465467453, \"chain\": 1, \"draw\": 89}, {\"mouse\": 7, \"draws\": 250, \"mu_intercept_per_group\": 6.927292346954346, \"sigma_intercept_per_group\": 0.031234029680490494, \"sigma_obs\": 0.0035665277391672134, \"slope\": 0.18990600109100342, \"chain\": 1, \"draw\": 90}, {\"mouse\": 7, \"draws\": 251, \"mu_intercept_per_group\": 7.512913703918457, \"sigma_intercept_per_group\": 0.029962357133626938, \"sigma_obs\": 0.0035730984527617693, \"slope\": 0.19321487843990326, \"chain\": 1, \"draw\": 91}, {\"mouse\": 7, \"draws\": 252, \"mu_intercept_per_group\": 7.590645790100098, \"sigma_intercept_per_group\": 0.029448455199599266, \"sigma_obs\": 0.0035748486407101154, \"slope\": 0.19174104928970337, \"chain\": 1, \"draw\": 92}, {\"mouse\": 7, \"draws\": 253, \"mu_intercept_per_group\": 7.832711696624756, \"sigma_intercept_per_group\": 0.028688976541161537, \"sigma_obs\": 0.0035747343208640814, \"slope\": 0.1911826729774475, \"chain\": 1, \"draw\": 93}, {\"mouse\": 7, \"draws\": 254, \"mu_intercept_per_group\": 8.02859115600586, \"sigma_intercept_per_group\": 0.02761010080575943, \"sigma_obs\": 0.0035826421808451414, \"slope\": 0.18689493834972382, \"chain\": 1, \"draw\": 94}, {\"mouse\": 7, \"draws\": 255, \"mu_intercept_per_group\": 9.093605995178223, \"sigma_intercept_per_group\": 0.02630421705543995, \"sigma_obs\": 0.0035863870289176702, \"slope\": 0.18805865943431854, \"chain\": 1, \"draw\": 95}, {\"mouse\": 7, \"draws\": 256, \"mu_intercept_per_group\": 9.966830253601074, \"sigma_intercept_per_group\": 0.022694528102874756, \"sigma_obs\": 0.003579413052648306, \"slope\": 0.18086297810077667, \"chain\": 1, \"draw\": 96}, {\"mouse\": 7, \"draws\": 257, \"mu_intercept_per_group\": 10.196884155273438, \"sigma_intercept_per_group\": 0.022501207888126373, \"sigma_obs\": 0.003576268907636404, \"slope\": 0.18334351480007172, \"chain\": 1, \"draw\": 97}, {\"mouse\": 7, \"draws\": 258, \"mu_intercept_per_group\": 10.178518295288086, \"sigma_intercept_per_group\": 0.023381955921649933, \"sigma_obs\": 0.003622583579272032, \"slope\": 0.1869308054447174, \"chain\": 1, \"draw\": 98}, {\"mouse\": 7, \"draws\": 259, \"mu_intercept_per_group\": 9.909396171569824, \"sigma_intercept_per_group\": 0.0238795205950737, \"sigma_obs\": 0.0036210569087415934, \"slope\": 0.18659576773643494, \"chain\": 1, \"draw\": 99}, {\"mouse\": 7, \"draws\": 260, \"mu_intercept_per_group\": 9.83348560333252, \"sigma_intercept_per_group\": 0.02352846972644329, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.18421776592731476, \"chain\": 1, \"draw\": 100}, {\"mouse\": 7, \"draws\": 261, \"mu_intercept_per_group\": 8.311078071594238, \"sigma_intercept_per_group\": 0.028682518750429153, \"sigma_obs\": 0.003624812699854374, \"slope\": 0.19165822863578796, \"chain\": 1, \"draw\": 101}, {\"mouse\": 7, \"draws\": 262, \"mu_intercept_per_group\": 8.138319969177246, \"sigma_intercept_per_group\": 0.029197175055742264, \"sigma_obs\": 0.0036074162926524878, \"slope\": 0.18239012360572815, \"chain\": 1, \"draw\": 102}, {\"mouse\": 7, \"draws\": 263, \"mu_intercept_per_group\": 8.105721473693848, \"sigma_intercept_per_group\": 0.028144795447587967, \"sigma_obs\": 0.0035675603430718184, \"slope\": 0.18346956372261047, \"chain\": 1, \"draw\": 103}, {\"mouse\": 7, \"draws\": 264, \"mu_intercept_per_group\": 7.768963813781738, \"sigma_intercept_per_group\": 0.029011620208621025, \"sigma_obs\": 0.0035687971394509077, \"slope\": 0.18135108053684235, \"chain\": 1, \"draw\": 104}, {\"mouse\": 7, \"draws\": 265, \"mu_intercept_per_group\": 8.123887062072754, \"sigma_intercept_per_group\": 0.028008993715047836, \"sigma_obs\": 0.0035874200984835625, \"slope\": 0.1957925707101822, \"chain\": 1, \"draw\": 105}, {\"mouse\": 7, \"draws\": 266, \"mu_intercept_per_group\": 6.734941005706787, \"sigma_intercept_per_group\": 0.03595634549856186, \"sigma_obs\": 0.003601265139877796, \"slope\": 0.18532100319862366, \"chain\": 1, \"draw\": 106}, {\"mouse\": 7, \"draws\": 267, \"mu_intercept_per_group\": 5.612227439880371, \"sigma_intercept_per_group\": 0.03959035128355026, \"sigma_obs\": 0.003598781069740653, \"slope\": 0.18565046787261963, \"chain\": 1, \"draw\": 107}, {\"mouse\": 7, \"draws\": 268, \"mu_intercept_per_group\": 6.318391799926758, \"sigma_intercept_per_group\": 0.03865744173526764, \"sigma_obs\": 0.0035932220052927732, \"slope\": 0.18693575263023376, \"chain\": 1, \"draw\": 108}, {\"mouse\": 7, \"draws\": 269, \"mu_intercept_per_group\": 19.546354293823242, \"sigma_intercept_per_group\": 0.012422486208379269, \"sigma_obs\": 0.0036293058656156063, \"slope\": 0.1844932734966278, \"chain\": 1, \"draw\": 109}, {\"mouse\": 7, \"draws\": 270, \"mu_intercept_per_group\": 16.8531436920166, \"sigma_intercept_per_group\": 0.014126663096249104, \"sigma_obs\": 0.003637847723439336, \"slope\": 0.18316125869750977, \"chain\": 1, \"draw\": 110}, {\"mouse\": 7, \"draws\": 271, \"mu_intercept_per_group\": 15.997653007507324, \"sigma_intercept_per_group\": 0.014797269366681576, \"sigma_obs\": 0.0036301903892308474, \"slope\": 0.1819605827331543, \"chain\": 1, \"draw\": 111}, {\"mouse\": 7, \"draws\": 272, \"mu_intercept_per_group\": 12.138011932373047, \"sigma_intercept_per_group\": 0.018830733373761177, \"sigma_obs\": 0.003586633363738656, \"slope\": 0.18569451570510864, \"chain\": 1, \"draw\": 112}, {\"mouse\": 7, \"draws\": 273, \"mu_intercept_per_group\": 13.087748527526855, \"sigma_intercept_per_group\": 0.017615539953112602, \"sigma_obs\": 0.003597940318286419, \"slope\": 0.18887081742286682, \"chain\": 1, \"draw\": 113}, {\"mouse\": 7, \"draws\": 274, \"mu_intercept_per_group\": 16.428693771362305, \"sigma_intercept_per_group\": 0.014478337951004505, \"sigma_obs\": 0.003621645737439394, \"slope\": 0.1782492846250534, \"chain\": 1, \"draw\": 114}, {\"mouse\": 7, \"draws\": 275, \"mu_intercept_per_group\": 14.098936080932617, \"sigma_intercept_per_group\": 0.015826409682631493, \"sigma_obs\": 0.003603924298658967, \"slope\": 0.19035987555980682, \"chain\": 1, \"draw\": 115}, {\"mouse\": 7, \"draws\": 276, \"mu_intercept_per_group\": 15.820218086242676, \"sigma_intercept_per_group\": 0.015503759495913982, \"sigma_obs\": 0.0036246415693312883, \"slope\": 0.18436670303344727, \"chain\": 1, \"draw\": 116}, {\"mouse\": 7, \"draws\": 277, \"mu_intercept_per_group\": 13.744246482849121, \"sigma_intercept_per_group\": 0.016271788626909256, \"sigma_obs\": 0.0035994057543575764, \"slope\": 0.18883921205997467, \"chain\": 1, \"draw\": 117}, {\"mouse\": 7, \"draws\": 278, \"mu_intercept_per_group\": 13.664725303649902, \"sigma_intercept_per_group\": 0.017538465559482574, \"sigma_obs\": 0.003625785931944847, \"slope\": 0.18826287984848022, \"chain\": 1, \"draw\": 118}, {\"mouse\": 7, \"draws\": 279, \"mu_intercept_per_group\": 14.161970138549805, \"sigma_intercept_per_group\": 0.01680116541683674, \"sigma_obs\": 0.0036094982642680407, \"slope\": 0.1834767907857895, \"chain\": 1, \"draw\": 119}, {\"mouse\": 7, \"draws\": 280, \"mu_intercept_per_group\": 11.34384822845459, \"sigma_intercept_per_group\": 0.02022159844636917, \"sigma_obs\": 0.003597456496208906, \"slope\": 0.19560086727142334, \"chain\": 1, \"draw\": 120}, {\"mouse\": 7, \"draws\": 281, \"mu_intercept_per_group\": 14.073280334472656, \"sigma_intercept_per_group\": 0.015948720276355743, \"sigma_obs\": 0.003592514432966709, \"slope\": 0.18437497317790985, \"chain\": 1, \"draw\": 121}, {\"mouse\": 7, \"draws\": 282, \"mu_intercept_per_group\": 14.033628463745117, \"sigma_intercept_per_group\": 0.016516467556357384, \"sigma_obs\": 0.0035825890954583883, \"slope\": 0.18570800125598907, \"chain\": 1, \"draw\": 122}, {\"mouse\": 7, \"draws\": 283, \"mu_intercept_per_group\": 13.442943572998047, \"sigma_intercept_per_group\": 0.01675274968147278, \"sigma_obs\": 0.0035853167064487934, \"slope\": 0.1905423104763031, \"chain\": 1, \"draw\": 123}, {\"mouse\": 7, \"draws\": 284, \"mu_intercept_per_group\": 13.735260963439941, \"sigma_intercept_per_group\": 0.01690402440726757, \"sigma_obs\": 0.003610642859712243, \"slope\": 0.19291435182094574, \"chain\": 1, \"draw\": 124}, {\"mouse\": 7, \"draws\": 285, \"mu_intercept_per_group\": 14.390303611755371, \"sigma_intercept_per_group\": 0.01659676618874073, \"sigma_obs\": 0.003606516635045409, \"slope\": 0.18290679156780243, \"chain\": 1, \"draw\": 125}, {\"mouse\": 7, \"draws\": 286, \"mu_intercept_per_group\": 13.460063934326172, \"sigma_intercept_per_group\": 0.01688326522707939, \"sigma_obs\": 0.0035769594833254814, \"slope\": 0.1939602941274643, \"chain\": 1, \"draw\": 126}, {\"mouse\": 7, \"draws\": 287, \"mu_intercept_per_group\": 14.478861808776855, \"sigma_intercept_per_group\": 0.015069274231791496, \"sigma_obs\": 0.0035751366522163153, \"slope\": 0.1899918168783188, \"chain\": 1, \"draw\": 127}, {\"mouse\": 7, \"draws\": 288, \"mu_intercept_per_group\": 14.643204689025879, \"sigma_intercept_per_group\": 0.015985775738954544, \"sigma_obs\": 0.00357793178409338, \"slope\": 0.1889169067144394, \"chain\": 1, \"draw\": 128}, {\"mouse\": 7, \"draws\": 289, \"mu_intercept_per_group\": 14.704259872436523, \"sigma_intercept_per_group\": 0.01486921589821577, \"sigma_obs\": 0.0035876936744898558, \"slope\": 0.1916923224925995, \"chain\": 1, \"draw\": 129}, {\"mouse\": 7, \"draws\": 290, \"mu_intercept_per_group\": 14.675769805908203, \"sigma_intercept_per_group\": 0.015122504904866219, \"sigma_obs\": 0.0035950164310634136, \"slope\": 0.1879352629184723, \"chain\": 1, \"draw\": 130}, {\"mouse\": 7, \"draws\": 291, \"mu_intercept_per_group\": 13.97838020324707, \"sigma_intercept_per_group\": 0.016862137243151665, \"sigma_obs\": 0.003615741152316332, \"slope\": 0.18876725435256958, \"chain\": 1, \"draw\": 131}, {\"mouse\": 7, \"draws\": 292, \"mu_intercept_per_group\": 14.072586059570312, \"sigma_intercept_per_group\": 0.015527242794632912, \"sigma_obs\": 0.0036224161740392447, \"slope\": 0.18819333612918854, \"chain\": 1, \"draw\": 132}, {\"mouse\": 7, \"draws\": 293, \"mu_intercept_per_group\": 11.780965805053711, \"sigma_intercept_per_group\": 0.018385466188192368, \"sigma_obs\": 0.003613061038777232, \"slope\": 0.19203223288059235, \"chain\": 1, \"draw\": 133}, {\"mouse\": 7, \"draws\": 294, \"mu_intercept_per_group\": 11.392871856689453, \"sigma_intercept_per_group\": 0.019694998860359192, \"sigma_obs\": 0.003619320224970579, \"slope\": 0.1952902227640152, \"chain\": 1, \"draw\": 134}, {\"mouse\": 7, \"draws\": 295, \"mu_intercept_per_group\": 10.689013481140137, \"sigma_intercept_per_group\": 0.02246893383562565, \"sigma_obs\": 0.0036011466290801764, \"slope\": 0.17853647470474243, \"chain\": 1, \"draw\": 135}, {\"mouse\": 7, \"draws\": 296, \"mu_intercept_per_group\": 9.544307708740234, \"sigma_intercept_per_group\": 0.02337423525750637, \"sigma_obs\": 0.0035860808566212654, \"slope\": 0.18738596141338348, \"chain\": 1, \"draw\": 136}, {\"mouse\": 7, \"draws\": 297, \"mu_intercept_per_group\": 7.048957824707031, \"sigma_intercept_per_group\": 0.031577542424201965, \"sigma_obs\": 0.0035759618040174246, \"slope\": 0.1912917047739029, \"chain\": 1, \"draw\": 137}, {\"mouse\": 7, \"draws\": 298, \"mu_intercept_per_group\": 8.053902626037598, \"sigma_intercept_per_group\": 0.027299463748931885, \"sigma_obs\": 0.0035715277772396803, \"slope\": 0.19211705029010773, \"chain\": 1, \"draw\": 138}, {\"mouse\": 7, \"draws\": 299, \"mu_intercept_per_group\": 9.534790992736816, \"sigma_intercept_per_group\": 0.0246946532279253, \"sigma_obs\": 0.003592298598960042, \"slope\": 0.19111508131027222, \"chain\": 1, \"draw\": 139}, {\"mouse\": 7, \"draws\": 300, \"mu_intercept_per_group\": 9.681097030639648, \"sigma_intercept_per_group\": 0.023843474686145782, \"sigma_obs\": 0.003590808715671301, \"slope\": 0.18685384094715118, \"chain\": 1, \"draw\": 140}, {\"mouse\": 7, \"draws\": 301, \"mu_intercept_per_group\": 10.349991798400879, \"sigma_intercept_per_group\": 0.022835025563836098, \"sigma_obs\": 0.003623124212026596, \"slope\": 0.1915266215801239, \"chain\": 1, \"draw\": 141}, {\"mouse\": 7, \"draws\": 302, \"mu_intercept_per_group\": 9.835482597351074, \"sigma_intercept_per_group\": 0.0233517587184906, \"sigma_obs\": 0.003588677616789937, \"slope\": 0.18544736504554749, \"chain\": 1, \"draw\": 142}, {\"mouse\": 7, \"draws\": 303, \"mu_intercept_per_group\": 11.408327102661133, \"sigma_intercept_per_group\": 0.020919853821396828, \"sigma_obs\": 0.0035792305134236813, \"slope\": 0.17709283530712128, \"chain\": 1, \"draw\": 143}, {\"mouse\": 7, \"draws\": 304, \"mu_intercept_per_group\": 9.545672416687012, \"sigma_intercept_per_group\": 0.02434835396707058, \"sigma_obs\": 0.00363722862675786, \"slope\": 0.19385939836502075, \"chain\": 1, \"draw\": 144}, {\"mouse\": 7, \"draws\": 305, \"mu_intercept_per_group\": 8.696833610534668, \"sigma_intercept_per_group\": 0.02612742781639099, \"sigma_obs\": 0.0036273836158216, \"slope\": 0.19826561212539673, \"chain\": 1, \"draw\": 145}, {\"mouse\": 7, \"draws\": 306, \"mu_intercept_per_group\": 8.653395652770996, \"sigma_intercept_per_group\": 0.02651270478963852, \"sigma_obs\": 0.003635264001786709, \"slope\": 0.19641907513141632, \"chain\": 1, \"draw\": 146}, {\"mouse\": 7, \"draws\": 307, \"mu_intercept_per_group\": 9.718098640441895, \"sigma_intercept_per_group\": 0.023122631013393402, \"sigma_obs\": 0.0036219393368810415, \"slope\": 0.1863662600517273, \"chain\": 1, \"draw\": 147}, {\"mouse\": 7, \"draws\": 308, \"mu_intercept_per_group\": 8.718841552734375, \"sigma_intercept_per_group\": 0.02703934721648693, \"sigma_obs\": 0.003610701533034444, \"slope\": 0.1796274036169052, \"chain\": 1, \"draw\": 148}, {\"mouse\": 7, \"draws\": 309, \"mu_intercept_per_group\": 12.103772163391113, \"sigma_intercept_per_group\": 0.018360251560807228, \"sigma_obs\": 0.003606241662055254, \"slope\": 0.1920708864927292, \"chain\": 1, \"draw\": 149}, {\"mouse\": 7, \"draws\": 310, \"mu_intercept_per_group\": 11.731871604919434, \"sigma_intercept_per_group\": 0.018086250871419907, \"sigma_obs\": 0.00354804378002882, \"slope\": 0.18987154960632324, \"chain\": 1, \"draw\": 150}, {\"mouse\": 7, \"draws\": 311, \"mu_intercept_per_group\": 10.670454025268555, \"sigma_intercept_per_group\": 0.020448464900255203, \"sigma_obs\": 0.0035738737788051367, \"slope\": 0.19343441724777222, \"chain\": 1, \"draw\": 151}, {\"mouse\": 7, \"draws\": 312, \"mu_intercept_per_group\": 11.462501525878906, \"sigma_intercept_per_group\": 0.019432537257671356, \"sigma_obs\": 0.0035712826065719128, \"slope\": 0.1983719766139984, \"chain\": 1, \"draw\": 152}, {\"mouse\": 7, \"draws\": 313, \"mu_intercept_per_group\": 14.681675910949707, \"sigma_intercept_per_group\": 0.016170285642147064, \"sigma_obs\": 0.0035988325253129005, \"slope\": 0.18265153467655182, \"chain\": 1, \"draw\": 153}, {\"mouse\": 7, \"draws\": 314, \"mu_intercept_per_group\": 9.380514144897461, \"sigma_intercept_per_group\": 0.023241179063916206, \"sigma_obs\": 0.0035908976569771767, \"slope\": 0.1974664330482483, \"chain\": 1, \"draw\": 154}, {\"mouse\": 7, \"draws\": 315, \"mu_intercept_per_group\": 10.400063514709473, \"sigma_intercept_per_group\": 0.022078560665249825, \"sigma_obs\": 0.0035941097885370255, \"slope\": 0.19150948524475098, \"chain\": 1, \"draw\": 155}, {\"mouse\": 7, \"draws\": 316, \"mu_intercept_per_group\": 12.273658752441406, \"sigma_intercept_per_group\": 0.018591120839118958, \"sigma_obs\": 0.0035880599170923233, \"slope\": 0.19546255469322205, \"chain\": 1, \"draw\": 156}, {\"mouse\": 7, \"draws\": 317, \"mu_intercept_per_group\": 12.116131782531738, \"sigma_intercept_per_group\": 0.018377698957920074, \"sigma_obs\": 0.003600488882511854, \"slope\": 0.19270102679729462, \"chain\": 1, \"draw\": 157}, {\"mouse\": 7, \"draws\": 318, \"mu_intercept_per_group\": 12.536803245544434, \"sigma_intercept_per_group\": 0.018283378332853317, \"sigma_obs\": 0.003592968452721834, \"slope\": 0.1945229023694992, \"chain\": 1, \"draw\": 158}, {\"mouse\": 7, \"draws\": 319, \"mu_intercept_per_group\": 14.159012794494629, \"sigma_intercept_per_group\": 0.015730880200862885, \"sigma_obs\": 0.003599634161219001, \"slope\": 0.18652509152889252, \"chain\": 1, \"draw\": 159}, {\"mouse\": 7, \"draws\": 320, \"mu_intercept_per_group\": 4.433682441711426, \"sigma_intercept_per_group\": 0.05169814079999924, \"sigma_obs\": 0.0036158824805170298, \"slope\": 0.18915338814258575, \"chain\": 2, \"draw\": 0}, {\"mouse\": 7, \"draws\": 321, \"mu_intercept_per_group\": 4.811509609222412, \"sigma_intercept_per_group\": 0.049769822508096695, \"sigma_obs\": 0.0036063482984900475, \"slope\": 0.19161678850650787, \"chain\": 2, \"draw\": 1}, {\"mouse\": 7, \"draws\": 322, \"mu_intercept_per_group\": 5.004357814788818, \"sigma_intercept_per_group\": 0.045843519270420074, \"sigma_obs\": 0.0036014472134411335, \"slope\": 0.18982595205307007, \"chain\": 2, \"draw\": 2}, {\"mouse\": 7, \"draws\": 323, \"mu_intercept_per_group\": 4.47194242477417, \"sigma_intercept_per_group\": 0.0499105378985405, \"sigma_obs\": 0.0036154496483504772, \"slope\": 0.19725501537322998, \"chain\": 2, \"draw\": 3}, {\"mouse\": 7, \"draws\": 324, \"mu_intercept_per_group\": 7.308453559875488, \"sigma_intercept_per_group\": 0.030035903677344322, \"sigma_obs\": 0.0035830093547701836, \"slope\": 0.18112558126449585, \"chain\": 2, \"draw\": 4}, {\"mouse\": 7, \"draws\": 325, \"mu_intercept_per_group\": 8.388505935668945, \"sigma_intercept_per_group\": 0.029611118137836456, \"sigma_obs\": 0.0035871497821062803, \"slope\": 0.18133217096328735, \"chain\": 2, \"draw\": 5}, {\"mouse\": 7, \"draws\": 326, \"mu_intercept_per_group\": 7.639347553253174, \"sigma_intercept_per_group\": 0.029088201001286507, \"sigma_obs\": 0.003586034756153822, \"slope\": 0.1823234260082245, \"chain\": 2, \"draw\": 6}, {\"mouse\": 7, \"draws\": 327, \"mu_intercept_per_group\": 8.648792266845703, \"sigma_intercept_per_group\": 0.028426725417375565, \"sigma_obs\": 0.0036077103577554226, \"slope\": 0.18234524130821228, \"chain\": 2, \"draw\": 7}, {\"mouse\": 7, \"draws\": 328, \"mu_intercept_per_group\": 9.313817977905273, \"sigma_intercept_per_group\": 0.025795534253120422, \"sigma_obs\": 0.003628317965194583, \"slope\": 0.18413014709949493, \"chain\": 2, \"draw\": 8}, {\"mouse\": 7, \"draws\": 329, \"mu_intercept_per_group\": 7.86465311050415, \"sigma_intercept_per_group\": 0.02779727429151535, \"sigma_obs\": 0.003613576292991638, \"slope\": 0.196947380900383, \"chain\": 2, \"draw\": 9}, {\"mouse\": 7, \"draws\": 330, \"mu_intercept_per_group\": 9.162460327148438, \"sigma_intercept_per_group\": 0.025959070771932602, \"sigma_obs\": 0.0036247954703867435, \"slope\": 0.19487518072128296, \"chain\": 2, \"draw\": 10}, {\"mouse\": 7, \"draws\": 331, \"mu_intercept_per_group\": 8.700263977050781, \"sigma_intercept_per_group\": 0.02489308826625347, \"sigma_obs\": 0.0035841611679643393, \"slope\": 0.18754896521568298, \"chain\": 2, \"draw\": 11}, {\"mouse\": 7, \"draws\": 332, \"mu_intercept_per_group\": 9.498454093933105, \"sigma_intercept_per_group\": 0.024858737364411354, \"sigma_obs\": 0.0035841662902384996, \"slope\": 0.18888120353221893, \"chain\": 2, \"draw\": 12}, {\"mouse\": 7, \"draws\": 333, \"mu_intercept_per_group\": 9.134915351867676, \"sigma_intercept_per_group\": 0.02533101662993431, \"sigma_obs\": 0.003618312533944845, \"slope\": 0.18809255957603455, \"chain\": 2, \"draw\": 13}, {\"mouse\": 7, \"draws\": 334, \"mu_intercept_per_group\": 9.36000919342041, \"sigma_intercept_per_group\": 0.02540900744497776, \"sigma_obs\": 0.0036131953820586205, \"slope\": 0.1835336834192276, \"chain\": 2, \"draw\": 14}, {\"mouse\": 7, \"draws\": 335, \"mu_intercept_per_group\": 9.6476411819458, \"sigma_intercept_per_group\": 0.02374514564871788, \"sigma_obs\": 0.0035696702543646097, \"slope\": 0.1867826282978058, \"chain\": 2, \"draw\": 15}, {\"mouse\": 7, \"draws\": 336, \"mu_intercept_per_group\": 9.04462718963623, \"sigma_intercept_per_group\": 0.025453584268689156, \"sigma_obs\": 0.003575890325009823, \"slope\": 0.1830562949180603, \"chain\": 2, \"draw\": 16}, {\"mouse\": 7, \"draws\": 337, \"mu_intercept_per_group\": 9.78683853149414, \"sigma_intercept_per_group\": 0.023291707038879395, \"sigma_obs\": 0.00358897028490901, \"slope\": 0.1841292381286621, \"chain\": 2, \"draw\": 17}, {\"mouse\": 7, \"draws\": 338, \"mu_intercept_per_group\": 16.923458099365234, \"sigma_intercept_per_group\": 0.014171834103763103, \"sigma_obs\": 0.0035902659874409437, \"slope\": 0.18422052264213562, \"chain\": 2, \"draw\": 18}, {\"mouse\": 7, \"draws\": 339, \"mu_intercept_per_group\": 14.022960662841797, \"sigma_intercept_per_group\": 0.017112314701080322, \"sigma_obs\": 0.0035974187776446342, \"slope\": 0.19581757485866547, \"chain\": 2, \"draw\": 19}, {\"mouse\": 7, \"draws\": 340, \"mu_intercept_per_group\": 12.665775299072266, \"sigma_intercept_per_group\": 0.017232734709978104, \"sigma_obs\": 0.0035966760478913784, \"slope\": 0.19810624420642853, \"chain\": 2, \"draw\": 20}, {\"mouse\": 7, \"draws\": 341, \"mu_intercept_per_group\": 12.419373512268066, \"sigma_intercept_per_group\": 0.018659381195902824, \"sigma_obs\": 0.003580761607736349, \"slope\": 0.18905995786190033, \"chain\": 2, \"draw\": 21}, {\"mouse\": 7, \"draws\": 342, \"mu_intercept_per_group\": 11.995328903198242, \"sigma_intercept_per_group\": 0.018924027681350708, \"sigma_obs\": 0.00361212738789618, \"slope\": 0.1900034248828888, \"chain\": 2, \"draw\": 22}, {\"mouse\": 7, \"draws\": 343, \"mu_intercept_per_group\": 11.994388580322266, \"sigma_intercept_per_group\": 0.019117914140224457, \"sigma_obs\": 0.0036180433817207813, \"slope\": 0.19182652235031128, \"chain\": 2, \"draw\": 23}, {\"mouse\": 7, \"draws\": 344, \"mu_intercept_per_group\": 15.71795654296875, \"sigma_intercept_per_group\": 0.014559837989509106, \"sigma_obs\": 0.003584562800824642, \"slope\": 0.18324248492717743, \"chain\": 2, \"draw\": 24}, {\"mouse\": 7, \"draws\": 345, \"mu_intercept_per_group\": 18.86307144165039, \"sigma_intercept_per_group\": 0.011320019140839577, \"sigma_obs\": 0.0035737049765884876, \"slope\": 0.19709204137325287, \"chain\": 2, \"draw\": 25}, {\"mouse\": 7, \"draws\": 346, \"mu_intercept_per_group\": 12.670778274536133, \"sigma_intercept_per_group\": 0.01789524033665657, \"sigma_obs\": 0.0036254175938665867, \"slope\": 0.18906189501285553, \"chain\": 2, \"draw\": 26}, {\"mouse\": 7, \"draws\": 347, \"mu_intercept_per_group\": 10.841840744018555, \"sigma_intercept_per_group\": 0.021711429581046104, \"sigma_obs\": 0.003579749260097742, \"slope\": 0.18542157113552094, \"chain\": 2, \"draw\": 27}, {\"mouse\": 7, \"draws\": 348, \"mu_intercept_per_group\": 9.537745475769043, \"sigma_intercept_per_group\": 0.022590454667806625, \"sigma_obs\": 0.003567240433767438, \"slope\": 0.18971914052963257, \"chain\": 2, \"draw\": 28}, {\"mouse\": 7, \"draws\": 349, \"mu_intercept_per_group\": 10.45400333404541, \"sigma_intercept_per_group\": 0.023162534460425377, \"sigma_obs\": 0.003577657276764512, \"slope\": 0.17228156328201294, \"chain\": 2, \"draw\": 29}, {\"mouse\": 7, \"draws\": 350, \"mu_intercept_per_group\": 12.47652816772461, \"sigma_intercept_per_group\": 0.01932036317884922, \"sigma_obs\": 0.0036495928652584553, \"slope\": 0.1983005702495575, \"chain\": 2, \"draw\": 30}, {\"mouse\": 7, \"draws\": 351, \"mu_intercept_per_group\": 12.57809066772461, \"sigma_intercept_per_group\": 0.019336100667715073, \"sigma_obs\": 0.0036142379976809025, \"slope\": 0.19143837690353394, \"chain\": 2, \"draw\": 31}, {\"mouse\": 7, \"draws\": 352, \"mu_intercept_per_group\": 12.601237297058105, \"sigma_intercept_per_group\": 0.017494598403573036, \"sigma_obs\": 0.003586576785892248, \"slope\": 0.1900261491537094, \"chain\": 2, \"draw\": 32}, {\"mouse\": 7, \"draws\": 353, \"mu_intercept_per_group\": 15.345636367797852, \"sigma_intercept_per_group\": 0.015090630389750004, \"sigma_obs\": 0.0035983710549771786, \"slope\": 0.17695727944374084, \"chain\": 2, \"draw\": 33}, {\"mouse\": 7, \"draws\": 354, \"mu_intercept_per_group\": 8.889330863952637, \"sigma_intercept_per_group\": 0.0260974932461977, \"sigma_obs\": 0.0036187819205224514, \"slope\": 0.19184330105781555, \"chain\": 2, \"draw\": 34}, {\"mouse\": 7, \"draws\": 355, \"mu_intercept_per_group\": 8.67694091796875, \"sigma_intercept_per_group\": 0.025875793769955635, \"sigma_obs\": 0.0036144517362117767, \"slope\": 0.1917268931865692, \"chain\": 2, \"draw\": 35}, {\"mouse\": 7, \"draws\": 356, \"mu_intercept_per_group\": 8.750593185424805, \"sigma_intercept_per_group\": 0.026581522077322006, \"sigma_obs\": 0.0036479905247688293, \"slope\": 0.1927458792924881, \"chain\": 2, \"draw\": 36}, {\"mouse\": 7, \"draws\": 357, \"mu_intercept_per_group\": 8.834709167480469, \"sigma_intercept_per_group\": 0.026668520644307137, \"sigma_obs\": 0.00363333523273468, \"slope\": 0.1907307356595993, \"chain\": 2, \"draw\": 37}, {\"mouse\": 7, \"draws\": 358, \"mu_intercept_per_group\": 8.95480728149414, \"sigma_intercept_per_group\": 0.027099961414933205, \"sigma_obs\": 0.003634671214967966, \"slope\": 0.19096526503562927, \"chain\": 2, \"draw\": 38}, {\"mouse\": 7, \"draws\": 359, \"mu_intercept_per_group\": 9.38204288482666, \"sigma_intercept_per_group\": 0.02649247832596302, \"sigma_obs\": 0.0036461122799664736, \"slope\": 0.1925925612449646, \"chain\": 2, \"draw\": 39}, {\"mouse\": 7, \"draws\": 360, \"mu_intercept_per_group\": 8.554287910461426, \"sigma_intercept_per_group\": 0.028705252334475517, \"sigma_obs\": 0.0036215076688677073, \"slope\": 0.19390513002872467, \"chain\": 2, \"draw\": 40}, {\"mouse\": 7, \"draws\": 361, \"mu_intercept_per_group\": 9.700864791870117, \"sigma_intercept_per_group\": 0.025530189275741577, \"sigma_obs\": 0.003637629095464945, \"slope\": 0.19770047068595886, \"chain\": 2, \"draw\": 41}, {\"mouse\": 7, \"draws\": 362, \"mu_intercept_per_group\": 9.475761413574219, \"sigma_intercept_per_group\": 0.024692198261618614, \"sigma_obs\": 0.0036216957960277796, \"slope\": 0.19755598902702332, \"chain\": 2, \"draw\": 42}, {\"mouse\": 7, \"draws\": 363, \"mu_intercept_per_group\": 9.394735336303711, \"sigma_intercept_per_group\": 0.02465062215924263, \"sigma_obs\": 0.00362231582403183, \"slope\": 0.197505921125412, \"chain\": 2, \"draw\": 43}, {\"mouse\": 7, \"draws\": 364, \"mu_intercept_per_group\": 11.08381462097168, \"sigma_intercept_per_group\": 0.021248528733849525, \"sigma_obs\": 0.0035927302669733763, \"slope\": 0.1828784942626953, \"chain\": 2, \"draw\": 44}, {\"mouse\": 7, \"draws\": 365, \"mu_intercept_per_group\": 11.075885772705078, \"sigma_intercept_per_group\": 0.020847711712121964, \"sigma_obs\": 0.0035741361789405346, \"slope\": 0.18394827842712402, \"chain\": 2, \"draw\": 45}, {\"mouse\": 7, \"draws\": 366, \"mu_intercept_per_group\": 10.54545783996582, \"sigma_intercept_per_group\": 0.02156893163919449, \"sigma_obs\": 0.003576193703338504, \"slope\": 0.18897753953933716, \"chain\": 2, \"draw\": 46}, {\"mouse\": 7, \"draws\": 367, \"mu_intercept_per_group\": 10.084576606750488, \"sigma_intercept_per_group\": 0.02286677062511444, \"sigma_obs\": 0.0035695869009941816, \"slope\": 0.19092333316802979, \"chain\": 2, \"draw\": 47}, {\"mouse\": 7, \"draws\": 368, \"mu_intercept_per_group\": 12.314638137817383, \"sigma_intercept_per_group\": 0.018173061311244965, \"sigma_obs\": 0.003590700915083289, \"slope\": 0.18981793522834778, \"chain\": 2, \"draw\": 48}, {\"mouse\": 7, \"draws\": 369, \"mu_intercept_per_group\": 7.384014129638672, \"sigma_intercept_per_group\": 0.032409362494945526, \"sigma_obs\": 0.0035930455196648836, \"slope\": 0.1738370656967163, \"chain\": 2, \"draw\": 49}, {\"mouse\": 7, \"draws\": 370, \"mu_intercept_per_group\": 7.612643718719482, \"sigma_intercept_per_group\": 0.032345470041036606, \"sigma_obs\": 0.0036202678456902504, \"slope\": 0.17858436703681946, \"chain\": 2, \"draw\": 50}, {\"mouse\": 7, \"draws\": 371, \"mu_intercept_per_group\": 7.098739147186279, \"sigma_intercept_per_group\": 0.03358941152691841, \"sigma_obs\": 0.0036220222245901823, \"slope\": 0.17923274636268616, \"chain\": 2, \"draw\": 51}, {\"mouse\": 7, \"draws\": 372, \"mu_intercept_per_group\": 6.884673118591309, \"sigma_intercept_per_group\": 0.031174229457974434, \"sigma_obs\": 0.0036058444529771805, \"slope\": 0.19789548218250275, \"chain\": 2, \"draw\": 52}, {\"mouse\": 7, \"draws\": 373, \"mu_intercept_per_group\": 7.425764083862305, \"sigma_intercept_per_group\": 0.030944766476750374, \"sigma_obs\": 0.0036114195827394724, \"slope\": 0.1973891705274582, \"chain\": 2, \"draw\": 53}, {\"mouse\": 7, \"draws\": 374, \"mu_intercept_per_group\": 7.199800491333008, \"sigma_intercept_per_group\": 0.0311176385730505, \"sigma_obs\": 0.0036132936365902424, \"slope\": 0.19666753709316254, \"chain\": 2, \"draw\": 54}, {\"mouse\": 7, \"draws\": 375, \"mu_intercept_per_group\": 9.15973949432373, \"sigma_intercept_per_group\": 0.02575615420937538, \"sigma_obs\": 0.0036063394509255886, \"slope\": 0.18113549053668976, \"chain\": 2, \"draw\": 55}, {\"mouse\": 7, \"draws\": 376, \"mu_intercept_per_group\": 9.876193046569824, \"sigma_intercept_per_group\": 0.021710362285375595, \"sigma_obs\": 0.0035672897938638926, \"slope\": 0.20174190402030945, \"chain\": 2, \"draw\": 56}, {\"mouse\": 7, \"draws\": 377, \"mu_intercept_per_group\": 8.387222290039062, \"sigma_intercept_per_group\": 0.02882622554898262, \"sigma_obs\": 0.0036255023442208767, \"slope\": 0.1809121072292328, \"chain\": 2, \"draw\": 57}, {\"mouse\": 7, \"draws\": 378, \"mu_intercept_per_group\": 8.401693344116211, \"sigma_intercept_per_group\": 0.028865661472082138, \"sigma_obs\": 0.003658599453046918, \"slope\": 0.18159842491149902, \"chain\": 2, \"draw\": 58}, {\"mouse\": 7, \"draws\": 379, \"mu_intercept_per_group\": 8.204906463623047, \"sigma_intercept_per_group\": 0.02944941073656082, \"sigma_obs\": 0.0036390325985848904, \"slope\": 0.1887775957584381, \"chain\": 2, \"draw\": 59}, {\"mouse\": 7, \"draws\": 380, \"mu_intercept_per_group\": 6.897432327270508, \"sigma_intercept_per_group\": 0.03266706317663193, \"sigma_obs\": 0.003588029183447361, \"slope\": 0.19052085280418396, \"chain\": 2, \"draw\": 60}, {\"mouse\": 7, \"draws\": 381, \"mu_intercept_per_group\": 9.02954387664795, \"sigma_intercept_per_group\": 0.02482687123119831, \"sigma_obs\": 0.0035690846852958202, \"slope\": 0.18536493182182312, \"chain\": 2, \"draw\": 61}, {\"mouse\": 7, \"draws\": 382, \"mu_intercept_per_group\": 6.972280979156494, \"sigma_intercept_per_group\": 0.032673031091690063, \"sigma_obs\": 0.0036209102254360914, \"slope\": 0.19290147721767426, \"chain\": 2, \"draw\": 62}, {\"mouse\": 7, \"draws\": 383, \"mu_intercept_per_group\": 7.341432094573975, \"sigma_intercept_per_group\": 0.03195314109325409, \"sigma_obs\": 0.0036213642451912165, \"slope\": 0.1902262270450592, \"chain\": 2, \"draw\": 63}, {\"mouse\": 7, \"draws\": 384, \"mu_intercept_per_group\": 12.322853088378906, \"sigma_intercept_per_group\": 0.018204597756266594, \"sigma_obs\": 0.003603688906878233, \"slope\": 0.19885632395744324, \"chain\": 2, \"draw\": 64}, {\"mouse\": 7, \"draws\": 385, \"mu_intercept_per_group\": 12.525711059570312, \"sigma_intercept_per_group\": 0.018363792449235916, \"sigma_obs\": 0.003617065493017435, \"slope\": 0.19494123756885529, \"chain\": 2, \"draw\": 65}, {\"mouse\": 7, \"draws\": 386, \"mu_intercept_per_group\": 11.230805397033691, \"sigma_intercept_per_group\": 0.02026706375181675, \"sigma_obs\": 0.0035811117850244045, \"slope\": 0.19573931396007538, \"chain\": 2, \"draw\": 66}, {\"mouse\": 7, \"draws\": 387, \"mu_intercept_per_group\": 11.255461692810059, \"sigma_intercept_per_group\": 0.020176352933049202, \"sigma_obs\": 0.0035818631295114756, \"slope\": 0.19553019106388092, \"chain\": 2, \"draw\": 67}, {\"mouse\": 7, \"draws\": 388, \"mu_intercept_per_group\": 10.802995681762695, \"sigma_intercept_per_group\": 0.020585179328918457, \"sigma_obs\": 0.0035856568720191717, \"slope\": 0.19482725858688354, \"chain\": 2, \"draw\": 68}, {\"mouse\": 7, \"draws\": 389, \"mu_intercept_per_group\": 11.960826873779297, \"sigma_intercept_per_group\": 0.018333105370402336, \"sigma_obs\": 0.0035784386564046144, \"slope\": 0.19319382309913635, \"chain\": 2, \"draw\": 69}, {\"mouse\": 7, \"draws\": 390, \"mu_intercept_per_group\": 12.253438949584961, \"sigma_intercept_per_group\": 0.01921037770807743, \"sigma_obs\": 0.0036013389471918344, \"slope\": 0.18625542521476746, \"chain\": 2, \"draw\": 70}, {\"mouse\": 7, \"draws\": 391, \"mu_intercept_per_group\": 10.763121604919434, \"sigma_intercept_per_group\": 0.02095952443778515, \"sigma_obs\": 0.003608116414397955, \"slope\": 0.19975653290748596, \"chain\": 2, \"draw\": 71}, {\"mouse\": 7, \"draws\": 392, \"mu_intercept_per_group\": 11.498046875, \"sigma_intercept_per_group\": 0.019434183835983276, \"sigma_obs\": 0.003594479989260435, \"slope\": 0.19938917458057404, \"chain\": 2, \"draw\": 72}, {\"mouse\": 7, \"draws\": 393, \"mu_intercept_per_group\": 10.979312896728516, \"sigma_intercept_per_group\": 0.020829254761338234, \"sigma_obs\": 0.0036295049358159304, \"slope\": 0.18448205292224884, \"chain\": 2, \"draw\": 73}, {\"mouse\": 7, \"draws\": 394, \"mu_intercept_per_group\": 11.600772857666016, \"sigma_intercept_per_group\": 0.02021731249988079, \"sigma_obs\": 0.003611319698393345, \"slope\": 0.19080576300621033, \"chain\": 2, \"draw\": 74}, {\"mouse\": 7, \"draws\": 395, \"mu_intercept_per_group\": 11.025726318359375, \"sigma_intercept_per_group\": 0.02086137980222702, \"sigma_obs\": 0.0036033657379448414, \"slope\": 0.19413988292217255, \"chain\": 2, \"draw\": 75}, {\"mouse\": 7, \"draws\": 396, \"mu_intercept_per_group\": 11.452569007873535, \"sigma_intercept_per_group\": 0.020083265379071236, \"sigma_obs\": 0.0036170221865177155, \"slope\": 0.193069189786911, \"chain\": 2, \"draw\": 76}, {\"mouse\": 7, \"draws\": 397, \"mu_intercept_per_group\": 11.625408172607422, \"sigma_intercept_per_group\": 0.020086057484149933, \"sigma_obs\": 0.003618443850427866, \"slope\": 0.19545862078666687, \"chain\": 2, \"draw\": 77}, {\"mouse\": 7, \"draws\": 398, \"mu_intercept_per_group\": 11.477405548095703, \"sigma_intercept_per_group\": 0.019906144589185715, \"sigma_obs\": 0.0036235181614756584, \"slope\": 0.19617794454097748, \"chain\": 2, \"draw\": 78}, {\"mouse\": 7, \"draws\": 399, \"mu_intercept_per_group\": 10.357848167419434, \"sigma_intercept_per_group\": 0.022383417934179306, \"sigma_obs\": 0.0035982525441795588, \"slope\": 0.18184629082679749, \"chain\": 2, \"draw\": 79}, {\"mouse\": 7, \"draws\": 400, \"mu_intercept_per_group\": 10.142298698425293, \"sigma_intercept_per_group\": 0.022849397733807564, \"sigma_obs\": 0.0035963125992566347, \"slope\": 0.18135537207126617, \"chain\": 2, \"draw\": 80}, {\"mouse\": 7, \"draws\": 401, \"mu_intercept_per_group\": 8.808533668518066, \"sigma_intercept_per_group\": 0.024993902072310448, \"sigma_obs\": 0.0035910294391214848, \"slope\": 0.19372381269931793, \"chain\": 2, \"draw\": 81}, {\"mouse\": 7, \"draws\": 402, \"mu_intercept_per_group\": 9.186028480529785, \"sigma_intercept_per_group\": 0.02525361254811287, \"sigma_obs\": 0.0035929461009800434, \"slope\": 0.19206935167312622, \"chain\": 2, \"draw\": 82}, {\"mouse\": 7, \"draws\": 403, \"mu_intercept_per_group\": 8.140854835510254, \"sigma_intercept_per_group\": 0.027527617290616035, \"sigma_obs\": 0.003599048824980855, \"slope\": 0.20105738937854767, \"chain\": 2, \"draw\": 83}, {\"mouse\": 7, \"draws\": 404, \"mu_intercept_per_group\": 11.249858856201172, \"sigma_intercept_per_group\": 0.019838368520140648, \"sigma_obs\": 0.003558591241016984, \"slope\": 0.17769160866737366, \"chain\": 2, \"draw\": 84}, {\"mouse\": 7, \"draws\": 405, \"mu_intercept_per_group\": 11.950621604919434, \"sigma_intercept_per_group\": 0.01947549171745777, \"sigma_obs\": 0.003618883667513728, \"slope\": 0.19099947810173035, \"chain\": 2, \"draw\": 85}, {\"mouse\": 7, \"draws\": 406, \"mu_intercept_per_group\": 12.186288833618164, \"sigma_intercept_per_group\": 0.018856314942240715, \"sigma_obs\": 0.003612678498029709, \"slope\": 0.18838873505592346, \"chain\": 2, \"draw\": 86}, {\"mouse\": 7, \"draws\": 407, \"mu_intercept_per_group\": 11.27682876586914, \"sigma_intercept_per_group\": 0.021054208278656006, \"sigma_obs\": 0.0036133695393800735, \"slope\": 0.18378958106040955, \"chain\": 2, \"draw\": 87}, {\"mouse\": 7, \"draws\": 408, \"mu_intercept_per_group\": 11.212031364440918, \"sigma_intercept_per_group\": 0.02221425250172615, \"sigma_obs\": 0.003649370279163122, \"slope\": 0.1823308914899826, \"chain\": 2, \"draw\": 88}, {\"mouse\": 7, \"draws\": 409, \"mu_intercept_per_group\": 10.776966094970703, \"sigma_intercept_per_group\": 0.02220531553030014, \"sigma_obs\": 0.0036118226125836372, \"slope\": 0.19313567876815796, \"chain\": 2, \"draw\": 89}, {\"mouse\": 7, \"draws\": 410, \"mu_intercept_per_group\": 10.444023132324219, \"sigma_intercept_per_group\": 0.02121194824576378, \"sigma_obs\": 0.0036054335068911314, \"slope\": 0.1930496096611023, \"chain\": 2, \"draw\": 90}, {\"mouse\": 7, \"draws\": 411, \"mu_intercept_per_group\": 10.02772045135498, \"sigma_intercept_per_group\": 0.025407716631889343, \"sigma_obs\": 0.0036242231726646423, \"slope\": 0.18194900453090668, \"chain\": 2, \"draw\": 91}, {\"mouse\": 7, \"draws\": 412, \"mu_intercept_per_group\": 9.24424934387207, \"sigma_intercept_per_group\": 0.025814605876803398, \"sigma_obs\": 0.003618642222136259, \"slope\": 0.18442481756210327, \"chain\": 2, \"draw\": 92}, {\"mouse\": 7, \"draws\": 413, \"mu_intercept_per_group\": 12.052868843078613, \"sigma_intercept_per_group\": 0.018409404903650284, \"sigma_obs\": 0.0036143430043011904, \"slope\": 0.1888689547777176, \"chain\": 2, \"draw\": 93}, {\"mouse\": 7, \"draws\": 414, \"mu_intercept_per_group\": 12.713994979858398, \"sigma_intercept_per_group\": 0.019388938322663307, \"sigma_obs\": 0.003610569052398205, \"slope\": 0.18705306947231293, \"chain\": 2, \"draw\": 94}, {\"mouse\": 7, \"draws\": 415, \"mu_intercept_per_group\": 12.409842491149902, \"sigma_intercept_per_group\": 0.01823892630636692, \"sigma_obs\": 0.0036327550187706947, \"slope\": 0.18881027400493622, \"chain\": 2, \"draw\": 95}, {\"mouse\": 7, \"draws\": 416, \"mu_intercept_per_group\": 10.791082382202148, \"sigma_intercept_per_group\": 0.019754460081458092, \"sigma_obs\": 0.003556312993168831, \"slope\": 0.18627792596817017, \"chain\": 2, \"draw\": 96}, {\"mouse\": 7, \"draws\": 417, \"mu_intercept_per_group\": 10.720513343811035, \"sigma_intercept_per_group\": 0.021841716021299362, \"sigma_obs\": 0.003625784069299698, \"slope\": 0.19541692733764648, \"chain\": 2, \"draw\": 97}, {\"mouse\": 7, \"draws\": 418, \"mu_intercept_per_group\": 11.113096237182617, \"sigma_intercept_per_group\": 0.020162364467978477, \"sigma_obs\": 0.0036061727441847324, \"slope\": 0.19858185946941376, \"chain\": 2, \"draw\": 98}, {\"mouse\": 7, \"draws\": 419, \"mu_intercept_per_group\": 10.711718559265137, \"sigma_intercept_per_group\": 0.020947977900505066, \"sigma_obs\": 0.003606267273426056, \"slope\": 0.19262361526489258, \"chain\": 2, \"draw\": 99}, {\"mouse\": 7, \"draws\": 420, \"mu_intercept_per_group\": 11.298882484436035, \"sigma_intercept_per_group\": 0.021426107734441757, \"sigma_obs\": 0.0036034793592989445, \"slope\": 0.17676812410354614, \"chain\": 2, \"draw\": 100}, {\"mouse\": 7, \"draws\": 421, \"mu_intercept_per_group\": 10.683910369873047, \"sigma_intercept_per_group\": 0.021769218146800995, \"sigma_obs\": 0.003603917546570301, \"slope\": 0.19290581345558167, \"chain\": 2, \"draw\": 101}, {\"mouse\": 7, \"draws\": 422, \"mu_intercept_per_group\": 12.63023567199707, \"sigma_intercept_per_group\": 0.018745319917798042, \"sigma_obs\": 0.003614356741309166, \"slope\": 0.1847299486398697, \"chain\": 2, \"draw\": 102}, {\"mouse\": 7, \"draws\": 423, \"mu_intercept_per_group\": 11.501649856567383, \"sigma_intercept_per_group\": 0.01987389288842678, \"sigma_obs\": 0.003589593106880784, \"slope\": 0.17697250843048096, \"chain\": 2, \"draw\": 103}, {\"mouse\": 7, \"draws\": 424, \"mu_intercept_per_group\": 11.917733192443848, \"sigma_intercept_per_group\": 0.0196974016726017, \"sigma_obs\": 0.003584509715437889, \"slope\": 0.17958058416843414, \"chain\": 2, \"draw\": 104}, {\"mouse\": 7, \"draws\": 425, \"mu_intercept_per_group\": 10.243572235107422, \"sigma_intercept_per_group\": 0.02087869681417942, \"sigma_obs\": 0.003584197023883462, \"slope\": 0.19920219480991364, \"chain\": 2, \"draw\": 105}, {\"mouse\": 7, \"draws\": 426, \"mu_intercept_per_group\": 13.912221908569336, \"sigma_intercept_per_group\": 0.01675279811024666, \"sigma_obs\": 0.0035857544280588627, \"slope\": 0.18239182233810425, \"chain\": 2, \"draw\": 106}, {\"mouse\": 7, \"draws\": 427, \"mu_intercept_per_group\": 14.090718269348145, \"sigma_intercept_per_group\": 0.016848981380462646, \"sigma_obs\": 0.0035932871978729963, \"slope\": 0.1834600567817688, \"chain\": 2, \"draw\": 107}, {\"mouse\": 7, \"draws\": 428, \"mu_intercept_per_group\": 14.244917869567871, \"sigma_intercept_per_group\": 0.016078338027000427, \"sigma_obs\": 0.003617817535996437, \"slope\": 0.18628324568271637, \"chain\": 2, \"draw\": 108}, {\"mouse\": 7, \"draws\": 429, \"mu_intercept_per_group\": 14.9103422164917, \"sigma_intercept_per_group\": 0.01564958319067955, \"sigma_obs\": 0.0036297610495239496, \"slope\": 0.19038258492946625, \"chain\": 2, \"draw\": 109}, {\"mouse\": 7, \"draws\": 430, \"mu_intercept_per_group\": 14.042609214782715, \"sigma_intercept_per_group\": 0.016557013615965843, \"sigma_obs\": 0.0035613139625638723, \"slope\": 0.18815121054649353, \"chain\": 2, \"draw\": 110}, {\"mouse\": 7, \"draws\": 431, \"mu_intercept_per_group\": 12.648893356323242, \"sigma_intercept_per_group\": 0.018656045198440552, \"sigma_obs\": 0.00361360190436244, \"slope\": 0.19154906272888184, \"chain\": 2, \"draw\": 111}, {\"mouse\": 7, \"draws\": 432, \"mu_intercept_per_group\": 12.636263847351074, \"sigma_intercept_per_group\": 0.01790970005095005, \"sigma_obs\": 0.0036140363663434982, \"slope\": 0.18898749351501465, \"chain\": 2, \"draw\": 112}, {\"mouse\": 7, \"draws\": 433, \"mu_intercept_per_group\": 12.347711563110352, \"sigma_intercept_per_group\": 0.018048016354441643, \"sigma_obs\": 0.0035729417577385902, \"slope\": 0.19495706260204315, \"chain\": 2, \"draw\": 113}, {\"mouse\": 7, \"draws\": 434, \"mu_intercept_per_group\": 11.52521800994873, \"sigma_intercept_per_group\": 0.019897982478141785, \"sigma_obs\": 0.0036066679749637842, \"slope\": 0.1926048845052719, \"chain\": 2, \"draw\": 114}, {\"mouse\": 7, \"draws\": 435, \"mu_intercept_per_group\": 11.574653625488281, \"sigma_intercept_per_group\": 0.019671903923153877, \"sigma_obs\": 0.0036055813543498516, \"slope\": 0.20067961513996124, \"chain\": 2, \"draw\": 115}, {\"mouse\": 7, \"draws\": 436, \"mu_intercept_per_group\": 12.863534927368164, \"sigma_intercept_per_group\": 0.017857691273093224, \"sigma_obs\": 0.003579288488253951, \"slope\": 0.17857608199119568, \"chain\": 2, \"draw\": 116}, {\"mouse\": 7, \"draws\": 437, \"mu_intercept_per_group\": 13.17519474029541, \"sigma_intercept_per_group\": 0.017294736579060555, \"sigma_obs\": 0.003583817509934306, \"slope\": 0.19194456934928894, \"chain\": 2, \"draw\": 117}, {\"mouse\": 7, \"draws\": 438, \"mu_intercept_per_group\": 14.078084945678711, \"sigma_intercept_per_group\": 0.016338279470801353, \"sigma_obs\": 0.0036117087583988905, \"slope\": 0.19773371517658234, \"chain\": 2, \"draw\": 118}, {\"mouse\": 7, \"draws\": 439, \"mu_intercept_per_group\": 13.49814510345459, \"sigma_intercept_per_group\": 0.016991619020700455, \"sigma_obs\": 0.0035989047028124332, \"slope\": 0.18368619680404663, \"chain\": 2, \"draw\": 119}, {\"mouse\": 7, \"draws\": 440, \"mu_intercept_per_group\": 13.377963066101074, \"sigma_intercept_per_group\": 0.017126109451055527, \"sigma_obs\": 0.003610983956605196, \"slope\": 0.18102000653743744, \"chain\": 2, \"draw\": 120}, {\"mouse\": 7, \"draws\": 441, \"mu_intercept_per_group\": 14.087303161621094, \"sigma_intercept_per_group\": 0.017224116250872612, \"sigma_obs\": 0.003599098650738597, \"slope\": 0.17822147905826569, \"chain\": 2, \"draw\": 121}, {\"mouse\": 7, \"draws\": 442, \"mu_intercept_per_group\": 15.894698143005371, \"sigma_intercept_per_group\": 0.015252308920025826, \"sigma_obs\": 0.0036405930295586586, \"slope\": 0.19198937714099884, \"chain\": 2, \"draw\": 122}, {\"mouse\": 7, \"draws\": 443, \"mu_intercept_per_group\": 18.06110382080078, \"sigma_intercept_per_group\": 0.012627441436052322, \"sigma_obs\": 0.0035852466244250536, \"slope\": 0.17791637778282166, \"chain\": 2, \"draw\": 123}, {\"mouse\": 7, \"draws\": 444, \"mu_intercept_per_group\": 17.932432174682617, \"sigma_intercept_per_group\": 0.012793847359716892, \"sigma_obs\": 0.003555088769644499, \"slope\": 0.1779908686876297, \"chain\": 2, \"draw\": 124}, {\"mouse\": 7, \"draws\": 445, \"mu_intercept_per_group\": 16.70292091369629, \"sigma_intercept_per_group\": 0.014551113359630108, \"sigma_obs\": 0.0036527197808027267, \"slope\": 0.1989598125219345, \"chain\": 2, \"draw\": 125}, {\"mouse\": 7, \"draws\": 446, \"mu_intercept_per_group\": 10.4523344039917, \"sigma_intercept_per_group\": 0.020901288837194443, \"sigma_obs\": 0.003560828510671854, \"slope\": 0.17730630934238434, \"chain\": 2, \"draw\": 126}, {\"mouse\": 7, \"draws\": 447, \"mu_intercept_per_group\": 10.77991008758545, \"sigma_intercept_per_group\": 0.020541133359074593, \"sigma_obs\": 0.003558351891115308, \"slope\": 0.18700234591960907, \"chain\": 2, \"draw\": 127}, {\"mouse\": 7, \"draws\": 448, \"mu_intercept_per_group\": 9.05896282196045, \"sigma_intercept_per_group\": 0.026962053030729294, \"sigma_obs\": 0.003600538708269596, \"slope\": 0.17693592607975006, \"chain\": 2, \"draw\": 128}, {\"mouse\": 7, \"draws\": 449, \"mu_intercept_per_group\": 9.13316535949707, \"sigma_intercept_per_group\": 0.025734055787324905, \"sigma_obs\": 0.003613193752244115, \"slope\": 0.18218769133090973, \"chain\": 2, \"draw\": 129}, {\"mouse\": 7, \"draws\": 450, \"mu_intercept_per_group\": 10.163662910461426, \"sigma_intercept_per_group\": 0.023211553692817688, \"sigma_obs\": 0.0036175930872559547, \"slope\": 0.18682743608951569, \"chain\": 2, \"draw\": 130}, {\"mouse\": 7, \"draws\": 451, \"mu_intercept_per_group\": 18.26988410949707, \"sigma_intercept_per_group\": 0.012533655390143394, \"sigma_obs\": 0.0035968665033578873, \"slope\": 0.1870592087507248, \"chain\": 2, \"draw\": 131}, {\"mouse\": 7, \"draws\": 452, \"mu_intercept_per_group\": 17.265840530395508, \"sigma_intercept_per_group\": 0.013070343062281609, \"sigma_obs\": 0.0036127353087067604, \"slope\": 0.20064552128314972, \"chain\": 2, \"draw\": 132}, {\"mouse\": 7, \"draws\": 453, \"mu_intercept_per_group\": 19.590431213378906, \"sigma_intercept_per_group\": 0.011407632380723953, \"sigma_obs\": 0.0035648257471621037, \"slope\": 0.1834632307291031, \"chain\": 2, \"draw\": 133}, {\"mouse\": 7, \"draws\": 454, \"mu_intercept_per_group\": 18.463560104370117, \"sigma_intercept_per_group\": 0.012139679864048958, \"sigma_obs\": 0.003588051302358508, \"slope\": 0.19474107027053833, \"chain\": 2, \"draw\": 134}, {\"mouse\": 7, \"draws\": 455, \"mu_intercept_per_group\": 19.313377380371094, \"sigma_intercept_per_group\": 0.01199289970099926, \"sigma_obs\": 0.0035843285731971264, \"slope\": 0.1898583173751831, \"chain\": 2, \"draw\": 135}, {\"mouse\": 7, \"draws\": 456, \"mu_intercept_per_group\": 18.08652114868164, \"sigma_intercept_per_group\": 0.012334774248301983, \"sigma_obs\": 0.0035743594635277987, \"slope\": 0.18416078388690948, \"chain\": 2, \"draw\": 136}, {\"mouse\": 7, \"draws\": 457, \"mu_intercept_per_group\": 18.456092834472656, \"sigma_intercept_per_group\": 0.012519529089331627, \"sigma_obs\": 0.0035930746234953403, \"slope\": 0.1932351440191269, \"chain\": 2, \"draw\": 137}, {\"mouse\": 7, \"draws\": 458, \"mu_intercept_per_group\": 19.99809455871582, \"sigma_intercept_per_group\": 0.011873673647642136, \"sigma_obs\": 0.0036066165193915367, \"slope\": 0.1787996143102646, \"chain\": 2, \"draw\": 138}, {\"mouse\": 7, \"draws\": 459, \"mu_intercept_per_group\": 10.037954330444336, \"sigma_intercept_per_group\": 0.021836789324879646, \"sigma_obs\": 0.003571287728846073, \"slope\": 0.18720035254955292, \"chain\": 2, \"draw\": 139}, {\"mouse\": 7, \"draws\": 460, \"mu_intercept_per_group\": 9.698882102966309, \"sigma_intercept_per_group\": 0.02370741404592991, \"sigma_obs\": 0.003570644184947014, \"slope\": 0.18608695268630981, \"chain\": 2, \"draw\": 140}, {\"mouse\": 7, \"draws\": 461, \"mu_intercept_per_group\": 9.882332801818848, \"sigma_intercept_per_group\": 0.022096654400229454, \"sigma_obs\": 0.0035691324155777693, \"slope\": 0.1874566227197647, \"chain\": 2, \"draw\": 141}, {\"mouse\": 7, \"draws\": 462, \"mu_intercept_per_group\": 9.11053466796875, \"sigma_intercept_per_group\": 0.027973756194114685, \"sigma_obs\": 0.003638071473687887, \"slope\": 0.1849568784236908, \"chain\": 2, \"draw\": 142}, {\"mouse\": 7, \"draws\": 463, \"mu_intercept_per_group\": 8.414717674255371, \"sigma_intercept_per_group\": 0.02702467143535614, \"sigma_obs\": 0.003628036007285118, \"slope\": 0.1850833296775818, \"chain\": 2, \"draw\": 143}, {\"mouse\": 7, \"draws\": 464, \"mu_intercept_per_group\": 9.429102897644043, \"sigma_intercept_per_group\": 0.024459687992930412, \"sigma_obs\": 0.003632917767390609, \"slope\": 0.17935709655284882, \"chain\": 2, \"draw\": 144}, {\"mouse\": 7, \"draws\": 465, \"mu_intercept_per_group\": 8.984553337097168, \"sigma_intercept_per_group\": 0.026810720562934875, \"sigma_obs\": 0.003622257150709629, \"slope\": 0.19028358161449432, \"chain\": 2, \"draw\": 145}, {\"mouse\": 7, \"draws\": 466, \"mu_intercept_per_group\": 9.016618728637695, \"sigma_intercept_per_group\": 0.026209644973278046, \"sigma_obs\": 0.003622060175985098, \"slope\": 0.18880131840705872, \"chain\": 2, \"draw\": 146}, {\"mouse\": 7, \"draws\": 467, \"mu_intercept_per_group\": 9.321554183959961, \"sigma_intercept_per_group\": 0.02493632212281227, \"sigma_obs\": 0.003606007667258382, \"slope\": 0.1926887184381485, \"chain\": 2, \"draw\": 147}, {\"mouse\": 7, \"draws\": 468, \"mu_intercept_per_group\": 9.575602531433105, \"sigma_intercept_per_group\": 0.02400926500558853, \"sigma_obs\": 0.0036151877138763666, \"slope\": 0.1935034990310669, \"chain\": 2, \"draw\": 148}, {\"mouse\": 7, \"draws\": 469, \"mu_intercept_per_group\": 9.47808837890625, \"sigma_intercept_per_group\": 0.023568566888570786, \"sigma_obs\": 0.003597101429477334, \"slope\": 0.19470258057117462, \"chain\": 2, \"draw\": 149}, {\"mouse\": 7, \"draws\": 470, \"mu_intercept_per_group\": 9.523959159851074, \"sigma_intercept_per_group\": 0.023802921175956726, \"sigma_obs\": 0.0035981978289783, \"slope\": 0.1945735663175583, \"chain\": 2, \"draw\": 150}, {\"mouse\": 7, \"draws\": 471, \"mu_intercept_per_group\": 10.553288459777832, \"sigma_intercept_per_group\": 0.02126855030655861, \"sigma_obs\": 0.0036032095085829496, \"slope\": 0.17964039742946625, \"chain\": 2, \"draw\": 151}, {\"mouse\": 7, \"draws\": 472, \"mu_intercept_per_group\": 10.81861686706543, \"sigma_intercept_per_group\": 0.02134786732494831, \"sigma_obs\": 0.003600809955969453, \"slope\": 0.17985863983631134, \"chain\": 2, \"draw\": 152}, {\"mouse\": 7, \"draws\": 473, \"mu_intercept_per_group\": 13.002190589904785, \"sigma_intercept_per_group\": 0.017413783818483353, \"sigma_obs\": 0.003575380425900221, \"slope\": 0.19632083177566528, \"chain\": 2, \"draw\": 153}, {\"mouse\": 7, \"draws\": 474, \"mu_intercept_per_group\": 14.9756441116333, \"sigma_intercept_per_group\": 0.015105287544429302, \"sigma_obs\": 0.0035872473381459713, \"slope\": 0.1836777776479721, \"chain\": 2, \"draw\": 154}, {\"mouse\": 7, \"draws\": 475, \"mu_intercept_per_group\": 16.933565139770508, \"sigma_intercept_per_group\": 0.014207471162080765, \"sigma_obs\": 0.0035999000538140535, \"slope\": 0.17847751080989838, \"chain\": 2, \"draw\": 155}, {\"mouse\": 7, \"draws\": 476, \"mu_intercept_per_group\": 16.22969627380371, \"sigma_intercept_per_group\": 0.014138281345367432, \"sigma_obs\": 0.003595781046897173, \"slope\": 0.1782684028148651, \"chain\": 2, \"draw\": 156}, {\"mouse\": 7, \"draws\": 477, \"mu_intercept_per_group\": 14.819085121154785, \"sigma_intercept_per_group\": 0.014905320480465889, \"sigma_obs\": 0.0036101851146668196, \"slope\": 0.1922270953655243, \"chain\": 2, \"draw\": 157}, {\"mouse\": 7, \"draws\": 478, \"mu_intercept_per_group\": 15.049208641052246, \"sigma_intercept_per_group\": 0.014373648911714554, \"sigma_obs\": 0.003601421369239688, \"slope\": 0.19412484765052795, \"chain\": 2, \"draw\": 158}, {\"mouse\": 7, \"draws\": 479, \"mu_intercept_per_group\": 15.333222389221191, \"sigma_intercept_per_group\": 0.014316389337182045, \"sigma_obs\": 0.0035850482527166605, \"slope\": 0.18656855821609497, \"chain\": 2, \"draw\": 159}, {\"mouse\": 7, \"draws\": 480, \"mu_intercept_per_group\": 11.949214935302734, \"sigma_intercept_per_group\": 0.018793528899550438, \"sigma_obs\": 0.0035750053357332945, \"slope\": 0.1846868395805359, \"chain\": 3, \"draw\": 0}, {\"mouse\": 7, \"draws\": 481, \"mu_intercept_per_group\": 11.668681144714355, \"sigma_intercept_per_group\": 0.019390825182199478, \"sigma_obs\": 0.0035800121258944273, \"slope\": 0.18357504904270172, \"chain\": 3, \"draw\": 1}, {\"mouse\": 7, \"draws\": 482, \"mu_intercept_per_group\": 10.402152061462402, \"sigma_intercept_per_group\": 0.02063724398612976, \"sigma_obs\": 0.0035582620184868574, \"slope\": 0.1871715486049652, \"chain\": 3, \"draw\": 2}, {\"mouse\": 7, \"draws\": 483, \"mu_intercept_per_group\": 10.90945053100586, \"sigma_intercept_per_group\": 0.02016781084239483, \"sigma_obs\": 0.0035615975502878428, \"slope\": 0.18710751831531525, \"chain\": 3, \"draw\": 3}, {\"mouse\": 7, \"draws\": 484, \"mu_intercept_per_group\": 10.81752872467041, \"sigma_intercept_per_group\": 0.021626226603984833, \"sigma_obs\": 0.003600968047976494, \"slope\": 0.18107876181602478, \"chain\": 3, \"draw\": 4}, {\"mouse\": 7, \"draws\": 485, \"mu_intercept_per_group\": 10.330848693847656, \"sigma_intercept_per_group\": 0.022784151136875153, \"sigma_obs\": 0.0035997473169118166, \"slope\": 0.17876575887203217, \"chain\": 3, \"draw\": 5}, {\"mouse\": 7, \"draws\": 486, \"mu_intercept_per_group\": 10.589546203613281, \"sigma_intercept_per_group\": 0.02300894260406494, \"sigma_obs\": 0.003598784562200308, \"slope\": 0.1791088730096817, \"chain\": 3, \"draw\": 6}, {\"mouse\": 7, \"draws\": 487, \"mu_intercept_per_group\": 9.973832130432129, \"sigma_intercept_per_group\": 0.022535819560289383, \"sigma_obs\": 0.003598559647798538, \"slope\": 0.17932267487049103, \"chain\": 3, \"draw\": 7}, {\"mouse\": 7, \"draws\": 488, \"mu_intercept_per_group\": 8.202228546142578, \"sigma_intercept_per_group\": 0.027181973680853844, \"sigma_obs\": 0.003604042809456587, \"slope\": 0.1921774297952652, \"chain\": 3, \"draw\": 8}, {\"mouse\": 7, \"draws\": 489, \"mu_intercept_per_group\": 9.831948280334473, \"sigma_intercept_per_group\": 0.022597704082727432, \"sigma_obs\": 0.003611605614423752, \"slope\": 0.19013375043869019, \"chain\": 3, \"draw\": 9}, {\"mouse\": 7, \"draws\": 490, \"mu_intercept_per_group\": 8.61691665649414, \"sigma_intercept_per_group\": 0.027177127078175545, \"sigma_obs\": 0.0036149790976196527, \"slope\": 0.19592604041099548, \"chain\": 3, \"draw\": 10}, {\"mouse\": 7, \"draws\": 491, \"mu_intercept_per_group\": 8.925427436828613, \"sigma_intercept_per_group\": 0.02586279809474945, \"sigma_obs\": 0.0036117604468017817, \"slope\": 0.1982659250497818, \"chain\": 3, \"draw\": 11}, {\"mouse\": 7, \"draws\": 492, \"mu_intercept_per_group\": 9.665080070495605, \"sigma_intercept_per_group\": 0.02350063994526863, \"sigma_obs\": 0.0036153357941657305, \"slope\": 0.188862144947052, \"chain\": 3, \"draw\": 12}, {\"mouse\": 7, \"draws\": 493, \"mu_intercept_per_group\": 8.663387298583984, \"sigma_intercept_per_group\": 0.026464518159627914, \"sigma_obs\": 0.0035919167567044497, \"slope\": 0.18651701509952545, \"chain\": 3, \"draw\": 13}, {\"mouse\": 7, \"draws\": 494, \"mu_intercept_per_group\": 14.242582321166992, \"sigma_intercept_per_group\": 0.015964172780513763, \"sigma_obs\": 0.003617424052208662, \"slope\": 0.18674202263355255, \"chain\": 3, \"draw\": 14}, {\"mouse\": 7, \"draws\": 495, \"mu_intercept_per_group\": 13.165971755981445, \"sigma_intercept_per_group\": 0.017614347860217094, \"sigma_obs\": 0.0035997028462588787, \"slope\": 0.18770620226860046, \"chain\": 3, \"draw\": 15}, {\"mouse\": 7, \"draws\": 496, \"mu_intercept_per_group\": 11.419358253479004, \"sigma_intercept_per_group\": 0.01979820989072323, \"sigma_obs\": 0.0035865716636180878, \"slope\": 0.18613404035568237, \"chain\": 3, \"draw\": 16}, {\"mouse\": 7, \"draws\": 497, \"mu_intercept_per_group\": 11.59504222869873, \"sigma_intercept_per_group\": 0.01941036246716976, \"sigma_obs\": 0.0035803928039968014, \"slope\": 0.1867128610610962, \"chain\": 3, \"draw\": 17}, {\"mouse\": 7, \"draws\": 498, \"mu_intercept_per_group\": 11.449594497680664, \"sigma_intercept_per_group\": 0.019380241632461548, \"sigma_obs\": 0.0035806114319711924, \"slope\": 0.18663710355758667, \"chain\": 3, \"draw\": 18}, {\"mouse\": 7, \"draws\": 499, \"mu_intercept_per_group\": 11.234237670898438, \"sigma_intercept_per_group\": 0.02053423970937729, \"sigma_obs\": 0.003633302403613925, \"slope\": 0.1971641629934311, \"chain\": 3, \"draw\": 19}, {\"mouse\": 7, \"draws\": 500, \"mu_intercept_per_group\": 11.625036239624023, \"sigma_intercept_per_group\": 0.019635435193777084, \"sigma_obs\": 0.0036372700706124306, \"slope\": 0.19863028824329376, \"chain\": 3, \"draw\": 20}, {\"mouse\": 7, \"draws\": 501, \"mu_intercept_per_group\": 12.98870849609375, \"sigma_intercept_per_group\": 0.016981089487671852, \"sigma_obs\": 0.0035575919318944216, \"slope\": 0.17979522049427032, \"chain\": 3, \"draw\": 21}, {\"mouse\": 7, \"draws\": 502, \"mu_intercept_per_group\": 12.557905197143555, \"sigma_intercept_per_group\": 0.017365142703056335, \"sigma_obs\": 0.0035360537003725767, \"slope\": 0.1832214891910553, \"chain\": 3, \"draw\": 22}, {\"mouse\": 7, \"draws\": 503, \"mu_intercept_per_group\": 12.145800590515137, \"sigma_intercept_per_group\": 0.017646217718720436, \"sigma_obs\": 0.0035629498306661844, \"slope\": 0.18016251921653748, \"chain\": 3, \"draw\": 23}, {\"mouse\": 7, \"draws\": 504, \"mu_intercept_per_group\": 12.233484268188477, \"sigma_intercept_per_group\": 0.01777147874236107, \"sigma_obs\": 0.003584655001759529, \"slope\": 0.1824834793806076, \"chain\": 3, \"draw\": 24}, {\"mouse\": 7, \"draws\": 505, \"mu_intercept_per_group\": 12.661812782287598, \"sigma_intercept_per_group\": 0.017882078886032104, \"sigma_obs\": 0.0035821825731545687, \"slope\": 0.1808357685804367, \"chain\": 3, \"draw\": 25}, {\"mouse\": 7, \"draws\": 506, \"mu_intercept_per_group\": 10.791397094726562, \"sigma_intercept_per_group\": 0.02153826877474785, \"sigma_obs\": 0.003615670371800661, \"slope\": 0.19289802014827728, \"chain\": 3, \"draw\": 26}, {\"mouse\": 7, \"draws\": 507, \"mu_intercept_per_group\": 10.943082809448242, \"sigma_intercept_per_group\": 0.02184201218187809, \"sigma_obs\": 0.0036017647944390774, \"slope\": 0.18468278646469116, \"chain\": 3, \"draw\": 27}, {\"mouse\": 7, \"draws\": 508, \"mu_intercept_per_group\": 13.470155715942383, \"sigma_intercept_per_group\": 0.01731618493795395, \"sigma_obs\": 0.0035510549787431955, \"slope\": 0.1878516525030136, \"chain\": 3, \"draw\": 28}, {\"mouse\": 7, \"draws\": 509, \"mu_intercept_per_group\": 13.865983009338379, \"sigma_intercept_per_group\": 0.015945952385663986, \"sigma_obs\": 0.0035603055730462074, \"slope\": 0.18821831047534943, \"chain\": 3, \"draw\": 29}, {\"mouse\": 7, \"draws\": 510, \"mu_intercept_per_group\": 13.21607780456543, \"sigma_intercept_per_group\": 0.01772969216108322, \"sigma_obs\": 0.0036204750649631023, \"slope\": 0.18965774774551392, \"chain\": 3, \"draw\": 30}, {\"mouse\": 7, \"draws\": 511, \"mu_intercept_per_group\": 16.27344512939453, \"sigma_intercept_per_group\": 0.013371432200074196, \"sigma_obs\": 0.003550421679392457, \"slope\": 0.19294379651546478, \"chain\": 3, \"draw\": 31}, {\"mouse\": 7, \"draws\": 512, \"mu_intercept_per_group\": 18.273025512695312, \"sigma_intercept_per_group\": 0.013382287696003914, \"sigma_obs\": 0.003616142785176635, \"slope\": 0.18714098632335663, \"chain\": 3, \"draw\": 32}, {\"mouse\": 7, \"draws\": 513, \"mu_intercept_per_group\": 14.289527893066406, \"sigma_intercept_per_group\": 0.0157723780721426, \"sigma_obs\": 0.003615480614826083, \"slope\": 0.18600225448608398, \"chain\": 3, \"draw\": 33}, {\"mouse\": 7, \"draws\": 514, \"mu_intercept_per_group\": 14.269876480102539, \"sigma_intercept_per_group\": 0.01619158871471882, \"sigma_obs\": 0.0035861406940966845, \"slope\": 0.1881256103515625, \"chain\": 3, \"draw\": 34}, {\"mouse\": 7, \"draws\": 515, \"mu_intercept_per_group\": 13.634252548217773, \"sigma_intercept_per_group\": 0.01674601621925831, \"sigma_obs\": 0.0035830880515277386, \"slope\": 0.1875041425228119, \"chain\": 3, \"draw\": 35}, {\"mouse\": 7, \"draws\": 516, \"mu_intercept_per_group\": 13.781076431274414, \"sigma_intercept_per_group\": 0.01673298142850399, \"sigma_obs\": 0.0036193651612848043, \"slope\": 0.1873663365840912, \"chain\": 3, \"draw\": 36}, {\"mouse\": 7, \"draws\": 517, \"mu_intercept_per_group\": 13.776945114135742, \"sigma_intercept_per_group\": 0.01720339059829712, \"sigma_obs\": 0.003620649455115199, \"slope\": 0.18820346891880035, \"chain\": 3, \"draw\": 37}, {\"mouse\": 7, \"draws\": 518, \"mu_intercept_per_group\": 13.86768913269043, \"sigma_intercept_per_group\": 0.01676558330655098, \"sigma_obs\": 0.0036198552697896957, \"slope\": 0.18779025971889496, \"chain\": 3, \"draw\": 38}, {\"mouse\": 7, \"draws\": 519, \"mu_intercept_per_group\": 14.022978782653809, \"sigma_intercept_per_group\": 0.016475863754749298, \"sigma_obs\": 0.0036210380494594574, \"slope\": 0.1941835731267929, \"chain\": 3, \"draw\": 39}, {\"mouse\": 7, \"draws\": 520, \"mu_intercept_per_group\": 9.793961524963379, \"sigma_intercept_per_group\": 0.021445706486701965, \"sigma_obs\": 0.003546413267031312, \"slope\": 0.19647429883480072, \"chain\": 3, \"draw\": 40}, {\"mouse\": 7, \"draws\": 521, \"mu_intercept_per_group\": 10.889704704284668, \"sigma_intercept_per_group\": 0.02190762758255005, \"sigma_obs\": 0.0036069706548005342, \"slope\": 0.17704494297504425, \"chain\": 3, \"draw\": 41}, {\"mouse\": 7, \"draws\": 522, \"mu_intercept_per_group\": 10.075024604797363, \"sigma_intercept_per_group\": 0.022320862859487534, \"sigma_obs\": 0.0036076174583286047, \"slope\": 0.1813744604587555, \"chain\": 3, \"draw\": 42}, {\"mouse\": 7, \"draws\": 523, \"mu_intercept_per_group\": 10.746500968933105, \"sigma_intercept_per_group\": 0.021789245307445526, \"sigma_obs\": 0.00360893364995718, \"slope\": 0.18052537739276886, \"chain\": 3, \"draw\": 43}, {\"mouse\": 7, \"draws\": 524, \"mu_intercept_per_group\": 7.293745994567871, \"sigma_intercept_per_group\": 0.030943313613533974, \"sigma_obs\": 0.0035921684466302395, \"slope\": 0.19597119092941284, \"chain\": 3, \"draw\": 44}, {\"mouse\": 7, \"draws\": 525, \"mu_intercept_per_group\": 7.528172016143799, \"sigma_intercept_per_group\": 0.030631165951490402, \"sigma_obs\": 0.003597204340621829, \"slope\": 0.1917290985584259, \"chain\": 3, \"draw\": 45}, {\"mouse\": 7, \"draws\": 526, \"mu_intercept_per_group\": 7.686507225036621, \"sigma_intercept_per_group\": 0.03062462992966175, \"sigma_obs\": 0.003606442827731371, \"slope\": 0.18942080438137054, \"chain\": 3, \"draw\": 46}, {\"mouse\": 7, \"draws\": 527, \"mu_intercept_per_group\": 10.343385696411133, \"sigma_intercept_per_group\": 0.02215665765106678, \"sigma_obs\": 0.0035874799359589815, \"slope\": 0.18641942739486694, \"chain\": 3, \"draw\": 47}, {\"mouse\": 7, \"draws\": 528, \"mu_intercept_per_group\": 11.31760311126709, \"sigma_intercept_per_group\": 0.020104780793190002, \"sigma_obs\": 0.0035941165406256914, \"slope\": 0.1859269142150879, \"chain\": 3, \"draw\": 48}, {\"mouse\": 7, \"draws\": 529, \"mu_intercept_per_group\": 10.842963218688965, \"sigma_intercept_per_group\": 0.020968180149793625, \"sigma_obs\": 0.003588783787563443, \"slope\": 0.18986544013023376, \"chain\": 3, \"draw\": 49}, {\"mouse\": 7, \"draws\": 530, \"mu_intercept_per_group\": 10.001209259033203, \"sigma_intercept_per_group\": 0.023519277572631836, \"sigma_obs\": 0.0036085827741771936, \"slope\": 0.17977668344974518, \"chain\": 3, \"draw\": 50}, {\"mouse\": 7, \"draws\": 531, \"mu_intercept_per_group\": 8.664310455322266, \"sigma_intercept_per_group\": 0.025069594383239746, \"sigma_obs\": 0.003601651405915618, \"slope\": 0.19780851900577545, \"chain\": 3, \"draw\": 51}, {\"mouse\": 7, \"draws\": 532, \"mu_intercept_per_group\": 9.291108131408691, \"sigma_intercept_per_group\": 0.023170754313468933, \"sigma_obs\": 0.0035906939301639795, \"slope\": 0.20111554861068726, \"chain\": 3, \"draw\": 52}, {\"mouse\": 7, \"draws\": 533, \"mu_intercept_per_group\": 9.455000877380371, \"sigma_intercept_per_group\": 0.023600555956363678, \"sigma_obs\": 0.003587466198951006, \"slope\": 0.19825610518455505, \"chain\": 3, \"draw\": 53}, {\"mouse\": 7, \"draws\": 534, \"mu_intercept_per_group\": 11.80007266998291, \"sigma_intercept_per_group\": 0.019761228933930397, \"sigma_obs\": 0.0036122926976531744, \"slope\": 0.18485115468502045, \"chain\": 3, \"draw\": 54}, {\"mouse\": 7, \"draws\": 535, \"mu_intercept_per_group\": 10.777748107910156, \"sigma_intercept_per_group\": 0.0203214343637228, \"sigma_obs\": 0.0035931894090026617, \"slope\": 0.19131381809711456, \"chain\": 3, \"draw\": 55}, {\"mouse\": 7, \"draws\": 536, \"mu_intercept_per_group\": 9.823101997375488, \"sigma_intercept_per_group\": 0.022839728742837906, \"sigma_obs\": 0.003584446618333459, \"slope\": 0.1956043690443039, \"chain\": 3, \"draw\": 56}, {\"mouse\": 7, \"draws\": 537, \"mu_intercept_per_group\": 7.634424686431885, \"sigma_intercept_per_group\": 0.031132716685533524, \"sigma_obs\": 0.003613743232563138, \"slope\": 0.18749307096004486, \"chain\": 3, \"draw\": 57}, {\"mouse\": 7, \"draws\": 538, \"mu_intercept_per_group\": 7.167606353759766, \"sigma_intercept_per_group\": 0.03152378648519516, \"sigma_obs\": 0.00360685377381742, \"slope\": 0.18796981871128082, \"chain\": 3, \"draw\": 58}, {\"mouse\": 7, \"draws\": 539, \"mu_intercept_per_group\": 7.066221237182617, \"sigma_intercept_per_group\": 0.03179066255688667, \"sigma_obs\": 0.0035922317765653133, \"slope\": 0.18621371686458588, \"chain\": 3, \"draw\": 59}, {\"mouse\": 7, \"draws\": 540, \"mu_intercept_per_group\": 9.72808837890625, \"sigma_intercept_per_group\": 0.024020830169320107, \"sigma_obs\": 0.0036113455425947905, \"slope\": 0.18349197506904602, \"chain\": 3, \"draw\": 60}, {\"mouse\": 7, \"draws\": 541, \"mu_intercept_per_group\": 9.412628173828125, \"sigma_intercept_per_group\": 0.024557720869779587, \"sigma_obs\": 0.0035984343849122524, \"slope\": 0.19529053568840027, \"chain\": 3, \"draw\": 61}, {\"mouse\": 7, \"draws\": 542, \"mu_intercept_per_group\": 8.98169994354248, \"sigma_intercept_per_group\": 0.024932481348514557, \"sigma_obs\": 0.0036004476714879274, \"slope\": 0.19528566300868988, \"chain\": 3, \"draw\": 62}, {\"mouse\": 7, \"draws\": 543, \"mu_intercept_per_group\": 9.864893913269043, \"sigma_intercept_per_group\": 0.02380625158548355, \"sigma_obs\": 0.0036084174644201994, \"slope\": 0.18747736513614655, \"chain\": 3, \"draw\": 63}, {\"mouse\": 7, \"draws\": 544, \"mu_intercept_per_group\": 12.189886093139648, \"sigma_intercept_per_group\": 0.018427541479468346, \"sigma_obs\": 0.0035863355733454227, \"slope\": 0.1897362470626831, \"chain\": 3, \"draw\": 64}, {\"mouse\": 7, \"draws\": 545, \"mu_intercept_per_group\": 12.023582458496094, \"sigma_intercept_per_group\": 0.01884840428829193, \"sigma_obs\": 0.003601095173507929, \"slope\": 0.18965503573417664, \"chain\": 3, \"draw\": 65}, {\"mouse\": 7, \"draws\": 546, \"mu_intercept_per_group\": 9.691656112670898, \"sigma_intercept_per_group\": 0.022709928452968597, \"sigma_obs\": 0.003609047271311283, \"slope\": 0.19729287922382355, \"chain\": 3, \"draw\": 66}, {\"mouse\": 7, \"draws\": 547, \"mu_intercept_per_group\": 12.405975341796875, \"sigma_intercept_per_group\": 0.018024245277047157, \"sigma_obs\": 0.003601033240556717, \"slope\": 0.19092001020908356, \"chain\": 3, \"draw\": 67}, {\"mouse\": 7, \"draws\": 548, \"mu_intercept_per_group\": 11.562335968017578, \"sigma_intercept_per_group\": 0.01976897194981575, \"sigma_obs\": 0.003579746000468731, \"slope\": 0.1892424374818802, \"chain\": 3, \"draw\": 68}, {\"mouse\": 7, \"draws\": 549, \"mu_intercept_per_group\": 11.639060974121094, \"sigma_intercept_per_group\": 0.018758736550807953, \"sigma_obs\": 0.0035769969690591097, \"slope\": 0.18863849341869354, \"chain\": 3, \"draw\": 69}, {\"mouse\": 7, \"draws\": 550, \"mu_intercept_per_group\": 13.219423294067383, \"sigma_intercept_per_group\": 0.01770014315843582, \"sigma_obs\": 0.00358360237441957, \"slope\": 0.18509505689144135, \"chain\": 3, \"draw\": 70}, {\"mouse\": 7, \"draws\": 551, \"mu_intercept_per_group\": 13.162672996520996, \"sigma_intercept_per_group\": 0.017586492002010345, \"sigma_obs\": 0.003584019374102354, \"slope\": 0.1844484955072403, \"chain\": 3, \"draw\": 71}, {\"mouse\": 7, \"draws\": 552, \"mu_intercept_per_group\": 12.658014297485352, \"sigma_intercept_per_group\": 0.018092667683959007, \"sigma_obs\": 0.0036213418934494257, \"slope\": 0.19185452163219452, \"chain\": 3, \"draw\": 72}, {\"mouse\": 7, \"draws\": 553, \"mu_intercept_per_group\": 11.928388595581055, \"sigma_intercept_per_group\": 0.01933879777789116, \"sigma_obs\": 0.003598818788304925, \"slope\": 0.18605118989944458, \"chain\": 3, \"draw\": 73}, {\"mouse\": 7, \"draws\": 554, \"mu_intercept_per_group\": 12.68416976928711, \"sigma_intercept_per_group\": 0.01843596249818802, \"sigma_obs\": 0.00361131620593369, \"slope\": 0.1916276216506958, \"chain\": 3, \"draw\": 74}, {\"mouse\": 7, \"draws\": 555, \"mu_intercept_per_group\": 13.170607566833496, \"sigma_intercept_per_group\": 0.017522525042295456, \"sigma_obs\": 0.003604341996833682, \"slope\": 0.1903112679719925, \"chain\": 3, \"draw\": 75}, {\"mouse\": 7, \"draws\": 556, \"mu_intercept_per_group\": 15.06847095489502, \"sigma_intercept_per_group\": 0.015831978991627693, \"sigma_obs\": 0.003636396024376154, \"slope\": 0.18440118432044983, \"chain\": 3, \"draw\": 76}, {\"mouse\": 7, \"draws\": 557, \"mu_intercept_per_group\": 14.663665771484375, \"sigma_intercept_per_group\": 0.01653214730322361, \"sigma_obs\": 0.0036377697251737118, \"slope\": 0.18585434556007385, \"chain\": 3, \"draw\": 77}, {\"mouse\": 7, \"draws\": 558, \"mu_intercept_per_group\": 14.32145881652832, \"sigma_intercept_per_group\": 0.016408398747444153, \"sigma_obs\": 0.0036101918667554855, \"slope\": 0.18550054728984833, \"chain\": 3, \"draw\": 78}, {\"mouse\": 7, \"draws\": 559, \"mu_intercept_per_group\": 14.355459213256836, \"sigma_intercept_per_group\": 0.016191203147172928, \"sigma_obs\": 0.0036424805875867605, \"slope\": 0.19228872656822205, \"chain\": 3, \"draw\": 79}, {\"mouse\": 7, \"draws\": 560, \"mu_intercept_per_group\": 11.188118934631348, \"sigma_intercept_per_group\": 0.020473456010222435, \"sigma_obs\": 0.003587863175198436, \"slope\": 0.18407145142555237, \"chain\": 3, \"draw\": 80}, {\"mouse\": 7, \"draws\": 561, \"mu_intercept_per_group\": 11.107966423034668, \"sigma_intercept_per_group\": 0.020513340830802917, \"sigma_obs\": 0.003581705968827009, \"slope\": 0.18452733755111694, \"chain\": 3, \"draw\": 81}, {\"mouse\": 7, \"draws\": 562, \"mu_intercept_per_group\": 14.007497787475586, \"sigma_intercept_per_group\": 0.017035434022545815, \"sigma_obs\": 0.003634166903793812, \"slope\": 0.19001875817775726, \"chain\": 3, \"draw\": 82}, {\"mouse\": 7, \"draws\": 563, \"mu_intercept_per_group\": 12.092328071594238, \"sigma_intercept_per_group\": 0.01858886517584324, \"sigma_obs\": 0.003586075734347105, \"slope\": 0.1843891143798828, \"chain\": 3, \"draw\": 83}, {\"mouse\": 7, \"draws\": 564, \"mu_intercept_per_group\": 8.752177238464355, \"sigma_intercept_per_group\": 0.02524333819746971, \"sigma_obs\": 0.0036117122508585453, \"slope\": 0.19187575578689575, \"chain\": 3, \"draw\": 84}, {\"mouse\": 7, \"draws\": 565, \"mu_intercept_per_group\": 9.303275108337402, \"sigma_intercept_per_group\": 0.023980624973773956, \"sigma_obs\": 0.0035916357301175594, \"slope\": 0.19738131761550903, \"chain\": 3, \"draw\": 85}, {\"mouse\": 7, \"draws\": 566, \"mu_intercept_per_group\": 9.167104721069336, \"sigma_intercept_per_group\": 0.024548541754484177, \"sigma_obs\": 0.0035921153612434864, \"slope\": 0.1987427920103073, \"chain\": 3, \"draw\": 86}, {\"mouse\": 7, \"draws\": 567, \"mu_intercept_per_group\": 8.066573143005371, \"sigma_intercept_per_group\": 0.027865925803780556, \"sigma_obs\": 0.003611135296523571, \"slope\": 0.19563473761081696, \"chain\": 3, \"draw\": 87}, {\"mouse\": 7, \"draws\": 568, \"mu_intercept_per_group\": 9.59017276763916, \"sigma_intercept_per_group\": 0.02385457418859005, \"sigma_obs\": 0.003599876072257757, \"slope\": 0.17862160503864288, \"chain\": 3, \"draw\": 88}, {\"mouse\": 7, \"draws\": 569, \"mu_intercept_per_group\": 8.78339958190918, \"sigma_intercept_per_group\": 0.027210166677832603, \"sigma_obs\": 0.003589432220906019, \"slope\": 0.17765319347381592, \"chain\": 3, \"draw\": 89}, {\"mouse\": 7, \"draws\": 570, \"mu_intercept_per_group\": 9.151691436767578, \"sigma_intercept_per_group\": 0.025621000677347183, \"sigma_obs\": 0.0035894683096557856, \"slope\": 0.17756660282611847, \"chain\": 3, \"draw\": 90}, {\"mouse\": 7, \"draws\": 571, \"mu_intercept_per_group\": 8.965655326843262, \"sigma_intercept_per_group\": 0.025941085070371628, \"sigma_obs\": 0.003591621993109584, \"slope\": 0.17775902152061462, \"chain\": 3, \"draw\": 91}, {\"mouse\": 7, \"draws\": 572, \"mu_intercept_per_group\": 8.980620384216309, \"sigma_intercept_per_group\": 0.025299925357103348, \"sigma_obs\": 0.0035912059247493744, \"slope\": 0.19367483258247375, \"chain\": 3, \"draw\": 92}, {\"mouse\": 7, \"draws\": 573, \"mu_intercept_per_group\": 12.573892593383789, \"sigma_intercept_per_group\": 0.018407698720693588, \"sigma_obs\": 0.0035958478692919016, \"slope\": 0.18281510472297668, \"chain\": 3, \"draw\": 93}, {\"mouse\": 7, \"draws\": 574, \"mu_intercept_per_group\": 12.082387924194336, \"sigma_intercept_per_group\": 0.019687768071889877, \"sigma_obs\": 0.003609179751947522, \"slope\": 0.19199497997760773, \"chain\": 3, \"draw\": 94}, {\"mouse\": 7, \"draws\": 575, \"mu_intercept_per_group\": 13.643655776977539, \"sigma_intercept_per_group\": 0.016820739954710007, \"sigma_obs\": 0.00360158272087574, \"slope\": 0.19281287491321564, \"chain\": 3, \"draw\": 95}, {\"mouse\": 7, \"draws\": 576, \"mu_intercept_per_group\": 13.934240341186523, \"sigma_intercept_per_group\": 0.01609567366540432, \"sigma_obs\": 0.003601010888814926, \"slope\": 0.18766789138317108, \"chain\": 3, \"draw\": 96}, {\"mouse\": 7, \"draws\": 577, \"mu_intercept_per_group\": 16.283496856689453, \"sigma_intercept_per_group\": 0.014035603031516075, \"sigma_obs\": 0.0036355014890432358, \"slope\": 0.19160720705986023, \"chain\": 3, \"draw\": 97}, {\"mouse\": 7, \"draws\": 578, \"mu_intercept_per_group\": 18.458879470825195, \"sigma_intercept_per_group\": 0.012920662760734558, \"sigma_obs\": 0.003615922061726451, \"slope\": 0.18153676390647888, \"chain\": 3, \"draw\": 98}, {\"mouse\": 7, \"draws\": 579, \"mu_intercept_per_group\": 16.87954330444336, \"sigma_intercept_per_group\": 0.012891123071312904, \"sigma_obs\": 0.0035836449824273586, \"slope\": 0.19704407453536987, \"chain\": 3, \"draw\": 99}, {\"mouse\": 7, \"draws\": 580, \"mu_intercept_per_group\": 16.068159103393555, \"sigma_intercept_per_group\": 0.01423618383705616, \"sigma_obs\": 0.0035781110636889935, \"slope\": 0.18922735750675201, \"chain\": 3, \"draw\": 100}, {\"mouse\": 7, \"draws\": 581, \"mu_intercept_per_group\": 14.545585632324219, \"sigma_intercept_per_group\": 0.016148671507835388, \"sigma_obs\": 0.0036217477172613144, \"slope\": 0.18959632515907288, \"chain\": 3, \"draw\": 101}, {\"mouse\": 7, \"draws\": 582, \"mu_intercept_per_group\": 13.890661239624023, \"sigma_intercept_per_group\": 0.016965873539447784, \"sigma_obs\": 0.003610593033954501, \"slope\": 0.19542628526687622, \"chain\": 3, \"draw\": 102}, {\"mouse\": 7, \"draws\": 583, \"mu_intercept_per_group\": 14.142515182495117, \"sigma_intercept_per_group\": 0.016098622232675552, \"sigma_obs\": 0.003599792020395398, \"slope\": 0.18751761317253113, \"chain\": 3, \"draw\": 103}, {\"mouse\": 7, \"draws\": 584, \"mu_intercept_per_group\": 12.367781639099121, \"sigma_intercept_per_group\": 0.017515499144792557, \"sigma_obs\": 0.0036076982505619526, \"slope\": 0.19487647712230682, \"chain\": 3, \"draw\": 104}, {\"mouse\": 7, \"draws\": 585, \"mu_intercept_per_group\": 16.947235107421875, \"sigma_intercept_per_group\": 0.014014997519552708, \"sigma_obs\": 0.0035701366141438484, \"slope\": 0.1834084540605545, \"chain\": 3, \"draw\": 105}, {\"mouse\": 7, \"draws\": 586, \"mu_intercept_per_group\": 17.293228149414062, \"sigma_intercept_per_group\": 0.013422057032585144, \"sigma_obs\": 0.003600840922445059, \"slope\": 0.19176925718784332, \"chain\": 3, \"draw\": 106}, {\"mouse\": 7, \"draws\": 587, \"mu_intercept_per_group\": 16.411766052246094, \"sigma_intercept_per_group\": 0.01373498048633337, \"sigma_obs\": 0.003594903275370598, \"slope\": 0.1928805112838745, \"chain\": 3, \"draw\": 107}, {\"mouse\": 7, \"draws\": 588, \"mu_intercept_per_group\": 17.661447525024414, \"sigma_intercept_per_group\": 0.012962810695171356, \"sigma_obs\": 0.0035905141849070787, \"slope\": 0.188307523727417, \"chain\": 3, \"draw\": 108}, {\"mouse\": 7, \"draws\": 589, \"mu_intercept_per_group\": 17.440860748291016, \"sigma_intercept_per_group\": 0.013026981614530087, \"sigma_obs\": 0.0035857269540429115, \"slope\": 0.18800950050354004, \"chain\": 3, \"draw\": 109}, {\"mouse\": 7, \"draws\": 590, \"mu_intercept_per_group\": 16.905393600463867, \"sigma_intercept_per_group\": 0.013479582965373993, \"sigma_obs\": 0.0035793858114629984, \"slope\": 0.18708018958568573, \"chain\": 3, \"draw\": 110}, {\"mouse\": 7, \"draws\": 591, \"mu_intercept_per_group\": 18.042564392089844, \"sigma_intercept_per_group\": 0.012887644581496716, \"sigma_obs\": 0.0035827532410621643, \"slope\": 0.18695157766342163, \"chain\": 3, \"draw\": 111}, {\"mouse\": 7, \"draws\": 592, \"mu_intercept_per_group\": 17.89263153076172, \"sigma_intercept_per_group\": 0.012930555269122124, \"sigma_obs\": 0.0036055417731404305, \"slope\": 0.18494270741939545, \"chain\": 3, \"draw\": 112}, {\"mouse\": 7, \"draws\": 593, \"mu_intercept_per_group\": 18.60683822631836, \"sigma_intercept_per_group\": 0.01221191044896841, \"sigma_obs\": 0.00357837718911469, \"slope\": 0.1912536472082138, \"chain\": 3, \"draw\": 113}, {\"mouse\": 7, \"draws\": 594, \"mu_intercept_per_group\": 18.22900390625, \"sigma_intercept_per_group\": 0.013123339042067528, \"sigma_obs\": 0.0036223470233380795, \"slope\": 0.18431900441646576, \"chain\": 3, \"draw\": 114}, {\"mouse\": 7, \"draws\": 595, \"mu_intercept_per_group\": 18.15667724609375, \"sigma_intercept_per_group\": 0.012793621979653835, \"sigma_obs\": 0.0036040067207068205, \"slope\": 0.18724356591701508, \"chain\": 3, \"draw\": 115}, {\"mouse\": 7, \"draws\": 596, \"mu_intercept_per_group\": 19.945480346679688, \"sigma_intercept_per_group\": 0.012649046257138252, \"sigma_obs\": 0.003613837994635105, \"slope\": 0.18464496731758118, \"chain\": 3, \"draw\": 116}, {\"mouse\": 7, \"draws\": 597, \"mu_intercept_per_group\": 16.9851016998291, \"sigma_intercept_per_group\": 0.012702295556664467, \"sigma_obs\": 0.0035991414915770292, \"slope\": 0.18977291882038116, \"chain\": 3, \"draw\": 117}, {\"mouse\": 7, \"draws\": 598, \"mu_intercept_per_group\": 18.945213317871094, \"sigma_intercept_per_group\": 0.012061669491231441, \"sigma_obs\": 0.0035833921283483505, \"slope\": 0.1871080845594406, \"chain\": 3, \"draw\": 118}, {\"mouse\": 7, \"draws\": 599, \"mu_intercept_per_group\": 19.10544776916504, \"sigma_intercept_per_group\": 0.012324180454015732, \"sigma_obs\": 0.003598170354962349, \"slope\": 0.19471289217472076, \"chain\": 3, \"draw\": 119}, {\"mouse\": 7, \"draws\": 600, \"mu_intercept_per_group\": 18.38855743408203, \"sigma_intercept_per_group\": 0.012552669271826744, \"sigma_obs\": 0.0035964378621429205, \"slope\": 0.19556677341461182, \"chain\": 3, \"draw\": 120}, {\"mouse\": 7, \"draws\": 601, \"mu_intercept_per_group\": 19.600540161132812, \"sigma_intercept_per_group\": 0.011839435435831547, \"sigma_obs\": 0.0035855064634233713, \"slope\": 0.19097794592380524, \"chain\": 3, \"draw\": 121}, {\"mouse\": 7, \"draws\": 602, \"mu_intercept_per_group\": 16.65052604675293, \"sigma_intercept_per_group\": 0.012716580182313919, \"sigma_obs\": 0.003577476367354393, \"slope\": 0.1888200342655182, \"chain\": 3, \"draw\": 122}, {\"mouse\": 7, \"draws\": 603, \"mu_intercept_per_group\": 17.229984283447266, \"sigma_intercept_per_group\": 0.013112235814332962, \"sigma_obs\": 0.0035818922333419323, \"slope\": 0.19023184478282928, \"chain\": 3, \"draw\": 123}, {\"mouse\": 7, \"draws\": 604, \"mu_intercept_per_group\": 17.919578552246094, \"sigma_intercept_per_group\": 0.01250343956053257, \"sigma_obs\": 0.003586977021768689, \"slope\": 0.19242295622825623, \"chain\": 3, \"draw\": 124}, {\"mouse\": 7, \"draws\": 605, \"mu_intercept_per_group\": 18.845430374145508, \"sigma_intercept_per_group\": 0.012796996161341667, \"sigma_obs\": 0.003609312232583761, \"slope\": 0.1781543642282486, \"chain\": 3, \"draw\": 125}, {\"mouse\": 7, \"draws\": 606, \"mu_intercept_per_group\": 17.767263412475586, \"sigma_intercept_per_group\": 0.013115599751472473, \"sigma_obs\": 0.003600113093852997, \"slope\": 0.190125972032547, \"chain\": 3, \"draw\": 126}, {\"mouse\": 7, \"draws\": 607, \"mu_intercept_per_group\": 16.67557716369629, \"sigma_intercept_per_group\": 0.013593625277280807, \"sigma_obs\": 0.003638017689809203, \"slope\": 0.1945844143629074, \"chain\": 3, \"draw\": 127}, {\"mouse\": 7, \"draws\": 608, \"mu_intercept_per_group\": 9.868005752563477, \"sigma_intercept_per_group\": 0.02276713401079178, \"sigma_obs\": 0.0035561569966375828, \"slope\": 0.17862161993980408, \"chain\": 3, \"draw\": 128}, {\"mouse\": 7, \"draws\": 609, \"mu_intercept_per_group\": 9.700410842895508, \"sigma_intercept_per_group\": 0.02301597222685814, \"sigma_obs\": 0.0035663594026118517, \"slope\": 0.17802125215530396, \"chain\": 3, \"draw\": 129}, {\"mouse\": 7, \"draws\": 610, \"mu_intercept_per_group\": 9.360735893249512, \"sigma_intercept_per_group\": 0.023415053263306618, \"sigma_obs\": 0.0035750071983784437, \"slope\": 0.18705984950065613, \"chain\": 3, \"draw\": 130}, {\"mouse\": 7, \"draws\": 611, \"mu_intercept_per_group\": 10.022723197937012, \"sigma_intercept_per_group\": 0.022211479023098946, \"sigma_obs\": 0.0035851849243044853, \"slope\": 0.18809522688388824, \"chain\": 3, \"draw\": 131}, {\"mouse\": 7, \"draws\": 612, \"mu_intercept_per_group\": 9.826160430908203, \"sigma_intercept_per_group\": 0.023446744307875633, \"sigma_obs\": 0.00359828001819551, \"slope\": 0.19333185255527496, \"chain\": 3, \"draw\": 132}, {\"mouse\": 7, \"draws\": 613, \"mu_intercept_per_group\": 9.114191055297852, \"sigma_intercept_per_group\": 0.02479546144604683, \"sigma_obs\": 0.0036140051670372486, \"slope\": 0.19325610995292664, \"chain\": 3, \"draw\": 133}, {\"mouse\": 7, \"draws\": 614, \"mu_intercept_per_group\": 9.566826820373535, \"sigma_intercept_per_group\": 0.024167215451598167, \"sigma_obs\": 0.003616867121309042, \"slope\": 0.1850779801607132, \"chain\": 3, \"draw\": 134}, {\"mouse\": 7, \"draws\": 615, \"mu_intercept_per_group\": 10.331360816955566, \"sigma_intercept_per_group\": 0.022687582299113274, \"sigma_obs\": 0.003627037862315774, \"slope\": 0.1854581981897354, \"chain\": 3, \"draw\": 135}, {\"mouse\": 7, \"draws\": 616, \"mu_intercept_per_group\": 10.619444847106934, \"sigma_intercept_per_group\": 0.021612094715237617, \"sigma_obs\": 0.0036025135777890682, \"slope\": 0.18698853254318237, \"chain\": 3, \"draw\": 136}, {\"mouse\": 7, \"draws\": 617, \"mu_intercept_per_group\": 10.980886459350586, \"sigma_intercept_per_group\": 0.020710553973913193, \"sigma_obs\": 0.0036023263819515705, \"slope\": 0.18757405877113342, \"chain\": 3, \"draw\": 137}, {\"mouse\": 7, \"draws\": 618, \"mu_intercept_per_group\": 15.400731086730957, \"sigma_intercept_per_group\": 0.014685777947306633, \"sigma_obs\": 0.0035792014095932245, \"slope\": 0.18776942789554596, \"chain\": 3, \"draw\": 138}, {\"mouse\": 7, \"draws\": 619, \"mu_intercept_per_group\": 15.731500625610352, \"sigma_intercept_per_group\": 0.014384928159415722, \"sigma_obs\": 0.0035764342173933983, \"slope\": 0.1931193619966507, \"chain\": 3, \"draw\": 139}, {\"mouse\": 7, \"draws\": 620, \"mu_intercept_per_group\": 15.671440124511719, \"sigma_intercept_per_group\": 0.014834119006991386, \"sigma_obs\": 0.003587676677852869, \"slope\": 0.19158856570720673, \"chain\": 3, \"draw\": 140}, {\"mouse\": 7, \"draws\": 621, \"mu_intercept_per_group\": 15.543590545654297, \"sigma_intercept_per_group\": 0.01423179917037487, \"sigma_obs\": 0.0035663628950715065, \"slope\": 0.1873210072517395, \"chain\": 3, \"draw\": 141}, {\"mouse\": 7, \"draws\": 622, \"mu_intercept_per_group\": 15.1685152053833, \"sigma_intercept_per_group\": 0.01503229234367609, \"sigma_obs\": 0.0035645454190671444, \"slope\": 0.18613557517528534, \"chain\": 3, \"draw\": 142}, {\"mouse\": 7, \"draws\": 623, \"mu_intercept_per_group\": 16.88866424560547, \"sigma_intercept_per_group\": 0.0137303052470088, \"sigma_obs\": 0.0036293163429945707, \"slope\": 0.18804918229579926, \"chain\": 3, \"draw\": 143}, {\"mouse\": 7, \"draws\": 624, \"mu_intercept_per_group\": 16.123300552368164, \"sigma_intercept_per_group\": 0.013632688671350479, \"sigma_obs\": 0.003588378196582198, \"slope\": 0.19001144170761108, \"chain\": 3, \"draw\": 144}, {\"mouse\": 7, \"draws\": 625, \"mu_intercept_per_group\": 16.42278480529785, \"sigma_intercept_per_group\": 0.013633456081151962, \"sigma_obs\": 0.0035747140645980835, \"slope\": 0.18872523307800293, \"chain\": 3, \"draw\": 145}, {\"mouse\": 7, \"draws\": 626, \"mu_intercept_per_group\": 15.62364673614502, \"sigma_intercept_per_group\": 0.014775785617530346, \"sigma_obs\": 0.0036006176378577948, \"slope\": 0.19629628956317902, \"chain\": 3, \"draw\": 146}, {\"mouse\": 7, \"draws\": 627, \"mu_intercept_per_group\": 15.247666358947754, \"sigma_intercept_per_group\": 0.014492075890302658, \"sigma_obs\": 0.0035771557595580816, \"slope\": 0.19197137653827667, \"chain\": 3, \"draw\": 147}, {\"mouse\": 7, \"draws\": 628, \"mu_intercept_per_group\": 14.932868003845215, \"sigma_intercept_per_group\": 0.015233796089887619, \"sigma_obs\": 0.0035766337532550097, \"slope\": 0.19295060634613037, \"chain\": 3, \"draw\": 148}, {\"mouse\": 7, \"draws\": 629, \"mu_intercept_per_group\": 8.2759370803833, \"sigma_intercept_per_group\": 0.027129441499710083, \"sigma_obs\": 0.0036090731155127287, \"slope\": 0.18265590071678162, \"chain\": 3, \"draw\": 149}, {\"mouse\": 7, \"draws\": 630, \"mu_intercept_per_group\": 9.66146469116211, \"sigma_intercept_per_group\": 0.024454772472381592, \"sigma_obs\": 0.0036204077769070864, \"slope\": 0.18110139667987823, \"chain\": 3, \"draw\": 150}, {\"mouse\": 7, \"draws\": 631, \"mu_intercept_per_group\": 7.956097602844238, \"sigma_intercept_per_group\": 0.027230948209762573, \"sigma_obs\": 0.0035805345978587866, \"slope\": 0.19369569420814514, \"chain\": 3, \"draw\": 151}, {\"mouse\": 7, \"draws\": 632, \"mu_intercept_per_group\": 10.982549667358398, \"sigma_intercept_per_group\": 0.02208734303712845, \"sigma_obs\": 0.0036136433482170105, \"slope\": 0.1828446388244629, \"chain\": 3, \"draw\": 152}, {\"mouse\": 7, \"draws\": 633, \"mu_intercept_per_group\": 10.347886085510254, \"sigma_intercept_per_group\": 0.022605691105127335, \"sigma_obs\": 0.003604884957894683, \"slope\": 0.18460769951343536, \"chain\": 3, \"draw\": 153}, {\"mouse\": 7, \"draws\": 634, \"mu_intercept_per_group\": 12.057632446289062, \"sigma_intercept_per_group\": 0.019191408529877663, \"sigma_obs\": 0.0036150480154901743, \"slope\": 0.19020111858844757, \"chain\": 3, \"draw\": 154}, {\"mouse\": 7, \"draws\": 635, \"mu_intercept_per_group\": 12.04118537902832, \"sigma_intercept_per_group\": 0.019791683182120323, \"sigma_obs\": 0.0036232885904610157, \"slope\": 0.18061307072639465, \"chain\": 3, \"draw\": 155}, {\"mouse\": 7, \"draws\": 636, \"mu_intercept_per_group\": 12.49259090423584, \"sigma_intercept_per_group\": 0.01943766325712204, \"sigma_obs\": 0.003612776752561331, \"slope\": 0.18002110719680786, \"chain\": 3, \"draw\": 156}, {\"mouse\": 7, \"draws\": 637, \"mu_intercept_per_group\": 10.704244613647461, \"sigma_intercept_per_group\": 0.02232523262500763, \"sigma_obs\": 0.0036230431869626045, \"slope\": 0.174944669008255, \"chain\": 3, \"draw\": 157}, {\"mouse\": 7, \"draws\": 638, \"mu_intercept_per_group\": 9.934815406799316, \"sigma_intercept_per_group\": 0.02396565116941929, \"sigma_obs\": 0.003616411704570055, \"slope\": 0.18353979289531708, \"chain\": 3, \"draw\": 158}, {\"mouse\": 7, \"draws\": 639, \"mu_intercept_per_group\": 9.355141639709473, \"sigma_intercept_per_group\": 0.025246160104870796, \"sigma_obs\": 0.00362180988304317, \"slope\": 0.18443134427070618, \"chain\": 3, \"draw\": 159}], \"data-063f70b53db191562db0db28221b259e\": [{\"index\": \"C(stim, Treatment)[T.1]\", \"center interval\": 0.14, \"Std.Err.\": 0.002, \"z\": 64.581, \"p\": 0.0, \"higher interval\": 0.135, \"lower interval\": 0.144, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 27,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# NBVAL_SKIP\n",
    "(chart_power_difference_monster | chart_power_difference_monster_lme)\n"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "hide_code_all_hidden": true,
  "hide_input": false,
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 1
}
